@@ -15,71 +15,66 @@ m.Template = m.Class({
 	// TODO: there's no support for "_string" values here.
 	get: function(string)
 	{
-		var value = this._template;
-		if (this._auraTemplateModif && this._auraTemplateModif.has(string))
-			return this._auraTemplateModif.get(string);
-		else if (this._techModif && this._techModif.has(string))
-			return this._techModif.get(string);
-		else
+		let value = this._template;
+		if (this._entityModif && this._entityModif.has(string))
+			return this._entityModif.get(string);
+		else if (this._templateModif && this._templateModif.has(string))
+			return this._templateModif.get(string);
+
+		if (!this._tpCache.has(string))
 		{
-			if (!this._tpCache.has(string))
+			let args = string.split("/");
+			for (let arg of args)
 			{
-				var args = string.split("/");
-				for (let arg of args)
+				if (value[arg])
+					value = value[arg];
+				else
 				{
-					if (value[arg])
-						value = value[arg];
-					else
-					{
-						value = undefined;
-						break;
-					}
+					value = undefined;
+					break;
 				}
-				this._tpCache.set(string, value);
 			}
-			return this._tpCache.get(string);
+			this._tpCache.set(string, value);
 		}
- 
+		return this._tpCache.get(string);
 	},
 
 	genericName: function() {
-		if (!this.get("Identity") || !this.get("Identity/GenericName"))
-			return undefined;
 		return this.get("Identity/GenericName");
 	},
 
 	rank: function() {
-		if (!this.get("Identity"))
-			return undefined;
 		return this.get("Identity/Rank");
 	},
 
 	classes: function() {
-		var template = this.get("Identity");
+		let template = this.get("Identity");
 		if (!template)
 			return undefined;
 		return GetIdentityClasses(template);
 	},
-	
+
 	requiredTech: function() {
 		return this.get("Identity/RequiredTechnology");
 	},
 
 	available: function(gameState) {
-		if (this.requiredTech() === undefined)
+		let techRequired = this.requiredTech();
+		if (!techRequired)
 			return true;
-		return gameState.isResearched(this.get("Identity/RequiredTechnology"));
+		return gameState.isResearched(techRequired);
 	},
 
 	// specifically
 	phase: function() {
-		if (!this.get("Identity/RequiredTechnology"))
+		let techRequired = this.requiredTech();
+		if (!techRequired)
 			return 0;
-		if (this.get("Identity/RequiredTechnology") == "phase_village")
+		if (techRequired === "phase_village")
 			return 1;
-		if (this.get("Identity/RequiredTechnology") == "phase_town")
+		if (techRequired === "phase_town")
 			return 2;
-		if (this.get("Identity/RequiredTechnology") == "phase_city")
+		if (techRequired === "phase_city")
 			return 3;
 		return 0;
 	},
@@ -87,8 +82,8 @@ m.Template = m.Class({
 	hasClass: function(name) {
 		if (!this._classes)
 			this._classes = this.classes();
-		var classes = this._classes;
-		return (classes && classes.indexOf(name) != -1);
+		let classes = this._classes;
+		return classes && classes.indexOf(name) !== -1;
 	},
 
 	hasClasses: function(array) {
@@ -108,26 +103,30 @@ m.Template = m.Class({
 		return this.get("Identity/Civ");
 	},
 
-	cost: function() {
+	"cost": function(productionQueue) {
 		if (!this.get("Cost"))
 			return undefined;
 
-		var ret = {};
-		for (var type in this.get("Cost/Resources"))
+		let ret = {};
+		for (let type in this.get("Cost/Resources"))
 			ret[type] = +this.get("Cost/Resources/" + type);
 		return ret;
 	},
 
-	costSum: function() {
-		if (!this.get("Cost"))
+	"costSum": function(productionQueue) {
+		let cost = this.cost(productionQueue);
+		if (!cost)
 			return undefined;
-
-		var ret = 0;
-		for (var type in this.get("Cost/Resources"))
-			ret += +this.get("Cost/Resources/" + type);
+		let ret = 0;
+		for (let type in cost)
+			ret += cost[type];
 		return ret;
 	},
 
+	"techCostMultiplier": function(type) {
+		return +(this.get("ProductionQueue/TechCostMultiplier/"+type) || 1);
+	},
+
 	/**
 	 * Returns the radius of a circle surrounding this entity's
 	 * obstruction shape, or undefined if no obstruction.
@@ -138,8 +137,8 @@ m.Template = m.Class({
 
 		if (this.get("Obstruction/Static"))
 		{
-			var w = +this.get("Obstruction/Static/@width");
-			var h = +this.get("Obstruction/Static/@depth");
+			let w = +this.get("Obstruction/Static/@width");
+			let h = +this.get("Obstruction/Static/@depth");
 			return Math.sqrt(w*w + h*h) / 2;
 		}
 
@@ -159,8 +158,8 @@ m.Template = m.Class({
 
 		if (this.get("Footprint/Square"))
 		{
-			var w = +this.get("Footprint/Square/@width");
-			var h = +this.get("Footprint/Square/@depth");
+			let w = +this.get("Footprint/Square/@width");
+			let h = +this.get("Footprint/Square/@depth");
 			return Math.sqrt(w*w + h*h) / 2;
 		}
 
@@ -172,9 +171,7 @@ m.Template = m.Class({
 
 	maxHitpoints: function()
 	{
-		if (this.get("Health") !== undefined)
-			return +this.get("Health/Max");
-		return 0;
+		return +(this.get("Health/Max") || 0);
 	},
 
 	isHealable: function()
@@ -208,8 +205,8 @@ m.Template = m.Class({
 		if (!this.get("Attack"))
 			return undefined;
 
-		var ret = [];
-		for (var type in this.get("Attack"))
+		let ret = [];
+		for (let type in this.get("Attack"))
 			ret.push(type);
 
 		return ret;
@@ -220,8 +217,8 @@ m.Template = m.Class({
 			return undefined;
 
 		return {
-				max: +this.get("Attack/" + type +"/MaxRange"),
-				min: +(this.get("Attack/" + type +"/MinRange") || 0)
+			max: +this.get("Attack/" + type +"/MaxRange"),
+			min: +(this.get("Attack/" + type +"/MinRange") || 0)
 		};
 	},
 
@@ -259,14 +256,18 @@ m.Template = m.Class({
 		if (!this.get("Attack"))
 			return undefined;
 
-		var Classes = [];
-		for (var i in this.get("Attack"))
+		let Classes = [];
+		for (let type in this.get("Attack"))
 		{
-			if (!this.get("Attack/" + i + "/Bonuses"))
+			let bonuses = this.get("Attack/" + type + "/Bonuses");
+			if (!bonuses)
 				continue;
-			for (var o in this.get("Attack/" + i + "/Bonuses"))
-				if (this.get("Attack/" + i + "/Bonuses/" + o + "/Classes"))
-					Classes.push([this.get("Attack/" + i +"/Bonuses/" + o +"/Classes").split(" "), +this.get("Attack/" + i +"/Bonuses" +o +"/Multiplier")]);
+			for (let b in bonuses)
+			{
+				let bonusClasses = this.get("Attack/" + type + "/Bonuses/" + b + "/Classes");
+				if (bonusClasses)
+					Classes.push([bonusClasses.split(" "), +this.get("Attack/" + type +"/Bonuses" + b +"/Multiplier")]);
+			}
 		}
 		return Classes;
 	},
@@ -276,14 +277,18 @@ m.Template = m.Class({
 	countersClasses: function(classes) {
 		if (!this.get("Attack"))
 			return false;
-		var mcounter = [];
-		for (let i in this.get("Attack"))
+		let mcounter = [];
+		for (let type in this.get("Attack"))
 		{
-			if (!this.get("Attack/" + i + "/Bonuses"))
+			let bonuses = this.get("Attack/" + type + "/Bonuses");
+			if (!bonuses)
 				continue;
-			for (let o in this.get("Attack/" + i + "/Bonuses"))
-				if (this.get("Attack/" + i + "/Bonuses/" + o + "/Classes"))
-					mcounter.concat(this.get("Attack/" + i + "/Bonuses/" + o + "/Classes").split(" "));
+			for (let b in bonuses)
+			{
+				let bonusClasses = this.get("Attack/" + type + "/Bonuses/" + b + "/Classes");
+				if (bonusClasses)
+					mcounter.concat(bonusClasses.split(" "));
+			}
 		}
 		for (let i in classes)
 		{
@@ -299,15 +304,17 @@ m.Template = m.Class({
 			return undefined;
 
 		if (this.get("Attack/" + type + "/Bonuses"))
-			for (var o in this.get("Attack/" + type + "/Bonuses"))
+		{
+			for (let b in this.get("Attack/" + type + "/Bonuses"))
 			{
-				if (!this.get("Attack/" + type + "/Bonuses/" + o + "/Classes"))
+				let bonusClasses = this.get("Attack/" + type + "/Bonuses/" + b + "/Classes");
+				if (!bonusClasses)
 					continue;
-				var total = this.get("Attack/" + type + "/Bonuses/" + o + "/Classes").split(" ");
-				for (var j in total)
-					if (total[j] === againstClass)
-						return +this.get("Attack/" + type + "/Bonuses/" + o + "/Multiplier");
+				for (let bcl of bonusesClasses.split(" "))
+					if (bcl === againstClass)
+						return +this.get("Attack/" + type + "/Bonuses/" + b + "/Multiplier");
 			}
+		}
 		return 1;
 	},
 
@@ -316,75 +323,72 @@ m.Template = m.Class({
 		if (!this.get("Attack"))
 			return false;
 
-		for (var i in this.get("Attack")) {
-			if (!this.get("Attack/" + i + "/RestrictedClasses") || !this.get("Attack/" + i + "/RestrictedClasses/_string"))
-				continue;
-			var cannotAttack = this.get("Attack/" + i + "/RestrictedClasses/_string").split(" ");
-			if (cannotAttack.indexOf(saidClass) !== -1)
+		for (let type in this.get("Attack"))
+		{
+			let restrictedClasses = this.get("Attack/" + type + "/RestrictedClasses/_string");
+			if (restrictedClasses && !MatchesClassList([saidClass], restrictedClasses))
 				return false;
 		}
+
 		return true;
 	},
 
-	buildableEntities: function() {
-		if (!this.get("Builder/Entities/_string"))
+	"buildableEntities": function() {
+		let templates = this.get("Builder/Entities/_string");
+		if (!templates)
 			return [];
-		var civ = this.civ();
-		var templates = this.get("Builder/Entities/_string").replace(/\{civ\}/g, civ).split(/\s+/);
-		return templates; // TODO: map to Entity?
+		let civ = this.civ();
+		return templates.replace(/\{civ\}/g, civ).split(/\s+/);
 	},
 
-	trainableEntities: function(civ) {
-		if (!this.get("ProductionQueue/Entities/_string"))
+	"trainableEntities": function(civ) {
+		let templates = this.get("ProductionQueue/Entities/_string");
+		if (!templates)
 			return undefined;
-		var templates = this.get("ProductionQueue/Entities/_string").replace(/\{civ\}/g, civ).split(/\s+/);
-		return templates;
+		if (civ)
+			templates = templates.replace(/\{civ\}/g, civ);
+		return templates.split(/\s+/);
 	},
 
-	researchableTechs: function(civ) {
-		if (this.civ() !== civ)     // techs can only be researched in structure from the player civ
+	"researchableTechs": function(civ) {
+		if (this.civ() !== civ)     // techs can only be researched in structures from the player civ TODO no more true
 			return undefined;
-		if (!this.get("ProductionQueue/Technologies/_string"))
+		let templates = this.get("ProductionQueue/Technologies/_string");
+		if (!templates)
 			return undefined;
-		var templates = this.get("ProductionQueue/Technologies/_string").split(/\s+/);
-		return templates;
+		return templates.split(/\s+/);
 	},
 
 	resourceSupplyType: function() {
 		if (!this.get("ResourceSupply"))
 			return undefined;
-		var [type, subtype] = this.get("ResourceSupply/Type").split('.');
+		let [type, subtype] = this.get("ResourceSupply/Type").split('.');
 		return { "generic": type, "specific": subtype };
 	},
 	// will return either "food", "wood", "stone", "metal" and not treasure.
 	getResourceType: function() {
 		if (!this.get("ResourceSupply"))
 			return undefined;
-		var [type, subtype] = this.get("ResourceSupply/Type").split('.');
+		let [type, subtype] = this.get("ResourceSupply/Type").split('.');
 		if (type == "treasure")
 			return subtype;
 		return type;
 	},
 
 	resourceSupplyMax: function() {
-		if (!this.get("ResourceSupply"))
-			return undefined;
 		return +this.get("ResourceSupply/Amount");
 	},
 
-	maxGatherers: function()
-	{
-		if (this.get("ResourceSupply") !== undefined)
-			return +this.get("ResourceSupply/MaxGatherers");
-		return 0;
+	maxGatherers: function() {
+		return +(this.get("ResourceSupply/MaxGatherers") || 0);
 	},
-	
+
 	resourceGatherRates: function() {
 		if (!this.get("ResourceGatherer"))
 			return undefined;
-		var ret = {};
-		var baseSpeed = +this.get("ResourceGatherer/BaseSpeed");
-		for (var r in this.get("ResourceGatherer/Rates"))
+		let ret = {};
+		let baseSpeed = +this.get("ResourceGatherer/BaseSpeed");
+		for (let r in this.get("ResourceGatherer/Rates"))
 			ret[r] = +this.get("ResourceGatherer/Rates/" + r) * baseSpeed;
 		return ret;
 	},
@@ -399,32 +403,22 @@ m.Template = m.Class({
 
 
 	garrisonableClasses: function() {
-		if (!this.get("GarrisonHolder"))
-			return undefined;
 		return this.get("GarrisonHolder/List/_string");
 	},
 
 	garrisonMax: function() {
-		if (!this.get("GarrisonHolder"))
-			return undefined;
 		return this.get("GarrisonHolder/Max");
 	},
 
 	garrisonEjectHealth: function() {
-		if (!this.get("GarrisonHolder"))
-			return undefined;
 		return +this.get("GarrisonHolder/EjectHealth");
 	},
 
 	getDefaultArrow: function() {
-		if (!this.get("BuildingAI"))
-			return undefined;
 		return +this.get("BuildingAI/DefaultArrowCount");
 	},
 
 	getArrowMultiplier: function() {
-		if (!this.get("BuildingAI"))
-			return undefined;
 		return +this.get("BuildingAI/GarrisonArrowMultiplier");
 	},
 
@@ -435,14 +429,10 @@ m.Template = m.Class({
 	},
 
 	buffHeal: function() {
-		if (!this.get("GarrisonHolder"))
-			return undefined;
 		return +this.get("GarrisonHolder/BuffHeal");
 	},
 
 	promotion: function() {
-		if (!this.get("Promotion"))
-			return undefined;
 		return this.get("Promotion/Entity");
 	},
 
@@ -450,61 +440,45 @@ m.Template = m.Class({
 	 * Returns whether this is an animal that is too difficult to hunt.
 	 * (Any non domestic currently.)
 	 */
-	isUnhuntable: function() {   // used by Aegis
-		if (!this.get("UnitAI") || !this.get("UnitAI/NaturalBehaviour"))
-			return false;
-
-		// only attack domestic animals since they won't flee nor retaliate.
-		return this.get("UnitAI/NaturalBehaviour") !== "domestic";
-	},
-
-	isHuntable: function() {     // used by Petra
-		if(!this.get("ResourceSupply") || !this.get("ResourceSupply/KillBeforeGather"))
+	isHuntable: function() {
+		if(!this.get("ResourceSupply/KillBeforeGather"))
 			return false;
 
 		// special case: rabbits too difficult to hunt for such a small food amount
-		if (this.get("Identity") && this.get("Identity/SpecificName") && this.get("Identity/SpecificName") === "Rabbit")
+		let specificName = this.get("Identity/SpecificName");
+		if (specificName && specificName === "Rabbit")
 			return false;
 
 		// do not hunt retaliating animals (animals without UnitAI are dead animals)
-		return !this.get("UnitAI") || !(this.get("UnitAI/NaturalBehaviour") === "violent" ||
-			this.get("UnitAI/NaturalBehaviour") === "aggressive" ||
-			this.get("UnitAI/NaturalBehaviour") === "defensive");
+		let behaviour = this.get("UnitAI/NaturalBehaviour");
+		return !this.get("UnitAI") ||
+		       !(behaviour === "violent" || behaviour === "aggressive" || behaviour === "defensive");
 	},
 
 	walkSpeed: function() {
-		if (!this.get("UnitMotion") || !this.get("UnitMotion/WalkSpeed"))
-			 return undefined;
 		return +this.get("UnitMotion/WalkSpeed");
 	},
 
 	trainingCategory: function() {
-		if (!this.get("TrainingRestrictions") || !this.get("TrainingRestrictions/Category"))
-			return undefined;
 		return this.get("TrainingRestrictions/Category");
 	},
 
 	buildCategory: function() {
-		if (!this.get("BuildRestrictions") || !this.get("BuildRestrictions/Category"))
-			return undefined;
 		return this.get("BuildRestrictions/Category");
 	},
-	
-	buildTime: function() {
-		if (!this.get("Cost") || !this.get("Cost/BuildTime"))
-			return undefined;
-		return +this.get("Cost/BuildTime");
+
+	"buildTime": function(productionQueue) {
+		let time = +this.get("Cost/BuildTime");
+		if (productionQueue)
+			time *= productionQueue.techCostMultiplier("time");
+		return time;
 	},
 
 	buildDistance: function() {
-		if (!this.get("BuildRestrictions") || !this.get("BuildRestrictions/Distance"))
-			return undefined;
 		return this.get("BuildRestrictions/Distance");
 	},
 
 	buildPlacementType: function() {
-		if (!this.get("BuildRestrictions") || !this.get("BuildRestrictions/PlacementType"))
-			return undefined;
 		return this.get("BuildRestrictions/PlacementType");
 	},
 
@@ -515,48 +489,50 @@ m.Template = m.Class({
 	},
 
 	hasBuildTerritory: function(territory) {
-		var territories = this.buildTerritories();
-		return (territories && territories.indexOf(territory) != -1);
+		let territories = this.buildTerritories();
+		return territories && territories.indexOf(territory) !== -1;
 	},
 
 	hasTerritoryInfluence: function() {
-		return (this.get("TerritoryInfluence") !== undefined);
+		return this.get("TerritoryInfluence") !== undefined;
 	},
 
 	hasDefensiveFire: function() {
-		if (!this.get("Attack") || !this.get("Attack/Ranged"))
+		if (!this.get("Attack/Ranged"))
 			return false;
-		return (this.getDefaultArrow() || this.getArrowMultiplier());
+		return this.getDefaultArrow() || this.getArrowMultiplier();
 	},
 
 	territoryInfluenceRadius: function() {
 		if (this.get("TerritoryInfluence") !== undefined)
 			return +this.get("TerritoryInfluence/Radius");
-		else
-			return -1;
+		return -1;
 	},
 
 	territoryInfluenceWeight: function() {
 		if (this.get("TerritoryInfluence") !== undefined)
 			return +this.get("TerritoryInfluence/Weight");
-		else
-			return -1;
+		return -1;
 	},
 
 	territoryDecayRate: function() {
-		return (this.get("TerritoryDecay") ? +this.get("TerritoryDecay/DecayRate") : 0);
+		return +(this.get("TerritoryDecay/DecayRate") || 0);
 	},
 
 	defaultRegenRate: function() {
-		return (this.get("Capturable") ? +this.get("Capturable/RegenRate") : 0);
+		return +(this.get("Capturable/RegenRate") || 0);
 	},
 
 	garrisonRegenRate: function() {
-		return (this.get("Capturable") ? +this.get("Capturable/GarrisonRegenRate") : 0);
+		return +(this.get("Capturable/GarrisonRegenRate") || 0);
 	},
 
 	visionRange: function() {
 		return +this.get("Vision/Range");
+	},
+
+	gainMultiplier: function() {
+		return +this.get("Trader/GainMultiplier");
 	}
 });
 
@@ -572,11 +548,16 @@ m.Entity = m.Class({
 
 		this._templateName = entity.template;
 		this._entity = entity;
-		this._auraTemplateModif = new Map();	// template modification from auras. this is only for this entity.
+
 		this._ai = sharedAI;
-		if (!sharedAI._techModifications[entity.owner][this._templateName])
-			sharedAI._techModifications[entity.owner][this._templateName] = new Map();
-		this._techModif = sharedAI._techModifications[entity.owner][this._templateName]; // save a reference to the template tech modifications
+		// save a reference to the template tech modifications
+		if (!sharedAI._templatesModifications[entity.owner][this._templateName])
+			sharedAI._templatesModifications[entity.owner][this._templateName] = new Map();
+		this._templateModif = sharedAI._templatesModifications[entity.owner][this._templateName];
+		// save a reference to the entity tech/aura modifications
+		if (!sharedAI._entitiesModifications.has(entity.id))
+			sharedAI._entitiesModifications.set(entity.id, new Map());
+		this._entityModif = sharedAI._entitiesModifications.get(entity.id);
 	},
 
 	toString: function() {
@@ -616,6 +597,7 @@ m.Entity = m.Class({
 	},
 
 	position: function() { return this._entity.position; },
+	angle: function() { return this._entity.angle; },
 
 	isIdle: function() {
 		if (typeof this._entity.idle === "undefined")
@@ -623,32 +605,34 @@ m.Entity = m.Class({
 		return this._entity.idle;
 	},
 
-	unitAIState: function() { return ((this._entity.unitAIState !== undefined) ? this._entity.unitAIState : undefined); },
-	unitAIOrderData: function() { return ((this._entity.unitAIOrderData !== undefined) ? this._entity.unitAIOrderData : undefined); },
+	unitAIState: function() { return this._entity.unitAIState !== undefined ? this._entity.unitAIState : undefined; },
+	unitAIOrderData: function() { return this._entity.unitAIOrderData !== undefined ? this._entity.unitAIOrderData : undefined; },
 
-	hitpoints: function() { return ((this._entity.hitpoints !== undefined) ? this._entity.hitpoints : undefined); },
-	isHurt: function() { return (this.hitpoints() < this.maxHitpoints()); },
-	healthLevel: function() { return (this.hitpoints() / this.maxHitpoints()); },
+	hitpoints: function() { return this._entity.hitpoints !== undefined ? this._entity.hitpoints : undefined; },
+	isHurt: function() { return this.hitpoints() < this.maxHitpoints(); },
+	healthLevel: function() { return this.hitpoints() / this.maxHitpoints(); },
 	needsHeal: function() { return this.isHurt() && this.isHealable(); },
 	needsRepair: function() { return this.isHurt() && this.isRepairable(); },
-	decaying: function() { return ((this._entity.decaying !== undefined) ? this._entity.decaying : undefined); },
-	capturePoints: function() {return ((this._entity.capturePoints !== undefined) ? this._entity.capturePoints : undefined); },
+	decaying: function() { return this._entity.decaying !== undefined ? this._entity.decaying : undefined; },
+	capturePoints: function() {return this._entity.capturePoints !== undefined ? this._entity.capturePoints : undefined; },
+
+	"isSharedDropsite": function() { return this._entity.sharedDropsite === true; },
 
 	/**
 	 * Returns the current training queue state, of the form
 	 * [ { "id": 0, "template": "...", "count": 1, "progress": 0.5, "metadata": ... }, ... ]
 	 */
 	trainingQueue: function() {
-		var queue = this._entity.trainingQueue;
+		let queue = this._entity.trainingQueue;
 		return queue;
 	},
 
 	trainingQueueTime: function() {
-		var queue = this._entity.trainingQueue;
+		let queue = this._entity.trainingQueue;
 		if (!queue)
 			return undefined;
-		var time = 0;
-		for (var item of queue)
+		let time = 0;
+		for (let item of queue)
 			time += item.timeRemaining;
 		return time/1000;
 	},
@@ -680,13 +664,13 @@ m.Entity = m.Class({
 	},
 
 	isOwn: function(player) {
-		if (typeof(this._entity.owner) === "undefined")
+		if (typeof this._entity.owner === "undefined")
 			return false;
 		return this._entity.owner === player;
 	},
 
 	resourceSupplyAmount: function() {
-		if(this._entity.resourceSupplyAmount === undefined)
+		if (this._entity.resourceSupplyAmount === undefined)
 			return undefined;
 		return this._entity.resourceSupplyAmount;
 	},
@@ -701,15 +685,15 @@ m.Entity = m.Class({
 	isFull: function()
 	{
 		if (this._entity.resourceSupplyNumGatherers !== undefined)
-			return (this.maxGatherers() === this._entity.resourceSupplyNumGatherers);
+			return this.maxGatherers() === this._entity.resourceSupplyNumGatherers;
 
 		return undefined;
 	},
 
 	resourceCarrying: function() {
-		if(this._entity.resourceCarrying === undefined)
+		if (this._entity.resourceCarrying === undefined)
 			return undefined;
-		return this._entity.resourceCarrying; 
+		return this._entity.resourceCarrying;
 	},
 
 	currentGatherRate: function() {
@@ -748,9 +732,10 @@ m.Entity = m.Class({
 	isBuilder: function() { return this.get("Builder") !== undefined; },
 	isGatherer: function() { return this.get("ResourceGatherer") !== undefined; },
 	canGather: function(type) {
-		if (!this.get("ResourceGatherer") || !this.get("ResourceGatherer/Rates"))
+		let gatherRates = this.get("ResourceGatherer/Rates");
+		if (!gatherRates)
 			return false;
-		for (let r in this.get("ResourceGatherer/Rates"))
+		for (let r in gatherRates)
 			if (r.split('.')[0] === type)
 				return true;
 		return false;
@@ -813,8 +798,8 @@ m.Entity = m.Class({
 	// moveApart from a point in the opposite direction with a distance dist
 	moveApart: function(point, dist) {
 		if (this.position() !== undefined) {
-			var direction = [this.position()[0] - point[0], this.position()[1] - point[1]];
-			var norm = m.VectorDistance(point, this.position());
+			let direction = [this.position()[0] - point[0], this.position()[1] - point[1]];
+			let norm = m.VectorDistance(point, this.position());
 			if (norm === 0)
 				direction = [1, 0];
 			else
@@ -830,12 +815,13 @@ m.Entity = m.Class({
 	// Flees from a unit in the opposite direction.
 	flee: function(unitToFleeFrom) {
 		if (this.position() !== undefined && unitToFleeFrom.position() !== undefined) {
-			var FleeDirection = [this.position()[0] - unitToFleeFrom.position()[0],this.position()[1] - unitToFleeFrom.position()[1]];
-			var dist = m.VectorDistance(unitToFleeFrom.position(), this.position() );
-			FleeDirection[0] = (FleeDirection[0]/dist) * 8;
-			FleeDirection[1] = (FleeDirection[1]/dist) * 8;
+			let FleeDirection = [this.position()[0] - unitToFleeFrom.position()[0],
+			                     this.position()[1] - unitToFleeFrom.position()[1]];
+			let dist = m.VectorDistance(unitToFleeFrom.position(), this.position() );
+			FleeDirection[0] = 40 * FleeDirection[0]/dist;
+			FleeDirection[1] = 40 * FleeDirection[1]/dist;
 
-			Engine.PostCommand(PlayerID,{"type": "walk", "entities": [this.id()], "x": this.position()[0] + FleeDirection[0]*5, "z": this.position()[1] + FleeDirection[1]*5, "queued": false});
+			Engine.PostCommand(PlayerID,{"type": "walk", "entities": [this.id()], "x": this.position()[0] + FleeDirection[0], "z": this.position()[1] + FleeDirection[1], "queued": false});
 		}
 		return this;
 	},
@@ -871,7 +857,7 @@ m.Entity = m.Class({
 	},
 
 	setRallyPoint: function(target, command) {
-		var data = {"command": command, "target": target.id()};
+		let data = {"command": command, "target": target.id()};
 		Engine.PostCommand(PlayerID, {"type": "set-rallypoint", "entities": [this.id()], "x": target.position()[0], "z": target.position()[1], "data": data});
 		return this;
 	},
@@ -883,7 +869,7 @@ m.Entity = m.Class({
 
 	train: function(civ, type, count, metadata, promotedTypes)
 	{
-		var trainable = this.trainableEntities(civ);
+		let trainable = this.trainableEntities(civ);
 		if (!trainable)
 		{
 			error("Called train("+type+", "+count+") on non-training entity "+this);
@@ -925,7 +911,7 @@ m.Entity = m.Class({
 		return this;
 	},
 
-	 research: function(template) {
+	research: function(template) {
 		Engine.PostCommand(PlayerID,{ "type": "research", "entity": this.id(), "template": template });
 		return this;
 	},
@@ -936,10 +922,10 @@ m.Entity = m.Class({
 	},
 
 	stopAllProduction: function(percentToStopAt) {
-		var queue = this._entity.trainingQueue;
+		let queue = this._entity.trainingQueue;
 		if (!queue)
 			return true;	// no queue, so technically we stopped all production.
-		for (var item of queue)
+		for (let item of queue)
 			if (item.progress < percentToStopAt)
 				Engine.PostCommand(PlayerID,{ "type": "stop-production", "entity": this.id(), "id": item.id });
 		return this;
