@@ -7,10 +7,10 @@ m.EntityCollection = function(sharedAI, entities = new Map(), filters = [])
 	this._entities = entities;
 	this._filters = filters;
 	this.dynamicProp = [];
-	for (var filter of this._filters)
+	for (let filter of this._filters)
 		if (filter.dynamicProperties.length)
 			this.dynamicProp = this.dynamicProp.concat(filter.dynamicProperties);
-	
+
 	Object.defineProperty(this, "length", {
 		get: function () {
 			return this._entities.size;
@@ -21,8 +21,8 @@ m.EntityCollection = function(sharedAI, entities = new Map(), filters = [])
 
 m.EntityCollection.prototype.Serialize = function()
 {
-	var filters = [];
-	for (var f of this._filters)
+	let filters = [];
+	for (let f of this._filters)
 		filters.push(uneval(f));
 	return {
 		"ents": this.toIdArray(),
@@ -46,14 +46,17 @@ m.EntityCollection.prototype.Deserialize = function(data, sharedAI)
 		this.defreeze();
 };
 
-// If an entitycollection is frozen, it will never automatically add a unit.
-// But can remove one.
-// this makes it easy to create entity collection that will auto-remove dead units
-// but never add new ones.
+/**
+ * If an entitycollection is frozen, it will never automatically add a unit.
+ * But can remove one.
+ * this makes it easy to create entity collection that will auto-remove dead units
+ * but never add new ones.
+ */
 m.EntityCollection.prototype.freeze = function()
 {
 	this.frozen = true;
 };
+
 m.EntityCollection.prototype.defreeze = function()
 {
 	this.frozen = false;
@@ -83,12 +86,12 @@ m.EntityCollection.prototype.filter = function(filter, thisp)
 {
 	if (typeof filter === "function")
 		filter = {"func": filter, "dynamicProperties": []};
-	
-	var ret = new Map();
+
+	let ret = new Map();
 	for (let [id, ent] of this._entities)
 		if (filter.func.call(thisp, ent, id, this))
 			ret.set(id, ent);
-	
+
 	return new m.EntityCollection(this._ai, ret, this._filters.concat([filter]));
 };
 
@@ -98,7 +101,7 @@ m.EntityCollection.prototype.filter = function(filter, thisp)
 m.EntityCollection.prototype.filterNearest = function(targetPos, n)
 {
 	// Compute the distance of each entity
-	var data = []; // [ [id, ent, distance], ... ]
+	let data = []; // [ [id, ent, distance], ... ]
 	for (let [id, ent] of this._entities)
 		if (ent.position())
 			data.push([id, ent, m.SquareVectorDistance(targetPos, ent.position())]);
@@ -121,7 +124,7 @@ m.EntityCollection.prototype.filterNearest = function(targetPos, n)
 
 m.EntityCollection.prototype.filter_raw = function(callback, thisp)
 {
-	var ret = new Map();
+	let ret = new Map();
 	for (let [id, ent] of this._entities)
 	{
 		let val = ent._entity;
@@ -138,6 +141,11 @@ m.EntityCollection.prototype.forEach = function(callback)
 	return this;
 };
 
+m.EntityCollection.prototype.hasEntities = function()
+{
+	return this._entities.size !== 0;
+};
+
 m.EntityCollection.prototype.move = function(x, z, queued)
 {
 	queued = queued || false;
@@ -172,25 +180,24 @@ m.EntityCollection.prototype.destroy = function()
 	return this;
 };
 
-m.EntityCollection.prototype.attack = function(unit)
+m.EntityCollection.prototype.attack = function(unitId)
 {
-	var unitId = unit;
 	Engine.PostCommand(PlayerID,{"type": "attack", "entities": this.toIdArray(), "target": unitId, "queued": false});
 	return this;
 };
 
-// violent, aggressive, defensive, passive, standground
+/** violent, aggressive, defensive, passive, standground */
 m.EntityCollection.prototype.setStance = function(stance)
 {
 	Engine.PostCommand(PlayerID,{"type": "stance", "entities": this.toIdArray(), "name" : stance, "queued": false});
 	return this;
 };
 
-// Returns the average position of all units
+/** Returns the average position of all units */
 m.EntityCollection.prototype.getCentrePosition = function()
 {
-	var sumPos = [0, 0];
-	var count = 0;
+	let sumPos = [0, 0];
+	let count = 0;
 	for (let ent of this._entities.values())
 	{
 		if (!ent.position())
@@ -200,19 +207,18 @@ m.EntityCollection.prototype.getCentrePosition = function()
 		count ++;
 	}
 
-	if (count === 0)
-		return undefined;
-	else
-		return [sumPos[0]/count, sumPos[1]/count];
+	return count ? [sumPos[0]/count, sumPos[1]/count] : undefined;
 };
 
-// returns the average position from the sample first units.
-// This might be faster for huge collections, but there's
-// always a risk that it'll be unprecise.
+/**
+ * returns the average position from the sample first units.
+ * This might be faster for huge collections, but there's
+ * always a risk that it'll be unprecise.
+ */
 m.EntityCollection.prototype.getApproximatePosition = function(sample)
 {
-	var sumPos = [0, 0];
-	var i = 0;
+	let sumPos = [0, 0];
+	let i = 0;
 	for (let ent of this._entities.values())
 	{
 		if (!ent.position())
@@ -223,14 +229,16 @@ m.EntityCollection.prototype.getApproximatePosition = function(sample)
 		if (i === sample)
 			break;
 	}
-	if (i === 0)
-		return undefined;
-	else
-		return [sumPos[0]/i, sumPos[1]/i];
+
+	return i ? [sumPos[0]/i, sumPos[1]/i] : undefined;
 };
 
+m.EntityCollection.prototype.hasEntId = function(id)
+{
+	return this._entities.has(id);
+};
 
-// Removes an entity from the collection, returns true if the entity was a member, false otherwise
+/** Removes an entity from the collection, returns true if the entity was a member, false otherwise */
 m.EntityCollection.prototype.removeEnt = function(ent)
 {
 	if (!this._entities.has(ent.id()))
@@ -239,7 +247,7 @@ m.EntityCollection.prototype.removeEnt = function(ent)
 	return true;
 };
 
-// Adds an entity to the collection, returns true if the entity was not member, false otherwise
+/** Adds an entity to the collection, returns true if the entity was not member, false otherwise */
 m.EntityCollection.prototype.addEnt = function(ent)
 {
 	if (this._entities.has(ent.id()))
@@ -248,15 +256,17 @@ m.EntityCollection.prototype.addEnt = function(ent)
 	return true;
 };
 
-// Checks the entity against the filters, and adds or removes it appropriately, returns true if the
-// entity collection was modified.
-// Force can add a unit despite a freezing.
-// If an entitycollection is frozen, it will never automatically add a unit.
-// But can remove one.
+/**
+ * Checks the entity against the filters, and adds or removes it appropriately, returns true if the
+ * entity collection was modified.
+ * Force can add a unit despite a freezing.
+ * If an entitycollection is frozen, it will never automatically add a unit.
+ * But can remove one.
+ */
 m.EntityCollection.prototype.updateEnt = function(ent, force)
 {
-	var passesFilters = true;
-	for (var filter of this._filters)
+	let passesFilters = true;
+	for (let filter of this._filters)
 		passesFilters = passesFilters && filter.func(ent);
 
 	if (passesFilters)
@@ -265,8 +275,8 @@ m.EntityCollection.prototype.updateEnt = function(ent, force)
 			return false;
 		return this.addEnt(ent);
 	}
-	else
-		return this.removeEnt(ent);
+
+	return this.removeEnt(ent);
 };
 
 m.EntityCollection.prototype.registerUpdates = function()
