@@ -38,7 +38,7 @@ m.Filters = {
 
 	byMetadata: function(player, key, value){
 		return {"func" : function(ent){
-			return (ent.getMetadata(player, key) == value);
+			return ent.getMetadata(player, key) == value;
 		}, 
 		"dynamicProperties": ['metadata.' + key]};
 	},
@@ -46,14 +46,14 @@ m.Filters = {
 	// can be used for stuffs which won't change once entities are created.
 	byStaticMetadata: function(player, key, value){
 		return {"func" : function(ent){
-			return (ent.getMetadata(player, key) == value);
+			return ent.getMetadata(player, key) == value;
 		},
 		"dynamicProperties": []};
 	},
 	
 	byHasMetadata: function(player, key){
 		return {"func" : function(ent){
-			return (ent.getMetadata(player, key) != undefined);
+			return ent.getMetadata(player, key) !== undefined;
 		},
 		"dynamicProperties": ['metadata.' + key]};
 	},
@@ -81,14 +81,14 @@ m.Filters = {
 	
 	byOwner: function(owner){
 		return {"func" : function(ent){
-			return (ent.owner() === owner);
+			return ent.owner() === owner;
 		}, 
 		"dynamicProperties": ['owner']};
 	},
 	
 	byNotOwner: function(owner){
 		return {"func" : function(ent){
-			return (ent.owner() !== owner);
+			return ent.owner() !== owner;
 		}, 
 		"dynamicProperties": ['owner']};
 	},
@@ -123,7 +123,7 @@ m.Filters = {
 	},
 	byTargetedEntity: function(targetID){
 		return {"func": function(ent) {
-			return (ent.unitAIOrderData().length && ent.unitAIOrderData()[0].target && ent.unitAIOrderData()[0].target == targetID);
+			return ent.unitAIOrderData().length && ent.unitAIOrderData()[0].target && ent.unitAIOrderData()[0].target == targetID;
 		},
 		"dynamicProperties": ['unitAIOrderData']};
 	},
@@ -179,10 +179,9 @@ m.Filters = {
 
 	byDistance: function(startPoint, dist){
 		return {"func": function(ent){
-			if (ent.position() === undefined)
+			if (!ent.position())
 				return false;
-			else
-				return (m.SquareVectorDistance(startPoint, ent.position()) < dist*dist);
+			return m.SquareVectorDistance(startPoint, ent.position()) < dist*dist;
 		},
 		"dynamicProperties": ['position']};
 	},
@@ -192,55 +191,47 @@ m.Filters = {
 		return {"func": function(ent){
 			if (!ent.position())
 				return false;
-			else
-				return (m.SquareVectorDistance(startPoint, ent.position()) < dist*dist);
+			return m.SquareVectorDistance(startPoint, ent.position()) < dist*dist;
 		},
 		"dynamicProperties": []};
 	},
 	
 	byTerritory: function(Map, territoryIndex){
 		return {"func": function(ent){
-			if (Map.point(ent.position()) == territoryIndex)
-				return true;
-			else
-				return false;
+			return Map.point(ent.position()) == territoryIndex;
 		},
 		"dynamicProperties": ['position']};
 	},
 
 	isDropsite: function(resourceType){
 		return {"func": function(ent){
-			return (ent.resourceDropsiteTypes() && (resourceType === undefined || ent.resourceDropsiteTypes().indexOf(resourceType) !== -1));
+			return ent.resourceDropsiteTypes() && (resourceType === undefined || ent.resourceDropsiteTypes().indexOf(resourceType) !== -1);
 		},
 		"dynamicProperties": []};
 	},
 	
 	byResource: function(resourceType){
 		return {"func" : function(ent){
-			var type = ent.resourceSupplyType();
+			if (!ent.resourceSupplyMax())
+				return false;
+
+			let type = ent.resourceSupplyType();
 			if (!type)
 				return false;
-			var amount = ent.resourceSupplyMax();
-			if (!amount)
-				return false;
-			
+
 			// Skip targets that are too hard to hunt
-			if (ent.isUnhuntable())
+			if (!ent.isHuntable() || ent.hasClass("SeaCreature"))
 				return false;
-			
-			// And don't go for the bloody fish! TODO: better accessibility checks 
-			if (ent.hasClass("SeaCreature"))
-				return false;
-			
+
 			// Don't go for floating treasures since we won't be able to reach them and it kills the pathfinder.
 			if (ent.templateName() == "other/special_treasure_shipwreck_debris" || 
-					ent.templateName() == "other/special_treasure_shipwreck" )
+			    ent.templateName() == "other/special_treasure_shipwreck" )
 				return false;
-			
+
 			if (type.generic == "treasure")
-				return (resourceType == type.specific);
-			else
-				return (resourceType == type.generic);
+				return resourceType == type.specific;
+
+			return resourceType == type.generic;
 		},
 		"dynamicProperties": []};
 	},
@@ -249,8 +240,7 @@ m.Filters = {
 		return {"func" : function(ent){
 			if (!ent.hasClass("Animal"))
 				return false;
-			var amount = ent.resourceSupplyMax();
-			if (!amount)
+			if (!ent.resourceSupplyMax())
 				return false;
 			// Skip targets that are too hard to hunt
 			if (!ent.isHuntable())
