@@ -1,7 +1,7 @@
 var API3 = function(m)
 {
 
-// Shared script handling templates and basic terrain analysis
+/** Shared script handling templates and basic terrain analysis */
 m.SharedScript = function(settings)
 {
 	if (!settings)
@@ -18,49 +18,48 @@ m.SharedScript = function(settings)
 
 	// array of entity collections
 	this._entityCollections = new Map();
-	this._techModifications = {};
+	this._entitiesModifications = new Map();	// entities modifications
+	this._templatesModifications = {};	// template modifications
 	// each name is a reference to the actual one.
 	this._entityCollectionsName = new Map();
 	this._entityCollectionsByDynProp = {};
 	this._entityCollectionsUID = 0;
-
-	// A few notes about these maps. They're updated by checking for "create" and "destroy" events for all resources
-	// TODO: change the map when the resource amounts change for at least stone and metal mines.
-	this.resourceMaps = {}; // Contains maps showing the density of wood, stone and metal
-	this.CCResourceMaps = {}; // Contains maps showing the density of wood, stone and metal, optimized for CC placement.
-	// Resource maps data.
-	// By how much to divide the resource amount when filling the map (ie a tree having 200 wood is "4").
-	this.decreaseFactor = {"wood": 50.0, "stone": 90.0, "metal": 90.0};
 };
 
-//Return a simple object (using no classes etc) that will be serialized into saved games
+/** Return a simple object (using no classes etc) that will be serialized into saved games */
 m.SharedScript.prototype.Serialize = function()
 {
 	return {
 		"players": this._players,
-		"techTp": this._techTemplates,
-		"techModifications": this._techModifications,
+		"techTemplates": this._techTemplates,
+		"templatesModifications": this._templatesModifications,
+		"entitiesModifications": this._entitiesModifications,
 		"metadata": this._entityMetadata
 	};
 };
 
-// Called after the constructor when loading a saved game, with 'data' being
-// whatever Serialize() returned
+/**
+ * Called after the constructor when loading a saved game, with 'data' being
+ * whatever Serialize() returned
+ */
 m.SharedScript.prototype.Deserialize = function(data)
 {
 	this._players = data.players;
-	this._techTemplates = data.techTp;
-	this._techModifications = data.techModifications;
+	this._techTemplates = data.techTemplates;
+	this._templatesModifications = data.templatesModifications;
+	this._entitiesModifications = data.entitiesModifications;
 	this._entityMetadata = data.metadata;
-	this._derivedTemplates = {}; 
+	this._derivedTemplates = {};
 
 	this.isDeserialized = true;
 };
 
-// Components that will be disabled in foundation entity templates.
-// (This is a bit yucky and fragile since it's the inverse of
-// CCmpTemplateManager::CopyFoundationSubset and only includes components
-// that our Template class currently uses.)
+/**
+ * Components that will be disabled in foundation entity templates.
+ * (This is a bit yucky and fragile since it's the inverse of
+ * CCmpTemplateManager::CopyFoundationSubset and only includes components
+ * that our Template class currently uses.)
+ */
 m.g_FoundationForbiddenComponents = {
 	"ProductionQueue": 1,
 	"ResourceSupply": 1,
@@ -68,8 +67,10 @@ m.g_FoundationForbiddenComponents = {
 	"GarrisonHolder": 1,
 };
 
-// Components that will be disabled in resource entity templates.
-// Roughly the inverse of CCmpTemplateManager::CopyResourceSubset.
+/**
+ * Components that will be disabled in resource entity templates.
+ * Roughly the inverse of CCmpTemplateManager::CopyResourceSubset.
+ */
 m.g_ResourceForbiddenComponents = {
 	"Cost": 1,
 	"Decay": 1,
@@ -83,10 +84,10 @@ m.SharedScript.prototype.GetTemplate = function(name)
 {	
 	if (this._templates[name])
 		return this._templates[name];
-	
+
 	if (this._derivedTemplates[name])
 		return this._derivedTemplates[name];
-	
+
 	// If this is a foundation template, construct it automatically
 	if (name.indexOf("foundation|") !== -1)
 	{
@@ -112,19 +113,24 @@ m.SharedScript.prototype.GetTemplate = function(name)
 		this._derivedTemplates[name] = resource;
 		return resource;
 	}
-	
+
 	error("Tried to retrieve invalid template '"+name+"'");
 	return null;
 };
 
-// Initialize the shared component.
-// We need to know the initial state of the game for this, as we will use it.
-// This is called right at the end of the map generation.
+/**
+ * Initialize the shared component.
+ * We need to know the initial state of the game for this, as we will use it.
+ * This is called right at the end of the map generation.
+ */
 m.SharedScript.prototype.init = function(state, deserialization)
 {
 	if (!deserialization)
+	{
+		this._entitiesModifications = new Map();
 		for (let i = 0; i < state.players.length; ++i)
-			this._techModifications[i] = {};
+			this._templatesModifications[i] = {};
+	}
 
 	this.ApplyTemplatesDelta(state);
 
@@ -138,20 +144,20 @@ m.SharedScript.prototype.init = function(state, deserialization)
 	this.barterPrices = state.barterPrices;
 
 	this.passabilityMap = state.passabilityMap;
-	if (this.mapSize % this.passabilityMap.width != 0)
-		 error("AI shared component inconsistent sizes: map=" + this.mapSize + " while passability=" +  this.passabilityMap.width);
+	if (this.mapSize % this.passabilityMap.width !== 0)
+		 error("AI shared component inconsistent sizes: map=" + this.mapSize + " while passability=" + this.passabilityMap.width);
 	this.passabilityMap.cellSize = this.mapSize / this.passabilityMap.width;
 	this.territoryMap = state.territoryMap;
-	if (this.mapSize % this.territoryMap.width != 0)
-		 error("AI shared component inconsistent sizes: map=" + this.mapSize + " while territory=" +  this.territoryMap.width);
+	if (this.mapSize % this.territoryMap.width !== 0)
+		 error("AI shared component inconsistent sizes: map=" + this.mapSize + " while territory=" + this.territoryMap.width);
 	this.territoryMap.cellSize = this.mapSize / this.territoryMap.width;
 
 /*
-	var landPassMap = new Uint8Array(this.passabilityMap.data.length);
-	var waterPassMap = new Uint8Array(this.passabilityMap.data.length);
-	var obstructionMaskLand = this.passabilityClasses["default-terrain-only"];
-	var obstructionMaskWater = this.passabilityClasses["ship-terrain-only"];
-	for (var i = 0; i < this.passabilityMap.data.length; ++i)
+	let landPassMap = new Uint8Array(this.passabilityMap.data.length);
+	let waterPassMap = new Uint8Array(this.passabilityMap.data.length);
+	let obstructionMaskLand = this.passabilityClasses["default-terrain-only"];
+	let obstructionMaskWater = this.passabilityClasses["ship-terrain-only"];
+	for (let i = 0; i < this.passabilityMap.data.length; ++i)
 	{
 		landPassMap[i] = (this.passabilityMap.data[i] & obstructionMaskLand) ? 0 : 255;
 		waterPassMap[i] = (this.passabilityMap.data[i] & obstructionMaskWater) ? 0 : 255;
@@ -166,26 +172,55 @@ m.SharedScript.prototype.init = function(state, deserialization)
 			this._entities.set(+id, new m.Entity(this, state.entities[id]));
 	// entity collection updated on create/destroy event.
 	this.entities = new m.EntityCollection(this, this._entities);
-	
+
 	// create the terrain analyzer
 	this.terrainAnalyzer = new m.TerrainAnalysis();
 	this.terrainAnalyzer.init(this, state);
 	this.accessibility = new m.Accessibility();
 	this.accessibility.init(state, this.terrainAnalyzer);
-	
-	// defined in TerrainAnalysis.js
-	this.createResourceMaps(this);
+
+	// Setup resources
+	this.resourceTypes = { "food": 0, "wood": 1, "stone": 2, "metal": 2 };
+	this.resourceList = [];
+	for (let res in this.resourceTypes)
+		this.resourceList.push(res);
+	m.Resources.prototype.types = this.resourceList;
+	// Resource types: 0 = not used for resource maps
+	//                 1 = abondant resource with small amount each
+	//                 2 = spare resource, but huge amount each
+	// The following maps are defined in TerrainAnalysis.js and are used for some building placement (cc, dropsites)
+	// They are updated by checking for create and destroy events for all resources
+	this.normalizationFactor = { "1": 50, "2": 90 };
+	this.influenceRadius = { "1": 36, "2": 48 };
+	this.ccInfluenceRadius = { "1": 60, "2": 120 };
+	this.resourceMaps = {};   // Contains maps showing the density of resources
+	this.ccResourceMaps = {}; // Contains maps showing the density of resources, optimized for CC placement.
+	this.createResourceMaps();
+
+	/** Keep in sync with gui/common/l10n.js */
+	this.resourceNames = {
+		// Translation: Word as used in the middle of a sentence (which may require using lowercase for your language).
+		"food": markForTranslationWithContext("withinSentence", "Food"),
+		// Translation: Word as used in the middle of a sentence (which may require using lowercase for your language).
+		"wood": markForTranslationWithContext("withinSentence", "Wood"),
+		// Translation: Word as used in the middle of a sentence (which may require using lowercase for your language).
+		"metal": markForTranslationWithContext("withinSentence", "Metal"),
+		// Translation: Word as used in the middle of a sentence (which may require using lowercase for your language).
+		"stone": markForTranslationWithContext("withinSentence", "Stone"),
+	};
 
 	this.gameState = {};
-	for (var i in this._players)
+	for (let i in this._players)
 	{
 		this.gameState[this._players[i]] = new m.GameState();
 		this.gameState[this._players[i]].init(this,state, this._players[i]);
 	}
 };
 
-// General update of the shared script, before each AI's update
-// applies entity deltas, and each gamestate.
+/**
+ * General update of the shared script, before each AI's update
+ * applies entity deltas, and each gamestate.
+ */
 m.SharedScript.prototype.onUpdate = function(state)
 {
 	if (this.isDeserialized)
@@ -212,11 +247,11 @@ m.SharedScript.prototype.onUpdate = function(state)
 	this.territoryMap = state.territoryMap;
 	this.territoryMap.cellSize = this.mapSize / this.territoryMap.width;
 	
-	for (var i in this.gameState)
-		this.gameState[i].update(this,state);
+	for (let i in this.gameState)
+		this.gameState[i].update(this);
 
 	// TODO: merge this with "ApplyEntitiesDelta" since after all they do the same.
-	this.updateResourceMaps(this, this.events);
+	this.updateResourceMaps(this.events);
 	
 	Engine.ProfileStop();
 };
@@ -225,12 +260,12 @@ m.SharedScript.prototype.ApplyEntitiesDelta = function(state)
 {
 	Engine.ProfileStart("Shared ApplyEntitiesDelta");
 
-	var foundationFinished = {};
+	let foundationFinished = {};
 	
 	// by order of updating:
 	// we "Destroy" last because we want to be able to switch Metadata first.
 
-	var CreateEvents = state.events.Create;
+	let CreateEvents = state.events.Create;
 	for (let i = 0; i < CreateEvents.length; ++i)
 	{
 		let evt = CreateEvents[i];
@@ -283,7 +318,7 @@ m.SharedScript.prototype.ApplyEntitiesDelta = function(state)
 			this.setMetadata(evt.owner, this._entities.get(evt.id), key, evt.metadata[key]);
 	}
 	
-	var DestroyEvents = state.events.Destroy;
+	let DestroyEvents = state.events.Destroy;
 	for (let i = 0; i < DestroyEvents.length; ++i)
 	{
 		let evt = DestroyEvents[i];
@@ -296,20 +331,21 @@ m.SharedScript.prototype.ApplyEntitiesDelta = function(state)
 
 		if (foundationFinished[evt.entity])
 			evt.SuccessfulFoundation = true;
-		
+
 		// The entity was destroyed but its data may still be useful, so
 		// remember the entity and this AI's metadata concerning it
 		evt.metadata = {};
 		evt.entityObj = this._entities.get(evt.entity);
 		for (let j in this._players)
 			evt.metadata[this._players[j]] = this._entityMetadata[this._players[j]][evt.entity];
-		
+
 		let entity = this._entities.get(evt.entity);
 		for (let entCol of this._entityCollections.values())
 			entCol.removeEnt(entity);
 		this.entities.removeEnt(entity);
-		
+
 		this._entities.delete(evt.entity);
+		this._entitiesModifications.delete(evt.entity);
 		for (let j in this._players)
 			delete this._entityMetadata[this._players[j]][evt.entity];
 	}
@@ -332,9 +368,11 @@ m.SharedScript.prototype.ApplyEntitiesDelta = function(state)
 		if (!this._entities.has(+id))
 			continue;	// dead, presumably.
 		let changes = state.changedEntityTemplateInfo[id];
-		let entity = this._entities.get(+id);
+		if (!this._entitiesModifications.has(+id))
+			this._entitiesModifications.set(+id, new Map());
+		let modif = this._entitiesModifications.get(+id);
 		for (let change of changes)
-			entity._auraTemplateModif.set(change.variable, change.value);
+			modif.set(change.variable, change.value);
 	}
 	Engine.ProfileStop();
 };
@@ -349,10 +387,11 @@ m.SharedScript.prototype.ApplyTemplatesDelta = function(state)
 		for (let template in playerDiff)
 		{
 			let changes = playerDiff[template];
-			if (!this._techModifications[player][template])
-				this._techModifications[player][template] = new Map();
+			if (!this._templatesModifications[player][template])
+				this._templatesModifications[player][template] = new Map();
+			let modif = this._templatesModifications[player][template];
 			for (let change of changes)
-				this._techModifications[player][template].set(change.variable, change.value);
+				modif.set(change.variable, change.value);
 		}
 	}
 	Engine.ProfileStop();
@@ -394,19 +433,19 @@ m.SharedScript.prototype.updateEntityCollections = function(property, ent)
 
 m.SharedScript.prototype.setMetadata = function(player, ent, key, value)
 {
-	var metadata = this._entityMetadata[player][ent.id()];
+	let metadata = this._entityMetadata[player][ent.id()];
 	if (!metadata)
 		metadata = this._entityMetadata[player][ent.id()] = {};
 	metadata[key] = value;
-	
+
 	this.updateEntityCollections('metadata', ent);
 	this.updateEntityCollections('metadata.' + key, ent);
 };
 
 m.SharedScript.prototype.getMetadata = function(player, ent, key)
 {
-	var metadata = this._entityMetadata[player][ent.id()];
-	
+	let metadata = this._entityMetadata[player][ent.id()];
+
 	if (!metadata || !(key in metadata))
 		return undefined;
 	return metadata[key];
@@ -414,8 +453,8 @@ m.SharedScript.prototype.getMetadata = function(player, ent, key)
 
 m.SharedScript.prototype.deleteMetadata = function(player, ent, key)
 {
-	var metadata = this._entityMetadata[player][ent.id()];
-	
+	let metadata = this._entityMetadata[player][ent.id()];
+
 	if (!metadata || !(key in metadata))
 		return true;
 	metadata[key] = undefined;
@@ -425,13 +464,16 @@ m.SharedScript.prototype.deleteMetadata = function(player, ent, key)
 	return true;
 };
 
-m.copyPrototype = function(descendant, parent) {
-    var sConstructor = parent.toString();
-    var aMatch = sConstructor.match( /\s*function (.*)\(/ );
-	if ( aMatch != null ) { descendant.prototype[aMatch[1]] = parent; }
-	for (var m in parent.prototype) {
-		descendant.prototype[m] = parent.prototype[m];
-	}
+m.copyPrototype = function(descendant, parent)
+{
+	let sConstructor = parent.toString();
+	let aMatch = sConstructor.match( /\s*function (.*)\(/ );
+
+	if ( aMatch != null )
+		descendant.prototype[aMatch[1]] = parent;
+
+	for (let p in parent.prototype)
+		descendant.prototype[p] = parent.prototype[p];
 };
 
 return m;
