@@ -1,13 +1,13 @@
 var API3 = function(m)
 {
 
-// Wrapper around a technology template
+/** Wrapper around a technology template */
 
 m.Technology = function(allTemplates, templateName)
 {
 	this._templateName = templateName;
-	var template = allTemplates[templateName];
-	
+	let template = allTemplates[templateName];
+
 	// check if this is one of two paired technologies.
 	this._isPair = template.pair !== undefined;
 	if (this._isPair)
@@ -23,7 +23,7 @@ m.Technology = function(allTemplates, templateName)
 	this._techTemplates = allTemplates;
 };
 
-// returns generic, or specific if civ provided.
+/** returns generic, or specific if civ provided. */
 m.Technology.prototype.name = function(civ)
 {
 	if (civ === undefined)
@@ -39,15 +39,15 @@ m.Technology.prototype.pairDef = function()
 	return this._definesPair;
 };
 
-// in case this defines a pair only, returns the two paired technologies.
+/** in case this defines a pair only, returns the two paired technologies. */
 m.Technology.prototype.getPairedTechs = function()
 {
 	if (!this._definesPair)
 		return undefined;
-	
-	var techOne = new m.Technology(this._techTemplates, this._template.top);
-	var techTwo = new m.Technology(this._techTemplates, this._template.bottom);
-	
+
+	let techOne = new m.Technology(this._techTemplates, this._template.top);
+	let techTwo = new m.Technology(this._techTemplates, this._template.bottom);
+
 	return [techOne,techTwo];
 };
 
@@ -65,14 +65,31 @@ m.Technology.prototype.pairedWith = function()
 	return this._pairedWith;
 };
 
-m.Technology.prototype.cost = function()
+m.Technology.prototype.cost = function(productionQueue)
 {
 	if (!this._template.cost)
 		return undefined;
-	return this._template.cost;
+	let cost = {};
+	for (let type in this._template.cost)
+	{
+		cost[type] = +this._template.cost[type];
+		if (productionQueue)
+			cost[type] *= productionQueue.techCostMultiplier(type);
+	}
+	return cost;
+};
+
+m.Technology.prototype.costSum = function(productionQueue)
+{
+	let cost = this.cost(productionQueue);
+	if (!cost)
+		return undefined;
+	let ret = 0;
+	for (let type in cost)
+		ret += cost[type];
+	return ret;
 };
 
-// seconds
 m.Technology.prototype.researchTime = function()
 {
 	if (!this._template.researchTime)
