@@ -1,7 +1,8 @@
 var PETRA = function(m)
 {
 
-/* Defines an army
+/**
+ * Defines an army
  * An army is a collection of own entities and enemy entities.
  * This doesn't use entity collections are they aren't really useful
  * and it would probably slow the rest of the system down too much.
@@ -17,7 +18,7 @@ m.Army = function(gameState, ownEntities, foeEntities)
 	this.defenseRatio = this.Config.Defense.defenseRatio;
 	this.compactSize = this.Config.Defense.armyCompactSize;
 	this.breakawaySize = this.Config.Defense.armyBreakawaySize;
-		
+
 	// average
 	this.foePosition = [0,0];
 	this.positionLastUpdate = gameState.ai.elapsedTime;
@@ -28,39 +29,39 @@ m.Army = function(gameState, ownEntities, foeEntities)
 	this.assignedAgainst = {};
 	// who we assigned against, for quick removal.
 	this.assignedTo = {};
-	
+
 	this.foeEntities = [];
 	this.foeStrength = 0;
-	
+
 	this.ownEntities = [];
 	this.ownStrength = 0;
-	
+
 	// actually add units
 	for (let id of foeEntities)
 		this.addFoe(gameState, id, true);
 	for (let id of ownEntities)
 		this.addOwn(gameState, id);
-	
+
 	this.recalculatePosition(gameState, true);
 
 	return true;
 };
 
-// if not forced, will only recalculate if on a different turn.
+/** if not forced, will only recalculate if on a different turn. */
 m.Army.prototype.recalculatePosition = function(gameState, force)
 {
 	if (!force && this.positionLastUpdate === gameState.ai.elapsedTime)
 		return;
 
-	var npos = 0;
-	var pos = [0, 0];
-	for (var id of this.foeEntities)
+	let npos = 0;
+	let pos = [0, 0];
+	for (let id of this.foeEntities)
 	{
-		var ent = gameState.getEntityById(id);
+		let ent = gameState.getEntityById(id);
 		if (!ent || !ent.position())
 			continue;
 		npos++;
-		var epos = ent.position();
+		let epos = ent.position();
 		pos[0] += epos[0];
 		pos[1] += epos[1];
 	}
@@ -74,13 +75,10 @@ m.Army.prototype.recalculatePosition = function(gameState, force)
 	this.positionLastUpdate = gameState.ai.elapsedTime;
 };
 
-// helper
 m.Army.prototype.recalculateStrengths = function (gameState)
 {
-	this.ownStrength  = 0;
-	this.foeStrength  = 0;
-	
-	// todo: deal with specifics.
+	this.ownStrength = 0;
+	this.foeStrength = 0;
 
 	for (let id of this.foeEntities)
 		this.evaluateStrength(gameState.getEntityById(id));
@@ -88,14 +86,14 @@ m.Army.prototype.recalculateStrengths = function (gameState)
 		this.evaluateStrength(gameState.getEntityById(id), true);
 };
 
-// adds or remove the strength of the entity either to the enemy or to our units.
+/** adds or remove the strength of the entity either to the enemy or to our units. */
 m.Army.prototype.evaluateStrength = function (ent, isOwn, remove)
 {
-	var entStrength;
+	let entStrength;
 	if (ent.hasClass("Structure"))
 	{
 		if (ent.owner() !== PlayerID)
-			entStrength = (ent.getDefaultArrow() ? 6*ent.getDefaultArrow() : 4);
+			entStrength = ent.getDefaultArrow() ? 6*ent.getDefaultArrow() : 4;
 		else	// small strength used only when we try to recover capture points
 			entStrength = 2;
 	}
@@ -116,10 +114,12 @@ m.Army.prototype.evaluateStrength = function (ent, isOwn, remove)
 		this.foeStrength += entStrength;
 };
 
-// add an entity to the enemy army
-// Will return true if the entity was added and false otherwise.
-// won't recalculate our position but will dirty it.
-// force is true at army creation or when merging armies, so in this case we should add it even if far
+/**
+ * add an entity to the enemy army
+ * Will return true if the entity was added and false otherwise.
+ * won't recalculate our position but will dirty it.
+ * force is true at army creation or when merging armies, so in this case we should add it even if far
+ */
 m.Army.prototype.addFoe = function (gameState, enemyId, force)
 {
 	if (this.foeEntities.indexOf(enemyId) !== -1)
@@ -127,11 +127,11 @@ m.Army.prototype.addFoe = function (gameState, enemyId, force)
 	let ent = gameState.getEntityById(enemyId);
 	if (!ent || !ent.position())
 		return false;
-	
+
 	// check distance
 	if (!force && API3.SquareVectorDistance(ent.position(), this.foePosition) > this.compactSize)
 			return false;
-	
+
 	this.foeEntities.push(enemyId);
 	this.assignedAgainst[enemyId] = [];
 	this.positionLastUpdate = 0;
@@ -141,8 +141,10 @@ m.Army.prototype.addFoe = function (gameState, enemyId, force)
 	return true;
 };
 
-// returns true if the entity was removed and false otherwise.
-// TODO: when there is a technology update, we should probably recompute the strengths, or weird stuffs will happen.
+/**
+ * returns true if the entity was removed and false otherwise.
+ * TODO: when there is a technology update, we should probably recompute the strengths, or weird stuffs will happen.
+ */
 m.Army.prototype.removeFoe = function (gameState, enemyId, enemyEntity)
 {
 	let idx = this.foeEntities.indexOf(enemyId);
@@ -150,13 +152,13 @@ m.Army.prototype.removeFoe = function (gameState, enemyId, enemyEntity)
 		return false;
 
 	this.foeEntities.splice(idx, 1);
-	
+
 	this.assignedAgainst[enemyId] = undefined;
 	for (let to in this.assignedTo)
 		if (this.assignedTo[to] == enemyId)
 			this.assignedTo[to] = undefined;
 
-	let ent = (enemyEntity ? enemyEntity : gameState.getEntityById(enemyId));
+	let ent = enemyEntity ? enemyEntity : gameState.getEntityById(enemyId);
 	if (ent)    // TODO recompute strength when no entities (could happen if capture+destroy)
 	{
 		this.evaluateStrength(ent, false, true);
@@ -166,13 +168,15 @@ m.Army.prototype.removeFoe = function (gameState, enemyId, enemyEntity)
 	return true;
 };
 
-// adds a defender but doesn't assign him yet.
-// force is true when merging armies, so in this case we should add it even if no position as it can be in a ship
+/**
+ * adds a defender but doesn't assign him yet.
+ * force is true when merging armies, so in this case we should add it even if no position as it can be in a ship
+ */
 m.Army.prototype.addOwn = function (gameState, id, force)
 {
 	if (this.ownEntities.indexOf(id) !== -1)
 		return false;
-	var ent = gameState.getEntityById(id);
+	let ent = gameState.getEntityById(id);
 	if (!ent || (!ent.position() && !force))
 		return false;
 
@@ -181,12 +185,12 @@ m.Army.prototype.addOwn = function (gameState, id, force)
 	ent.setMetadata(PlayerID, "PartOfArmy", this.ID);
 	this.assignedTo[id] = 0;
 
-	var plan = ent.getMetadata(PlayerID, "plan");
+	let plan = ent.getMetadata(PlayerID, "plan");
 	if (plan !== undefined)
 		ent.setMetadata(PlayerID, "plan", -2);
 	else
  		ent.setMetadata(PlayerID, "plan", -3);
-	var subrole = ent.getMetadata(PlayerID, "subrole");
+	let subrole = ent.getMetadata(PlayerID, "subrole");
 	if (subrole === undefined || subrole !== "defender")
 		ent.setMetadata(PlayerID, "formerSubrole", subrole);
 	ent.setMetadata(PlayerID, "subrole", "defender");
@@ -195,7 +199,7 @@ m.Army.prototype.addOwn = function (gameState, id, force)
 
 m.Army.prototype.removeOwn = function (gameState, id, Entity)
 {
-	var idx = this.ownEntities.indexOf(id);
+	let idx = this.ownEntities.indexOf(id);
 	if (idx === -1)
 		return false;
 
@@ -203,13 +207,13 @@ m.Army.prototype.removeOwn = function (gameState, id, Entity)
 
 	if (this.assignedTo[id] !== 0)
 	{
-		var temp = this.assignedAgainst[this.assignedTo[id]];
+		let temp = this.assignedAgainst[this.assignedTo[id]];
 		if (temp)
 			temp.splice(temp.indexOf(id), 1);
 	}
 	this.assignedTo[id] = undefined;
 
-	let ent = (Entity ? Entity : gameState.getEntityById(id));
+	let ent = Entity ? Entity : gameState.getEntityById(id);
 	if (ent)    // TODO recompute strength when no entities (could happen if capture+destroy)
 	{
 		this.evaluateStrength(ent, true, true);
@@ -219,7 +223,7 @@ m.Army.prototype.removeOwn = function (gameState, id, Entity)
 		else
 			ent.setMetadata(PlayerID, "plan", undefined);
 
-		var formerSubrole = ent.getMetadata(PlayerID, "formerSubrole");
+		let formerSubrole = ent.getMetadata(PlayerID, "formerSubrole");
 		if (formerSubrole !== undefined)
 			ent.setMetadata(PlayerID, "subrole", formerSubrole);
 		else
@@ -229,13 +233,13 @@ m.Army.prototype.removeOwn = function (gameState, id, Entity)
 		// TODO be sure that all units in the transport need the cancelation
 /*		if (!ent.position())	// this unit must still be in a transport plan ... try to cancel it
 		{
-			var planID = ent.getMetadata(PlayerID, "transport");
+			let planID = ent.getMetadata(PlayerID, "transport");
 			// no plans must mean that the unit was in a ship which was destroyed, so do nothing
 			if (planID)
 			{
 				if (gameState.ai.Config.debug > 0)
 					warn("ent from army still in transport plan: plan " + planID + " canceled");
-				var plan = gameState.ai.HQ.navalManager.getPlan(planID);
+				let plan = gameState.ai.HQ.navalManager.getPlan(planID);
 				if (plan && !plan.canceled)
 					plan.cancelTransport(gameState);
 			}
@@ -245,25 +249,31 @@ m.Army.prototype.removeOwn = function (gameState, id, Entity)
 	return true;
 };
 
-// Special army set to capture a gaia building.
-// It must only contain one foe (the building to capture) and never be merged
+/**
+ * Special army set to capture a gaia building.
+ * It must only contain one foe (the building to capture) and never be merged
+ */
 m.Army.prototype.isCapturing = function (gameState)
 {
 	if (this.foeEntities.length != 1)
 		return false;
 	let ent = gameState.getEntityById(this.foeEntities[0]);
-	return (ent && ent.hasClass("Structure"));
+	return ent && ent.hasClass("Structure");
 };    
 
-// this one is "undefined entity" proof because it's called at odd times.
-// Orders a unit to attack an enemy.
-// overridden by specific army classes.
+/**
+ * this one is "undefined entity" proof because it's called at odd times.
+ * Orders a unit to attack an enemy.
+ * overridden by specific army classes.
+ */
 m.Army.prototype.assignUnit = function (gameState, entID)
 {
 };
 
-// resets the army properly.
-// assumes we already cleared dead units.
+/**
+ * resets the army properly.
+ * assumes we already cleared dead units.
+ */
 m.Army.prototype.clear = function (gameState)
 {
 	while (this.foeEntities.length > 0)
@@ -278,9 +288,11 @@ m.Army.prototype.clear = function (gameState)
 	this.recalculatePosition(gameState);
 };
 
-// merge this army with another properly.
-// assumes units are in only one army.
-// also assumes that all have been properly cleaned up (no dead units).
+/**
+ * merge this army with another properly.
+ * assumes units are in only one army.
+ * also assumes that all have been properly cleaned up (no dead units).
+ */
 m.Army.prototype.merge = function (gameState, otherArmy)
 {
 	// copy over all parameters.
@@ -306,7 +318,6 @@ m.Army.prototype.merge = function (gameState, otherArmy)
 	return true;
 };
 
-// TODO: when there is a technology update, we should probably recompute the strengths, or weird stuffs might happen.
 m.Army.prototype.checkEvents = function (gameState, events)
 {
 	// Warning the metadata is already cloned in shared.js. Futhermore, changes should be done before destroyEvents
@@ -324,7 +335,7 @@ m.Army.prototype.checkEvents = function (gameState, events)
 			this.assignedAgainst[evt.newentity] = this.assignedAgainst[evt.entity];
 			this.assignedAgainst[evt.entity] = undefined;
 			for (let to in this.assignedTo)
-				if (this.assignedTo[to] == evt.entity)
+				if (this.assignedTo[to] === evt.entity)
 					this.assignedTo[to] = evt.newentity;
 		}
 		else if (this.ownEntities.indexOf(evt.entity) !== -1)
@@ -363,30 +374,25 @@ m.Army.prototype.checkEvents = function (gameState, events)
 	}
 };
 
-// assumes cleaned army.
+/** assumes cleaned army. */
 m.Army.prototype.onUpdate = function (gameState)
 {
 	if (this.isCapturing(gameState))
 	{
-		let done = true;
+		// Check if we have still some capturePoints to recover
+		// and if not, remove this foe from the list (capture army have only one foe)
 		let capture = gameState.getEntityById(this.foeEntities[0]).capturePoints();
 		if (capture !== undefined)
 		{
 			for (let j = 0; j < capture.length; ++j)
-			{
 				if (gameState.isPlayerEnemy(j) && capture[j] > 0)
-				{
-					done = false;
-					break;
-				}
-			}
+					return [];
 		}
-		if (done)
-			this.removeFoe(gameState, this.foeEntities[0]);
+		this.removeFoe(gameState, this.foeEntities[0]);
 		return [];
 	}
 
-	var breakaways = [];
+	let breakaways = [];
 	// TODO: assign unassigned defenders, cleanup of a few things.
 	// perhaps occasional strength recomputation
 	
@@ -395,12 +401,12 @@ m.Army.prototype.onUpdate = function (gameState)
 	{
 		this.recalculatePosition(gameState);
 		this.positionLastUpdate = gameState.ai.elapsedTime;
-	
+
 		// Check for breakaways.
-		for (var i = 0; i < this.foeEntities.length; ++i)
+		for (let i = 0; i < this.foeEntities.length; ++i)
 		{
-			var id = this.foeEntities[i];
-			var ent = gameState.getEntityById(id);
+			let id = this.foeEntities[i];
+			let ent = gameState.getEntityById(id);
 			if (!ent || !ent.position())
 				continue;
 			if (API3.SquareVectorDistance(ent.position(), this.foePosition) > this.breakawaySize)
@@ -410,7 +416,7 @@ m.Army.prototype.onUpdate = function (gameState)
 					i--;
 			}
 		}
-		
+
 		this.recalculatePosition(gameState);
 	}
 
