@@ -1,15 +1,16 @@
 var PETRA = function(m)
 {
-/* Base Manager
+
+/**
+ * Base Manager
  * Handles lower level economic stuffs.
  * Some tasks:
-	-tasking workers: gathering/hunting/building/repairing?/scouting/plans.
-	-giving feedback/estimates on GR
-	-achieving building stuff plans (scouting/getting ressource/building) or other long-staying plans, if I ever get any.
-	-getting good spots for dropsites
-	-managing dropsite use in the base
-		> warning HQ if we'll need more space
-	-updating whatever needs updating, keeping track of stuffs (rebuilding needs…)
+ *  -tasking workers: gathering/hunting/building/repairing?/scouting/plans.
+ *  -giving feedback/estimates on GR
+ *  -achieving building stuff plans (scouting/getting ressource/building) or other long-staying plans.
+ *  -getting good spots for dropsites
+ *  -managing dropsite use in the base
+ *  -updating whatever needs updating, keeping track of stuffs (rebuilding needs…)
  */
 
 m.BaseManager = function(gameState, Config)
@@ -27,8 +28,8 @@ m.BaseManager = function(gameState, Config)
 	this.maxDistResourceSquare = 360*360;
 
 	this.constructing = false;
-	// Defenders to train in this cc when its construction is finished 
-	this.neededDefenders = ((this.Config.difficulty > 2) ? 3 + 2*(this.Config.difficulty - 3) : 0);
+	// Defenders to train in this cc when its construction is finished
+	this.neededDefenders = this.Config.difficulty > 2 ? 3 + 2*(this.Config.difficulty - 3) : 0;
 
 	// vector for iterating, to check one use the HQ map.
 	this.territoryIndices = [];
@@ -49,15 +50,15 @@ m.BaseManager.prototype.init = function(gameState, state)
 	this.units.registerUpdates();
 	this.workers.registerUpdates();
 	this.buildings.registerUpdates();
-	
+
 	// array of entity IDs, with each being
 	this.dropsites = {};
 	this.dropsiteSupplies = {};
 	this.gatherers = {};
-	for (let type of this.Config.resources)
+	for (let res of gameState.sharedScript.resourceList)
 	{
-		this.dropsiteSupplies[type] = {"nearby": [], "medium": [], "faraway": []};
-		this.gatherers[type] = {"nextCheck": 0, "used": 0, "lost": 0};
+		this.dropsiteSupplies[res] = { "nearby": [], "medium": [], "faraway": [] };
+		this.gatherers[res] = { "nextCheck": 0, "used": 0, "lost": 0 };
 	}
 };
 
@@ -75,7 +76,7 @@ m.BaseManager.prototype.setAnchor = function(gameState, anchorEntity)
 {
 	if (!anchorEntity.hasClass("Structure") || !anchorEntity.hasTerritoryInfluence())
 	{
-		warn("Error: Petra base " + this.ID + " has been assigned an anchor building that has no territorial influence. Please report this on the forum.");
+		warn("Error: Petra base " + this.ID + " has been assigned an anchor building that has no territorial influence.");
 		return false;
 	}
 	this.anchor = anchorEntity;
@@ -172,7 +173,6 @@ m.BaseManager.prototype.anchorLost = function (gameState, ent)
 	for (let entity of this.buildings.values())
 		bestbase.assignEntity(gameState, entity);
 	gameState.ai.HQ.resetActiveBase();
-	gameState.ai.HQ.updateTerritories(gameState);
 };
 
 /**
@@ -250,7 +250,7 @@ m.BaseManager.prototype.assignResourceToDropsite = function (gameState, dropsite
 		medium.sort((r1, r2) => r1.dist - r2.dist);
 		faraway.sort((r1, r2) => r1.dist - r2.dist);
 
-/*		var debug = false;
+/*		let debug = false;
 		if (debug)
 		{
 			faraway.forEach(function(res){ 
@@ -280,7 +280,7 @@ m.BaseManager.prototype.removeDropsite = function (gameState, ent)
 	if (!ent.id())
 		return;
 
-	var removeSupply = function(entId, supply){
+	let removeSupply = function(entId, supply){
 		for (let i = 0; i < supply.length; ++i)
 		{
 			// exhausted resource, remove it from this list
@@ -303,13 +303,14 @@ m.BaseManager.prototype.removeDropsite = function (gameState, ent)
 	return;
 };
 
-// Returns the position of the best place to build a new dropsite for the specified resource 
-// TODO check dropsites of other bases ... may-be better to do a simultaneous liste of dp and foundations
+/**
+ * Returns the position of the best place to build a new dropsite for the specified resource 
+ */
 m.BaseManager.prototype.findBestDropsiteLocation = function(gameState, resource)
 {
 	
-	var template = gameState.getTemplate(gameState.applyCiv("structures/{civ}_storehouse"));
-	var halfSize = 0;
+	let template = gameState.getTemplate(gameState.applyCiv("structures/{civ}_storehouse"));
+	let halfSize = 0;
 	if (template.get("Footprint/Square"))
 		halfSize = Math.max(+template.get("Footprint/Square/@depth"), +template.get("Footprint/Square/@width")) / 2;
 	else if (template.get("Footprint/Circle"))
@@ -320,19 +321,19 @@ m.BaseManager.prototype.findBestDropsiteLocation = function(gameState, resource)
 	// Then checks for a good spot in the territory. If none, and town/city phase, checks outside
 	// The AI will currently not build a CC if it wouldn't connect with an existing CC.
 
-	var obstructions = m.createObstructionMap(gameState, this.accessIndex, template);
+	let obstructions = m.createObstructionMap(gameState, this.accessIndex, template);
 
-	var dpEnts = gameState.getOwnEntitiesByClass("Storehouse", true).toEntityArray();
-	var ccEnts = gameState.getOwnEntitiesByClass("CivCentre", true).toEntityArray();
+	let dpEnts = gameState.getOwnEntitiesByClass("Storehouse", true).toEntityArray();
+	let ccEnts = gameState.getOwnEntitiesByClass("CivCentre", true).toEntityArray();
 
-	var bestIdx;
-	var bestVal = 0;
-	var radius = Math.ceil(template.obstructionRadius() / obstructions.cellSize);
+	let bestIdx;
+	let bestVal = 0;
+	let radius = Math.ceil(template.obstructionRadius() / obstructions.cellSize);
+
+	let territoryMap = gameState.ai.HQ.territoryMap;
+	let width = territoryMap.width;
+	let cellSize = territoryMap.cellSize;
 
-	var territoryMap = gameState.ai.HQ.territoryMap;
-	var width = territoryMap.width;
-	var cellSize = territoryMap.cellSize;
-    
 	for (let j of this.territoryIndices)
 	{
 		let i = territoryMap.getNonObstructedTile(j, radius, obstructions);
@@ -401,15 +402,15 @@ m.BaseManager.prototype.findBestDropsiteLocation = function(gameState, resource)
 	if (bestVal <= 0)
 		return {"quality": bestVal, "pos": [0, 0]};
 
-	var x = (bestIdx % obstructions.width + 0.5) * obstructions.cellSize;
-	var z = (Math.floor(bestIdx / obstructions.width) + 0.5) * obstructions.cellSize;
-	return {"quality": bestVal, "pos": [x, z]};
+	let x = (bestIdx % obstructions.width + 0.5) * obstructions.cellSize;
+	let z = (Math.floor(bestIdx / obstructions.width) + 0.5) * obstructions.cellSize;
+	return { "quality": bestVal, "pos": [x, z] };
 };
 
 m.BaseManager.prototype.getResourceLevel = function (gameState, type, nearbyOnly = false)
 {
-	var count = 0;
-	var check = {};
+	let count = 0;
+	let check = {};
 	for (let supply of this.dropsiteSupplies[type].nearby)
 	{
 		if (check[supply.id])    // avoid double counting as same resource can appear several time
@@ -430,16 +431,16 @@ m.BaseManager.prototype.getResourceLevel = function (gameState, type, nearbyOnly
 	return count;
 };
 
-// check our resource levels and react accordingly
+/** check our resource levels and react accordingly */
 m.BaseManager.prototype.checkResourceLevels = function (gameState, queues)
 {
-	for (let type of this.Config.resources)
+	for (let type of gameState.sharedScript.resourceList)
 	{
-		if (type == "food")
+		if (type === "food")
 		{
 			if (gameState.ai.HQ.canBuild(gameState, "structures/{civ}_field"))	// let's see if we need to add new farms.
 			{
-				let count = this.getResourceLevel(gameState, type, (gameState.currentPhase() > 1));  // animals are not accounted
+				let count = this.getResourceLevel(gameState, type, gameState.currentPhase() > 1);  // animals are not accounted
 				let numFarms = gameState.getOwnStructures().filter(API3.Filters.byClass("Field")).length;  // including foundations
 				let numQueue = queues.field.countQueuedUnits();
 
@@ -447,7 +448,10 @@ m.BaseManager.prototype.checkResourceLevels = function (gameState, queues)
 				if (numFarms + numQueue === 0)	// starting game, rely on fruits as long as we have enough of them
 				{
 					if (count < 600)
+					{
 						queues.field.addPlan(new m.ConstructionPlan(gameState, "structures/{civ}_field", { "base": this.ID }));
+						gameState.ai.HQ.needFarm = true;
+					}
 				}
 				else
 				{
@@ -459,12 +463,24 @@ m.BaseManager.prototype.checkResourceLevels = function (gameState, queues)
 						queues.field.addPlan(new m.ConstructionPlan(gameState, "structures/{civ}_field", { "base": this.ID }));
 				}
 			}
+			else if (gameState.isTemplateDisabled(gameState.applyCiv("structures/{civ}_field")) &&
+				 !queues.corral.hasQueuedUnits() &&
+				 !gameState.getOwnEntitiesByClass("Corral", true).hasEntities() &&
+				 gameState.ai.HQ.canBuild(gameState, "structures/{civ}_corral"))
+			{
+				let count = this.getResourceLevel(gameState, type, gameState.currentPhase() > 1);  // animals are not accounted
+				if (count < 600)
+				{
+					queues.corral.addPlan(new m.ConstructionPlan(gameState, "structures/{civ}_corral", { "base": this.ID }));
+					gameState.ai.HQ.needCorral = true;
+				}
+			}
 		}
-		else if (!queues.dropsites.length() && !gameState.getOwnFoundations().filter(API3.Filters.byClass("Storehouse")).length)
+		else if (!queues.dropsites.hasQueuedUnits() && !gameState.getOwnFoundations().filter(API3.Filters.byClass("Storehouse")).hasEntities())
 		{
 			if (gameState.ai.playedTurn > this.gatherers[type].nextCheck)
 			{
-				var self = this;
+				let self = this;
 				this.gatherersByType(gameState, type).forEach(function (ent) {
 					if (ent.unitAIState() === "INDIVIDUAL.GATHER.GATHERING")
 						++self.gatherers[type].used;
@@ -481,7 +497,7 @@ m.BaseManager.prototype.checkResourceLevels = function (gameState, queues)
 						let newDP = this.findBestDropsiteLocation(gameState, type);
 						if (newDP.quality > 50 && gameState.ai.HQ.canBuild(gameState, "structures/{civ}_storehouse"))
 							queues.dropsites.addPlan(new m.ConstructionPlan(gameState, "structures/{civ}_storehouse", { "base": this.ID, "type": type }, newDP.pos));
-						else if (!gameState.getOwnFoundations().filter(API3.Filters.byClass("CivCentre")).length && !queues.civilCentre.length())
+						else if (!gameState.getOwnFoundations().filter(API3.Filters.byClass("CivCentre")).hasEntities() && !queues.civilCentre.hasQueuedUnits())
 						{
 							// No good dropsite, try to build a new base if no base already planned,
 							// and if not possible, be less strict on dropsite quality
@@ -508,7 +524,7 @@ m.BaseManager.prototype.checkResourceLevels = function (gameState, queues)
 	
 };
 
-// Adds the estimated gather rates from this base to the currentRates
+/** Adds the estimated gather rates from this base to the currentRates */
 m.BaseManager.prototype.getGatherRates = function(gameState, currentRates)
 {
 	for (let res in currentRates)
@@ -560,22 +576,24 @@ m.BaseManager.prototype.assignRolelessUnits = function(gameState, roleless)
 	}
 };
 
-// If the numbers of workers on the resources is unbalanced then set some of workers to idle so
-// they can be reassigned by reassignIdleWorkers.
-// TODO: actually this probably should be in the HQ.
+/**
+ * If the numbers of workers on the resources is unbalanced then set some of workers to idle so
+ * they can be reassigned by reassignIdleWorkers.
+ * TODO: actually this probably should be in the HQ.
+ */
 m.BaseManager.prototype.setWorkersIdleByPriority = function(gameState)
 {
 	// change resource only towards one which is more needed, and if changing will not change this order
-	var nb = 1;    // no more than 1 change per turn (otherwise we should update the rates)
-	var mostNeeded = gameState.ai.HQ.pickMostNeededResources(gameState);
-	var sumWanted = 0;
-	var sumCurrent = 0;
+	let nb = 1;    // no more than 1 change per turn (otherwise we should update the rates)
+	let mostNeeded = gameState.ai.HQ.pickMostNeededResources(gameState);
+	let sumWanted = 0;
+	let sumCurrent = 0;
 	for (let need of mostNeeded)
 	{
 		sumWanted += need.wanted;
 		sumCurrent += need.current;
 	}
-	var scale = 1;
+	let scale = 1;
 	if (sumWanted > 0)
 		scale = sumCurrent / sumWanted;
 
@@ -590,21 +608,21 @@ m.BaseManager.prototype.setWorkersIdleByPriority = function(gameState)
 				continue;
 			// If we assume a mean rate of 0.5 per gatherer, this diff should be > 1
 			// but we require a bit more to avoid too frequent changes
-			if ((scale*moreNeed.wanted - moreNeed.current) - (scale*lessNeed.wanted - lessNeed.current) > 1.5)
+			if (scale*moreNeed.wanted - moreNeed.current - scale*lessNeed.wanted + lessNeed.current > 1.5)
 			{
 				let only;
 				// in average, females are less efficient for stone and metal, and citizenSoldiers for food
 				let gatherers = this.gatherersByType(gameState, lessNeed.type);
-				if (lessNeed.type === "food" && gatherers.filter(API3.Filters.byClass("CitizenSoldier")).length)
+				if (lessNeed.type === "food" && gatherers.filter(API3.Filters.byClass("CitizenSoldier")).hasEntities())
 					only = "CitizenSoldier";
 				else if ((lessNeed.type === "stone" || lessNeed.type === "metal") && moreNeed.type !== "stone" && moreNeed.type !== "metal" &&
-					gatherers.filter(API3.Filters.byClass("Female")).length) 
+					gatherers.filter(API3.Filters.byClass("Female")).hasEntities()) 
 					only = "Female";
 
 				gatherers.forEach( function (ent) {
 					if (!ent.canGather(moreNeed.type))
 						return;
-					if (nb == 0)
+					if (nb === 0)
 						return;
 					if (only && !ent.hasClass(only))
 						return;
@@ -613,7 +631,7 @@ m.BaseManager.prototype.setWorkersIdleByPriority = function(gameState)
 					ent.setMetadata(PlayerID, "gather-type", moreNeed.type);
 					gameState.ai.HQ.AddTCResGatherer(moreNeed.type);
 				});
-				if (nb == 0)
+				if (nb === 0)
 					return;
 			}
 		}
@@ -628,7 +646,7 @@ m.BaseManager.prototype.reassignIdleWorkers = function(gameState, idleWorkers)
 		let filter = API3.Filters.byMetadata(PlayerID, "subrole", "idle");
 		idleWorkers = gameState.updatingCollection("idle-workers-base-" + this.ID, filter, this.workers).values();
 	}
-	
+
 	for (let ent of idleWorkers)
 	{
 		// Check that the worker isn't garrisoned
@@ -681,12 +699,13 @@ m.BaseManager.prototype.gatherersByType = function(gameState, type)
 	return gameState.updatingCollection("workers-gathering-" + type +"-base-" + this.ID, API3.Filters.byMetadata(PlayerID, "gather-type", type), this.workersBySubrole(gameState, "gatherer"));
 };
 
-
-// returns an entity collection of workers.
-// They are idled immediatly and their subrole set to idle.
+/**
+ * returns an entity collection of workers.
+ * They are idled immediatly and their subrole set to idle.
+ */
 m.BaseManager.prototype.pickBuilders = function(gameState, workers, number)
 {
-	var availableWorkers = this.workers.filter(function (ent) {
+	let availableWorkers = this.workers.filter(function (ent) {
 		if (!ent.position() || !ent.isBuilder())
 			return false;
 		if (ent.getMetadata(PlayerID, "plan") == -2 || ent.getMetadata(PlayerID, "plan") == -3)
@@ -710,9 +729,9 @@ m.BaseManager.prototype.pickBuilders = function(gameState, workers, number)
 			vala = -20;
 		if (b.getMetadata(PlayerID, "plan") === undefined)
 			valb = -20;
-		return (vala - valb);
+		return vala - valb;
 	});
-	var needed = Math.min(number, availableWorkers.length - 3);
+	let needed = Math.min(number, availableWorkers.length - 3);
 	for (let i = 0; i < needed; ++i)
 	{
 		availableWorkers[i].stopMoving();
@@ -722,27 +741,27 @@ m.BaseManager.prototype.pickBuilders = function(gameState, workers, number)
 	return;
 };
 
+/**
+ * If we have some foundations, and we don't have enough builder-workers,
+ * try reassigning some other workers who are nearby	
+ * AI tries to use builders sensibly, not completely stopping its econ.
+ */
 m.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
-{
-	// If we have some foundations, and we don't have enough builder-workers,
-	// try reassigning some other workers who are nearby	
-	// AI tries to use builders sensibly, not completely stopping its econ.
-	
-	// TODO: this is not perfect performance-wise.
-	var foundations = this.buildings.filter(API3.Filters.and(API3.Filters.isFoundation(),API3.Filters.not(API3.Filters.byClass("Field")))).toEntityArray();
-	
-	var damagedBuildings = this.buildings.filter(ent => ent.foundationProgress() === undefined && ent.needsRepair());
-	
+{	
+	let foundations = this.buildings.filter(API3.Filters.and(API3.Filters.isFoundation(),API3.Filters.not(API3.Filters.byClass("Field")))).toEntityArray();
+
+	let damagedBuildings = this.buildings.filter(ent => ent.foundationProgress() === undefined && ent.needsRepair());
+
 	// Check if nothing to build
 	if (!foundations.length && !damagedBuildings.length)
 		return;
 
-	var workers = this.workers.filter(ent => ent.isBuilder());
-	var builderWorkers = this.workersBySubrole(gameState, "builder");
-	var idleBuilderWorkers = builderWorkers.filter(API3.Filters.isIdle());
+	let workers = this.workers.filter(ent => ent.isBuilder());
+	let builderWorkers = this.workersBySubrole(gameState, "builder");
+	let idleBuilderWorkers = builderWorkers.filter(API3.Filters.isIdle());
 
 	// if we're constructing and we have the foundations to our base anchor, only try building that.
-	if (this.constructing == true && this.buildings.filter(API3.Filters.and(API3.Filters.isFoundation(), API3.Filters.byMetadata(PlayerID, "baseAnchor", true))).length != 0)
+	if (this.constructing === true && this.buildings.filter(API3.Filters.and(API3.Filters.isFoundation(), API3.Filters.byMetadata(PlayerID, "baseAnchor", true))).hasEntities())
 	{
 		foundations = this.buildings.filter(API3.Filters.byMetadata(PlayerID, "baseAnchor", true)).toEntityArray();
 		let tID = foundations[0].id();
@@ -759,7 +778,7 @@ m.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 	if (workers.length < 2)
 	{
 		let fromOtherBase = gameState.ai.HQ.bulkPickWorkers(gameState, this, 2);
-		if(fromOtherBase)
+		if (fromOtherBase)
 		{
 			let baseID = this.ID;
 			fromOtherBase.forEach(function (worker) {
@@ -772,8 +791,8 @@ m.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 		}
 	}
 
-	var builderTot = builderWorkers.length - idleBuilderWorkers.length;	
-	
+	let builderTot = builderWorkers.length - idleBuilderWorkers.length;	
+
 	for (let target of foundations)
 	{
 		if (target.hasClass("Field"))
@@ -789,7 +808,7 @@ m.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 
 		let assigned = gameState.getOwnEntitiesByMetadata("target-foundation", target.id()).length;
 		let maxTotalBuilders = Math.ceil(workers.length * 0.2);
-		if (target.hasClass("House") && gameState.getPopulationLimit() < (gameState.getPopulation() + 5) &&
+		if (target.hasClass("House") && gameState.getPopulationLimit() < gameState.getPopulation() + 5 &&
 			gameState.getPopulationLimit() < gameState.getPopulationMax())
 			maxTotalBuilders = maxTotalBuilders + 2;
 		let targetNB = 2;
@@ -799,7 +818,7 @@ m.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 			targetNB = 4;
 		else if (target.hasClass("Fortress"))
 			targetNB = 7;
-		if (target.getMetadata(PlayerID, "baseAnchor") == true || (target.hasClass("Wonder") && gameState.getGameType() === "wonder"))
+		if (target.getMetadata(PlayerID, "baseAnchor") === true || (target.hasClass("Wonder") && gameState.getGameType() === "wonder"))
 		{
 			targetNB = 15;
 			maxTotalBuilders = Math.max(maxTotalBuilders, 15);
@@ -841,15 +860,15 @@ m.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 					let coeffA = API3.SquareVectorDistance(target.position(),workerA.position());
 					// elephant moves slowly, so when far away they are only useful if build time is long
 					if (workerA.hasClass("Elephant"))
-						coeffA *= 0.5 * (1 + (Math.sqrt(coeffA)/150)*(30/time));
+						coeffA *= 0.5 * (1 + Math.sqrt(coeffA)/5/time);
 					else if (workerA.getMetadata(PlayerID, "gather-type") === "food")
 						coeffA *= 3;
 					let coeffB = API3.SquareVectorDistance(target.position(),workerB.position());
 					if (workerB.hasClass("Elephant"))
-						coeffB *= 0.5 * (1 + (Math.sqrt(coeffB)/150)*(30/time));
+						coeffB *= 0.5 * (1 + Math.sqrt(coeffB)/5/time);
 					else if (workerB.getMetadata(PlayerID, "gather-type") === "food")
 						coeffB *= 3;
-					return (coeffA - coeffB);						
+					return coeffA - coeffB;						
 				});
 				let current = 0;
 				let nonBuilderTot = nonBuilderWorkers.length;
@@ -875,16 +894,16 @@ m.BaseManager.prototype.assignToFoundations = function(gameState, noRepair)
 				continue;
 		else if (noRepair && !target.hasClass("CivCentre"))
 			continue;
-		
+
 		if (target.decaying())
 			continue;
-		
+
 		let assigned = gameState.getOwnEntitiesByMetadata("target-foundation", target.id()).length;
 		let maxTotalBuilders = Math.ceil(workers.length * 0.2);
 		let targetNB = 1;
 		if (target.hasClass("Fortress"))
 			targetNB = 3;
-		if (target.getMetadata(PlayerID, "baseAnchor") == true || (target.hasClass("Wonder") && gameState.getGameType() === "wonder"))
+		if (target.getMetadata(PlayerID, "baseAnchor") === true || (target.hasClass("Wonder") && gameState.getGameType() === "wonder"))
 		{
 			maxTotalBuilders = Math.ceil(workers.length * 0.3);
 			targetNB = 5;
@@ -1041,7 +1060,7 @@ m.BaseManager.prototype.Deserialize = function(gameState, data)
 	for (let key in data)
 		this[key] = data[key];
 
-	this.anchor = ((this.anchorId !== undefined) ? gameState.getEntityById(this.anchorId) : undefined);
+	this.anchor = this.anchorId !== undefined ? gameState.getEntityById(this.anchorId) : undefined;
 };
 
 return m;
