@@ -7,6 +7,9 @@ m.DefenseManager = function(Config)
 	this.Config = Config;
 	this.targetList = [];
 	this.armyMergeSize = this.Config.Defense.armyMergeSize;
+	this.attackingArmies = {};	// stats on how many enemies are currently attacking our allies
+	this.attackingUnits = {};
+	this.attackedAllies = {};
 };
 
 m.DefenseManager.prototype.update = function(gameState, events)
@@ -17,6 +20,42 @@ m.DefenseManager.prototype.update = function(gameState, events)
 
 	this.checkEvents(gameState, events);
 
+	// Check if our potential targets are still valid
+	for (let i = 0; i < this.targetList.length; ++i)
+	{
+		let target = gameState.getEntityById(this.targetList[i]);
+		if (!target || !target.position() || !gameState.isPlayerEnemy(target.owner()))
+			this.targetList.splice(i--, 1);
+	}
+
+	// Count the number of enemies attacking our allies in the previous turn
+	// We'll be more cooperative if several enemies are attacking him simultaneously
+	this.attackedAllies = {};
+	let attackingArmies = clone(this.attackingArmies);
+	for (let enemy in this.attackingUnits)
+	{
+		if (!this.attackingUnits[enemy])
+			continue;
+		for (let ally in this.attackingUnits[enemy])
+		{
+			if (this.attackingUnits[enemy][ally] < 8)
+				continue;
+			if (attackingArmies[enemy] === undefined)
+				attackingArmies[enemy] = {};
+			if (attackingArmies[enemy][ally] === undefined)
+				attackingArmies[enemy][ally] = 0;
+			attackingArmies[enemy][ally] += 1;
+		}
+	}
+	for (let enemy in attackingArmies)
+	{
+		for (let ally in attackingArmies[enemy])
+		{
+			if (this.attackedAllies[ally] === undefined)
+				this.attackedAllies[ally] = 0;
+			this.attackedAllies[ally] += 1;
+		}
+	}
 	this.checkEnemyArmies(gameState);
 	this.checkEnemyUnits(gameState);
 	this.assignDefenders(gameState);
@@ -32,7 +71,7 @@ m.DefenseManager.prototype.makeIntoArmy = function(gameState, entityID)
 			return;	// over
 
 	// Create a new army for it.
-	var army = new m.DefenseArmy(gameState, [], [entityID]);
+	let army = new m.DefenseArmy(gameState, [], [entityID]);
 	this.armies.push(army);
 };
 
@@ -46,7 +85,6 @@ m.DefenseManager.prototype.getArmy = function(partOfArmy)
 	return undefined;
 };
 
-// TODO: this algorithm needs to be improved, sorta.
 m.DefenseManager.prototype.isDangerous = function(gameState, entity)
 {
 	if (!entity.position())
@@ -63,21 +101,26 @@ m.DefenseManager.prototype.isDangerous = function(gameState, entity)
 		if (this.targetList.indexOf(targetId) !== -1)
 			return true;
 		let target = gameState.getEntityById(targetId);
-		if (target && this.territoryMap.getOwner(entity.position()) === PlayerID)
+		if (target)
 		{
-			this.targetList.push(targetId);
-			return true;
-		}
-		else if (target && target.hasClass("CivCentre"))
-		{
-			let myBuildings = gameState.getOwnStructures();
-			for (let building of myBuildings.values())
+			let isTargetEnemy = gameState.isPlayerEnemy(target.owner());
+			if (isTargetEnemy && territoryOwner === PlayerID)
 			{
-				if (API3.SquareVectorDistance(building.position(), entity.position()) > 30000)
-					continue;
-				this.targetList.push(targetId);
+				if (target.hasClass("Structure"))
+					this.targetList.push(targetId);
 				return true;
 			}
+			else if (isTargetEnemy && target.hasClass("CivCentre"))
+			{
+				let myBuildings = gameState.getOwnStructures();
+				for (let building of myBuildings.values())
+				{
+					if (API3.SquareVectorDistance(building.position(), entity.position()) > 30000)
+						continue;
+					this.targetList.push(targetId);
+					return true;
+				}
+			}
 		}
 	}
 
@@ -88,27 +131,27 @@ m.DefenseManager.prototype.isDangerous = function(gameState, entity)
 	if (entity.attackTypes().indexOf("Ranged") !== -1)
 		dist2Min = (entity.attackRange("Ranged").max + 30) * (entity.attackRange("Ranged").max + 30);
     
-	for (let i = 0; i < this.targetList.length; ++i)
+	for (let targetId of this.targetList)
 	{
-		let target = gameState.getEntityById(this.targetList[i]);
+		let target = gameState.getEntityById(targetId);
 		if (!target || !target.position())   // the enemy base is either destroyed or built
-			this.targetList.splice(i--, 1);
-		else if (API3.SquareVectorDistance(target.position(), entity.position()) < dist2Min)
+			continue;
+		if (API3.SquareVectorDistance(target.position(), entity.position()) < dist2Min)
 			return true;
 	}
 
-	if (this.Config.personality.cooperative > 0.3)
+	let ccEnts = gameState.updatingGlobalCollection("allCCs", API3.Filters.byClass("CivCentre"));
+	for (let cc of ccEnts.values())
 	{
-		let ccEnts = gameState.updatingGlobalCollection("allCCs", API3.Filters.byClass("CivCentre"));
-		for (let cc of ccEnts.values())
-		{
-			if (!gameState.isEntityExclusiveAlly(cc))
-				continue;
-			if (this.Config.personality.cooperative < 0.6 && cc.foundationProgress() !== undefined)
-				continue;
-			if (API3.SquareVectorDistance(cc.position(), entity.position()) < dist2Min)
-				return true;
-		}
+		if (!gameState.isEntityExclusiveAlly(cc) || cc.foundationProgress() === 0)
+			continue;
+		let cooperation = this.GetCooperationLevel(cc);
+		if (cooperation < 0.6 && cc.foundationProgress() !== undefined)
+			continue;
+		if (cooperation < 0.3)
+			continue;
+		if (API3.SquareVectorDistance(cc.position(), entity.position()) < dist2Min)
+			return true;
 	}
 
 	let myBuildings = gameState.getOwnStructures();
@@ -120,14 +163,25 @@ m.DefenseManager.prototype.isDangerous = function(gameState, entity)
 			return true;
 	}
 
+	// Update the number of enemies attacking this ally
+	if (gameState.isPlayerMutualAlly(territoryOwner))
+	{
+		let enemy = entity.owner();
+		if (this.attackingUnits[enemy] === undefined)
+			this.attackingUnits[enemy] = {};
+		if (this.attackingUnits[enemy][territoryOwner] === undefined)
+			this.attackingUnits[enemy][territoryOwner] = 0;
+		this.attackingUnits[enemy][territoryOwner] += 1;
+	}
+
 	return false;
 };
 
-
 m.DefenseManager.prototype.checkEnemyUnits = function(gameState)
 {
-	var nbPlayers = gameState.sharedScript.playersData.length;
-	var i = gameState.ai.playedTurn % nbPlayers;
+	const nbPlayers = gameState.sharedScript.playersData.length;
+	let i = gameState.ai.playedTurn % nbPlayers;
+ 	this.attackingUnits[i] = undefined;
 
 	if (i === PlayerID)
 	{
@@ -238,13 +292,33 @@ m.DefenseManager.prototype.checkEnemyArmies = function(gameState)
 	if (gameState.ai.playedTurn % 5 !== 0)
 		return;
 	// Check if any army is no more dangerous (possibly because it has defeated us and destroyed our base)
+ 	this.attackingArmies = {};
 	for (let i = 0; i < this.armies.length; ++i)
 	{
 		let army = this.armies[i];
 		army.recalculatePosition(gameState);
 		let owner = this.territoryMap.getOwner(army.foePosition);
 		if (!gameState.isPlayerEnemy(owner))
+		{
+			if (gameState.isPlayerMutualAlly(owner))
+			{
+				// update the number of enemies attacking this ally
+				for (let id of army.foeEntities)
+				{
+					let ent = gameState.getEntityById(id);
+					if (!ent)
+						continue;
+					let enemy = ent.owner();
+					if (this.attackingArmies[enemy] === undefined)
+						this.attackingArmies[enemy] = {};
+					if (this.attackingArmies[enemy][owner] === undefined)
+						this.attackingArmies[enemy][owner] = 0;
+					this.attackingArmies[enemy][owner] += 1;
+					break;
+				}
+			}
 			continue;
+		}
 		else if (owner !== 0)   // enemy army back in its territory
 		{
 			army.clear(gameState);
@@ -260,7 +334,8 @@ m.DefenseManager.prototype.checkEnemyArmies = function(gameState)
 		{
 			if (!gameState.isEntityAlly(base))
 				continue;
-			if (this.Config.personality.cooperative < 0.3 && !gameState.isEntityOwn(base))
+			let cooperation = this.GetCooperationLevel(base);
+			if (cooperation < 0.3 && !gameState.isEntityOwn(base))
 				continue;
 			if (API3.SquareVectorDistance(base.position(), army.foePosition) > 40000)
 				continue;
@@ -282,9 +357,8 @@ m.DefenseManager.prototype.assignDefenders = function(gameState)
 	if (this.armies.length === 0)
 		return;
 	
-	var armiesNeeding = [];
-	// Okay, let's add defenders
-	// TODO: this is dumb.
+	let armiesNeeding = [];
+	// let's add defenders
 	for (let army of this.armies)
 	{
 		let needsDef = army.needsDefenders(gameState);
@@ -300,7 +374,7 @@ m.DefenseManager.prototype.assignDefenders = function(gameState)
 		return;
 
 	// let's get our potential units
-	var potentialDefenders = []; 
+	let potentialDefenders = []; 
 	gameState.getOwnUnits().forEach(function(ent) {
 		if (!ent.position())
 			return;
@@ -314,9 +388,11 @@ m.DefenseManager.prototype.assignDefenders = function(gameState)
 			return;
 		if (ent.getMetadata(PlayerID, "transport") !== undefined || ent.getMetadata(PlayerID, "transporter") !== undefined)
 			return;
+		if (gameState.getGameType() === "regicide" && ent.hasClass("Hero") && ent.healthLevel() < 0.8)
+			return;
 		if (ent.getMetadata(PlayerID, "plan") !== undefined && ent.getMetadata(PlayerID, "plan") !== -1)
 		{
-			var subrole = ent.getMetadata(PlayerID, "subrole");
+			let subrole = ent.getMetadata(PlayerID, "subrole");
 			if (subrole && (subrole === "completing" || subrole === "walking" || subrole === "attacking"))
 				return;
 		}
@@ -359,7 +435,7 @@ m.DefenseManager.prototype.assignDefenders = function(gameState)
 	if (!armiesNeeding.length)
 		return;
 	// If shortage of defenders, produce infantry garrisoned in nearest civil centre
-	var armiesPos = [];
+	let armiesPos = [];
 	for (let a = 0; a < armiesNeeding.length; ++a)
 		armiesPos.push(armiesNeeding[a].army.foePosition);
 	gameState.ai.HQ.trainEmergencyUnits(gameState, armiesPos);
@@ -377,9 +453,11 @@ m.DefenseManager.prototype.abortArmy = function(gameState, army)
 	}
 };
 
-// If our defense structures are attacked, garrison soldiers inside when possible
-// and if a support unit is attacked and has less than 55% health, garrison it inside the nearest healing structure
-// and if a ranged siege unit (not used for defense) is attacked, garrison it in the nearest fortress
+/**
+ * If our defense structures are attacked, garrison soldiers inside when possible
+ * and if a support unit is attacked and has less than 55% health, garrison it inside the nearest healing structure
+ * and if a ranged siege unit (not used for defense) is attacked, garrison it in the nearest fortress
+ */
 m.DefenseManager.prototype.checkEvents = function(gameState, events)
 {
 	// must be called every turn for all armies
@@ -399,8 +477,41 @@ m.DefenseManager.prototype.checkEvents = function(gameState, events)
 		if (target.hasClass("Ship"))    // TODO integrate ships later   need to be sure it is accessible
 			continue;
 
-		// If inside a started attack plan, let the plan deal with this unit
 		let plan = target.getMetadata(PlayerID, "plan");
+
+		// Retreat the hero in regicide mode if wounded
+		if (gameState.getGameType() == "regicide" && target.hasClass("Hero") && target.healthLevel() < 0.7)
+		{
+			target.stopMoving();
+
+			if (plan >= 0)
+			{
+				let attackPlan = gameState.ai.HQ.attackManager.getPlan(target.getMetadata(PlayerID, "plan"));
+				if (attackPlan)
+					attackPlan.removeUnit(target, true);
+			}
+
+			if (target.getMetadata(PlayerID, "PartOfArmy"))
+			{
+				let army = gameState.ai.HQ.defenseManager.getArmy(target.getMetadata(PlayerID, "PartOfArmy"));
+				if (army)
+					army.removeOwn(gameState, target.id());
+			}
+
+			this.garrisonUnitForHealing(gameState, target);
+
+			if (plan >= 0) // couldn't find a place to garrison, so the hero will flee from attacks
+			{
+				target.setStance("passive");
+				let accessIndex = gameState.ai.accessibility.getAccessValue(target.position());
+				let basePos = m.getBestBase(gameState, target);
+				if (basePos && basePos.accessIndex == accessIndex)
+					target.move(basePos.anchor.position()[0], basePos.anchor.position()[1]);
+			}
+			continue;
+		}
+
+		// If inside a started attack plan, let the plan deal with this unit
 		if (plan !== undefined && plan >= 0)
 		{
 			let attack = gameState.ai.HQ.attackManager.getPlan(plan);
@@ -489,10 +600,10 @@ m.DefenseManager.prototype.garrisonRangedUnitsInside = function(gameState, targe
 		if (dist >= range*range)
 			return;
 	}
-	var index = gameState.ai.accessibility.getAccessValue(target.position());
-	var garrisonManager = gameState.ai.HQ.garrisonManager;
-	var garrisonArrowClasses = target.getGarrisonArrowClasses();
-	var units = gameState.getOwnUnits().filter(function (ent) { return MatchesClassList(garrisonArrowClasses, ent.classes()); }).filterNearest(target.position());
+	let index = gameState.ai.accessibility.getAccessValue(target.position());
+	let garrisonManager = gameState.ai.HQ.garrisonManager;
+	let garrisonArrowClasses = target.getGarrisonArrowClasses();
+	let units = gameState.getOwnUnits().filter(ent => MatchesClassList(garrisonArrowClasses, ent.classes())).filterNearest(target.position());
 	for (let ent of units.values())
 	{
 		if (garrisonManager.numberOfGarrisonedUnits(target) >= minGarrison)
@@ -505,7 +616,7 @@ m.DefenseManager.prototype.garrisonRangedUnitsInside = function(gameState, targe
 			continue;
 		if (ent.getMetadata(PlayerID, "plan") !== undefined && ent.getMetadata(PlayerID, "plan") !== -1)
 		{
-			var subrole = ent.getMetadata(PlayerID, "subrole");
+			let subrole = ent.getMetadata(PlayerID, "subrole");
 			if (subrole && (subrole === "completing" || subrole === "walking" || subrole === "attacking")) 
 				continue;
 		}
@@ -515,7 +626,7 @@ m.DefenseManager.prototype.garrisonRangedUnitsInside = function(gameState, targe
 	}
 };
 
-// garrison a attacked siege ranged unit inside the nearest fortress
+/** garrison a attacked siege ranged unit inside the nearest fortress */
 m.DefenseManager.prototype.garrisonSiegeUnit = function(gameState, unit)
 {
 	let distmin = Math.min();
@@ -529,7 +640,7 @@ m.DefenseManager.prototype.garrisonSiegeUnit = function(gameState, unit)
 			return;
 		if (ent.hitpoints() < ent.garrisonEjectHealth() * ent.maxHitpoints())
 			return;
-		var entAccess = ent.getMetadata(PlayerID, "access");
+		let entAccess = ent.getMetadata(PlayerID, "access");
 		if (!entAccess)
 		{
 			entAccess = gameState.ai.accessibility.getAccessValue(ent.position());
@@ -547,7 +658,7 @@ m.DefenseManager.prototype.garrisonSiegeUnit = function(gameState, unit)
 		garrisonManager.garrison(gameState, unit, nearest, "protection");
 };
 
-// garrison a hurt unit inside the nearest healing structure
+/** garrison a hurt unit inside the nearest healing structure */
 m.DefenseManager.prototype.garrisonUnitForHealing = function(gameState, unit)
 {
 	let distmin = Math.min();
@@ -581,11 +692,26 @@ m.DefenseManager.prototype.garrisonUnitForHealing = function(gameState, unit)
 		garrisonManager.garrison(gameState, unit, nearest, "protection");
 };
 
+/**
+ * Be more inclined to help an ally attacked by several enemies
+ */
+m.DefenseManager.prototype.GetCooperationLevel = function(ent)
+{
+	let ally = ent.owner();
+	let cooperation = this.Config.personality.cooperative;
+	if (this.attackedAllies[ally] && this.attackedAllies[ally] > 1)
+		cooperation += 0.2 * (this.attackedAllies[ally] - 1);
+	return cooperation;
+};
+
 m.DefenseManager.prototype.Serialize = function()
 {
 	let properties = {
 		"targetList" : this.targetList,
-		"armyMergeSize": this.armyMergeSize
+		"armyMergeSize": this.armyMergeSize,
+		"attackingUnits": this.attackingUnits,
+		"attackingArmies": this.attackingArmies,
+		"attackedAllies": this.attackedAllies
 	};
 
 	let armies = [];
