@@ -15,14 +15,16 @@ m.DiplomacyManager = function(Config)
 	this.nextTributeRequest.set("all", 240);
 };
 
-// Check if any allied needs help (tribute) and sent it if we have enough resource
-// or ask for a tribute if we are in need and one ally can help
+/**
+ * Check if any allied needs help (tribute) and sent it if we have enough resource
+ * or ask for a tribute if we are in need and one ally can help
+ */
 m.DiplomacyManager.prototype.tributes = function(gameState)
 {
 	this.nextTributeUpdate = gameState.ai.elapsedTime + 30;
-	var totalResources = gameState.getResources();
-	var availableResources = gameState.ai.queueManager.getAvailableResources(gameState);
-	var mostNeeded;
+	let totalResources = gameState.getResources();
+	let availableResources = gameState.ai.queueManager.getAvailableResources(gameState);
+	let mostNeeded;
 	for (let i = 1; i < gameState.sharedScript.playersData.length; ++i)
 	{
 		if (i === PlayerID || !gameState.isPlayerAlly(i) || gameState.ai.HQ.attackManager.defeated[i])
@@ -71,7 +73,7 @@ m.DiplomacyManager.prototype.tributes = function(gameState)
 			API3.warn("Tribute " + uneval(tribute) + " sent to player " + i);
 		if (this.Config.chat)
 			m.chatSentTribute(gameState, i);
-		Engine.PostCommand(PlayerID, {"type": "tribute", "player": i, "amounts": tribute});
+		Engine.PostCommand(PlayerID, { "type": "tribute", "player": i, "amounts": tribute });
 	}
 };
 
@@ -91,7 +93,7 @@ m.DiplomacyManager.prototype.checkEvents = function (gameState, events)
 			else
 				tributes += 2*evt.amounts[key];
 		}
-		this.Config.personality.cooperative = Math.min(1, this.Config.personality.cooperative + 0.0002 * tributes);
+		this.Config.personality.cooperative = Math.min(1, this.Config.personality.cooperative + 0.0001 * tributes);
 	}
 
 	for (let evt of events.Attacked)
