@@ -17,6 +17,32 @@ m.GarrisonManager = function()
 
 m.GarrisonManager.prototype.update = function(gameState, events)
 {
+	// First check for possible upgrade of a structure
+	for (let evt of events.EntityRenamed)
+	{
+		for (let id of this.holders.keys())
+		{
+			if (id !== evt.entity)
+				continue;
+			let list = this.holders.get(id);
+			this.holders.delete(id);
+			this.holders.set(evt.newentity, list);
+		}
+		for (let id of this.decayingStructures.keys())
+		{
+			if (id !== evt.entity)
+				continue;
+			this.decayingStructures.delete(id);
+			if (this.decayingStructures.has(evt.newentity))
+				continue;
+			let ent = gameState.getEntityById(evt.newentity);
+			if (!ent || !ent.territoryDecayRate() || !ent.garrisonRegenRate())
+				continue;
+			let gmin = Math.ceil((ent.territoryDecayRate() - ent.defaultRegenRate()) / ent.garrisonRegenRate());
+			this.decayingStructures.set(evt.newentity, gmin);
+		}
+	}
+
 	for (let [id, list] of this.holders.entries())
 	{
 		let holder = gameState.getEntityById(id);
@@ -147,7 +173,7 @@ m.GarrisonManager.prototype.numberOfGarrisonedUnits = function(holder)
 	if (!this.holders.has(holder.id()))
 		return holder.garrisoned().length;
 
-	return (holder.garrisoned().length + this.holders.get(holder.id()).length);
+	return holder.garrisoned().length + this.holders.get(holder.id()).length;
 };
 
 // This is just a pre-garrison state, while the entity walk to the garrison holder
@@ -163,7 +189,7 @@ m.GarrisonManager.prototype.garrison = function(gameState, ent, holder, type)
 	{
 		warn("garrison unit " + ent.genericName() + " in " + holder.genericName() + " with type " + type);
 		warn(" we try to garrison a unit with plan " + ent.getMetadata(PlayerID, "plan") + " and role " + ent.getMetadata(PlayerID, "role") +
-		     " and subrole " +  ent.getMetadata(PlayerID, "subrole") + " and transport " +  ent.getMetadata(PlayerID, "transport"));
+		     " and subrole " + ent.getMetadata(PlayerID, "subrole") + " and transport " + ent.getMetadata(PlayerID, "transport"));
 	}
 
 	if (ent.getMetadata(PlayerID, "plan") !== undefined)
@@ -207,12 +233,14 @@ m.GarrisonManager.prototype.keepGarrisoned = function(ent, holder, enemiesAround
 	default:
 		if (ent.getMetadata(PlayerID, "onBoard") === "onBoard")  // transport is not (yet ?) managed by garrisonManager 
 			return true;
-		warn("unknown type in garrisonManager " + ent.getMetadata(PlayerID, "garrisonType"));
+		API3.warn("unknown type in garrisonManager " + ent.getMetadata(PlayerID, "garrisonType") +
+			  " for " + ent.id() + " inside " + holder.id());
+		ent.setMetadata(PlayerID, "garrisonType", "protection");
 		return true;
 	}
 };
 
-// Add this holder in the list managed by the garrisonManager
+/** Add this holder in the list managed by the garrisonManager */
 m.GarrisonManager.prototype.registerHolder = function(gameState, holder)
 {
 	if (this.holders.has(holder.id()))    // already registered
@@ -221,9 +249,11 @@ m.GarrisonManager.prototype.registerHolder = function(gameState, holder)
 	holder.setMetadata(PlayerID, "holderTimeUpdate", gameState.ai.elapsedTime);
 };
 
-// Garrison units in decaying structures to stop their decay
-// do it only for structures useful for defense, except if we are expanding (justCaptured=true)
-// in which case we also do it for structures useful for unit trainings (TODO only Barracks are done)
+/**
+ * Garrison units in decaying structures to stop their decay
+ * do it only for structures useful for defense, except if we are expanding (justCaptured=true)
+ * in which case we also do it for structures useful for unit trainings (TODO only Barracks are done)
+ */
 m.GarrisonManager.prototype.addDecayingStructure = function(gameState, entId, justCaptured)
 {
 	if (this.decayingStructures.has(entId))
