@@ -36,13 +36,13 @@ m.QueueManager = function(Config, queues)
 		this.accounts[q] = new API3.Resources();
 		this.queueArrays.push([q, this.queues[q]]);
 	}
-	var priorities = this.priorities;
+	let priorities = this.priorities;
 	this.queueArrays.sort((a,b) => priorities[b[0]] - priorities[a[0]]);
 };
 
 m.QueueManager.prototype.getAvailableResources = function(gameState)
 {
-	var resources = gameState.getResources();
+	let resources = gameState.getResources();
 	for (let key in this.queues)
 		resources.subtract(this.accounts[key]);
 	return resources;
@@ -50,7 +50,7 @@ m.QueueManager.prototype.getAvailableResources = function(gameState)
 
 m.QueueManager.prototype.getTotalAccountedResources = function()
 {
-	var resources = new API3.Resources();
+	let resources = new API3.Resources();
 	for (let key in this.queues)
 		resources.add(this.accounts[key]);
 	return resources;
@@ -63,7 +63,7 @@ m.QueueManager.prototype.currentNeeds = function(gameState)
 	for (let q of this.queueArrays)
 	{
 		let queue = q[1];
-		if (!queue.length() || !queue.plans[0].isGo(gameState))
+		if (!queue.hasQueuedUnits() || !queue.plans[0].isGo(gameState))
 			continue;
 		let costs = queue.plans[0].getCost();
 		needed.add(costs);
@@ -80,20 +80,30 @@ m.QueueManager.prototype.currentNeeds = function(gameState)
 // TODO: many things.
 m.QueueManager.prototype.wantedGatherRates = function(gameState)
 {
-	if (gameState.ai.playedTurn == 0)
+	// default values for first turn when we have not yet set our queues.
+	if (gameState.ai.playedTurn === 0)
 	{
-		// default values for first turn when we have not yet set our queues.
-		return { "food": 10, "wood": 10, "stone": 0, "metal": 0 };
+		let ret = {};
+		for (let res of gameState.sharedScript.resourceList)
+			ret[res] = (res === "food" || res === "wood" ) ? 10 : 0;
+		return ret;
 	}
+
 	// get out current resources, not removing accounts.
-	var current = gameState.getResources();
+	let current = gameState.getResources();
 	// short queue is the first item of a queue, assumed to be ready in 30s
 	// medium queue is the second item of a queue, assumed to be ready in 60s
 	// long queue contains the isGo=false items, assumed to be ready in 300s
-	var totalShort = { "food": 200, "wood": 200, "stone": 100, "metal": 100 };
-	var totalMedium = { "food": 0, "wood": 0, "stone": 0, "metal": 0 };
-	var totalLong = { "food": 0, "wood": 0, "stone": 0, "metal": 0 };
-	var total;
+	let totalShort = {};
+	let totalMedium = {};
+	let totalLong = {};
+	for (let res of gameState.sharedScript.resourceList)
+	{
+		totalShort[res] = (res === "food" || res === "wood" ) ? 200 : 100;
+		totalMedium[res] = 0;
+		totalLong[res] = 0;
+	}
+	let total;
 	//queueArrays because it's faster.
 	for (let q of this.queueArrays)
 	{
@@ -107,7 +117,7 @@ m.QueueManager.prototype.wantedGatherRates = function(gameState)
 			let cost = queue.plans[j].getCost();
 			if (queue.plans[j].isGo(gameState))
 			{
-				if (j == 0)
+				if (j === 0)
 					total = totalShort;
 				else
 					total = totalMedium;
@@ -121,25 +131,25 @@ m.QueueManager.prototype.wantedGatherRates = function(gameState)
 		}
 	}
 	// global rates
-	var rates = { "food": 0, "wood": 0, "stone": 0, "metal": 0 };
-	var diff;
-	for (let type in rates)
+	let rates = {};
+	let diff;
+	for (let res of gameState.sharedScript.resourceList)
 	{
-		if (current[type] > 0)
+		if (current[res] > 0)
 		{
-			diff = Math.min(current[type], totalShort[type]);
-			totalShort[type] -= diff;
-			current[type] -= diff;
-			if (current[type] > 0)
+			diff = Math.min(current[res], totalShort[res]);
+			totalShort[res] -= diff;
+			current[res] -= diff;
+			if (current[res] > 0)
 			{
-				diff = Math.min(current[type], totalMedium[type]);
-				totalMedium[type] -= diff;
-				current[type] -= diff;
-				if (current[type] > 0)
-					totalLong[type] -= Math.min(current[type], totalLong[type]);
+				diff = Math.min(current[res], totalMedium[res]);
+				totalMedium[res] -= diff;
+				current[res] -= diff;
+				if (current[res] > 0)
+					totalLong[res] -= Math.min(current[res], totalLong[res]);
 			}
 		}
-		rates[type] = totalShort[type]/30 + totalMedium[type]/60 + totalLong[type]/300;
+		rates[res] = totalShort[res]/30 + totalMedium[res]/60 + totalLong[res]/300;
 	}
 
 	return rates;
@@ -147,24 +157,23 @@ m.QueueManager.prototype.wantedGatherRates = function(gameState)
 
 m.QueueManager.prototype.printQueues = function(gameState)
 {
-	var numWorkers = 0;
+	let numWorkers = 0;
 	gameState.getOwnUnits().forEach (function (ent) {
-		if (ent.getMetadata(PlayerID, "role") == "worker" && ent.getMetadata(PlayerID, "plan") == undefined)
+		if (ent.getMetadata(PlayerID, "role") === "worker" && ent.getMetadata(PlayerID, "plan") === undefined)
 			numWorkers++;
 	});
 	API3.warn("---------- QUEUES ------------ with pop " + gameState.getPopulation() + " and workers " + numWorkers);
 	for (let i in this.queues)
 	{
-		let qStr = "";
 		let q = this.queues[i];
-		if (q.length() > 0)
+		if (q.hasQueuedUnits())
 		{
 			API3.warn(i + ": ( with priority " + this.priorities[i] +" and accounts " + uneval(this.accounts[i]) +")");
 			API3.warn(" while maxAccountWanted(0.6) is " + uneval(q.maxAccountWanted(gameState, 0.6)));
 		}
 		for (let plan of q.plans)
 		{
-			qStr = "     " + plan.type + " ";
+			let qStr = "     " + plan.type + " ";
 			if (plan.number)
 				qStr += "x" + plan.number;
 			qStr += "   isGo " + plan.isGo(gameState);
@@ -193,7 +202,7 @@ m.QueueManager.prototype.clear = function()
  */
 m.QueueManager.prototype.setAccounts = function(gameState, cost, i)
 {
-	var available = this.getAvailableResources(gameState);
+	let available = this.getAvailableResources(gameState);
 	for (let res of this.accounts[i].types)
 	{
 		if (this.accounts[i][res] >= cost[res])
@@ -222,7 +231,7 @@ m.QueueManager.prototype.transferAccounts = function(cost, i, j)
  */
 m.QueueManager.prototype.distributeResources = function(gameState)
 {
-	var availableRes = this.getAvailableResources(gameState);
+	let availableRes = this.getAvailableResources(gameState);
 	for (let res of availableRes.types)
 	{
 		if (availableRes[res] < 0)    // rescale the accounts if we've spent resources already accounted (e.g. by bartering)
@@ -259,7 +268,7 @@ m.QueueManager.prototype.distributeResources = function(gameState)
 		{
 			// returns exactly the correct amount, ie 0 if we're not go.
 			let queueCost = this.queues[j].maxAccountWanted(gameState, 0.6);
-			if (this.queues[j].length() > 0 && this.accounts[j][res] < queueCost[res] && !this.queues[j].paused)
+			if (this.queues[j].hasQueuedUnits() && this.accounts[j][res] < queueCost[res] && !this.queues[j].paused)
 			{
 				// adding us to the list of queues that need an update.
 				tempPrio[j] = this.priorities[j];
@@ -316,7 +325,7 @@ m.QueueManager.prototype.switchResource = function(gameState, res)
 	// TODO: this isn't perfect compression.
 	for (let j in this.queues)
 	{
-		if (this.queues[j].length() === 0 || this.queues[j].paused)
+		if (!this.queues[j].hasQueuedUnits() || this.queues[j].paused)
 			continue;
 
 		let queue = this.queues[j];
@@ -352,18 +361,22 @@ m.QueueManager.prototype.startNextItems = function(gameState)
 	{
 		let name = q[0];
 		let queue = q[1];
-		if (queue.length() > 0 && !queue.paused)
+		if (queue.hasQueuedUnits() && !queue.paused)
 		{
 			let item = queue.getNext();
 			if (this.accounts[name].canAfford(item.getCost()) && item.canStart(gameState))
 			{
-				this.finishingTime = gameState.ai.elapsedTime;
-				this.accounts[name].subtract(item.getCost());
-				queue.startNext(gameState);
-				queue.switched = 0;
+				// canStart may update the cost because of the costMultiplier so we must check it again
+				if (this.accounts[name].canAfford(item.getCost()))
+				{
+					this.finishingTime = gameState.ai.elapsedTime;
+					this.accounts[name].subtract(item.getCost());
+					queue.startNext(gameState);
+					queue.switched = 0;
+				}
 			}
 		}
-		else if (queue.length() === 0)
+		else if (!queue.hasQueuedUnits())
 		{
 			this.accounts[name].reset();
 			queue.switched = 0;
@@ -402,15 +415,8 @@ m.QueueManager.prototype.update = function(gameState)
 // Recovery system: if short of workers after an attack, pause (and reset) some queues to favor worker training
 m.QueueManager.prototype.checkPausedQueues = function(gameState)
 {
-	let numWorkers = gameState.getOwnEntitiesByRole("worker", true).length;
-	gameState.getOwnTrainingFacilities().forEach(function(ent) {
-		ent.trainingQueue().forEach(function(item) {
-			if (item.metadata && item.metadata.role && item.metadata.role == "worker")
-				numWorkers += item.count;
-		});
-	});
-
-	var workersMin = Math.min(Math.max(12, 24 * this.Config.popScaling), this.Config.Economy.popForTown);
+	let numWorkers = gameState.countOwnEntitiesAndQueuedWithRole("worker");
+	let workersMin = Math.min(Math.max(12, 24 * this.Config.popScaling), this.Config.Economy.popForTown);
 	for (let q in this.queues)
 	{
 		let toBePaused = false;
@@ -429,13 +435,16 @@ m.QueueManager.prototype.checkPausedQueues = function(gameState)
 		if (toBePaused)
 		{
 			if (q === "field" && gameState.ai.HQ.needFarm &&
-				gameState.getOwnStructures().filter(API3.Filters.byClass("Field")).length === 0)
+				!gameState.getOwnStructures().filter(API3.Filters.byClass("Field")).hasEntities())
+				toBePaused = false;
+			if (q === "corral" && gameState.ai.HQ.needCorral &&
+				!gameState.getOwnStructures().filter(API3.Filters.byClass("Field")).hasEntities())
 				toBePaused = false;
 			if (q === "dock" && gameState.ai.HQ.needFish &&
-				gameState.getOwnStructures().filter(API3.Filters.byClass("Dock")).length === 0)
+				!gameState.getOwnStructures().filter(API3.Filters.byClass("Dock")).hasEntities())
 				toBePaused = false;
 			if (q === "ships" && gameState.ai.HQ.needFish &&
-				gameState.ai.HQ.navalManager.ships.filter(API3.Filters.byClass("FishingBoat")).length === 0)
+				!gameState.ai.HQ.navalManager.ships.filter(API3.Filters.byClass("FishingBoat")).hasEntities())
 				toBePaused = false;
 		}
 
@@ -512,7 +521,7 @@ m.QueueManager.prototype.addQueue = function(queueName, priority)
 	this.queueArrays = [];
 	for (let q in this.queues)
 		this.queueArrays.push([q, this.queues[q]]);
-	var priorities = this.priorities;
+	let priorities = this.priorities;
 	this.queueArrays.sort((a,b) => priorities[b[0]] - priorities[a[0]]);
 };
 
@@ -528,7 +537,7 @@ m.QueueManager.prototype.removeQueue = function(queueName)
 	this.queueArrays = [];
 	for (let q in this.queues)
 		this.queueArrays.push([q, this.queues[q]]);
-	var priorities = this.priorities;
+	let priorities = this.priorities;
 	this.queueArrays.sort((a,b) => priorities[b[0]] - priorities[a[0]]);
 };
 
@@ -543,14 +552,14 @@ m.QueueManager.prototype.changePriority = function(queueName, newPriority)
 		API3.warn(">>> Priority of queue " + queueName + " changed from " + this.priorities[queueName] + " to " + newPriority);
 	if (this.queues[queueName] !== undefined)
 		this.priorities[queueName] = newPriority;
-	var priorities = this.priorities;
+	let priorities = this.priorities;
 	this.queueArrays.sort((a,b) => priorities[b[0]] - priorities[a[0]]);
 };
 
 m.QueueManager.prototype.Serialize = function()
 {
-	var accounts = {};
-	var queues = {};
+	let accounts = {};
+	let queues = {};
 	for (let q in this.queues)
 	{
 		queues[q] = this.queues[q].Serialize();
