@@ -1,8 +1,10 @@
 var PETRA = function(m)
 {
 
-// Defines a construction plan, ie a building.
-// We'll try to fing a good position if non has been provided
+/**
+ * Defines a construction plan, ie a building.
+ * We'll try to fing a good position if non has been provided
+ */
 
 m.ConstructionPlan = function(gameState, type, metadata, position)
 {
@@ -18,9 +20,6 @@ m.ConstructionPlan = function(gameState, type, metadata, position)
 
 m.ConstructionPlan.prototype = Object.create(m.QueuePlan.prototype);
 
-// checks other than resource ones.
-// TODO: change this.
-// TODO: if there are specific requirements here, maybe try to do them?
 m.ConstructionPlan.prototype.canStart = function(gameState)
 {
 	if (gameState.ai.HQ.turnCache.buildingBuilt)   // do not start another building if already one this turn
@@ -32,27 +31,27 @@ m.ConstructionPlan.prototype.canStart = function(gameState)
 	if (this.template.requiredTech() && !gameState.isResearched(this.template.requiredTech()))
 		return false;
 
-	return (gameState.findBuilders(this.type).length > 0);
+	return gameState.findBuilder(this.type) !== undefined;
 };
 
 m.ConstructionPlan.prototype.start = function(gameState)
 {
 	Engine.ProfileStart("Building construction start");
 
-	var builders = gameState.findBuilders(this.type).toEntityArray();
-
 	// We don't care which builder we assign, since they won't actually
 	// do the building themselves - all we care about is that there is
-	// some unit that can start the foundation
+	// at least one unit that can start the foundation
+	let builder = gameState.findBuilder(this.type);
 
-	var pos = this.findGoodPosition(gameState);
+	let pos = this.findGoodPosition(gameState);
 	if (!pos)
 	{
 		gameState.ai.HQ.stopBuild(gameState, this.type);
 		Engine.ProfileStop();
 		return;
 	}
-	else if (this.metadata && this.metadata.expectedGain)
+
+	if (this.metadata && this.metadata.expectedGain)
 	{
 		// Check if this market is still worth building (others may have been built making it useless)
 		let tradeManager = gameState.ai.HQ.tradeManager;
@@ -78,38 +77,34 @@ m.ConstructionPlan.prototype.start = function(gameState)
 	if (this.template.buildCategory() === "Dock")
 	{
 		// adjust a bit the position if needed
-		// TODO we would need groundLevel and waterLevel to do it properly
 		let cosa = Math.cos(pos.angle);
 		let sina = Math.sin(pos.angle);
 		let shiftMax = gameState.ai.HQ.territoryMap.cellSize;
 		for (let shift = 0; shift <= shiftMax; shift += 2)
 		{
-			builders[0].construct(this.type, pos.x-shift*sina, pos.z-shift*cosa, pos.angle, this.metadata);
+			builder.construct(this.type, pos.x-shift*sina, pos.z-shift*cosa, pos.angle, this.metadata);
 			if (shift > 0)
-				builders[0].construct(this.type, pos.x+shift*sina, pos.z+shift*cosa, pos.angle, this.metadata);
+				builder.construct(this.type, pos.x+shift*sina, pos.z+shift*cosa, pos.angle, this.metadata);
 		}
 	}
 	else if (pos.xx === undefined || (pos.x == pos.xx && pos.z == pos.zz))
-		builders[0].construct(this.type, pos.x, pos.z, pos.angle, this.metadata);
+		builder.construct(this.type, pos.x, pos.z, pos.angle, this.metadata);
 	else // try with the lowest, move towards us unless we're same
 	{
 		for (let step = 0; step <= 1; step += 0.2)
-			builders[0].construct(this.type, (step*pos.x + (1-step)*pos.xx), (step*pos.z + (1-step)*pos.zz),
+			builder.construct(this.type, step*pos.x + (1-step)*pos.xx, step*pos.z + (1-step)*pos.zz,
 				pos.angle, this.metadata);
 	}
 	this.onStart(gameState);
 	Engine.ProfileStop();
 
-	// TODO should have a ConstructionStarted even in case the construct order fails
 	if (this.metadata && this.metadata.proximity)
 		gameState.ai.HQ.navalManager.createTransportIfNeeded(gameState, this.metadata.proximity, [pos.x, pos.z], this.metadata.access);
 };
 
-// TODO for dock, we should allow building them outside territory, and we should check that we are along the right sea
 m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 {
-
-	var template = this.template;
+	let template = this.template;
 
 	if (template.buildCategory() === "Dock")
 		return this.findDockPosition(gameState);
@@ -126,7 +121,7 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 			return { "x": pos[0], "z": pos[1], "angle": 3*Math.PI/4, "base": this.metadata.base };
 		}
 	}
-	
+
 	if (!this.position)
 	{
 		if (template.hasClass("CivCentre"))
@@ -142,20 +137,19 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 
 			if (pos)
 				return { "x": pos[0], "z": pos[1], "angle": 3*Math.PI/4, "base": 0 };
-			else
-				return false;
+			return false;
 		}
 		else if (template.hasClass("DefenseTower") || template.hasClass("Fortress") || template.hasClass("ArmyCamp"))
 		{
 			let pos = gameState.ai.HQ.findDefensiveLocation(gameState, template);
-
 			if (pos)
 				return { "x": pos[0], "z": pos[1], "angle": 3*Math.PI/4, "base": pos[2] };
-			else if (template.hasClass("DefenseTower") || gameState.civ() === "mace" || gameState.civ() === "maur" ||
+
+			if (template.hasClass("DefenseTower") || gameState.civ() === "mace" || gameState.civ() === "maur" ||
 				gameState.countEntitiesByType(gameState.applyCiv("structures/{civ}_fortress"), true) > 0 ||
 				gameState.countEntitiesByType(gameState.applyCiv("structures/{civ}_army_camp"), true) > 0)
 				return false;
-			// if this fortress is our first siege unit builder, just try the standard placement as we want siege units		    
+			// if this fortress is our first siege unit builder, just try the standard placement as we want siege units
 		}
 		else if (template.hasClass("Market"))	// Docks (i.e. NavalMarket) are done before
 		{
@@ -174,10 +168,10 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 
 	// Compute each tile's closeness to friendly structures:
 
-	var placement = new API3.Map(gameState.sharedScript, "territory");
-	var cellSize = placement.cellSize; // size of each tile
-	
-	var alreadyHasHouses = false;
+	let placement = new API3.Map(gameState.sharedScript, "territory");
+	let cellSize = placement.cellSize; // size of each tile
+
+	let alreadyHasHouses = false;
 
 	if (this.position)	// If a position was specified then place the building as close to it as possible
 	{
@@ -199,7 +193,7 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 		else
 		{
 			for (let j = 0; j < placement.map.length; ++j)
-				if (gameState.ai.HQ.basesMap.map[j] != 0)
+				if (gameState.ai.HQ.basesMap.map[j] !== 0)
 					placement.map[j] = 45;
 		}
 
@@ -212,7 +206,7 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 
 				if (ent.resourceDropsiteTypes() && ent.resourceDropsiteTypes().indexOf("food") !== -1)
 				{
-					if (template.hasClass("Field"))
+					if (template.hasClass("Field") || template.hasClass("Corral"))
 						placement.addInfluence(x, z, 80/cellSize, 50);
 					else // If this is not a field add a negative influence because we want to leave this area for fields
 						placement.addInfluence(x, z, 80/cellSize, -20);
@@ -227,21 +221,22 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 					else if (!ent.hasClass("StoneWall") || ent.hasClass("Gates"))
 						placement.addInfluence(x, z, 60/cellSize, -40);   // and further away from other stuffs
 				}
-				else if (template.hasClass("Farmstead") && (!ent.hasClass("Field") &&
+				else if (template.hasClass("Farmstead") && (!ent.hasClass("Field") && !ent.hasClass("Corral") &&
 					(!ent.hasClass("StoneWall") || ent.hasClass("Gates"))))
 					placement.addInfluence(x, z, 100/cellSize, -25);       // move farmsteads away to make room (StoneWall test needed for iber)
 				else if (template.hasClass("GarrisonFortress") && ent.genericName() == "House")
 					placement.addInfluence(x, z, 120/cellSize, -50);
 				else if (template.hasClass("Military"))
 					placement.addInfluence(x, z, 40/cellSize, -40);
+				else if (template.genericName() === "Rotary Mill" && ent.hasClass("Field"))
+					placement.addInfluence(x, z, 60/cellSize, 40);
 			});
 		}
-
 		if (template.hasClass("Farmstead"))
 		{
 			for (let j = 0; j < placement.map.length; ++j)
 			{
-				let value = placement.map[j] - (gameState.sharedScript.resourceMaps.wood.map[j])/3;
+				let value = placement.map[j] - gameState.sharedScript.resourceMaps.wood.map[j]/3;
 				placement.map[j] = value >= 0 ? value : 0;
 				if (gameState.ai.HQ.borderMap.map[j] > 0)
 					placement.map[j] /= 2;	// we need space around farmstead, so disfavor map border
@@ -249,11 +244,11 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 		}
 	}
 
-	// requires to be inside our territory, and inside our base territory if required
+	// Requires to be inside our territory, and inside our base territory if required
 	// and if our first market, put it on border if possible to maximize distance with next market
-	var favorBorder = template.hasClass("BarterMarket");
-	var disfavorBorder = (gameState.currentPhase() > 1 && !template.hasDefensiveFire());
-	var preferredBase = (this.metadata && this.metadata.preferredBase);
+	let favorBorder = template.hasClass("BarterMarket");
+	let disfavorBorder = gameState.currentPhase() > 1 && !template.hasDefensiveFire();
+	let preferredBase = this.metadata && this.metadata.preferredBase;
 	if (this.metadata && this.metadata.base !== undefined)
 	{
 		let base = this.metadata.base;
@@ -263,7 +258,7 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 				placement.map[j] = 0;
 			else if (favorBorder && gameState.ai.HQ.borderMap.map[j] > 0)
 				placement.map[j] += 50;
-			else if (disfavorBorder && gameState.ai.HQ.borderMap.map[j] == 0 && placement.map[j] > 0)
+			else if (disfavorBorder && gameState.ai.HQ.borderMap.map[j] === 0 && placement.map[j] > 0)
 				placement.map[j] += 10;
 
 			if (placement.map[j] > 0)
@@ -279,11 +274,11 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 	{
 		for (let j = 0; j < placement.map.length; ++j)
 		{
-			if (gameState.ai.HQ.basesMap.map[j] == 0)
+			if (gameState.ai.HQ.basesMap.map[j] === 0)
 				placement.map[j] = 0;
 			else if (favorBorder && gameState.ai.HQ.borderMap.map[j] > 0)
 				placement.map[j] += 50;
-			else if (disfavorBorder && gameState.ai.HQ.borderMap.map[j] == 0 && placement.map[j] > 0)
+			else if (disfavorBorder && gameState.ai.HQ.borderMap.map[j] === 0 && placement.map[j] > 0)
 				placement.map[j] += 10;
 
 			if (preferredBase && gameState.ai.HQ.basesMap.map[j] == this.metadata.preferredBase)
@@ -305,10 +300,10 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 	// note: not for houses and dropsites who ought to be closer to either each other or a resource.
 	// also not for fields who can be stacked quite a bit
 
-	var obstructions = m.createObstructionMap(gameState, 0, template);
+	let obstructions = m.createObstructionMap(gameState, 0, template);
 	//obstructions.dumpIm(template.buildCategory() + "_obstructions.png");
 
-	var radius = 0;
+	let radius = 0;
 	if (template.hasClass("Fortress") || this.type === gameState.applyCiv("structures/{civ}_siege_workshop") ||
 		this.type === gameState.applyCiv("structures/{civ}_elephant_stables"))
 		radius = Math.floor((template.obstructionRadius() + 12) / obstructions.cellSize);
@@ -317,26 +312,26 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 	else
 		radius = Math.ceil((template.obstructionRadius() + 0.5) / obstructions.cellSize);
 
-	var bestTile;
-	var bestVal;
+	let bestTile;
+	let bestVal;
 	if (template.hasClass("House") && !alreadyHasHouses)
 	{
 		// try to get some space to place several houses first
 		bestTile = placement.findBestTile(3*radius, obstructions);
 		bestVal = bestTile[1];
 	}
-	
+
 	if (bestVal === undefined || bestVal === -1)
 	{
 		bestTile = placement.findBestTile(radius, obstructions);
 		bestVal = bestTile[1];
 	}
-	var bestIdx = bestTile[0];
+	let bestIdx = bestTile[0];
 
 	if (bestVal <= 0)
 		return false;
 
-	let x = ((bestIdx % obstructions.width) + 0.5) * obstructions.cellSize;
+	let x = (bestIdx % obstructions.width + 0.5) * obstructions.cellSize;
 	let z = (Math.floor(bestIdx / obstructions.width) + 0.5) * obstructions.cellSize;
 
 	if (template.hasClass("House") || template.hasClass("Field") || template.resourceDropsiteTypes() !== undefined)
@@ -344,7 +339,7 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
 		let secondBest = obstructions.findNearestObstructed(bestIdx, radius);
 		if (secondBest >= 0)
 		{
-			x = ((secondBest % obstructions.width) + 0.5) * obstructions.cellSize;
+			x = (secondBest % obstructions.width + 0.5) * obstructions.cellSize;
 			z = (Math.floor(secondBest / obstructions.width) + 0.5) * obstructions.cellSize;
 		}
 	}
@@ -361,38 +356,38 @@ m.ConstructionPlan.prototype.findGoodPosition = function(gameState)
  */
 m.ConstructionPlan.prototype.findDockPosition = function(gameState)
 {
-	var template = this.template;
-	var territoryMap = gameState.ai.HQ.territoryMap;
+	let template = this.template;
+	let territoryMap = gameState.ai.HQ.territoryMap;
 
-	var obstructions = m.createObstructionMap(gameState, 0, template);
+	let obstructions = m.createObstructionMap(gameState, 0, template);
 	//obstructions.dumpIm(template.buildCategory() + "_obstructions.png");
 
-	var bestIdx;
-	var bestJdx;
-	var bestAngle;
-	var bestLand;
-	var bestWater;
-	var bestVal = -1;
-	var navalPassMap = gameState.ai.accessibility.navalPassMap;
+	let bestIdx;
+	let bestJdx;
+	let bestAngle;
+	let bestLand;
+	let bestWater;
+	let bestVal = -1;
+	let navalPassMap = gameState.ai.accessibility.navalPassMap;
 
-	var width = gameState.ai.HQ.territoryMap.width;
-	var cellSize = gameState.ai.HQ.territoryMap.cellSize;
+	let width = gameState.ai.HQ.territoryMap.width;
+	let cellSize = gameState.ai.HQ.territoryMap.cellSize;
 
-	var nbShips = gameState.ai.HQ.navalManager.transportShips.length;
-	var wantedLand = this.metadata && this.metadata.land ? this.metadata.land : null;
-	var wantedSea = this.metadata && this.metadata.sea ? this.metadata.sea : null;
-	var proxyAccess = this.metadata && this.metadata.proximity ? gameState.ai.accessibility.getAccessValue(this.metadata.proximity) : null;
+	let nbShips = gameState.ai.HQ.navalManager.transportShips.length;
+	let wantedLand = this.metadata && this.metadata.land ? this.metadata.land : null;
+	let wantedSea = this.metadata && this.metadata.sea ? this.metadata.sea : null;
+	let proxyAccess = this.metadata && this.metadata.proximity ? gameState.ai.accessibility.getAccessValue(this.metadata.proximity) : null;
 	if (nbShips === 0 && proxyAccess && proxyAccess > 1)
 	{
 		wantedLand = {};
 		wantedLand[proxyAccess] = true;
 	}
-	var dropsiteTypes = template.resourceDropsiteTypes();
-	var radius = Math.ceil(template.obstructionRadius() / obstructions.cellSize);
+	let dropsiteTypes = template.resourceDropsiteTypes();
+	let radius = Math.ceil(template.obstructionRadius() / obstructions.cellSize);
 
-	var halfSize = 0;    // used for dock angle
-	var halfDepth = 0;   // used by checkPlacement
-	var halfWidth = 0;   // used by checkPlacement
+	let halfSize = 0;    // used for dock angle
+	let halfDepth = 0;   // used by checkPlacement
+	let halfWidth = 0;   // used by checkPlacement
 	if (template.get("Footprint/Square"))
 	{
 		halfSize = Math.max(+template.get("Footprint/Square/@depth"), +template.get("Footprint/Square/@width")) / 2;
@@ -446,7 +441,7 @@ m.ConstructionPlan.prototype.findDockPosition = function(gameState)
 		if (bestIdx !== undefined && dist > bestVal + maxWater)
 			continue;
 
-		let x = ((i % obstructions.width) + 0.5) * obstructions.cellSize;
+		let x = (i % obstructions.width + 0.5) * obstructions.cellSize;
 		let z = (Math.floor(i / obstructions.width) + 0.5) * obstructions.cellSize;
 		let angle = this.getDockAngle(gameState, x, z, halfSize);
 		if (angle === false)
@@ -477,11 +472,11 @@ m.ConstructionPlan.prototype.findDockPosition = function(gameState)
 	if (!this.metadata.proximity && bestWater < 10 && gameState.currentPhase() == 1)
 		return false;
 
-	var x = ((bestIdx % obstructions.width) + 0.5) * obstructions.cellSize;
-	var z = (Math.floor(bestIdx / obstructions.width) + 0.5) * obstructions.cellSize;
+	let x = (bestIdx % obstructions.width + 0.5) * obstructions.cellSize;
+	let z = (Math.floor(bestIdx / obstructions.width) + 0.5) * obstructions.cellSize;
 
 	// Assign this dock to a base
-	var baseIndex = gameState.ai.HQ.basesMap.map[bestJdx];
+	let baseIndex = gameState.ai.HQ.basesMap.map[bestJdx];
 	if (!baseIndex)
 	{
 		for (let base of gameState.ai.HQ.baseManagers)
@@ -505,18 +500,18 @@ m.ConstructionPlan.prototype.findDockPosition = function(gameState)
 	return { "x": x, "z": z, "angle": bestAngle, "base": baseIndex, "access": bestLand };
 };
 
-// Algorithm taken from the function GetDockAngle in simulation/helpers/Commands.js
+/** Algorithm taken from the function GetDockAngle in simulation/helpers/Commands.js */
 m.ConstructionPlan.prototype.getDockAngle = function(gameState, x, z, size)
 {
-	var pos = gameState.ai.accessibility.gamePosToMapPos([x, z]);
-	var k = pos[0] + pos[1]*gameState.ai.accessibility.width;
-	var seaRef = gameState.ai.accessibility.navalPassMap[k];
+	let pos = gameState.ai.accessibility.gamePosToMapPos([x, z]);
+	let k = pos[0] + pos[1]*gameState.ai.accessibility.width;
+	let seaRef = gameState.ai.accessibility.navalPassMap[k];
 	if (seaRef < 2)
 		return false;
 	const numPoints = 16;
 	for (let dist = 0; dist < 4; ++dist)
 	{
-		var waterPoints = [];
+		let waterPoints = [];
 		for (let i = 0; i < numPoints; ++i)
 		{
 			let angle = (i/numPoints)*2*Math.PI;
@@ -536,9 +531,9 @@ m.ConstructionPlan.prototype.getDockAngle = function(gameState, x, z, size)
 		for (let i = 0; i < length; ++i)
 		{
 			let count = 0;
-			for (let j = 0; j < (length-1); ++j)
+			for (let j = 0; j < length-1; ++j)
 			{
-				if (((waterPoints[(i + j) % length]+1) % numPoints) == waterPoints[(i + j + 1) % length])
+				if ((waterPoints[(i + j) % length]+1) % numPoints == waterPoints[(i + j + 1) % length])
 					++count;
 				else
 					break;
@@ -555,7 +550,7 @@ m.ConstructionPlan.prototype.getDockAngle = function(gameState, x, z, size)
 				count = consec[c];
 			}
 		}
-		
+
 		// If we've found a shoreline, stop searching
 		if (count != numPoints-1)
 			return -((waterPoints[start] + consec[start]/2) % numPoints)/numPoints*2*Math.PI;
@@ -563,9 +558,11 @@ m.ConstructionPlan.prototype.getDockAngle = function(gameState, x, z, size)
 	return false;
 };
 
-// Algorithm taken from checkPlacement in simulation/components/BuildRestriction.js
-// to determine the special dock requirements
-// returns {"land": land index for this dock, "water": amount of water around this spot}
+/**
+ * Algorithm taken from checkPlacement in simulation/components/BuildRestriction.js
+ * to determine the special dock requirements
+ * returns {"land": land index for this dock, "water": amount of water around this spot}
+ */
 m.ConstructionPlan.prototype.checkDockPlacement = function(gameState, x, z, halfDepth, halfWidth, angle)
 {
 	let sz = halfDepth * Math.sin(angle);
@@ -633,12 +630,12 @@ const around = [ [ 1.0, 0.0], [ 0.87, 0.50], [ 0.50, 0.87], [ 0.0, 1.0], [-0.50,
 
 m.ConstructionPlan.prototype.isDockLocation = function(gameState, j, dimension, wantedLand, wantedSea)
 {
-	var width = gameState.ai.HQ.territoryMap.width;
-	var cellSize = gameState.ai.HQ.territoryMap.cellSize;
-	var dist = dimension + 2*cellSize;
+	let width = gameState.ai.HQ.territoryMap.width;
+	let cellSize = gameState.ai.HQ.territoryMap.cellSize;
+	let dist = dimension + 2*cellSize;
 
-	var x = (j%width + 0.5) * cellSize;
-	var z = (Math.floor(j/width) + 0.5) * cellSize;
+	let x = (j%width + 0.5) * cellSize;
+	let z = (Math.floor(j/width) + 0.5) * cellSize;
 	for (let a of around)
 	{
 		let pos = gameState.ai.accessibility.gamePosToMapPos([x + dist*a[0], z + dist*a[1]]);
@@ -672,16 +669,16 @@ m.ConstructionPlan.prototype.isDockLocation = function(gameState, j, dimension,
  */
 m.ConstructionPlan.prototype.getFrontierProximity = function(gameState, j)
 {
-	var territoryMap = gameState.ai.HQ.territoryMap;
+	let territoryMap = gameState.ai.HQ.territoryMap;
 	if (gameState.isPlayerAlly(territoryMap.getOwnerIndex(j)))
 		return 0;
 
-	var borderMap = gameState.ai.HQ.borderMap;
-	var width = territoryMap.width;
-	var step = Math.round(24 / territoryMap.cellSize);
-	var ix = j % width;
-	var iz = Math.floor(j / width);
-	var best = 5;
+	let borderMap = gameState.ai.HQ.borderMap;
+	let width = territoryMap.width;
+	let step = Math.round(24 / territoryMap.cellSize);
+	let ix = j % width;
+	let iz = Math.floor(j / width);
+	let best = 5;
 	for (let a of around)
 	{
 		for (let i = 1; i < 5; ++i)
@@ -707,9 +704,10 @@ m.ConstructionPlan.prototype.getFrontierProximity = function(gameState, j)
 	return best;
 };
 
-
-// get the sum of the resources (except food) around, inside a given radius
-// resources have a weight (1 if dist=0 and 0 if dist=size) doubled for wood
+/**
+ * get the sum of the resources (except food) around, inside a given radius
+ * resources have a weight (1 if dist=0 and 0 if dist=size) doubled for wood
+ */
 m.ConstructionPlan.prototype.getResourcesAround = function(gameState, types, i, radius)
 {
 	let resourceMaps = gameState.sharedScript.resourceMaps;
@@ -724,7 +722,7 @@ m.ConstructionPlan.prototype.getResourcesAround = function(gameState, types, i,
 	{
 		if (k === "food" || !resourceMaps[k])
 			continue;
-		let weigh0 = (k === "wood") ? 2 : 1;
+		let weigh0 = k === "wood" ? 2 : 1;
 		for (let dy = 0; dy <= size; ++dy)
 		{
 			let dxmax = size - dy;
@@ -736,23 +734,23 @@ m.ConstructionPlan.prototype.getResourcesAround = function(gameState, types, i,
 					let kx = ix + dx;
 					if (kx < 0 || kx >= w)
 						continue;
-					let ddx = (dx > 0) ? dx : -dx;
+					let ddx = dx > 0 ? dx : -dx;
 					let weight = weigh0 * (dxmax - ddx) / size;
 					total += weight * resourceMaps[k].map[kx + w * ky];
 					nbcell += weight;
 				}
 			}
-			if (dy == 0)
+			if (dy === 0)
 				continue;
 			ky = iy - dy;
-			if (ky  >= 0 && ky < w)
+			if (ky >= 0 && ky < w)
 			{
 				for (let dx = -dxmax; dx <= dxmax; ++dx)
 				{
 					let kx = ix + dx;
 					if (kx < 0 || kx >= w)
 						continue;
-					let ddx = (dx > 0) ? dx : -dx;
+					let ddx = dx > 0 ? dx : -dx;
 					let weight = weigh0 * (dxmax - ddx) / size;
 					total += weight * resourceMaps[k].map[kx + w * ky];
 					nbcell += weight;
@@ -760,7 +758,7 @@ m.ConstructionPlan.prototype.getResourcesAround = function(gameState, types, i,
 			}
 		}
 	}
-	return (nbcell ? (total / nbcell) : 0);
+	return nbcell ? total / nbcell : 0;
 };
 
 m.ConstructionPlan.prototype.Serialize = function()
