@@ -15,11 +15,11 @@ m.ResearchManager = function(Config)
  */
 m.ResearchManager.prototype.checkPhase = function(gameState, queues)
 {
-	if (queues.majorTech.length() !== 0)
+	if (queues.majorTech.hasQueuedUnits())
 		return;
 
-	var townPhase = gameState.townPhase();
-	var cityPhase = gameState.cityPhase();
+	let townPhase = gameState.townPhase();
+	let cityPhase = gameState.cityPhase();
 		
 	if (gameState.canResearch(townPhase,true) && gameState.getPopulation() >= this.Config.Economy.popForTown - 10 &&
 		gameState.hasResearchers(townPhase, true))
@@ -48,11 +48,11 @@ m.ResearchManager.prototype.checkPhase = function(gameState, queues)
 
 m.ResearchManager.prototype.researchPopulationBonus = function(gameState, queues)
 {
-	if (queues.minorTech.length() !== 0)
+	if (queues.minorTech.hasQueuedUnits())
 		return;
 
-	var techs = gameState.findAvailableTech();
-	for (var tech of techs)
+	let techs = gameState.findAvailableTech();
+	for (let tech of techs)
 	{
 		if (!tech[1]._template.modifications)
 			continue;
@@ -66,11 +66,11 @@ m.ResearchManager.prototype.researchPopulationBonus = function(gameState, queues
 
 m.ResearchManager.prototype.researchTradeBonus = function(gameState, queues)
 {
-	if (queues.minorTech.length() !== 0)
+	if (queues.minorTech.hasQueuedUnits())
 		return;
 
-	var techs = gameState.findAvailableTech();
-	for (var tech of techs)
+	let techs = gameState.findAvailableTech();
+	for (let tech of techs)
 	{
 		if (!tech[1]._template.modifications || !tech[1]._template.affects)
 			continue;
@@ -85,17 +85,17 @@ m.ResearchManager.prototype.researchTradeBonus = function(gameState, queues)
 	}
 };
 
-// Techs to be searched for as soon as they are available
+/** Techs to be searched for as soon as they are available */
 m.ResearchManager.prototype.researchWantedTechs = function(gameState, techs)
 {
-	var available = (gameState.currentPhase() == 1 ? gameState.ai.queueManager.getAvailableResources(gameState) : null);
-	var numWorkers = (gameState.currentPhase() == 1 ? gameState.getOwnEntitiesByRole("worker", true).length : 0);
+	let available = gameState.currentPhase() === 1 ? gameState.ai.queueManager.getAvailableResources(gameState) : null;
+	let numWorkers = gameState.currentPhase() === 1 ? gameState.getOwnEntitiesByRole("worker", true).length : 0;
 	for (let tech of techs)
 	{
 		if (!tech[1]._template.modifications)
 			continue;
 		let template = tech[1]._template;
-		if (gameState.currentPhase() == 1)
+		if (gameState.currentPhase() === 1)
 		{
 			let cost = template.cost;
 			let costMax = 0;
@@ -123,17 +123,17 @@ m.ResearchManager.prototype.researchWantedTechs = function(gameState, techs)
 	return false;
 };
 
-// Techs to be searched for as soon as they are available, but only after phase 2
+/** Techs to be searched for as soon as they are available, but only after phase 2 */
 m.ResearchManager.prototype.researchPreferredTechs = function(gameState, techs)
 {
-	var available = (gameState.currentPhase() == 2 ? gameState.ai.queueManager.getAvailableResources(gameState) : null);
-	var numWorkers = (gameState.currentPhase() == 2 ? gameState.getOwnEntitiesByRole("worker", true).length : 0);
+	let available = gameState.currentPhase() === 2 ? gameState.ai.queueManager.getAvailableResources(gameState) : null;
+	let numWorkers = gameState.currentPhase() === 2 ? gameState.getOwnEntitiesByRole("worker", true).length : 0;
 	for (let tech of techs)
 	{
 		if (!tech[1]._template.modifications)
 			continue;
 		let template = tech[1]._template;
-	    	if (gameState.currentPhase() == 2)
+	    	if (gameState.currentPhase() === 2)
 		{
 			let cost = template.cost;
 			let costMax = 0;
@@ -161,12 +161,12 @@ m.ResearchManager.prototype.researchPreferredTechs = function(gameState, techs)
 
 m.ResearchManager.prototype.update = function(gameState, queues)
 {
-	if (queues.minorTech.length() || queues.majorTech.length())
+	if (queues.minorTech.hasQueuedUnits() || queues.majorTech.hasQueuedUnits())
 		return;
 
-	var techs = gameState.findAvailableTech();
+	let techs = gameState.findAvailableTech();
 
-	var techName = this.researchWantedTechs(gameState, techs);
+	let techName = this.researchWantedTechs(gameState, techs);
 	if (techName)
 	{
 		queues.minorTech.addPlan(new m.ResearchPlan(gameState, techName));
@@ -187,7 +187,7 @@ m.ResearchManager.prototype.update = function(gameState, queues)
 		return;
 
 	// remove some techs not yet used by this AI
-	// remove alse sharedLos if we have no ally
+	// remove also sharedLos if we have no ally
 	for (let i = 0; i < techs.length; ++i)
 	{
 		let template = techs[i][1]._template;
@@ -208,7 +208,7 @@ m.ResearchManager.prototype.update = function(gameState, queues)
 	if (!techs.length)
 		return;
 	// randomly pick one. No worries about pairs in that case.
-	var p = Math.floor((Math.random()*techs.length));
+	let p = Math.floor(Math.random()*techs.length);
 	queues.minorTech.addPlan(new m.ResearchPlan(gameState, techs[p][0]));
 };
 
