@@ -24,7 +24,7 @@ m.TradeManager.prototype.init = function(gameState)
 
 m.TradeManager.prototype.hasTradeRoute = function()
 {
-	return (this.tradeRoute !== undefined);
+	return this.tradeRoute !== undefined;
 };
 
 m.TradeManager.prototype.assignTrader = function(ent)
@@ -33,26 +33,26 @@ m.TradeManager.prototype.assignTrader = function(ent)
 	this.traders.updateEnt(ent);
 };
 
-// TODO take trader ships into account
 m.TradeManager.prototype.trainMoreTraders = function(gameState, queues)
 {
 	if (!this.tradeRoute || queues.trader.hasQueuedUnits())
 		return;
 
-	var numTraders = this.traders.length;
-	var numSeaTraders = this.traders.filter(API3.Filters.byClass("Ship")).length;
-	var numLandTraders = numTraders - numSeaTraders;
+	let numTraders = this.traders.length;
+	let numSeaTraders = this.traders.filter(API3.Filters.byClass("Ship")).length;
+	let numLandTraders = numTraders - numSeaTraders;
 	// add traders already in training
 	gameState.getOwnTrainingFacilities().forEach(function(ent) {
-		ent.trainingQueue().forEach(function(item) {
+		for (let item of ent.trainingQueue())
+		{
 			if (!item.metadata || !item.metadata.role || item.metadata.role !== "trader")
-				return;
+				continue;
 			numTraders += item.count;
-			if (item.sea !== undefined)
+			if (item.metadata.sea !== undefined)
 				numSeaTraders += item.count;
 			else
 				numLandTraders += item.count;
-		});
+		}
 	});
         if (numTraders >= this.targetNumTraders &&
 		((!this.tradeRoute.sea && numLandTraders >= Math.floor(this.targetNumTraders/2)) ||
@@ -118,8 +118,8 @@ m.TradeManager.prototype.updateTrader = function(gameState, ent)
 		return;
 
 	Engine.ProfileStart("Trade Manager");
-	var access = ent.hasClass("Ship") ? ent.getMetadata(PlayerID, "sea") : gameState.ai.accessibility.getAccessValue(ent.position());
-	var route = this.checkRoutes(gameState, access);
+	let access = ent.hasClass("Ship") ? ent.getMetadata(PlayerID, "sea") : gameState.ai.accessibility.getAccessValue(ent.position());
+	let route = this.checkRoutes(gameState, access);
 	if (!route)
 	{
 		// TODO try to garrison land trader inside merchant ship when only sea routes available
@@ -129,7 +129,7 @@ m.TradeManager.prototype.updateTrader = function(gameState, ent)
 		return;
 	}
 
-	var nearerSource = true;
+	let nearerSource = true;
 	if (API3.SquareVectorDistance(route.target.position(), ent.position()) < API3.SquareVectorDistance(route.source.position(), ent.position()))
 		nearerSource = false;
 
@@ -153,40 +153,42 @@ m.TradeManager.prototype.updateTrader = function(gameState, ent)
 
 m.TradeManager.prototype.setTradingGoods = function(gameState)
 {
-	var tradingGoods = { "food": 0, "wood": 0, "stone": 0, "metal": 0 };
+	let tradingGoods = {};
+	for (let res in gameState.ai.HQ.wantedRates)
+		tradingGoods[res] = 0;
 	// first, try to anticipate future needs 
-	var stocks = gameState.ai.HQ.getTotalResourceLevel(gameState);
-	var mostNeeded = gameState.ai.HQ.pickMostNeededResources(gameState);
-	var remaining = 100;
-	var targetNum = this.Config.Economy.targetNumTraders;
-	for (var type in stocks)
+	let stocks = gameState.ai.HQ.getTotalResourceLevel(gameState);
+	let mostNeeded = gameState.ai.HQ.pickMostNeededResources(gameState);
+	let remaining = 100;
+	let targetNum = this.Config.Economy.targetNumTraders;
+	for (let res in stocks)
 	{
-		if (type == "food")
+		if (res === "food")
 			continue;
-		let wantedRate = gameState.ai.HQ.wantedRates[type];
-		if (stocks[type] < 200)
+		let wantedRate = gameState.ai.HQ.wantedRates[res];
+		if (stocks[res] < 200)
 		{
-			tradingGoods[type] = (wantedRate > 0) ? 20 : 10;
+			tradingGoods[res] = wantedRate > 0 ? 20 : 10;
 			targetNum += Math.min(5, 3 + Math.ceil(wantedRate/30));
 		}
-		else if (stocks[type] < 500)
+		else if (stocks[res] < 500)
 		{
-			tradingGoods[type] = (wantedRate > 0) ? 15 : 10;
+			tradingGoods[res] = wantedRate > 0 ? 15 : 10;
 			targetNum += 2;
 		}
-		else if (stocks[type] < 1000)
+		else if (stocks[res] < 1000)
 		{
-			tradingGoods[type] = 10;
+			tradingGoods[res] = 10;
 			targetNum += 1;
 		}
-		remaining -= tradingGoods[type];
+		remaining -= tradingGoods[res];
 	}
 	this.targetNumTraders = Math.round(this.Config.popScaling * targetNum);
 
 
 	// then add what is needed now
-	var mainNeed = Math.floor(remaining * 70 / 100);
-	var nextNeed = remaining - mainNeed;
+	let mainNeed = Math.floor(remaining * 70 / 100);
+	let nextNeed = remaining - mainNeed;
 
 	tradingGoods[mostNeeded[0].type] += mainNeed;
 	if (mostNeeded[1].wanted > 0)
@@ -198,33 +200,35 @@ m.TradeManager.prototype.setTradingGoods = function(gameState)
 		API3.warn(" trading goods set to " + uneval(tradingGoods));
 };
 
-// Try to barter unneeded resources for needed resources.
-// only once per turn because the info doesn't update between a turn and fixing isn't worth it.
+/**
+ * Try to barter unneeded resources for needed resources.
+ * only once per turn because the info is not updated within a turn
+ */
 m.TradeManager.prototype.performBarter = function(gameState)
 {
-	var barterers = gameState.getOwnEntitiesByClass("BarterMarket", true).filter(API3.Filters.isBuilt()).toEntityArray();
+	let barterers = gameState.getOwnEntitiesByClass("BarterMarket", true).filter(API3.Filters.isBuilt()).toEntityArray();
 	if (barterers.length === 0)
 		return false;
 
 	// Available resources after account substraction
-	var available = gameState.ai.queueManager.getAvailableResources(gameState);
-	var needs = gameState.ai.queueManager.currentNeeds(gameState);
+	let available = gameState.ai.queueManager.getAvailableResources(gameState);
+	let needs = gameState.ai.queueManager.currentNeeds(gameState);
 
-	var rates = gameState.ai.HQ.GetCurrentGatherRates(gameState);
+	let rates = gameState.ai.HQ.GetCurrentGatherRates(gameState);
 
-	var prices = gameState.getBarterPrices();
+	let prices = gameState.getBarterPrices();
 	// calculates conversion rates
-	var getBarterRate = function (prices,buy,sell) { return Math.round(100 * prices.sell[sell] / prices.buy[buy]); };
+	let getBarterRate = function (prices,buy,sell) { return Math.round(100 * prices.sell[sell] / prices.buy[buy]); };
 
 	// loop through each missing resource checking if we could barter and help finishing a queue quickly.
-	for (var buy of needs.types)
+	for (let buy of needs.types)
 	{
 		if (needs[buy] === 0 || needs[buy] < rates[buy]*30) // check if our rate allows to gather it fast enough
 			continue;
 
 		// pick the best resource to barter.
-		var bestToSell = undefined;
-		var bestRate = 0;
+		let bestToSell;
+		let bestRate = 0;
 		for (let sell of needs.types)
 		{
 			if (sell === buy)
@@ -273,15 +277,15 @@ m.TradeManager.prototype.performBarter = function(gameState)
 	// now do contingency bartering, selling food to buy finite resources (and annoy our ennemies by increasing prices)
 	if (available.food < 1000 || needs.food > 0)
 		return false;
-	var bestToBuy;
-	var bestChoice = 0;
+	let bestToBuy;
+	let bestChoice = 0;
 	for (let buy of needs.types)
 	{
 		if (buy === "food")
 			continue;
 		let barterRateMin = 80;
 		if (available[buy] < 5000 && available.food > 5000)
-			barterRateMin -= (20 - Math.floor(available[buy]/250));
+			barterRateMin -= 20 - Math.floor(available[buy]/250);
 		let barterRate = getBarterRate(prices, buy, "food");
 		if (barterRate < barterRateMin)
 			continue;
@@ -371,12 +375,14 @@ m.TradeManager.prototype.checkEvents = function(gameState, events)
 	return false;
 };
 
-// fills the best trade route in this.tradeRoute and the best potential route in this.potentialTradeRoute
-// If an index is given, it returns the best route with this index or the best land route if index is a land index 
+/**
+ * fills the best trade route in this.tradeRoute and the best potential route in this.potentialTradeRoute
+ * If an index is given, it returns the best route with this index or the best land route if index is a land index 
+ */
 m.TradeManager.prototype.checkRoutes = function(gameState, accessIndex)
 {
-	var market1 = gameState.updatingCollection("OwnMarkets", API3.Filters.byClass("Market"), gameState.getOwnStructures()).toEntityArray();
-	var market2 = gameState.updatingCollection("ExclusiveAllyMarkets", API3.Filters.byClass("Market"), gameState.getExclusiveAllyEntities()).toEntityArray();
+	let market1 = gameState.updatingCollection("OwnMarkets", API3.Filters.byClass("Market"), gameState.getOwnStructures()).toEntityArray();
+	let market2 = gameState.updatingCollection("ExclusiveAllyMarkets", API3.Filters.byClass("Market"), gameState.getExclusiveAllyEntities()).toEntityArray();
 	if (market1.length + market2.length < 2)  // We have to wait  ... markets will be built soon
 	{
 		this.tradeRoute = undefined;
@@ -386,29 +392,39 @@ m.TradeManager.prototype.checkRoutes = function(gameState, accessIndex)
 
 	if (!market2.length)
 		market2 = market1;
-	var candidate = { "gain": 0 };
-	var potential = { "gain": 0 };
-	var bestIndex = { "gain": 0 };
-	var bestLand  = { "gain": 0 };
-	for (var m1 of market1)
+	let candidate = { "gain": 0 };
+	let potential = { "gain": 0 };
+	let bestIndex = { "gain": 0 };
+	let bestLand  = { "gain": 0 };
+
+	let traderTemplatesGains = gameState.getTraderTemplatesGains();
+
+	for (let m1 of market1)
 	{
 		if (!m1.position())
 			continue;
-		var access1 = gameState.ai.accessibility.getAccessValue(m1.position());
-		var sea1 = m1.hasClass("NavalMarket") ? gameState.ai.HQ.navalManager.getDockIndex(gameState, m1, true) : undefined;
-		for (var m2 of market2)
+		let access1 = gameState.ai.accessibility.getAccessValue(m1.position());
+		let sea1 = m1.hasClass("NavalMarket") ? gameState.ai.HQ.navalManager.getDockIndex(gameState, m1, true) : undefined;
+		for (let m2 of market2)
 		{
 			if (m1.id() === m2.id())
 				continue;
 			if (!m2.position())
 				continue;
-			var access2 = gameState.ai.accessibility.getAccessValue(m2.position());
-			var sea2 = m2.hasClass("NavalMarket") ? gameState.ai.HQ.navalManager.getDockIndex(gameState, m2, true) : undefined;
-			var land = (access1 == access2) ? access1 : undefined;
-			var sea = (sea1 && sea1 == sea2) ? sea1 : undefined;
+			let access2 = gameState.ai.accessibility.getAccessValue(m2.position());
+			let sea2 = m2.hasClass("NavalMarket") ? gameState.ai.HQ.navalManager.getDockIndex(gameState, m2, true) : undefined;
+			let land = access1 == access2 ? access1 : undefined;
+			let sea = (sea1 && sea1 == sea2) ? sea1 : undefined;
 			if (!land && !sea)
 				continue;
-			var gain = Math.round(API3.SquareVectorDistance(m1.position(), m2.position()) / this.Config.distUnitGain);
+			let gainMultiplier;
+			if (land && traderTemplatesGains.landGainMultiplier)
+				gainMultiplier = traderTemplatesGains.landGainMultiplier;
+			else if (sea && traderTemplatesGains.navalGainMultiplier)
+				gainMultiplier = traderTemplatesGains.navalGainMultiplier;
+			else
+				continue;
+			let gain = Math.round(API3.SquareVectorDistance(m1.position(), m2.position()) * gainMultiplier / 10000);
 			if (gain < this.minimalGain)
 				continue;
 			if (m1.foundationProgress() === undefined && m2.foundationProgress() === undefined)
@@ -484,17 +500,15 @@ m.TradeManager.prototype.checkRoutes = function(gameState, accessIndex)
 			return bestIndex;
 		else if (gameState.ai.accessibility.regionType[accessIndex] === "land" && bestLand.gain > 0)
 			return bestLand;
-		else
-			return false;
+		return false;
 	}
-	else
-		return true;
+	return true;
 };
 
-// Called when a market was built or destroyed, and checks if trader orders should be changed
+/** Called when a market was built or destroyed, and checks if trader orders should be changed */
 m.TradeManager.prototype.checkTrader = function(gameState, ent)
 {
-	var presentRoute = ent.getMetadata(PlayerID, "route");
+	let presentRoute = ent.getMetadata(PlayerID, "route");
 	if (!presentRoute)
 		return;
 
@@ -505,8 +519,8 @@ m.TradeManager.prototype.checkTrader = function(gameState, ent)
 		return;
 	}
 
-	var access = ent.hasClass("Ship") ? ent.getMetadata(PlayerID, "sea") : gameState.ai.accessibility.getAccessValue(ent.position());
-	var possibleRoute = this.checkRoutes(gameState, access);
+	let access = ent.hasClass("Ship") ? ent.getMetadata(PlayerID, "sea") : gameState.ai.accessibility.getAccessValue(ent.position());
+	let possibleRoute = this.checkRoutes(gameState, access);
 	// Warning:  presentRoute is from metadata, so contains entity ids
 	if (!possibleRoute ||
 		(possibleRoute.source.id() != presentRoute.source && possibleRoute.source.id() != presentRoute.target) ||
@@ -527,11 +541,11 @@ m.TradeManager.prototype.prospectForNewMarket = function(gameState, queues)
 	if (!gameState.updatingCollection("OwnMarkets", API3.Filters.byClass("Market"), gameState.getOwnStructures()).length &&
 		!gameState.updatingCollection("ExclusiveAllyMarkets", API3.Filters.byClass("Market"), gameState.getExclusiveAllyEntities()).length)
 		return;
-	var template = gameState.getTemplate(gameState.applyCiv("structures/{civ}_market"));
+	let template = gameState.getTemplate(gameState.applyCiv("structures/{civ}_market"));
 	if (!template)
 		return;
 	this.checkRoutes(gameState);
-	var marketPos = gameState.ai.HQ.findMarketLocation(gameState, template);
+	let marketPos = gameState.ai.HQ.findMarketLocation(gameState, template);
 	if (!marketPos || marketPos[3] === 0)   // marketPos[3] is the expected gain
 	{	// no position found
 		gameState.ai.HQ.stopBuild(gameState, "structures/{civ}_market");
@@ -574,7 +588,7 @@ m.TradeManager.prototype.update = function(gameState, events, queues)
 	if (this.routeProspection)
 		this.prospectForNewMarket(gameState, queues);
 
-	var self = this;
+	let self = this;
 
 	if (this.checkEvents(gameState, events))  // true if one market was built or destroyed
 	{
@@ -600,7 +614,7 @@ m.TradeManager.prototype.routeEntToId = function(route)
 		return route;
 	let ret = {};
 	for (let key in route)
-		ret[key] = ((key == "source" || key == "target") ? route[key].id() : route[key]);
+		ret[key] = (key == "source" || key == "target") ? route[key].id() : route[key];
 	return ret;
 };
 
@@ -610,7 +624,7 @@ m.TradeManager.prototype.routeIdToEnt = function(gameState, route)
 		return route;
 	let ret = {};
 	for (let key in route)
-		ret[key] = ((key == "source" || key == "target") ? gameState.getEntityById(route[key]) : route[key]);
+		ret[key] = (key == "source" || key == "target") ? gameState.getEntityById(route[key]) : route[key];
 	return ret;
 };
 
