@@ -1,31 +1,19 @@
-/**
- * Contains global GUI functions accessible from every GUI script/file.
- */
-
-// *******************************************
-// messageBox
-// *******************************************
-// @params:     int mbWidth, int mbHeight, string mbMessage, string mbTitle, int mbMode, arr mbButtonCaptions, function mbBtnCode, var mbCallbackArgs
-// @return:     void
-// @desc:       Displays a new modal message box.
-// *******************************************
-
-
 // We want to pass callback functions for the different buttons in a convenient way.
 // Because passing functions accross compartment boundaries is a pain, we just store them here together with some optional arguments.
 // The messageBox page will return the code of the pressed button and the according function will be called.
-var g_messageBoxBtnFunctions = [];
-var g_messageBoxCallbackArgs = []; 
+var g_MessageBoxBtnFunctions = [];
+var g_MessageBoxCallbackArgs = [];
 
-var g_messageBoxCallbackFunction = function(btnCode)
+var g_MessageBoxCallbackFunction = function(btnCode)
 {
-	if (btnCode !== undefined && g_messageBoxBtnFunctions[btnCode])
+	if (btnCode !== undefined && g_MessageBoxBtnFunctions[btnCode])
 	{
 		// Cache the variables to make it possible to call a messageBox from a callback function.
-		var callbackFunction = g_messageBoxBtnFunctions[btnCode];
-		var callbackArgs = g_messageBoxCallbackArgs[btnCode];
-		g_messageBoxBtnFunctions  = [];
-		g_messageBoxCallbackArgs = [];
+		let callbackFunction = g_MessageBoxBtnFunctions[btnCode];
+		let callbackArgs = g_MessageBoxCallbackArgs[btnCode];
+
+		g_MessageBoxBtnFunctions = [];
+		g_MessageBoxCallbackArgs = [];
 
 		if (callbackArgs !== undefined)
 			callbackFunction(callbackArgs);
@@ -34,43 +22,43 @@ var g_messageBoxCallbackFunction = function(btnCode)
 		return;
 	}
 
-	g_messageBoxBtnFunctions  = [];
-	g_messageBoxCallbackArgs = [];
+	g_MessageBoxBtnFunctions = [];
+	g_MessageBoxCallbackArgs = [];
 };
 
-function messageBox (mbWidth, mbHeight, mbMessage, mbTitle, mbMode, mbButtonCaptions, mbBtnCode, mbCallbackArgs)
+function messageBox(mbWidth, mbHeight, mbMessage, mbTitle, mbButtonCaptions, mbBtnCode, mbCallbackArgs)
 {
-	if (g_messageBoxBtnFunctions && g_messageBoxBtnFunctions.length != 0)
+	if (g_MessageBoxBtnFunctions && g_MessageBoxBtnFunctions.length)
 	{
 		warn("A messagebox was called when a previous callback function is still set, aborting!");
 		return;
 	}
 
-	g_messageBoxBtnFunctions = mbBtnCode;
-	if (mbCallbackArgs)
-		g_messageBoxCallbackArgs = mbCallbackArgs;
+	g_MessageBoxBtnFunctions = mbBtnCode;
+	g_MessageBoxCallbackArgs = mbCallbackArgs || g_MessageBoxCallbackArgs;
 
-	var initData = {
-		width: mbWidth,
-		height: mbHeight,
-		message: mbMessage,
-		title: mbTitle,
-		mode: mbMode,
-		buttonCaptions: mbButtonCaptions,
-	};
-	if (mbBtnCode)
-		initData.callback = "g_messageBoxCallbackFunction";
-
-	Engine.PushGuiPage("page_msgbox.xml", initData);
+	Engine.PushGuiPage("page_msgbox.xml", {
+		"width": mbWidth,
+		"height": mbHeight,
+		"message": mbMessage,
+		"title": mbTitle,
+		"buttonCaptions": mbButtonCaptions,
+		"callback": mbBtnCode && "g_MessageBoxCallbackFunction"
+	});
 }
 
-// ====================================================================
-
-
 function openURL(url)
 {
 	Engine.OpenURL(url);
-	messageBox(600, 200, sprintf(translate("Opening %(url)s\n in default web browser. Please wait...."), { url: url }), translate("Opening page"), 2);
+
+	messageBox(
+		600, 200,
+		sprintf(
+			translate("Opening %(url)s\n in default web browser. Please wait...."),
+			{ "url": url }
+		),
+		translate("Opening page")
+	);
 }
 
 function updateCounters()
@@ -81,7 +69,7 @@ function updateCounters()
 
 	if (Engine.ConfigDB_GetValue("user", "overlay.fps") === "true")
 	{
-		caption += sprintf(translate("FPS: %(fps)4s"), { fps: Engine.GetFPS() }) + "\n";
+		caption += sprintf(translate("FPS: %(fps)4s"), { "fps": Engine.GetFPS() }) + "\n";
 		++linesCount;
 	}
 	if (Engine.ConfigDB_GetValue("user", "overlay.realtime") === "true")
@@ -98,12 +86,10 @@ function updateCounters()
 			var currentSpeed = Engine.GetSimRate();
 			if (currentSpeed != 1.0)
 				// Translation: The "x" means "times", with the mathematical meaning of multiplication.
-				caption += sprintf(translate("%(time)s (%(speed)sx)"),
-					{
-						time: timeToString(g_SimState.timeElapsed),
-						speed: Engine.FormatDecimalNumberIntoString(currentSpeed)
-					}
-				);
+				caption += sprintf(translate("%(time)s (%(speed)sx)"), {
+					"time": timeToString(g_SimState.timeElapsed),
+					"speed": Engine.FormatDecimalNumberIntoString(currentSpeed)
+				});
 			else
 				caption += timeToString(g_SimState.timeElapsed);
 			caption += "\n";
@@ -115,7 +101,11 @@ function updateCounters()
 		{
 			// Update ceasefire counter in the diplomacy window
 			var remainingTimeString = timeToString(g_SimState.ceasefireTimeRemaining);
-			diplomacyCeasefireCounter.caption = sprintf(translateWithContext("ceasefire", "Time remaining until ceasefire is over: %(time)s."), {"time": remainingTimeString});
+
+			diplomacyCeasefireCounter.caption = sprintf(
+				translateWithContext("ceasefire", "Time remaining until ceasefire is over: %(time)s."),
+				{ "time": remainingTimeString }
+			);
 
 			// Update ceasefire overlay counter
 			if (Engine.ConfigDB_GetValue("user", "gui.session.ceasefirecounter") === "true")
@@ -137,7 +127,7 @@ function updateCounters()
 
 	var dataCounter = Engine.GetGUIObjectByName("dataCounter");
 	dataCounter.caption = caption;
-	dataCounter.size = sprintf("100%%-100 40 100%%-5 %(bottom)s", { bottom: 40 + 14 * linesCount });
+	dataCounter.size = sprintf("100%%-100 40 100%%-5 %(bottom)s", { "bottom": 40 + 14 * linesCount });
 	dataCounter.hidden = linesCount == 0;
 }
 
@@ -149,8 +139,6 @@ function displayGamestateNotifications()
 	let messages = [];
 	let maxTextWidth = 0;
 
-	// TODO: Players who paused the game should be added here
-
 	// Add network warnings
 	if (Engine.ConfigDB_GetValue("user", "overlay.netwarnings") == "true")
 	{
@@ -177,3 +165,16 @@ function displayGamestateNotifications()
 
 	setTimeout(displayGamestateNotifications, 1000);
 }
+
+/**
+ * Also called from the C++ side when ending the game.
+ */
+function getReplayMetadata()
+{
+	let extendedSimState = Engine.GuiInterfaceCall("GetExtendedSimulationState");
+	return {
+		"timeElapsed" : extendedSimState.timeElapsed,
+		"playerStates": extendedSimState.players,
+		"mapSettings": Engine.GetInitAttributes().settings
+	};
+}
