@@ -1,3 +1,8 @@
+/**
+ * Used by notifyUser() to limit the number of pings
+ */
+var g_LastNickNotification = -1;
+
 function getRandom(randomMin, randomMax)
 {
 	// Returns a random whole number in a min..max range.
@@ -59,43 +64,61 @@ function sortNameIgnoreCase(x, y)
  * Escape tag start and escape characters, so users cannot use special formatting.
  * Also limit string length to 256 characters (not counting escape characters).
  */
-function escapeText(text)
+function escapeText(text, limitLength = true)
 {
 	if (!text)
 		return text;
 
-	return text.substr(0, 255).replace(/\\/g, "\\\\").replace(/\[/g, "\\[");
+	if (limitLength)
+		text = text.substr(0, 255);
+
+	return text.replace(/\\/g, "\\\\").replace(/\[/g, "\\[");
+}
+
+function unescapeText(text)
+{
+	if (!text)
+		return text;
+	return text.replace(/\\\\/g, "\\").replace(/\\\[/g, "\[");
 }
 
 /**
- * Returns map description and preview image or placeholder.
+ * Merge players by team to remove duplicate Team entries, thus reducing the packet size of the lobby report.
  */
-function getMapDescriptionAndPreview(mapType, mapName)
+function playerDataToStringifiedTeamList(playerData)
 {
-	var mapData;
-	if (mapType == "random" && mapName == "random")
-		mapData = { "settings": { "Description": translate("A randomly selected map.") } };
-	else if (mapType == "random" && Engine.FileExists(mapName + ".json"))
-		mapData = Engine.ReadJSONFile(mapName + ".json");
-	else if (Engine.FileExists(mapName + ".xml"))
-		mapData = Engine.LoadMapSettings(mapName + ".xml");
+	let teamList = {};
 
-	return {
-		"description": mapData && mapData.settings && mapData.settings.Description ? translate(mapData.settings.Description) : translate("Sorry, no description available."),
-		"preview": mapData && mapData.settings && mapData.settings.Preview ? mapData.settings.Preview : "nopreview.png"
-	};
+	for (let pData of playerData)
+	{
+		let team = pData.Team === undefined ? -1 : pData.Team;
+		if (!teamList[team])
+			teamList[team] = [];
+		teamList[team].push(pData);
+		delete teamList[team].Team;
+	}
+
+	return escapeText(JSON.stringify(teamList), false);
 }
 
-/**
- * Sets the mappreview image correctly.
- * It needs to be cropped as the engine only allows loading square textures.
- *
- * @param {string} guiObject
- * @param {string} filename
- */
-function setMapPreviewImage(guiObject, filename)
+function stringifiedTeamListToPlayerData(stringifiedTeamList)
 {
-	Engine.GetGUIObjectByName(guiObject).sprite = "cropped:" + 400/512+ "," + 300/512 + ":session/icons/mappreview/" + filename;
+	let teamList = JSON.parse(unescapeText(stringifiedTeamList));
+	let playerData = [];
+
+	for (let team in teamList)
+		for (let pData of teamList[team])
+		{
+			pData.Team = team;
+			playerData.push(pData);
+		}
+
+	return playerData;
+}
+
+function translateMapTitle(mapTitle)
+{
+	return mapTitle == "random" ? translateWithContext("map selection", "Random") : translate(mapTitle);
 }
 
 /**
@@ -141,6 +164,16 @@ function sanitizePlayerName(name, stripUnicode, stripSpaces)
 	return sanitizedName.substr(0,20);
 }
 
+function singleplayerName()
+{
+	return Engine.ConfigDB_GetValue("user", "playername.singleplayer") || Engine.GetSystemUsername();
+}
+
+function multiplayerName()
+{
+	return Engine.ConfigDB_GetValue("user", "playername.multiplayer") || Engine.GetSystemUsername();
+}
+
 function tryAutoComplete(text, autoCompleteList)
 {
 	if (!text.length)
@@ -158,7 +191,7 @@ function tryAutoComplete(text, autoCompleteList)
 	{
 		if (word.toLowerCase().indexOf(lastWord.toLowerCase()) != 0)
 			continue;
-		
+
 		text = wordSplit.join(" ");
 		if (text.length > 0)
 			text += " ";
@@ -169,22 +202,18 @@ function tryAutoComplete(text, autoCompleteList)
 	return text;
 }
 
-function autoCompleteNick(guiName, playerList)
+function autoCompleteNick(guiObject, playernames)
 {
-	var input = Engine.GetGUIObjectByName(guiName);
-	var text = input.caption;
+	let text = guiObject.caption;
 	if (!text.length)
 		return;
 
-	var autoCompleteList = [];
-	for (var player of playerList)
-		autoCompleteList.push(player.name);
+	let bufferPosition = guiObject.buffer_position;
+	let textTillBufferPosition = text.substring(0, bufferPosition);
+	let newText = tryAutoComplete(textTillBufferPosition, playernames);
 
-	var bufferPosition = input.buffer_position;
-	var textTillBufferPosition = text.substring(0, bufferPosition);
-	var newText = tryAutoComplete(textTillBufferPosition, autoCompleteList);
-	input.caption = newText + text.substring(bufferPosition);
-	input.buffer_position = bufferPosition + (newText.length - textTillBufferPosition.length);
+	guiObject.caption = newText + text.substring(bufferPosition);
+	guiObject.buffer_position = bufferPosition + (newText.length - textTillBufferPosition.length);
 }
 
 function clearChatMessages()
@@ -199,3 +228,20 @@ function clearChatMessages()
 	} catch (e) {
 	}
 }
+
+/**
+ * Plays a sound if user's nick is mentioned in chat
+ */
+function notifyUser(userName, msgText)
+{
+	if (Engine.ConfigDB_GetValue("user", "sound.notify.nick") != "true" ||
+	    msgText.toLowerCase().indexOf(userName.toLowerCase()) == -1)
+		return;
+
+	let timeNow = new Date().getTime();
+
+	if (!g_LastNickNotification || timeNow > g_LastNickNotification + 3000)
+		Engine.PlayUISound("audio/interface/ui/chat_alert.ogg", false);
+
+	g_LastNickNotification = timeNow;
+}
