@@ -8,6 +8,7 @@ AIInterface.prototype.EventNames = [
 	"Destroy",
 	"Attacked",
 	"ConstructionFinished",
+	"DiplomacyChanged",
 	"TrainingStarted",
 	"TrainingFinished",
 	"AIMetadata",
@@ -16,6 +17,7 @@ AIInterface.prototype.EventNames = [
 	"OwnershipChanged",
 	"Garrison",
 	"UnGarrison",
+	"TerritoriesChanged",
 	"TerritoryDecayChanged",
 	"TributeExchanged",
 	"AttackRequest"
@@ -39,13 +41,15 @@ AIInterface.prototype.Init = function()
 
 AIInterface.prototype.Serialize = function()
 {
-	var state = {};
+	let state = {};
 	for (var key in this)
 	{
 		if (!this.hasOwnProperty(key))
 			continue;
 		if (typeof this[key] == "function")
 			continue;
+		if (key == "templates")
+			continue;
 		state[key] = this[key];
 	}
 	return state;
@@ -53,7 +57,7 @@ AIInterface.prototype.Serialize = function()
 
 AIInterface.prototype.Deserialize = function(data)
 {
-	for (var key in data)
+	for (let key in data)
 	{
 		if (!data.hasOwnProperty(key))
 			continue;
@@ -70,7 +74,7 @@ AIInterface.prototype.Deserialize = function(data)
 AIInterface.prototype.Disable = function()
 {
 	this.enabled = false;
-	var nop = function(){};
+	let nop = function(){};
 	this.ChangedEntity = nop;
 	this.PushEvent = nop;
 	this.OnGlobalPlayerDefeated = nop;
@@ -82,10 +86,10 @@ AIInterface.prototype.Disable = function()
 
 AIInterface.prototype.GetNonEntityRepresentation = function()
 {
-	var cmpGuiInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
+	let cmpGuiInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
 
 	// Return the same game state as the GUI uses
-	var state = cmpGuiInterface.GetSimulationState(-1);
+	let state = cmpGuiInterface.GetSimulationState(-1);
 	
 	// Add some extra AI-specific data
 	// add custom events and reset them for the next turn
@@ -101,16 +105,16 @@ AIInterface.prototype.GetNonEntityRepresentation = function()
 
 AIInterface.prototype.GetRepresentation = function()
 {
-	var state = this.GetNonEntityRepresentation();
+	let state = this.GetNonEntityRepresentation();
 
 	// Add entity representations
 	Engine.ProfileStart("proxy representations");
 	state.entities = {};
-	for (var id in this.changedEntities)
+	for (let id in this.changedEntities)
 	{
-		var aiProxy = Engine.QueryInterface(+id, IID_AIProxy);
-		if (aiProxy)
-			state.entities[id] = aiProxy.GetRepresentation();
+		let cmpAIProxy = Engine.QueryInterface(+id, IID_AIProxy);
+		if (cmpAIProxy)
+			state.entities[id] = cmpAIProxy.GetRepresentation();
 	}
 	this.changedEntities = {};
 	Engine.ProfileStop();
@@ -123,10 +127,12 @@ AIInterface.prototype.GetRepresentation = function()
 	return state;
 };
 
-// Intended to be called first, during the map initialization: no caching
+/**
+ * Intended to be called first, during the map initialization: no caching
+ */
 AIInterface.prototype.GetFullRepresentation = function(flushEvents)
 {	
-	var state = this.GetNonEntityRepresentation();
+	let state = this.GetNonEntityRepresentation();
 
 	if (flushEvents)
 		for (let name of this.EventNames)
@@ -153,10 +159,11 @@ AIInterface.prototype.ChangedEntity = function(ent)
 	this.changedEntities[ent] = 1;
 };
 
-// AIProxy sets up a load of event handlers to capture interesting things going on
-// in the world, which we will report to AI. Handle those, and add a few more handlers
-// for events that AIProxy won't capture.
-
+/**
+ * AIProxy sets up a load of event handlers to capture interesting things going on
+ * in the world, which we will report to AI. Handle those, and add a few more handlers
+ * for events that AIProxy won't capture.
+ */
 AIInterface.prototype.PushEvent = function(type, msg)
 {
 	if (this.events[type] === undefined)
@@ -164,28 +171,38 @@ AIInterface.prototype.PushEvent = function(type, msg)
 	this.events[type].push(msg);
 };
 
+AIInterface.prototype.OnDiplomacyChanged = function(msg)
+{
+	this.events.DiplomacyChanged.push(msg);
+};
+
 AIInterface.prototype.OnGlobalPlayerDefeated = function(msg)
 {
-	this.events["PlayerDefeated"].push(msg);
+	this.events.PlayerDefeated.push(msg);
 };
 
 AIInterface.prototype.OnGlobalEntityRenamed = function(msg)
 {
-	var cmpMirage = Engine.QueryInterface(msg.entity, IID_Mirage);
-	if (!cmpMirage)
-		this.events["EntityRenamed"].push(msg);
+	if (!Engine.QueryInterface(msg.entity, IID_Mirage))
+		this.events.EntityRenamed.push(msg);
 };
 
 AIInterface.prototype.OnGlobalTributeExchanged = function(msg)
 {
-	this.events["TributeExchanged"].push(msg);
+	this.events.TributeExchanged.push(msg);
 };
 
-// When a new technology is researched, check which templates it affects,
-// and send the updated values to the AI.
-// this relies on the fact that any "value" in a technology can only ever change
-// one template value, and that the naming is the same (with / in place of .)
-// it's not incredibly fast but it's not incredibly slow.
+AIInterface.prototype.OnTerritoriesChanged = function(msg)
+{
+	this.events.TerritoriesChanged.push(msg);
+};
+
+/**
+ * When a new technology is researched, check which templates it affects,
+ * and send the updated values to the AI.
+ * this relies on the fact that any "value" in a technology can only ever change
+ * one template value, and that the naming is the same (with / in place of .)
+ */
 AIInterface.prototype.OnTemplateModification = function(msg)
 {
 	let cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
@@ -209,7 +226,8 @@ AIInterface.prototype.OnTemplateModification = function(msg)
 	for (let name of this.templates)
 	{
 		let template = cmpTemplateManager.GetTemplateWithoutValidation(name);
-
+		if (!template || !template[msg.component])
+			continue;
 		for (let valName of msg.valueNames)
 		{
 			// let's get the base template value.
@@ -229,10 +247,9 @@ AIInterface.prototype.OnTemplateModification = function(msg)
 			let oldValue = +item;
 			let newValue = ApplyValueModificationsToTemplate(valName, oldValue, msg.player, template);
 			// Apply the same roundings as in the components
-			if (valName === "Health/Max" || valName === "Player/MaxPopulation"
-				|| valName === "Cost/Population" || valName === "Cost/PopulationBonus")
+			if (valName === "Player/MaxPopulation" || valName === "Cost/Population" ||
+			    valName === "Cost/PopulationBonus")
 				newValue = Math.round(newValue);
-
 			// TODO in some cases, we can have two opposite changes which bring us to the old value,
 			// and we should keep it. But how to distinguish it ?
 			if(newValue == oldValue)
@@ -240,9 +257,9 @@ AIInterface.prototype.OnTemplateModification = function(msg)
 			if (!this.changedTemplateInfo[msg.player])
 				this.changedTemplateInfo[msg.player] = {};
 			if (!this.changedTemplateInfo[msg.player][name])
-				this.changedTemplateInfo[msg.player][name] = [{"variable": valName, "value": newValue}];
+				this.changedTemplateInfo[msg.player][name] = [{ "variable": valName, "value": newValue }];
 			else
-				this.changedTemplateInfo[msg.player][name].push({"variable": valName, "value": newValue});
+				this.changedTemplateInfo[msg.player][name].push({ "variable": valName, "value": newValue });
 		}
 	}
 };
@@ -257,6 +274,8 @@ AIInterface.prototype.OnGlobalValueModification = function(msg)
 		if (!templateName || !templateName.length)
 			continue;
 		let template = cmpTemplateManager.GetTemplateWithoutValidation(templateName);
+		if (!template || !template[msg.component])
+			continue;
 		for (let valName of msg.valueNames)
 		{
 			// let's get the base template value.
@@ -276,17 +295,17 @@ AIInterface.prototype.OnGlobalValueModification = function(msg)
 			let oldValue = +item;
 			let newValue = ApplyValueModificationsToEntity(valName, oldValue, ent);
 			// Apply the same roundings as in the components
-			if (valName === "Health/Max" || valName === "Player/MaxPopulation"
-				|| valName === "Cost/Population" || valName === "Cost/PopulationBonus")
+			if (valName === "Player/MaxPopulation" || valName === "Cost/Population" ||
+			    valName === "Cost/PopulationBonus")
 				newValue = Math.round(newValue);
 			// TODO in some cases, we can have two opposite changes which bring us to the old value,
 			// and we should keep it. But how to distinguish it ?
 			if (newValue == oldValue)
 				continue;
 			if (!this.changedEntityTemplateInfo[ent])
-				this.changedEntityTemplateInfo[ent] = [{"variable": valName, "value": newValue}];
+				this.changedEntityTemplateInfo[ent] = [{ "variable": valName, "value": newValue }];
 			else
-				this.changedEntityTemplateInfo[ent].push({"variable": valName, "value": newValue});
+				this.changedEntityTemplateInfo[ent].push({ "variable": valName, "value": newValue });
 		}
 	}
 };
