@@ -1,6 +1,6 @@
 function Attack() {}
 
-Attack.prototype.bonusesSchema = 
+Attack.prototype.bonusesSchema =
 	"<optional>" +
 		"<element name='Bonuses'>" +
 			"<zeroOrMore>" +
@@ -88,13 +88,6 @@ Attack.prototype.Schema =
 				"<Crush>0.0</Crush>" +
 			"</Splash>" +
 		"</Ranged>" +
-		"<Charge>" +
-			"<Hack>10.0</Hack>" +
-			"<Pierce>0.0</Pierce>" +
-			"<Crush>50.0</Crush>" +
-			"<MaxRange>24.0</MaxRange>" +
-			"<MinRange>20.0</MinRange>" +
-		"</Charge>" +
 		"<Slaughter>" +
 			"<Hack>1000.0</Hack>" +
 			"<Pierce>0.0</Pierce>" +
@@ -172,20 +165,6 @@ Attack.prototype.Schema =
 			"</interleave>" +
 		"</element>" +
 	"</optional>" +
-	"<optional>" +
-		"<element name='Charge'>" +
-			"<interleave>" +
-				"<element name='Hack' a:help='Hack damage strength'><ref name='nonNegativeDecimal'/></element>" +
-				"<element name='Pierce' a:help='Pierce damage strength'><ref name='nonNegativeDecimal'/></element>" +
-				"<element name='Crush' a:help='Crush damage strength'><ref name='nonNegativeDecimal'/></element>" +
-				"<element name='MaxRange'><ref name='nonNegativeDecimal'/></element>" + // TODO: how do these work?
-				"<element name='MinRange'><ref name='nonNegativeDecimal'/></element>" +
-				Attack.prototype.bonusesSchema +
-				Attack.prototype.preferredClassesSchema +
-				Attack.prototype.restrictedClassesSchema +
-			"</interleave>" +
-		"</element>" +
-	"</optional>" +
 	"<optional>" +
 		"<element name='Slaughter' a:help='A special attack to kill domestic animals'>" +
 			"<interleave>" +
@@ -208,21 +187,15 @@ Attack.prototype.Serialize = null; // we have no dynamic state to save
 
 Attack.prototype.GetAttackTypes = function()
 {
-	let ret = [];
-	if (this.template.Charge) ret.push("Charge");
-	if (this.template.Melee) ret.push("Melee");
-	if (this.template.Ranged) ret.push("Ranged");
-	if (this.template.Capture) ret.push("Capture");
-	return ret;
+	return ["Melee", "Ranged", "Capture"].filter(type => !!this.template[type]);
 };
 
 Attack.prototype.GetPreferredClasses = function(type)
 {
 	if (this.template[type] && this.template[type].PreferredClasses &&
 	    this.template[type].PreferredClasses._string)
-	{
 		return this.template[type].PreferredClasses._string.split(/\s+/);
-	}
+
 	return [];
 };
 
@@ -230,9 +203,8 @@ Attack.prototype.GetRestrictedClasses = function(type)
 {
 	if (this.template[type] && this.template[type].RestrictedClasses &&
 	    this.template[type].RestrictedClasses._string)
-	{
 		return this.template[type].RestrictedClasses._string.split(/\s+/);
-	}
+
 	return [];
 };
 
@@ -253,7 +225,7 @@ Attack.prototype.CanAttack = function(target)
 	let heightDiff = Math.abs(cmpThisPosition.GetHeightOffset() - cmpTargetPosition.GetHeightOffset());
 
 	const cmpIdentity = Engine.QueryInterface(target, IID_Identity);
-	if (!cmpIdentity) 
+	if (!cmpIdentity)
 		return undefined;
 
 	const targetClasses = cmpIdentity.GetClassesList();
@@ -263,9 +235,6 @@ Attack.prototype.CanAttack = function(target)
 		if (type == "Capture" && !QueryMiragedInterface(target, IID_Capturable))
 			continue;
 
-		if (type == "Slaughter" && targetClasses.indexOf("Domestic") == -1)
-			continue;
-
 		if (heightDiff > this.GetRange(type).max)
 			continue;
 
@@ -273,15 +242,7 @@ Attack.prototype.CanAttack = function(target)
 		if (!restrictedClasses.length)
 			return true;
 
-		let canAttack = true;
-		for (let targetClass of targetClasses)
-		{
-			if (restrictedClasses.indexOf(targetClass) == -1)
-				continue;
-			canAttack = false;
-			break;
-		}
-		if (canAttack)
+		if (!MatchesClassList(targetClasses, restrictedClasses))
 			return true;
 	}
 
@@ -294,7 +255,7 @@ Attack.prototype.CanAttack = function(target)
 Attack.prototype.GetPreference = function(target)
 {
 	const cmpIdentity = Engine.QueryInterface(target, IID_Identity);
-	if (!cmpIdentity) 
+	if (!cmpIdentity)
 		return undefined;
 
 	const targetClasses = cmpIdentity.GetClassesList();
@@ -323,14 +284,9 @@ Attack.prototype.GetFullAttackRange = function()
 	let ret = { "min": Infinity, "max": 0 };
 	for (let type of this.GetAttackTypes())
 	{
-		// Ignore the special attack "slaughter" dedicated to domestic animals
-		if (type == "Slaughter")
-			continue;
 		let range = this.GetRange(type);
-		if (range.min < ret.min)
-			ret.min = range.min;
-		if (range.max > ret.max)
-			ret.max = range.max;
+		ret.min = Math.min(ret.min, range.min);
+		ret.max = Math.max(ret.max, range.max);
 	}
 	return ret;
 };
@@ -341,29 +297,23 @@ Attack.prototype.GetBestAttackAgainst = function(target, allowCapture)
 	if (cmpFormation)
 	{
 		// TODO: Formation against formation needs review
-		let best = ["Ranged", "Melee", "Capture"];
 		let types = this.GetAttackTypes();
-		for (let attack of best)
-			if (types.indexOf(attack) != -1)
-				return attack;
-		return undefined;
+		return ["Ranged", "Melee", "Capture"].find(attack => types.indexOf(attack) != -1);
 	}
 
 	let cmpIdentity = Engine.QueryInterface(target, IID_Identity);
-	if (!cmpIdentity) 
+	if (!cmpIdentity)
 		return undefined;
 
 	let targetClasses = cmpIdentity.GetClassesList();
-	let isTargetClass = function (className) { return targetClasses.indexOf(className) != -1; };
+	let isTargetClass = className => targetClasses.indexOf(className) != -1;
 
 	// Always slaughter domestic animals instead of using a normal attack
-	if (isTargetClass("Domestic") && this.template.Slaughter) 
+	if (isTargetClass("Domestic") && this.template.Slaughter)
 		return "Slaughter";
 
 	let attack = this;
-	let isAllowed = function (type) { return !attack.GetRestrictedClasses(type).some(isTargetClass); };
-
-	let types = this.GetAttackTypes().filter(isAllowed);
+	let types = this.GetAttackTypes().filter(type => !attack.GetRestrictedClasses(type).some(isTargetClass));
 
 	// check if the target is capturable
 	let captureIndex = types.indexOf("Capture");
@@ -378,10 +328,11 @@ Attack.prototype.GetBestAttackAgainst = function(target, allowCapture)
 		types.splice(captureIndex, 1);
 	}
 
-	let isPreferred = function (className) { return attack.GetPreferredClasses(className).some(isTargetClass); };
-	let byPreference = function (a, b) { return (types.indexOf(a) + (isPreferred(a) ? types.length : 0) ) - (types.indexOf(b) + (isPreferred(b) ? types.length : 0) ); };
+	let isPreferred = className => attack.GetPreferredClasses(className).some(isTargetClass);
 
-	return types.sort(byPreference).pop();
+	return types.sort((a, b) =>
+		(types.indexOf(a) + (isPreferred(a) ? types.length : 0)) -
+		(types.indexOf(b) + (isPreferred(b) ? types.length : 0))).pop();
 };
 
 Attack.prototype.CompareEntitiesByPreference = function(a, b)
@@ -403,7 +354,7 @@ Attack.prototype.GetTimers = function(type)
 	let repeat = +(this.template[type].RepeatTime || 1000);
 	repeat = ApplyValueModificationsToEntity("Attack/" + type + "/RepeatTime", repeat, this.entity);
 
-	return { "prepare": prepare, "repeat": repeat, "recharge": repeat - prepare };
+	return { "prepare": prepare, "repeat": repeat };
 };
 
 Attack.prototype.GetAttackStrengths = function(type)
@@ -430,6 +381,16 @@ Attack.prototype.GetAttackStrengths = function(type)
 	};
 };
 
+Attack.prototype.GetSplashDamage = function(type)
+{
+	if (!this.template[type].Splash)
+		return false;
+
+	let splash = this.GetAttackStrengths(type + ".Splash");
+	splash.friendlyFire = this.template[type].Splash.FriendlyFire != "false";
+	return splash;
+};
+
 Attack.prototype.GetRange = function(type)
 {
 	let max = +this.template[type].MaxRange;
@@ -499,6 +460,9 @@ Attack.prototype.GetNormalDistribution = function(){
  */
 Attack.prototype.PerformAttack = function(type, target)
 {
+	let attackerOwner = Engine.QueryInterface(this.entity, IID_Ownership).GetOwner();
+ 	let cmpDamage = Engine.QueryInterface(SYSTEM_ENTITY, IID_Damage);
+ 	
 	// If this is a ranged attack, then launch a projectile
 	if (type == "Ranged")
 	{
@@ -535,9 +499,9 @@ Attack.prototype.PerformAttack = function(type, target)
 
 		let horizDistance = targetPosition.horizDistanceTo(selfPosition);
 
-		// This is an approximation of the time ot the target, it assumes that the target has a constant radial 
-		// velocity, but since units move in straight lines this is not true.  The exact value would be more 
-		// difficult to calculate and I think this is sufficiently accurate.  (I tested and for cavalry it was 
+		// This is an approximation of the time ot the target, it assumes that the target has a constant radial
+		// velocity, but since units move in straight lines this is not true.  The exact value would be more
+		// difficult to calculate and I think this is sufficiently accurate.  (I tested and for cavalry it was
 		// about 5% of the units radius out in the worst case)
 		let timeToTarget = horizDistance / (horizSpeed - radialSpeed);
 
@@ -566,168 +530,66 @@ Attack.prototype.PerformAttack = function(type, target)
 		let cmpProjectileManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_ProjectileManager);
 		let id = cmpProjectileManager.LaunchProjectileAtPoint(this.entity, realTargetPosition, horizSpeed, gravity);
 
-		let playerId = Engine.QueryInterface(this.entity, IID_Ownership).GetOwner();
 		cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
-		cmpTimer.SetTimeout(this.entity, IID_Attack, "MissileHit", timeToTarget * 1000, {
+		let data = {
 			"type": type,
+			"attacker": this.entity,
 			"target": target,
+			"strengths": this.GetAttackStrengths(type),
 			"position": realTargetPosition,
 			"direction": missileDirection,
 			"projectileId": id,
-			"playerId":playerId
-		});
+			"multiplier": this.GetAttackBonus(type, target),
+			"isSplash": false,
+			"attackerOwner": attackerOwner
+		};
+		if (this.template.Ranged.Splash)
+		{
+			data.friendlyFire = this.template.Ranged.Splash.FriendlyFire != "false";
+			data.radius = +this.template.Ranged.Splash.Range;
+			data.shape = this.template.Ranged.Splash.Shape;
+			data.isSplash = true;
+			data.splashStrengths = this.GetAttackStrengths(type+".Splash");
+		}
+		cmpTimer.SetTimeout(SYSTEM_ENTITY, IID_Damage, "MissileHit", timeToTarget * 1000, data);
 	}
 	else if (type == "Capture")
 	{
+		if (attackerOwner == -1)
+			return;
+		
 		let multiplier = this.GetAttackBonus(type, target);
 		let cmpHealth = Engine.QueryInterface(target, IID_Health);
 		if (!cmpHealth || cmpHealth.GetHitpoints() == 0)
 			return;
-		multiplier *= cmpHealth.GetMaxHitpoints() / cmpHealth.GetHitpoints();
+		multiplier *= cmpHealth.GetMaxHitpoints() / (0.1 * cmpHealth.GetMaxHitpoints() + 0.9 * cmpHealth.GetHitpoints());
 
-		let cmpOwnership = Engine.QueryInterface(this.entity, IID_Ownership);
-		if (!cmpOwnership || cmpOwnership.GetOwner() == -1)
-			return;
-
-		let owner = cmpOwnership.GetOwner();
 		let cmpCapturable = Engine.QueryInterface(target, IID_Capturable);
-		if (!cmpCapturable || !cmpCapturable.CanCapture(owner))
+		if (!cmpCapturable || !cmpCapturable.CanCapture(attackerOwner))
 			return;
 
 		let strength = this.GetAttackStrengths("Capture").value * multiplier;
-		if (cmpCapturable.Reduce(strength, owner))
+		if (cmpCapturable.Reduce(strength, attackerOwner))
 			Engine.PostMessage(target, MT_Attacked, {
 				"attacker": this.entity,
 				"target": target,
 				"type": type,
-				"damage": strength
+				"damage": strength,
+				"attackerOwner": attackerOwner
 			});
 	}
 	else
 	{
 		// Melee attack - hurt the target immediately
-		Damage.CauseDamage({
+		cmpDamage.CauseDamage({
 			"strengths": this.GetAttackStrengths(type),
 			"target": target,
 			"attacker": this.entity,
 			"multiplier": this.GetAttackBonus(type, target),
-			"type":type
+			"type": type,
+			"attackerOwner": attackerOwner
 		});
 	}
-	// TODO: charge attacks (need to design how they work)
-};
-
-Attack.prototype.InterpolatedLocation = function(ent, lateness)
-{
-	let cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
-	let turnLength = cmpTimer.GetLatestTurnLength()/1000;
-	let cmpTargetPosition = Engine.QueryInterface(ent, IID_Position);
-	if (!cmpTargetPosition || !cmpTargetPosition.IsInWorld()) // TODO: handle dead target properly
-		return undefined;
-	let curPos = cmpTargetPosition.GetPosition();
-	let prevPos = cmpTargetPosition.GetPreviousPosition();
-	lateness /= 1000;
-	return new Vector3D((curPos.x * (turnLength - lateness) + prevPos.x * lateness) / turnLength,
-			0,
-	        (curPos.z * (turnLength - lateness) + prevPos.z * lateness) / turnLength);
-};
-
-// Tests whether it point is inside of ent's footprint
-Attack.prototype.testCollision = function(ent, point, lateness)
-{
-	let targetPosition = this.InterpolatedLocation(ent, lateness);
-	if (!targetPosition)
-		return false;
-	let cmpFootprint = Engine.QueryInterface(ent, IID_Footprint);
-	if (!cmpFootprint)
-		return false;
-	let targetShape = cmpFootprint.GetShape();
-
-	if (!targetShape || !targetPosition)
-		return false;
-
-	if (targetShape.type === 'circle')
-	{
-		// Use VectorDistanceSquared and square targetShape.radius to avoid square roots.
-		return (targetPosition.horizDistanceTo(point) < (targetShape.radius * targetShape.radius));
-	}
-	else
-	{
-		let angle = Engine.QueryInterface(ent, IID_Position).GetRotation().y;
-
-		let d = Vector3D.sub(point, targetPosition);
-		d = Vector2D.from3D(d).rotate(-angle);
-
-		return d.x < Math.abs(targetShape.width/2) && d.y < Math.abs(targetShape.depth/2);
-	}
-};
-
-Attack.prototype.MissileHit = function(data, lateness)
-{
-	let targetPosition = this.InterpolatedLocation(data.target, lateness);
-	if (!targetPosition)
-		return;
-
-	if (this.template.Ranged.Splash) // splash damage, do this first in case the direct hit kills the target
-	{
-		let friendlyFire = this.template.Ranged.Splash.FriendlyFire;
-		let splashRadius = this.template.Ranged.Splash.Range;
-		let splashShape = this.template.Ranged.Splash.Shape;
-		let playersToDamage;
-		// If friendlyFire isn't enabled, get all player enemies to pass to "Damage.CauseSplashDamage".
-		if (friendlyFire == "false")
-		{
-			let cmpPlayer = QueryPlayerIDInterface(data.playerId);
-			playersToDamage = cmpPlayer.GetEnemies();
-		}
-		// Damage the units.
-		Damage.CauseSplashDamage({
-			"attacker": this.entity,
-			"origin": Vector2D.from3D(data.position),
-			"radius": splashRadius,
-			"shape": splashShape,
-			"strengths": this.GetAttackStrengths(data.type),
-			"direction": data.direction,
-			"playersToDamage": playersToDamage,
-			"type":data.type
-		});
-	}
-
-	if (this.testCollision(data.target, data.position, lateness))
-	{
-		data.attacker = this.entity;
-		data.multiplier = this.GetAttackBonus(data.type, data.target);
-		data.strengths = this.GetAttackStrengths(data.type);
-		// Hit the primary target
-		Damage.CauseDamage(data);
-
-		// Remove the projectile
-		let cmpProjectileManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_ProjectileManager);
-		cmpProjectileManager.RemoveProjectile(data.projectileId);
-	}
-	else
-	{
-		// If we didn't hit the main target look for nearby units
-		let cmpPlayer = QueryPlayerIDInterface(data.playerId);
-		let ents = Damage.EntitiesNearPoint(Vector2D.from3D(data.position), targetPosition.horizDistanceTo(data.position) * 2, cmpPlayer.GetEnemies());
-
-		for (let i = 0; i < ents.length; ++i)
-		{
-			if (this.testCollision(ents[i], data.position, lateness))
-			{
-				Damage.CauseDamage({
-						"strengths": this.GetAttackStrengths(data.type),
-						"target": ents[i],
-						"attacker": this.entity,
-						"multiplier": this.GetAttackBonus(data.type, ents[i]),
-						"type": data.type
-				});
-				// Remove the projectile
-				let cmpProjectileManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_ProjectileManager);
-				cmpProjectileManager.RemoveProjectile(data.projectileId);
-			}
-		}
-	}
 };
 
 Attack.prototype.OnValueModification = function(msg)
@@ -739,12 +601,9 @@ Attack.prototype.OnValueModification = function(msg)
 	if (!cmpUnitAI)
 		return;
 
-	for (let type of this.GetAttackTypes())
-		if (msg.valueNames.indexOf("Attack/"+type+"/MaxRange") !== -1)
-		{
-			cmpUnitAI.UpdateRangeQueries();
-			return;
-		}
+	if (this.GetAttackTypes().some(type =>
+	      msg.valueNames.indexOf("Attack/" + type + "/MaxRange") != -1))
+		cmpUnitAI.UpdateRangeQueries();
 };
 
 Engine.RegisterComponentType(IID_Attack, "Attack", Attack);
