@@ -1,114 +1,56 @@
 function Auras() {}
 
-var modificationSchema =
-	"<element name='Modifications' a:help='Modification list'>" +
-		"<oneOrMore>" +
-			"<element a:help='Name of the value to modify'>" +
-				"<anyName/>" +
-				"<choice>" +
-					"<element name='Add'>" +
-						"<data type='decimal'/>" +
-					"</element>" +
-					"<element name='Multiply'>" +
-						"<data type='decimal'/>" +
-					"</element>" +
-				"</choice>" +
-			"</element>" +
-		"</oneOrMore>" +
-	"</element>";
-
 Auras.prototype.Schema =
-	"<oneOrMore>" +
-		"<element a:help='Any name you want'>" +
-			"<anyName/>" +
-			"<interleave>" +
-				"<optional>" +
-					"<element name='Radius' a:help='Define the radius this aura affects, if it is a range aura'>" +
-						"<data type='nonNegativeInteger'/>" +
-					"</element>" +
-				"</optional>" +
-				"<element name='Type' a:help='Controls how this aura affects nearby units'>" +
-					"<choice>" +
-						"<value a:help='Affects units in the same formation'>formation</value>" +
-						"<value a:help='Affects units in a certain range'>range</value>" +
-						"<value a:help='Affects the structure or unit this unit is garrisoned in'>garrison</value>" +
-						"<value a:help='Affects the units that are garrisoned on a certain structure'>garrisonedUnits</value>" +
-						"<value a:help='Affects all units while this unit is alive'>global</value>" +
-					"</choice>" +
-				"</element>" +
-				modificationSchema +
-				"<optional>" +
-					"<element name='AuraName' a:help='name to display in the GUI'>" +
-						"<text/>" +
-					"</element>" +
-				"</optional>" +
-				"<optional>" +
-					"<element name='AuraDescription' a:help='description to display in the GUI, requires a name'>" +
-						"<text/>" +
-					"</element>" +
-				"</optional>" +
-				"<optional>" +
-					"<element name='OverlayIcon' a:help='Icon to show on the entities affected by this aura'>" +
-						"<text/>" +
-					"</element>" +
-				"</optional>" +
-				"<element name='Affects' a:help='Affected classes'>" +
-					"<text/>" +
-				"</element>" +
-				"<optional>" +
-					"<element name='AffectedPlayers' a:help='Affected players'>" +
-						"<text/>" +
-					"</element>" +
-				"</optional>" +
-			"</interleave>" +
-		"</element>" +
-	"</oneOrMore>";
+	"<attribute name='datatype'>" +
+		"<value>tokens</value>" +
+	"</attribute>" +
+	"<text a:help='A whitespace-separated list of aura files, placed under simulation/data/auras/'/>";
 
 Auras.prototype.Init = function()
 {
-	var cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
-	this.templateName = cmpTemplateManager.GetCurrentTemplateName(this.entity);
+	let cmpDataTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_DataTemplateManager);
 	this.auras = {};
 	this.affectedPlayers = {};
-	for (var name in this.template)
+	let auraNames = this.GetAuraNames();
+	for (let name of auraNames)
 	{
-		this.affectedPlayers[name] = []; // will be calculated on ownership change
-		var aura = {};
-		aura.affects = this.template[name].Affects;
-		if (this.template[name].AffectedPlayers)
-			aura.affectedPlayers = this.template[name].AffectedPlayers.split(/\s+/);
-		this.auras[name] = aura;
+		this.affectedPlayers[name] = [];
+		this.auras[name] = cmpDataTemplateManager.GetAuraTemplate(name);
 	}
 	// In case of autogarrisoning, this component can be called before ownership is set.
 	// So it needs to be completely initialised from the start.
 	this.Clean();
 };
 
-Auras.prototype.GetModifierIdentifier = function(name, mod)
+// We can modify identifier if we want stackable auras in some case.
+Auras.prototype.GetModifierIdentifier = function(name)
 {
-		return this.templateName + "/" + name + "/" + mod.value;
+	if (this.auras[name].stackable)
+		return name + this.entity;
+	return name;
 };
 
 Auras.prototype.GetDescriptions = function()
 {
+	let auraNames = this.GetAuraNames();
 	var ret = {};
-	for (let name in this.template)
+	for (let name of auraNames)
 	{
-		let aura = this.template[name];
-		if (aura.AuraName)
-			ret[aura.AuraName] = aura.AuraDescription || null;
+		let aura = this.auras[name];
+		if (aura.auraName)
+			ret[aura.auraName] = aura.auraDescription || null;
 	}
 	return ret;
 };
 
 Auras.prototype.GetAuraNames = function()
 {
-	return Object.keys(this.template);
+	return this.template._string.split(/\s+/);
 };
 
 Auras.prototype.GetOverlayIcon = function(name)
 {
-	return this.template[name].OverlayIcon || "";
+	return this.auras[name].overlayIcon || "";
 };
 
 Auras.prototype.GetAffectedEntities = function(name)
@@ -122,7 +64,7 @@ Auras.prototype.GetRange = function(name)
 		return undefined;
 	if (this.IsGlobalAura(name))
 		return -1; // -1 is infinite range
-	return +this.template[name].Radius;
+	return +this.auras[name].radius;
 };
 
 Auras.prototype.GetClasses = function(name)
@@ -145,7 +87,9 @@ Auras.prototype.CalculateAffectedPlayers = function(name)
 	var affectedPlayers = this.auras[name].affectedPlayers || ["Player"];
 	this.affectedPlayers[name] = [];
 
-	var cmpPlayer = QueryOwnerInterface(this.entity);
+	var cmpPlayer = Engine.QueryInterface(this.entity, IID_Player);
+	if (!cmpPlayer)
+		cmpPlayer = QueryOwnerInterface(this.entity);
 	if (!cmpPlayer)
 		return;
 
@@ -163,6 +107,16 @@ Auras.prototype.CalculateAffectedPlayers = function(name)
 	}
 };
 
+Auras.prototype.CanApply = function(name)
+{
+	if (!this.auras[name].requiredTechnology)
+		return true;
+	let cmpTechnologyManager = QueryOwnerInterface(this.entity, IID_TechnologyManager);
+	if (!cmpTechnologyManager)
+		return false;
+	return cmpTechnologyManager.IsTechnologyResearched(this.auras[name].requiredTechnology);
+};
+
 Auras.prototype.HasFormationAura = function()
 {
 	return this.GetAuraNames().some(n => this.IsFormationAura(n));
@@ -180,7 +134,7 @@ Auras.prototype.HasGarrisonedUnitsAura = function()
 
 Auras.prototype.GetType = function(name)
 {
-	return this.template[name].Type;
+	return this.auras[name].type;
 };
 
 Auras.prototype.IsFormationAura = function(name)
@@ -236,25 +190,6 @@ Auras.prototype.Clean = function()
 			cmpRangeManager.DestroyActiveQuery(this[name].rangeQuery);
 	}
 
-	for (let name in this.template)
-	{
-		let modifications = [];
-		for (let value in this.template[name].Modifications)
-		{
-			let mod = {};
-			mod.value = value.replace(/\./g, "/").replace(/\/\//g, ".");
-			let templateModifications = this.template[name].Modifications[value];
-			if (templateModifications.Add)
-				mod.add = ApplyValueModificationsToEntity("Auras/"+name+"/Modifications/"+mod.value+"/Add",
-					+templateModifications.Add, this.entity);
-			else if (templateModifications.Multiply)
-				mod.multiply = ApplyValueModificationsToEntity("Auras/"+name+"/Modifications/"+mod.value+"/Multiply",
-					+templateModifications.Multiply, this.entity);
-			modifications.push(mod);
-		}
-		this.auras[name].modifications = modifications;
-	}
-
 	for (let name of auraNames)
 	{
 		// only calculate the affected players on re-applying the bonuses
@@ -263,6 +198,7 @@ Auras.prototype.Clean = function()
 		// initialise range query
 		this[name] = {};
 		this[name].targetUnits = [];
+		this[name].isApplied = this.CanApply(name);
 		var affectedPlayers = this.GetAffectedPlayers(name);
 
 		if (!affectedPlayers.length)
@@ -343,6 +279,9 @@ Auras.prototype.ApplyGarrisonBonus = function(structure)
 
 Auras.prototype.ApplyTemplateBonus = function(name, players)
 {
+	if (!this[name].isApplied)
+		return;
+
 	if (!this.IsGlobalAura(name))
 		return;
 	var modifications = this.GetModifications(name);
@@ -351,7 +290,7 @@ Auras.prototype.ApplyTemplateBonus = function(name, players)
 
 	for (let mod of modifications)
 		for (let player of players)
-			cmpAuraManager.ApplyTemplateBonus(mod.value, player, classes, mod, this.GetModifierIdentifier(name, mod));
+			cmpAuraManager.ApplyTemplateBonus(mod.value, player, classes, mod, this.GetModifierIdentifier(name));
 };
 
 Auras.prototype.RemoveFormationBonus = function(memberList)
@@ -370,6 +309,8 @@ Auras.prototype.RemoveGarrisonBonus = function(structure)
 
 Auras.prototype.RemoveTemplateBonus = function(name)
 {
+	if (!this[name].isApplied)
+		return;
 	if (!this.IsGlobalAura(name))
 		return;
 
@@ -380,7 +321,7 @@ Auras.prototype.RemoveTemplateBonus = function(name)
 
 	for (let mod of modifications)
 		for (let player of players)
-			cmpAuraManager.RemoveTemplateBonus(mod.value, player, classes, this.GetModifierIdentifier(name, mod));
+			cmpAuraManager.RemoveTemplateBonus(mod.value, player, classes, this.GetModifierIdentifier(name));
 };
 
 Auras.prototype.ApplyBonus = function(name, ents)
@@ -390,12 +331,15 @@ Auras.prototype.ApplyBonus = function(name, ents)
 		return;
 
 	this[name].targetUnits = this[name].targetUnits.concat(validEnts);
+
+	if (!this[name].isApplied)
+		return;
+
 	var modifications = this.GetModifications(name);
 	var cmpAuraManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_AuraManager);
 
 	for (let mod of modifications)
-		cmpAuraManager.ApplyBonus(mod.value, validEnts, mod, this.GetModifierIdentifier(name, mod));
-
+		cmpAuraManager.ApplyBonus(mod.value, validEnts, mod, this.GetModifierIdentifier(name));
 	// update status bars if this has an icon
 	if (!this.GetOverlayIcon(name))
 		return;
@@ -415,11 +359,15 @@ Auras.prototype.RemoveBonus = function(name, ents)
 		return;
 
 	this[name].targetUnits = this[name].targetUnits.filter(v => validEnts.indexOf(v) == -1);
+
+	if (!this[name].isApplied)
+		return;
+
 	var modifications = this.GetModifications(name);
 	var cmpAuraManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_AuraManager);
 
 	for (let mod of modifications)
-		cmpAuraManager.RemoveBonus(mod.value, validEnts, this.GetModifierIdentifier(name, mod));
+		cmpAuraManager.RemoveBonus(mod.value, validEnts, this.GetModifierIdentifier(name));
 
 	// update status bars if this has an icon
 	if (!this.GetOverlayIcon(name))
@@ -440,15 +388,28 @@ Auras.prototype.OnOwnershipChanged = function(msg)
 
 Auras.prototype.OnDiplomacyChanged = function(msg)
 {
-	var cmpOwnership = Engine.QueryInterface(this.entity, IID_Ownership);
-	if (cmpOwnership && cmpOwnership.GetOwner() == msg.player)
+	var cmpPlayer = Engine.QueryInterface(this.entity, IID_Player);
+	if (cmpPlayer && (cmpPlayer.GetPlayerID() == msg.player || cmpPlayer.GetPlayerID() == msg.otherPlayer) ||
+	   IsOwnedByPlayer(msg.player, this.entity) ||
+	   IsOwnedByPlayer(msg.otherPlayer, this.entity))
 		this.Clean();
 };
 
-Auras.prototype.OnValueModification = function(msg)
+Auras.prototype.OnGlobalResearchFinished = function(msg)
 {
-	if (msg.component == "Auras")
-		this.Clean();
+	var cmpPlayer = Engine.QueryInterface(this.entity, IID_Player);
+	if ((!cmpPlayer || cmpPlayer.GetPlayerID() != msg.player) && !IsOwnedByPlayer(msg.player, this.entity))
+		return;
+	let auraNames = this.GetAuraNames();
+	for (let name of auraNames)
+	{
+		let requiredTech = this.auras[name].requiredTechnology;
+		if (requiredTech && requiredTech == msg.tech)
+		{
+			this.Clean();
+			return;
+		}
+	}
 };
 
 Engine.RegisterComponentType(IID_Auras, "Auras", Auras);
