@@ -91,7 +91,7 @@ Formation.prototype.Init = function()
 	this.centerGap = +(this.template.CenterGap || 0);
 
 	var animations = this.template.Animations;
-	this.animations = {}
+	this.animations = {};
 	for (var animationName in animations)
 	{
 		var differentAnimations = animations[animationName].split(/\s*;\s*/);
@@ -274,7 +274,7 @@ Formation.prototype.UnsetInPosition = function(ent)
 	var ind = this.inPosition.indexOf(ent);
 	if (ind != -1)
 		this.inPosition.splice(ind, 1);
-}
+};
 
 /**
  * Set whether we should rearrange formation members if
@@ -296,30 +296,13 @@ Formation.prototype.SetMembers = function(ents)
 
 	var cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
 	var templateName = cmpTemplateManager.GetCurrentTemplateName(this.entity);
-	// keep the number of entities per pass class to find the most used
-	// For land units, this will be "default", for ship units, it should be "ship"
-	var passClasses = {};
-	var bestPassClassNumber = 0;
-	var bestPassClass = "default";
 
 	for each (var ent in this.members)
 	{
-		var cmpUnitMotion = Engine.QueryInterface(ent,IID_UnitMotion);
-		var passClass = cmpUnitMotion.GetPassabilityClassName();
-		if (passClasses[passClass])
-			var number = passClasses[passClass]++;
-		else
-			var number = passClasses[passClass] = 1;
-		if (number > bestPassClassNumber)
-		{
-			bestPassClass = passClass;
-			bestPassClassNumber = number;
-		}
-
 		var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
 		cmpUnitAI.SetFormationController(this.entity);
 		cmpUnitAI.SetLastFormationTemplate(templateName);
-		
+
 		var cmpAuras = Engine.QueryInterface(ent, IID_Auras);
 		if (cmpAuras && cmpAuras.HasFormationAura())
 		{
@@ -327,13 +310,12 @@ Formation.prototype.SetMembers = function(ents)
 			cmpAuras.ApplyFormationBonus(ents);
 		}
 	}
-	var cmpUnitMotion = Engine.QueryInterface(this.entity, IID_UnitMotion);
-	cmpUnitMotion.SetPassabilityClassName(bestPassClass);
 
 	this.offsets = undefined;
 	// Locate this formation controller in the middle of its members
 	this.MoveToMembersCenter();
 
+	// Compute the speed etc. of the formation
 	this.ComputeMotionParameters();
 };
 
@@ -432,7 +414,7 @@ Formation.prototype.FindInPosition = function()
 				this.SetInPosition(this.members[i]);
 		}
 	}
-}
+};
 
 /**
  * Remove all members and destroy the formation.
@@ -748,7 +730,7 @@ Formation.prototype.ComputeFormationOffsets = function(active, positions)
 				offsets.push(new Vector2D(x + r1, z + r2));
 				offsets[offsets.length - 1].row = r+1;
 				offsets[offsets.length - 1].column = column;
-				left--
+				left--;
 			}
 			++r;
 			this.maxColumnsUsed[r] = n;
@@ -872,7 +854,7 @@ Formation.prototype.GetEstimatedOrientation = function(pos)
 };
 
 /**
- * Set formation controller's radius and speed based on its current members.
+ * Set formation controller's speed based on its current members.
  */
 Formation.prototype.ComputeMotionParameters = function()
 {
@@ -881,10 +863,6 @@ Formation.prototype.ComputeMotionParameters = function()
 
 	for each (var ent in this.members)
 	{
-		var cmpObstruction = Engine.QueryInterface(ent, IID_Obstruction);
-		if (cmpObstruction)
-			maxRadius = Math.max(maxRadius, cmpObstruction.GetUnitRadius());
-
 		var cmpUnitMotion = Engine.QueryInterface(ent, IID_UnitMotion);
 		if (cmpUnitMotion)
 			minSpeed = Math.min(minSpeed, cmpUnitMotion.GetWalkSpeed());
@@ -892,10 +870,7 @@ Formation.prototype.ComputeMotionParameters = function()
 	minSpeed *= this.GetSpeedMultiplier();
 
 	var cmpUnitMotion = Engine.QueryInterface(this.entity, IID_UnitMotion);
-	cmpUnitMotion.SetUnitRadius(maxRadius);
 	cmpUnitMotion.SetSpeed(minSpeed);
-
-	// TODO: we also need to do something about PassabilityClass, CostClass
 };
 
 Formation.prototype.ShapeUpdate = function()
@@ -980,7 +955,7 @@ Formation.prototype.OnGlobalEntityRenamed = function(msg)
 		// (e.g. packed vs. unpacked siege), we need to recompute motion parameters
 		this.ComputeMotionParameters();
 	}
-}
+};
 
 Formation.prototype.RegisterTwinFormation = function(entity)
 {
@@ -1012,7 +987,13 @@ Formation.prototype.LoadFormation = function(newTemplate)
 	this.Disband();
 
 	var newFormation = Engine.AddEntity(newTemplate);
-	// apply the info from the old formation to the new one
+
+	// Apply the info from the old formation to the new one
+
+	let cmpNewOwnership = Engine.QueryInterface(newFormation, IID_Ownership);
+	let cmpOwnership = Engine.QueryInterface(this.entity, IID_Ownership);
+	if (cmpOwnership && cmpNewOwnership)
+		cmpNewOwnership.SetOwner(cmpOwnership.GetOwner());
 
 	var cmpNewPosition = Engine.QueryInterface(newFormation, IID_Position);
 	var cmpPosition = Engine.QueryInterface(this.entity, IID_Position);
