@@ -65,16 +65,12 @@ Gate.prototype.OnDestroy = function()
 Gate.prototype.SetupRangeQuery = function(owner)
 {
 	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
-	var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
-	var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(owner), IID_Player);
+
 	if (this.unitsQuery)
 		cmpRangeManager.DestroyActiveQuery(this.unitsQuery);
 
 	// Only allied units can make the gate open.
-	var players = [];
-	for (var i = 0; i < cmpPlayer.GetDiplomacy().length; ++i)
-		if (cmpPlayer.IsAlly(i))
-			players.push(i);
+	var players = QueryPlayerIDInterface(owner).GetAllies();
 
 	var range = this.GetPassRange();
 	if (range > 0)
@@ -219,7 +215,7 @@ Gate.prototype.CloseGate = function()
 		return;
 
 	// The gate can't be closed if there are entities colliding with it.
-	var collisions = cmpObstruction.GetEntityCollisions(false, true);
+	var collisions = cmpObstruction.GetUnitCollisions();
 	if (collisions.length)
 	{		
 		if (!this.timer)
