@@ -17,8 +17,16 @@ Health.prototype.Schema =
 		"</element>" +
 	"</optional>" +
 	"<optional>" +
-		"<element name='SpawnEntityOnDeath' a:help='Entity template to spawn when this entity dies. Note: this is different than the corpse, which retains the original entity&apos;s appearance'>" +
-			"<text/>" +
+		"<element name='DamageVariants'>" + 
+			"<oneOrMore>" + 
+				"<element a:help='Name of the variant to select when health drops under the defined ratio'>" + 
+					"<anyName/>" + 
+					"<data type='decimal'>" + 
+						"<param name='minInclusive'>0</param>" + 
+						"<param name='maxInclusive'>1</param>" + 
+					"</data>" + 
+				"</element>" + 
+			"</oneOrMore>" + 
 		"</element>" +
 	"</optional>" +
 	"<element name='RegenRate' a:help='Hitpoint regeneration rate per second.'>" +
@@ -34,6 +42,11 @@ Health.prototype.Schema =
 			"<value a:help='Remain in the world with 0 health'>remain</value>" +
 		"</choice>" +
 	"</element>" +
+	"<optional>" +
+		"<element name='SpawnEntityOnDeath' a:help='Entity template to spawn when this entity dies. Note: this is different than the corpse, which retains the original entity&apos;s appearance'>" +
+			"<text/>" +
+		"</element>" +
+	"</optional>" +
 	"<element name='Undeletable' a:help='Prevent players from deleting this entity.'>" +
 		"<data type='boolean'/>" +
 	"</element>" +
@@ -44,13 +57,15 @@ Health.prototype.Schema =
 Health.prototype.Init = function()
 {
 	// Cache this value so it allows techs to maintain previous health level
-	this.maxHitpoints = Math.round(+this.template.Max);
+	this.maxHitpoints = +this.template.Max;
 	// Default to <Initial>, but use <Max> if it's undefined or zero
 	// (Allowing 0 initial HP would break our death detection code)
 	this.hitpoints = +(this.template.Initial || this.GetMaxHitpoints());
 	this.regenRate = ApplyValueModificationsToEntity("Health/RegenRate", +this.template.RegenRate, this.entity);
 	this.idleRegenRate = ApplyValueModificationsToEntity("Health/IdleRegenRate", +this.template.IdleRegenRate, this.entity);
+	this.undeletable = this.template.Undeletable == "true";
 	this.CheckRegenTimer();
+	this.UpdateActor();
 };
 
 //// Interface functions ////
@@ -92,7 +107,7 @@ Health.prototype.SetHitpoints = function(value)
 			cmpRangeManager.SetEntityFlag(this.entity, "injured", false);
 	}
 
-	Engine.PostMessage(this.entity, MT_HealthChanged, { "from": old, "to": this.hitpoints });
+	this.RegisterHealthChanged(old);
 };
 
 Health.prototype.IsRepairable = function()
@@ -109,7 +124,12 @@ Health.prototype.IsUnhealable = function()
 
 Health.prototype.IsUndeletable = function()
 {
-	return this.template.Undeletable == "true";
+	return this.undeletable;
+};
+
+Health.prototype.SetUndeletable = function(undeletable)
+{
+	this.undeletable = undeletable;
 };
 
 Health.prototype.GetIdleRegenRate = function()
@@ -223,16 +243,14 @@ Health.prototype.Reduce = function(amount)
 			}
 
 			this.hitpoints = 0;
-
-			Engine.PostMessage(this.entity, MT_HealthChanged, { "from": oldHitpoints, "to": this.hitpoints });
+			this.RegisterHealthChanged(oldHitpoints);
 		}
 
 	}
 	else
 	{
 		this.hitpoints -= amount;
-
-		Engine.PostMessage(this.entity, MT_HealthChanged, { "from": oldHitpoints, "to": this.hitpoints });
+		this.RegisterHealthChanged(oldHitpoints);
 	}
 	state.change = this.hitpoints - oldHitpoints;
 	return state;
@@ -262,8 +280,8 @@ Health.prototype.Increase = function(amount)
 			cmpRangeManager.SetEntityFlag(this.entity, "injured", false);
 	}
 
-	Engine.PostMessage(this.entity, MT_HealthChanged, { "from": old, "to": this.hitpoints });
-	// We return the old and the actual hp
+	this.RegisterHealthChanged(old);
+
 	return { "old": old, "new": this.hitpoints};
 };
 
@@ -337,16 +355,47 @@ Health.prototype.CreateDeathSpawnedEntity = function()
 	return spawnedEntity;
 };
 
+Health.prototype.UpdateActor = function()
+{
+	if (!this.template.DamageVariants)
+		return;
+	let ratio = this.GetHitpoints() / this.GetMaxHitpoints();
+	let newDamageVariant = "alive";
+	if (ratio > 0) 
+	{ 
+		let minTreshold = 1;
+		for (let key in this.template.DamageVariants) 
+		{ 
+			let treshold = +this.template.DamageVariants[key];
+			if (treshold < ratio || treshold > minTreshold) 
+				continue;
+			newDamageVariant = key;
+			minTreshold = treshold;
+		} 
+	} 
+	else 
+		newDamageVariant = "death";
+
+	if (this.damageVariant && this.damageVariant == newDamageVariant)
+		return;
+
+	this.damageVariant = newDamageVariant;
+
+	let cmpVisual = Engine.QueryInterface(this.entity, IID_Visual);
+	if (cmpVisual)
+		cmpVisual.SetVariant("health", newDamageVariant);
+};
+
 Health.prototype.OnValueModification = function(msg)
 {
 	if (msg.component != "Health")
 		return;
 
 	let oldMaxHitpoints = this.GetMaxHitpoints();
-	let newMaxHitpoints = Math.round(ApplyValueModificationsToEntity("Health/Max", +this.template.Max, this.entity));
+	let newMaxHitpoints = ApplyValueModificationsToEntity("Health/Max", +this.template.Max, this.entity);
 	if (oldMaxHitpoints != newMaxHitpoints)
 	{
-		let newHitpoints = Math.round(this.GetHitpoints() * newMaxHitpoints/oldMaxHitpoints);
+		let newHitpoints = this.GetHitpoints() * newMaxHitpoints/oldMaxHitpoints;
 		this.maxHitpoints = newMaxHitpoints;
 		this.SetHitpoints(newHitpoints);
 	}
@@ -361,9 +410,11 @@ Health.prototype.OnValueModification = function(msg)
 		this.CheckRegenTimer();
 };
 
-Health.prototype.OnHealthChanged = function()
+Health.prototype.RegisterHealthChanged = function(from)
 {
 	this.CheckRegenTimer();
+	this.UpdateActor();
+	Engine.PostMessage(this.entity, MT_HealthChanged, { "from": from, "to": this.hitpoints });
 };
 
 Engine.RegisterComponentType(IID_Health, "Health", Health);
