@@ -359,9 +359,60 @@ Player.prototype.GetState = function()
 	return this.state;
 };
 
-Player.prototype.SetState = function(newState)
+Player.prototype.SetState = function(newState, resign)
 {
+	if (this.state != "active")
+		return;
+
+	if (newState != "won" && newState != "defeated")
+	{
+		warn("Can't change playerstate to " + this.state);
+		return;
+	}
+
 	this.state = newState;
+
+	let won = newState == "won";
+	let cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+	if (won)
+		cmpRangeManager.SetLosRevealAll(this.playerID, true);
+	else
+	{
+		// Reassign all player's entities to Gaia
+		let entities = cmpRangeManager.GetEntitiesByPlayer(this.playerID);
+
+		// The ownership change is done in two steps so that entities don't hit idle
+		// (and thus possibly look for "enemies" to attack) before nearby allies get
+		// converted to Gaia as well.
+		for (let entity of entities)
+		{
+			let cmpOwnership = Engine.QueryInterface(entity, IID_Ownership);
+			cmpOwnership.SetOwnerQuiet(0);
+		}
+
+		// With the real ownership change complete, send OwnershipChanged messages.
+		for (let entity of entities)
+			Engine.PostMessage(entity, MT_OwnershipChanged, {
+				"entity": entity,
+				"from": this.playerID,
+				"to": 0
+			});
+	}
+
+	Engine.BroadcastMessage(won ? MT_PlayerWon : MT_PlayerDefeated, { "playerId": this.playerID });
+
+	let cmpGUIInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
+	if (won)
+		cmpGUIInterface.PushNotification({
+			"type": "won",
+			"players": [this.playerID]
+		});
+	else
+		cmpGUIInterface.PushNotification({
+			"type": "defeat",
+			"players": [this.playerID],
+			"resign": resign
+		});
 };
 
 Player.prototype.GetTeam = function()
@@ -381,7 +432,7 @@ Player.prototype.SetTeam = function(team)
 	if (cmpPlayerManager && this.team != -1)
 		for (let i = 0; i < cmpPlayerManager.GetNumPlayers(); ++i)
 		{
-			let cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(i), IID_Player);
+			let cmpPlayer = QueryPlayerIDInterface(i);
 			if (this.team != cmpPlayer.GetTeam())
 				continue;
 
@@ -389,7 +440,10 @@ Player.prototype.SetTeam = function(team)
 			cmpPlayer.SetAlly(this.playerID);
 		}
 
-	Engine.BroadcastMessage(MT_DiplomacyChanged, { "player": this.playerID });
+	Engine.BroadcastMessage(MT_DiplomacyChanged, {
+		"player": this.playerID,
+		"otherPlayer": null
+	});
 };
 
 Player.prototype.SetLockTeams = function(value)
@@ -404,22 +458,22 @@ Player.prototype.GetLockTeams = function()
 
 Player.prototype.GetDiplomacy = function()
 {
-	return this.diplomacy;
+	return this.diplomacy.slice();
 };
 
 Player.prototype.SetDiplomacy = function(dipl)
 {
-	this.diplomacy = dipl;
-	Engine.BroadcastMessage(MT_DiplomacyChanged, { "player": this.playerID });
+	this.diplomacy = dipl.slice();
+
+	Engine.BroadcastMessage(MT_DiplomacyChanged, {
+		"player": this.playerID,
+		"otherPlayer": null
+	});
 };
 
 Player.prototype.SetDiplomacyIndex = function(idx, value)
 {
-	var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
-	if (!cmpPlayerManager)
-		return;
-
-	var cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(idx), IID_Player);
+	let cmpPlayer = QueryPlayerIDInterface(idx);
 	if (!cmpPlayer)
 		return;
 
@@ -427,7 +481,11 @@ Player.prototype.SetDiplomacyIndex = function(idx, value)
 		return;
 
 	this.diplomacy[idx] = value;
-	Engine.BroadcastMessage(MT_DiplomacyChanged, { "player": this.playerID });
+
+	Engine.BroadcastMessage(MT_DiplomacyChanged, {
+		"player": this.playerID,
+		"otherPlayer": cmpPlayer.GetPlayerID()
+	});
 
 	// Mutual worsening of relations
 	if (cmpPlayer.diplomacy[this.playerID] > value)
@@ -437,22 +495,17 @@ Player.prototype.SetDiplomacyIndex = function(idx, value)
 Player.prototype.UpdateSharedLos = function()
 {
 	let cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
-	let cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
 	let cmpTechnologyManager = Engine.QueryInterface(this.entity, IID_TechnologyManager);
-	if (!cmpRangeManager || !cmpPlayerManager || !cmpTechnologyManager)
+	if (!cmpRangeManager || !cmpTechnologyManager)
 		return;
 
-	let sharedLos = [];
 	if (!cmpTechnologyManager.IsTechnologyResearched(this.template.SharedLosTech))
 	{
 		cmpRangeManager.SetSharedLos(this.playerID, [this.playerID]);
 		return;
 	}
-	for (var i = 0; i < cmpPlayerManager.GetNumPlayers(); ++i)
-		if (this.IsMutualAlly(i))
-			sharedLos.push(i);
 
-	cmpRangeManager.SetSharedLos(this.playerID, sharedLos);
+	cmpRangeManager.SetSharedLos(this.playerID, this.GetMutualAllies());
 };
 
 Player.prototype.GetFormations = function()
@@ -485,6 +538,11 @@ Player.prototype.HasStartingCamera = function()
 	return this.startCam !== undefined;
 };
 
+Player.prototype.HasSharedLos = function()
+{
+	let cmpTechnologyManager = Engine.QueryInterface(this.entity, IID_TechnologyManager);
+	return cmpTechnologyManager && cmpTechnologyManager.IsTechnologyResearched(this.template.SharedLosTech);
+};
 Player.prototype.HasSharedDropsites = function()
 {
 	return this.sharedDropsites;
@@ -510,6 +568,15 @@ Player.prototype.IsAI = function()
 	return this.isAI;
 };
 
+Player.prototype.GetPlayersByDiplomacy = function(func)
+{
+	var players = [];
+	for (var i = 0; i < this.diplomacy.length; ++i)
+		if (this[func](i))
+			players.push(i);
+	return players;
+};
+
 Player.prototype.SetAlly = function(id)
 {
 	this.SetDiplomacyIndex(id, 1);
@@ -523,6 +590,19 @@ Player.prototype.IsAlly = function(id)
 	return this.diplomacy[id] > 0;
 };
 
+Player.prototype.GetAllies = function()
+{
+	return this.GetPlayersByDiplomacy("IsAlly");
+};
+
+/**
+ * Check if given player is our ally excluding ourself
+ */
+Player.prototype.IsExclusiveAlly = function(id)
+{
+	return this.playerID != id && this.IsAlly(id);
+};
+
 /**
  * Check if given player is our ally, and we are its ally
  */
@@ -532,21 +612,22 @@ Player.prototype.IsMutualAlly = function(id)
 	return this.IsAlly(id) && cmpPlayer && cmpPlayer.IsAlly(this.playerID);
 };
 
-Player.prototype.SetEnemy = function(id)
+Player.prototype.GetMutualAllies = function()
 {
-	this.SetDiplomacyIndex(id, -1);
+	return this.GetPlayersByDiplomacy("IsMutualAlly");
 };
 
 /**
- * Get all enemies of a given player.
+ * Check if given player is our ally, and we are its ally, excluding ourself
  */
-Player.prototype.GetEnemies = function()
+Player.prototype.IsExclusiveMutualAlly = function(id)
 {
-	var enemies = [];
-	for (var i = 0; i < this.diplomacy.length; i++)
-		if (this.diplomacy[i] < 0)
-			enemies.push(i);
-	return enemies;
+	return this.playerID != id && this.IsMutualAlly(id);
+};
+
+Player.prototype.SetEnemy = function(id)
+{
+	this.SetDiplomacyIndex(id, -1);
 };
 
 /**
@@ -557,6 +638,11 @@ Player.prototype.IsEnemy = function(id)
 	return this.diplomacy[id] < 0;
 };
 
+Player.prototype.GetEnemies = function()
+{
+	return this.GetPlayersByDiplomacy("IsEnemy");
+};
+
 Player.prototype.SetNeutral = function(id)
 {
 	this.SetDiplomacyIndex(id, 0);
@@ -623,42 +709,6 @@ Player.prototype.OnGlobalOwnershipChanged = function(msg)
 	}
 };
 
-Player.prototype.OnPlayerDefeated = function(msg)
-{
-	this.state = "defeated";
-
-	// Reassign all player's entities to Gaia
-	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
-	var entities = cmpRangeManager.GetEntitiesByPlayer(this.playerID);
-
-	// The ownership change is done in two steps so that entities don't hit idle
-	// (and thus possibly look for "enemies" to attack) before nearby allies get
-	// converted to Gaia as well.
-	for (var entity of entities)
-	{
-		var cmpOwnership = Engine.QueryInterface(entity, IID_Ownership);
-		cmpOwnership.SetOwnerQuiet(0);
-	}
-
-	// With the real ownership change complete, send OwnershipChanged messages.
-	for (var entity of entities)
-		Engine.PostMessage(entity, MT_OwnershipChanged, {
-			"entity": entity,
-			"from": this.playerID,
-			"to": 0
-		});
-
-	// Reveal the map for this player.
-	cmpRangeManager.SetLosRevealAll(this.playerID, true);
-
-	// Send a chat message notifying of the player's defeat.
-	var cmpGUIInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
-	cmpGUIInterface.PushNotification({
-		"type": "defeat",
-		"players": [this.playerID]
-	});
-};
-
 Player.prototype.OnResearchFinished = function(msg)
 {
 	if (msg.tech == this.template.SharedLosTech)
