@@ -29,7 +29,16 @@ ProductionQueue.prototype.Schema =
 			"</attribute>" +
 			"<text/>" +
 		"</element>" +
-	"</optional>";
+	"</optional>" +
+	"<element name='TechCostMultiplier' a:help='Multiplier to modify ressources cost and research time of technologies searched in this building.'>" +
+		"<interleave>" +
+			"<element name='food'><ref name='nonNegativeDecimal'/></element>" +
+			"<element name='wood'><ref name='nonNegativeDecimal'/></element>" +
+			"<element name='stone'><ref name='nonNegativeDecimal'/></element>" +
+			"<element name='metal'><ref name='nonNegativeDecimal'/></element>" +
+			"<element name='time'><ref name='nonNegativeDecimal'/></element>" +
+		"</interleave>" +
+	"</element>";
 
 ProductionQueue.prototype.Init = function()
 {
@@ -141,26 +150,33 @@ ProductionQueue.prototype.GetTechnologiesList = function()
 {
 	if (!this.template.Technologies)
 		return [];
-	
+
 	var string = this.template.Technologies._string;
 	if (!string)
 		return [];
-	
+
 	var cmpTechnologyManager = QueryOwnerInterface(this.entity, IID_TechnologyManager);
 	if (!cmpTechnologyManager)
 		return [];
 	
 	var cmpPlayer = QueryOwnerInterface(this.entity);
 	var cmpIdentity = Engine.QueryInterface(this.entity, IID_Identity);
-	if (!cmpPlayer || !cmpIdentity || cmpPlayer.GetCiv() != cmpIdentity.GetCiv())
+	if (!cmpPlayer || !cmpIdentity)
 		return [];
 
 	var techs = string.split(/\s+/);
+
+	// Remove any technologies that can't be researched by this civ
+	techs = techs.filter(tech => {
+		let reqs = cmpTechnologyManager.GetTechnologyTemplate(tech).requirements || null;
+		return cmpTechnologyManager.CheckTechnologyRequirements(reqs, true);
+	});
+
 	var techList = [];
 	var superseded = {}; // Stores the tech which supersedes the key
 
 	var disabledTechnologies = cmpPlayer.GetDisabledTechnologies();
-	
+
 	// Add any top level technologies to an array which corresponds to the displayed icons
 	// Also store what a technology is superceded by in the superceded object {"tech1":"techWhichSupercedesTech1", ...}
 	for (var i in techs)
@@ -174,7 +190,7 @@ ProductionQueue.prototype.GetTechnologiesList = function()
 		else
 			superseded[template.supersedes] = tech;
 	}
-	
+
 	// Now make researched/in progress techs invisible
 	for (var i in techList)
 	{
@@ -186,9 +202,9 @@ ProductionQueue.prototype.GetTechnologiesList = function()
 		
 		techList[i] = tech;
 	}
-	
+
 	var ret = [];
-	
+
 	// This inserts the techs into the correct positions to line up the technology pairs
 	for (var i = 0; i < techList.length; i++)
 	{
@@ -198,17 +214,25 @@ ProductionQueue.prototype.GetTechnologiesList = function()
 			ret[i] = undefined;
 			continue;
 		}
-		
+
 		var template = cmpTechnologyManager.GetTechnologyTemplate(tech);
 		if (template.top)
 			ret[i] = {"pair": true, "top": template.top, "bottom": template.bottom};
 		else
 			ret[i] = tech;
 	}
-	
+
 	return ret;
 };
 
+ProductionQueue.prototype.GetTechCostMultiplier = function()
+{
+	let techCostMultiplier = {};
+	for (let res in this.template.TechCostMultiplier)
+		techCostMultiplier[res] = ApplyValueModificationsToEntity("ProductionQueue/TechCostMultiplier/"+res, +this.template.TechCostMultiplier[res], this.entity);
+	return techCostMultiplier;
+};
+
 ProductionQueue.prototype.IsTechnologyResearchedOrInProgress = function(tech)
 {
 	if (!tech)
@@ -309,17 +333,27 @@ ProductionQueue.prototype.AddBatch = function(templateName, type, count, metadat
 		else if (type == "technology")
 		{
 			// Load the technology template
-			var cmpTechnologyTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TechnologyTemplateManager);
-			var template = cmpTechnologyTemplateManager.GetTemplate(templateName);
+			var cmpDataTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_DataTemplateManager);
+			var template = cmpDataTemplateManager.GetTechnologyTemplate(templateName);
 			if (!template)
 				return;
+			if (!this.GetTechnologiesList().some(tech =>
+				tech &&
+					(tech == templateName ||
+						tech.pair &&
+						(tech.top == templateName || tech.bottom == templateName))))
+			{
+				error("This entity cannot research " + templateName);
+				return;
+			}
 			var cmpPlayer = QueryOwnerInterface(this.entity);
-			var time = template.researchTime * cmpPlayer.GetCheatTimeMultiplier();
+			let techCostMultiplier = this.GetTechCostMultiplier();
+			let time =  techCostMultiplier.time * template.researchTime * cmpPlayer.GetCheatTimeMultiplier();
 
 			var cost = {};
-			for each (var r in ["food", "wood", "stone", "metal"])
-				cost[r] = Math.floor(template.cost[r]);
-			
+			for (let res in template.cost)
+				cost[res] = Math.floor(techCostMultiplier[res] * template.cost[res]);
+
 			// TrySubtractResources should report error to player (they ran out of resources)
 			if (!cmpPlayer.TrySubtractResources(cost))
 				return;
