@@ -20,7 +20,7 @@ ResourceDropsite.prototype.Schema =
 ResourceDropsite.prototype.Init = function()
 {
 	this.sharable = this.template.Sharable == "true";
-	this.shared = false;
+	this.shared = this.sharable;
 };
 
 /**
@@ -52,8 +52,10 @@ ResourceDropsite.prototype.IsShared = function()
 
 ResourceDropsite.prototype.SetSharing = function(value)
 {
-	if (this.sharable)
-		this.shared = value;
+	if (!this.sharable)
+		return;
+	this.shared = value;
+	Engine.PostMessage(this.entity, MT_DropsiteSharingChanged, { "shared": this.shared });
 };
 
 Engine.RegisterComponentType(IID_ResourceDropsite, "ResourceDropsite", ResourceDropsite);
