@@ -5,7 +5,6 @@ StatisticsTracker.prototype.Schema =
 
 StatisticsTracker.prototype.Init = function()
 {
-	// units
 	this.unitsClasses = [
 		"Infantry",
 		"Worker",
@@ -13,9 +12,10 @@ StatisticsTracker.prototype.Init = function()
 		"Cavalry",
 		"Champion",
 		"Hero",
+		"Siege",
 		"Ship",
 		"Trader"
-	];	
+	];
 	this.unitsTrained = {
 		"Infantry": 0,
 		"Worker": 0,
@@ -23,6 +23,7 @@ StatisticsTracker.prototype.Init = function()
 		"Cavalry": 0,
 		"Champion": 0,
 		"Hero": 0,
+		"Siege": 0,
 		"Ship": 0,
 		"Trader": 0,
 		"total": 0
@@ -34,6 +35,7 @@ StatisticsTracker.prototype.Init = function()
 		"Cavalry": 0,
 		"Champion": 0,
 		"Hero": 0,
+		"Siege": 0,
 		"Ship": 0,
 		"Trader": 0,
 		"total": 0
@@ -46,12 +48,26 @@ StatisticsTracker.prototype.Init = function()
 		"Cavalry": 0,
 		"Champion": 0,
 		"Hero": 0,
+		"Siege": 0,
 		"Ship": 0,
 		"Trader": 0,
 		"total": 0
 	};
 	this.enemyUnitsKilledValue = 0;
-	// buildings
+	this.unitsCaptured = {
+		"Infantry": 0,
+		"Worker": 0,
+		"Female": 0,
+		"Cavalry": 0,
+		"Champion": 0,
+		"Hero": 0,
+		"Siege": 0,
+		"Ship": 0,
+		"Trader": 0,
+		"total": 0
+	};
+	this.unitsCapturedValue = 0;
+
 	this.buildingsClasses = [
 		"House",
 		"Economic",
@@ -69,7 +85,7 @@ StatisticsTracker.prototype.Init = function()
 		"Fortress": 0,
 		"CivCentre": 0,
 		"Wonder": 0,
-		"total": 0	
+		"total": 0
 	};
 	this.buildingsLost = {
 		"House": 0,
@@ -80,7 +96,7 @@ StatisticsTracker.prototype.Init = function()
 		"CivCentre": 0,
 		"Wonder": 0,
 		"total": 0
-		};
+	};
 	this.buildingsLostValue = 0;
 	this.enemyBuildingsDestroyed = {
 		"House": 0,
@@ -91,9 +107,20 @@ StatisticsTracker.prototype.Init = function()
 		"CivCentre": 0,
 		"Wonder": 0,
 		"total": 0
-		};
+	};
 	this.enemyBuildingsDestroyedValue = 0;
-	// resources
+	this.buildingsCaptured = {
+		"House": 0,
+		"Economic": 0,
+		"Outpost": 0,
+		"Military": 0,
+		"Fortress": 0,
+		"CivCentre": 0,
+		"Wonder": 0,
+		"total": 0
+	};
+	this.buildingsCapturedValue = 0;
+
 	this.resourcesGathered = {
 		"food": 0,
 		"wood": 0,
@@ -119,6 +146,7 @@ StatisticsTracker.prototype.Init = function()
 		"metal": 0,
 		"stone": 0
 	};
+
 	this.tributesSent = 0;
 	this.tributesReceived = 0;
 	this.tradeIncome = 0;
@@ -152,11 +180,15 @@ StatisticsTracker.prototype.GetStatistics = function()
 		"unitsLostValue": this.unitsLostValue,
 		"enemyUnitsKilled": this.enemyUnitsKilled,
 		"enemyUnitsKilledValue": this.enemyUnitsKilledValue,
+		"unitsCaptured": this.unitsCaptured,
+		"unitsCapturedValue": this.unitsCapturedValue,
 		"buildingsConstructed": this.buildingsConstructed,
 		"buildingsLost": this.buildingsLost,
 		"buildingsLostValue": this.buildingsLostValue,
 		"enemyBuildingsDestroyed": this.enemyBuildingsDestroyed,
 		"enemyBuildingsDestroyedValue": this.enemyBuildingsDestroyedValue,
+		"buildingsCaptured": this.buildingsCaptured,
+		"buildingsCapturedValue": this.buildingsCapturedValue,
 		"resourcesGathered": this.resourcesGathered,
 		"resourcesUsed": this.resourcesUsed,
 		"resourcesSold": this.resourcesSold,
@@ -186,15 +218,15 @@ StatisticsTracker.prototype.CounterIncrement = function(cmpIdentity, counter, ty
 	var classes = cmpIdentity.GetClassesList();
 	if (!classes)
 		return;
+
 	if (classes.indexOf(type) != -1)
-		this[counter][type]++;
+		++this[counter][type];
 };
 
-/** 
- * Counts the total number of units trained as well as an individual count for 
+/**
+ * Counts the total number of units trained as well as an individual count for
  * each unit type. Based on templates.
- * @param trainedUnit The unit that has been trained 
- */ 
+ */
 StatisticsTracker.prototype.IncreaseTrainedUnitsCounter = function(trainedUnit)
 {
 	var cmpUnitEntityIdentity = Engine.QueryInterface(trainedUnit, IID_Identity);
@@ -202,28 +234,27 @@ StatisticsTracker.prototype.IncreaseTrainedUnitsCounter = function(trainedUnit)
 	if (!cmpUnitEntityIdentity)
 		return;
 
-	for each (var type in this.unitsClasses)
+	for (let type of this.unitsClasses)
 		this.CounterIncrement(cmpUnitEntityIdentity, "unitsTrained", type);
 
-	this.unitsTrained.total++;
+	++this.unitsTrained.total;
 };
 
-/** 
- * Counts the total number of buildings constructed as well as an individual count for 
+/**
+ * Counts the total number of buildings constructed as well as an individual count for
  * each building type. Based on templates.
- * @param constructedBuilding The building that has been constructed 
- */ 
+ */
 StatisticsTracker.prototype.IncreaseConstructedBuildingsCounter = function(constructedBuilding)
 {
 	var cmpBuildingEntityIdentity = Engine.QueryInterface(constructedBuilding, IID_Identity);
-		
+
 	if (!cmpBuildingEntityIdentity)
 		return;
 
-	for each(var type in this.buildingsClasses)
+	for (let type of this.buildingsClasses)
 		this.CounterIncrement(cmpBuildingEntityIdentity, "buildingsConstructed", type);
 
-	this.buildingsConstructed.total++;
+	++this.buildingsConstructed.total;
 };
 
 StatisticsTracker.prototype.KilledEntity = function(targetEntity)
@@ -234,38 +265,33 @@ StatisticsTracker.prototype.KilledEntity = function(targetEntity)
 	if (!cmpTargetEntityIdentity)
 		return;
 
-	var cmpFoundation = Engine.QueryInterface(targetEntity, IID_Foundation);
-	// We want to deal only with real structures, not foundations
-	var targetIsStructure = cmpTargetEntityIdentity.HasClass("Structure") && cmpFoundation == null;
-	var targetIsDomesticAnimal = cmpTargetEntityIdentity.HasClass("Animal") && cmpTargetEntityIdentity.HasClass("Domestic");
-	// Don't count domestic animals as units
-	var targetIsUnit = cmpTargetEntityIdentity.HasClass("Unit") && !targetIsDomesticAnimal;
-
 	var cmpTargetOwnership = Engine.QueryInterface(targetEntity, IID_Ownership);
-    
-	// Don't increase counters if target player is gaia (player 0)
+
+	// Ignore gaia
 	if (cmpTargetOwnership.GetOwner() == 0)
 		return;
 
-	if (targetIsUnit)
+	if (cmpTargetEntityIdentity.HasClass("Unit") && !cmpTargetEntityIdentity.HasClass("Domestic"))
 	{
-		for each (var type in this.unitsClasses)
+		for (let type of this.unitsClasses)
 			this.CounterIncrement(cmpTargetEntityIdentity, "enemyUnitsKilled", type);
 
-		this.enemyUnitsKilled.total++;
-		
-		for each (var cost in costs)
-			this.enemyUnitsKilledValue += cost;
-	}	
-	if (targetIsStructure)
+		++this.enemyUnitsKilled.total;
+
+		for (let type in costs)
+			this.enemyUnitsKilledValue += costs[type];
+	}
+
+	let cmpFoundation = Engine.QueryInterface(targetEntity, IID_Foundation);
+	if (cmpTargetEntityIdentity.HasClass("Structure") && !cmpFoundation)
 	{
-		for each (var type in this.buildingsClasses)
+		for (let type of this.buildingsClasses)
 			this.CounterIncrement(cmpTargetEntityIdentity, "enemyBuildingsDestroyed", type);
 
-		this.enemyBuildingsDestroyed.total++;
-		
-		for each (var cost in costs)
-			this.enemyBuildingsDestroyedValue += cost;
+		++this.enemyBuildingsDestroyed.total;
+
+		for (let type in costs)
+			this.enemyBuildingsDestroyedValue += costs[type];
 	}
 };
 
@@ -276,33 +302,67 @@ StatisticsTracker.prototype.LostEntity = function(lostEntity)
 	var costs = cmpCost.GetResourceCosts();
 	if (!cmpLostEntityIdentity)
 		return;
-	
-	var cmpFoundation = Engine.QueryInterface(lostEntity, IID_Foundation);
-	// We want to deal only with real structures, not foundations
-	var lostEntityIsStructure = cmpLostEntityIdentity.HasClass("Structure") && cmpFoundation == null;
-	var lostEntityIsDomesticAnimal = cmpLostEntityIdentity.HasClass("Animal") && cmpLostEntityIdentity.HasClass("Domestic");
-	// Don't count domestic animals as units
-	var lostEntityIsUnit = cmpLostEntityIdentity.HasClass("Unit") && !lostEntityIsDomesticAnimal;
 
-	if (lostEntityIsUnit)
+	if (cmpLostEntityIdentity.HasClass("Unit") && !cmpLostEntityIdentity.HasClass("Domestic"))
 	{
-		for each (var type in this.unitsClasses)
+		for (let type of this.unitsClasses)
 			this.CounterIncrement(cmpLostEntityIdentity, "unitsLost", type);
 
-		this.unitsLost.total++;
-		
-		for each (var cost in costs)
-			this.unitsLostValue += cost;	
-	}	
-	if (lostEntityIsStructure)
+		++this.unitsLost.total;
+
+		for (let type in costs)
+			this.unitsLostValue += costs[type];
+	}
+
+	let cmpFoundation = Engine.QueryInterface(lostEntity, IID_Foundation);
+	if (cmpLostEntityIdentity.HasClass("Structure") && !cmpFoundation)
 	{
-		for each (var type in this.buildingsClasses)
+		for (let type of this.buildingsClasses)
 			this.CounterIncrement(cmpLostEntityIdentity, "buildingsLost", type);
 
-		this.buildingsLost.total++;
-		
-		for each (var cost in costs)
-			this.buildingsLostValue += cost;
+		++this.buildingsLost.total;
+
+		for (let type in costs)
+			this.buildingsLostValue += costs[type];
+	}
+};
+
+StatisticsTracker.prototype.CapturedEntity = function(capturedEntity)
+{
+	let cmpCapturedEntityIdentity = Engine.QueryInterface(capturedEntity, IID_Identity);
+	if (!cmpCapturedEntityIdentity)
+		return;
+
+	if (cmpCapturedEntityIdentity.HasClass("Unit"))
+	{
+		for (let type of this.unitsClasses)
+			this.CounterIncrement(cmpCapturedEntityIdentity, "unitsCaptured", type);
+
+		++this.unitsCaptured.total;
+
+		let cmpCost = Engine.QueryInterface(capturedEntity, IID_Cost);
+		if (!cmpCost)
+			return;
+
+		let costs = cmpCost.GetResourceCosts();
+		for (let type in costs)
+			this.unitsCapturedValue += costs[type];
+	}
+
+	if (cmpCapturedEntityIdentity.HasClass("Structure"))
+	{
+		for (let type of this.buildingsClasses)
+			this.CounterIncrement(cmpCapturedEntityIdentity, "buildingsCaptured", type);
+
+		++this.buildingsCaptured.total;
+
+		let cmpCost = Engine.QueryInterface(capturedEntity, IID_Cost);
+		if (!cmpCost)
+			return;
+
+		let costs = cmpCost.GetResourceCosts();
+		for (let type in costs)
+			this.buildingsCapturedValue += costs[type];
 	}
 };
 
@@ -314,7 +374,7 @@ StatisticsTracker.prototype.LostEntity = function(lostEntity)
 StatisticsTracker.prototype.IncreaseResourceGatheredCounter = function(type, amount, specificType)
 {
 	this.resourcesGathered[type] += amount;
-	
+
 	if (type == "food" && (specificType == "fruit" || specificType == "grain"))
 		this.resourcesGathered.vegetarianFood += amount;
 };
@@ -330,7 +390,7 @@ StatisticsTracker.prototype.IncreaseResourceUsedCounter = function(type, amount)
 
 StatisticsTracker.prototype.IncreaseTreasuresCollectedCounter = function()
 {
-	this.treasuresCollected++;
+	++this.treasuresCollected;
 };
 
 StatisticsTracker.prototype.IncreaseLootCollectedCounter = function(amount)
@@ -392,7 +452,7 @@ StatisticsTracker.prototype.GetTeamPercentMapExplored = function()
 	var teamPlayers = [];
 	for (var i = 1; i < cmpPlayerManager.GetNumPlayers(); ++i)
 	{
-		let cmpOtherPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(i), IID_Player);
+		let cmpOtherPlayer = QueryPlayerIDInterface(i);
 		if (cmpOtherPlayer && cmpOtherPlayer.GetTeam() == team)
 			teamPlayers.push(i);
 	}
@@ -425,7 +485,7 @@ StatisticsTracker.prototype.GetTeamPercentMapControlled = function()
 	var teamPercent = 0;
 	for (let i = 1; i < cmpPlayerManager.GetNumPlayers(); ++i)
 	{
-		let cmpOtherPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(i), IID_Player);
+		let cmpOtherPlayer = QueryPlayerIDInterface(i);
 		if (cmpOtherPlayer && cmpOtherPlayer.GetTeam() == team)
 			teamPercent += cmpTerritoryManager.GetTerritoryPercentage(i);
 	}
