@@ -41,7 +41,7 @@ TechnologyManager.prototype.Init = function()
 	// Some technologies are automatically researched when their conditions are met.  They have no cost and are 
 	// researched instantly.  This allows civ bonuses and more complicated technologies.
 	this.autoResearchTech = {};
-	var allTechs = Engine.QueryInterface(SYSTEM_ENTITY, IID_TechnologyTemplateManager).GetAllTechs();
+	var allTechs = Engine.QueryInterface(SYSTEM_ENTITY, IID_DataTemplateManager).GetAllTechs();
 	for (var key in allTechs)
 	{
 		if (allTechs[key].autoResearch || allTechs[key].top)
@@ -58,10 +58,10 @@ TechnologyManager.prototype.OnUpdate = function()
 // This function checks if the requirements of any autoresearch techs are met and if they are it researches them
 TechnologyManager.prototype.UpdateAutoResearch = function()
 {
-	var cmpTechTempMan = Engine.QueryInterface(SYSTEM_ENTITY, IID_TechnologyTemplateManager);
+	var cmpDataTempMan = Engine.QueryInterface(SYSTEM_ENTITY, IID_DataTemplateManager);
 	for (var key in this.autoResearchTech)
 	{
-		var tech = cmpTechTempMan.GetTemplate(key);
+		var tech = cmpDataTempMan.GetTechnologyTemplate(key);
 		if ((tech.autoResearch && this.CanResearch(key))
 			|| (tech.top && (this.IsTechnologyResearched(tech.top) || this.IsTechnologyResearched(tech.bottom))))
 		{
@@ -74,7 +74,7 @@ TechnologyManager.prototype.UpdateAutoResearch = function()
 
 TechnologyManager.prototype.GetTechnologyTemplate = function(tech)
 {
-	return Engine.QueryInterface(SYSTEM_ENTITY, IID_TechnologyTemplateManager).GetTemplate(tech);
+	return Engine.QueryInterface(SYSTEM_ENTITY, IID_DataTemplateManager).GetTechnologyTemplate(tech);
 };
 
 // Checks an entity template to see if its technology requirements have been met
@@ -85,8 +85,8 @@ TechnologyManager.prototype.CanProduce = function (templateName)
 
 	if (template.Identity && template.Identity.RequiredTechnology)
 		return this.IsTechnologyResearched(template.Identity.RequiredTechnology);
-	else
-		return true; // If there is no required technology then this entity can be produced
+	// If there is no required technology then this entity can be produced
+	return true;
 };
 
 TechnologyManager.prototype.IsTechnologyResearched = function(tech)
@@ -124,61 +124,44 @@ TechnologyManager.prototype.CanResearch = function(tech)
 	return this.CheckTechnologyRequirements(template.requirements || null);
 };
 
-// Private function for checking a set of requirements is met
-TechnologyManager.prototype.CheckTechnologyRequirements = function(reqs)
+/**
+ * Private function for checking a set of requirements is met
+ * @param reqs Object of technology requirements as given by the technology template
+ * @param civonly A boolean set to true if only the civ requirement is checked
+ *
+ * @return true if the requirements are checked
+ * false otherwise
+ */
+TechnologyManager.prototype.CheckTechnologyRequirements = function(reqs, civonly)
 {
 	// If there are no requirements then all requirements are met
 	if (!reqs)
 		return true;
 
-	if (reqs.tech)
+	if (reqs.all)
+		return reqs.all.every(r => this.CheckTechnologyRequirements(r, civonly));
+	if (reqs.any)
+		return reqs.any.some(r => this.CheckTechnologyRequirements(r, civonly));
+	if (reqs.civ)
 	{
-		return this.IsTechnologyResearched(reqs.tech);
+		let cmpPlayer = Engine.QueryInterface(this.entity, IID_Player);
+		return cmpPlayer && cmpPlayer.GetCiv() == reqs.civ;
 	}
-	else if (reqs.all)
+	if (reqs.notciv)
 	{
-		for (var i = 0; i < reqs.all.length; i++)
-		{
-			if (!this.CheckTechnologyRequirements(reqs.all[i]))
-				return false;
-		}
+		let cmpPlayer = Engine.QueryInterface(this.entity, IID_Player);
+		return cmpPlayer && cmpPlayer.GetCiv() != reqs.notciv;
+	}
+	if (civonly)
 		return true;
-	}
-	else if (reqs.any)
-	{
-		for (var i = 0; i < reqs.any.length; i++)
-		{
-			if (this.CheckTechnologyRequirements(reqs.any[i]))
-				return true;
-		}
-		return false;
-	}
-	else if (reqs.class)
-	{
-		if (reqs.numberOfTypes)
-		{
-			if (this.typeCountsByClass[reqs.class])
-				return (reqs.numberOfTypes <= Object.keys(this.typeCountsByClass[reqs.class]).length);
-			else
-				return false;
-		}
-		else if (reqs.number)
-		{
-			if (this.classCounts[reqs.class])
-				return (reqs.number <= this.classCounts[reqs.class]);
-			else
-				return false;
-		}
-	}
-	else if (reqs.civ) 
-	{
-		var cmpPlayer = Engine.QueryInterface(this.entity, IID_Player);
-		if (cmpPlayer && cmpPlayer.GetCiv() == reqs.civ) 
-			return true;
-		else 
-			return false;
-	}
-
+	if (reqs.tech)
+		return this.IsTechnologyResearched(reqs.tech);
+	if (reqs.class && reqs.numberOfTypes)
+		return this.typeCountsByClass[reqs.class] &&
+			Object.keys(this.typeCountsByClass[reqs.class]).length >= reqs.numberOfTypes;
+	if (reqs.class && reqs.number)
+		return this.classCounts[reqs.class] &&
+			this.classCounts[reqs.class] >= reqs.number;
 	// The technologies requirements are not a recognised format
 	error("Bad requirements " + uneval(reqs));
 	return false;
@@ -394,13 +377,13 @@ TechnologyManager.prototype.ApplyModifications = function(valueName, curValue, e
 
 	if (!this.modificationCache[valueName][ent] || this.modificationCache[valueName][ent].origValue != curValue)
 	{
-		this.modificationCache[valueName][ent] = {"origValue": curValue};
-		var cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
-		var templateName = cmpTemplateManager.GetCurrentTemplateName(ent);
-		// Ensure that preview or construction entites have the same properties as the final building
-		if (templateName.indexOf("preview|") > -1 || templateName.indexOf("construction|") > -1 )
-			templateName = templateName.slice(templateName.indexOf("|") + 1);
-		this.modificationCache[valueName][ent].newValue = GetTechModifiedProperty(this.modifications, cmpTemplateManager.GetTemplate(templateName), valueName, curValue);
+		let cmpIdentity = Engine.QueryInterface(ent, IID_Identity);
+		if (!cmpIdentity)
+			return curValue;
+		this.modificationCache[valueName][ent] = {
+			"origValue": curValue,
+			"newValue": GetTechModifiedProperty(this.modifications, cmpIdentity.GetClassesList(), valueName, curValue)
+		};
 	}
 
 	return this.modificationCache[valueName][ent].newValue;
@@ -409,7 +392,9 @@ TechnologyManager.prototype.ApplyModifications = function(valueName, curValue, e
 // Alternative version of ApplyModifications, applies to templates instead of entities
 TechnologyManager.prototype.ApplyModificationsTemplate = function(valueName, curValue, template)
 {
-	return GetTechModifiedProperty(this.modifications, template, valueName, curValue);
+	if (!template || !template.Identity)
+		return curValue;
+	return GetTechModifiedProperty(this.modifications, GetIdentityClasses(template.Identity), valueName, curValue);
 };
 
 // Marks a technology as being queued for research
