@@ -1,5 +1,5 @@
-// See helpers/TraderGain.js for the CalculateTaderGain() function which works out how many 
-// resources a trader gets 
+// See helpers/TraderGain.js for the CalculateTaderGain() function which works out how many
+// resources a trader gets
 
 // Additional gain for ships for each garrisoned trader, in percents
 const GARRISONED_TRADER_ADDITION = 20;
@@ -12,28 +12,26 @@ function Trader() {}
 Trader.prototype.Schema =
 	"<a:help>Lets the unit generate resouces while moving between markets (or docks in case of water trading).</a:help>" +
 	"<a:example>" +
-		"<MaxDistance>2.0</MaxDistance>" +
-		"<GainMultiplier>1.0</GainMultiplier>" +
+		"<GainMultiplier>0.75</GainMultiplier>" +
 	"</a:example>" +
-	"<element name='GainMultiplier' a:help='Additional gain multiplier'>" +
+	"<element name='GainMultiplier' a:help='Trader gain for a 100m distance'>" +
 		"<ref name='positiveDecimal'/>" +
 	"</element>";
 
 Trader.prototype.Init = function()
 {
-	this.firstMarket = INVALID_ENTITY;
-	this.secondMarket = INVALID_ENTITY;
-	// Gain from one pass between markets
-	this.gain = null;
-	// Selected resource for trading
-	this.requiredGoods = undefined;
-	// Currently carried goods
-	this.goods = { "type": null, "amount": null, "origin": null };
+	this.markets = [];
+	this.index = -1;
+	this.goods = {
+		"type": null,
+		"amount": null,
+		"origin": null
+	};
 };
 
-Trader.prototype.CalculateGain = function(firstMarket, secondMarket)
+Trader.prototype.CalculateGain = function(currentMarket, nextMarket)
 {
-	var gain = CalculateTraderGain(firstMarket, secondMarket, this.template, this.entity);
+	let gain = CalculateTraderGain(currentMarket, nextMarket, this.template, this.entity);
 	if (!gain)	// One of our markets must have been destroyed
 		return null;
 
@@ -47,7 +45,7 @@ Trader.prototype.CalculateGain = function(firstMarket, secondMarket)
 		{
 			var garrisonMultiplier = 1;
 			var garrisonedTradersCount = 0;
-			for each (var entity in cmpGarrisonHolder.GetEntities())
+			for (let entity of cmpGarrisonHolder.GetEntities())
 			{
 				var cmpGarrisonedUnitTrader = Engine.QueryInterface(entity, IID_Trader);
 				if (cmpGarrisonedUnitTrader)
@@ -63,177 +61,161 @@ Trader.prototype.CalculateGain = function(firstMarket, secondMarket)
 				gain.market2Gain = Math.round(garrisonMultiplier * gain.market2Gain);
 		}
 	}
-	
-	return gain;
-};
 
-Trader.prototype.GetGain = function()
-{
-	return this.gain;
+	return gain;
 };
 
 // Set target as target market.
 // Return true if at least one of markets was changed.
 Trader.prototype.SetTargetMarket = function(target, source)
 {
-	// Check that target is a market
-	var cmpTargetIdentity = Engine.QueryInterface(target, IID_Identity);
-	if (!cmpTargetIdentity)
+	let cmpTargetMarket = QueryMiragedInterface(target, IID_Market);
+	if (!cmpTargetMarket)
 		return false;
-	if (!cmpTargetIdentity.HasClass("Market") && !cmpTargetIdentity.HasClass("NavalMarket"))
-		return false;
-	var marketsChanged = true;
+
 	if (source)
 	{
 		// Establish a trade route with both markets in one go.
-		cmpTargetIdentity = Engine.QueryInterface(source, IID_Identity);
-		if (!cmpTargetIdentity)
+		let cmpSourceMarket = QueryMiragedInterface(source, IID_Market);
+		if (!cmpSourceMarket)
 			return false;
-		if (!cmpTargetIdentity.HasClass("Market") && !cmpTargetIdentity.HasClass("NavalMarket"))
-			return false;
-
-		this.firstMarket = source;
-		this.secondMarket = INVALID_ENTITY;
+		this.markets = [source];
 	}
-
-	if (this.secondMarket)
+	if (this.markets.length >= 2)
 	{
 		// If we already have both markets - drop them
 		// and use the target as first market
-		this.firstMarket = target;
-		this.secondMarket = INVALID_ENTITY;
+		for (let market of this.markets)
+		{
+			let cmpMarket = QueryMiragedInterface(market, IID_Market);
+			if (cmpMarket)
+				cmpMarket.RemoveTrader(this.entity);
+		}
+		this.index = 0;
+		this.markets = [target];
+		cmpTargetMarket.AddTrader(this.entity);
 	}
-	else if (this.firstMarket)
+	else if (this.markets.length == 1)
 	{
 		// If we have only one market and target is different from it,
 		// set the target as second one
-		if (target == this.firstMarket)
-			marketsChanged = false;
+		if (target == this.markets[0])
+			return false;
 		else
 		{
-			this.secondMarket = target;
-			this.gain = this.CalculateGain(this.firstMarket, this.secondMarket);
+			this.index = 0;
+			this.markets.push(target);
+			cmpTargetMarket.AddTrader(this.entity);
+			this.goods.amount = this.CalculateGain(this.markets[0], this.markets[1]);
 		}
 	}
 	else
 	{
 		// Else we don't have target markets at all,
 		// set the target as first market
-		this.firstMarket = target;
+		this.index = 0;
+		this.markets = [target];
+		cmpTargetMarket.AddTrader(this.entity);
 	}
-	if (marketsChanged)
-	{
-		// Drop carried goods
-		this.goods.amount = null;
-	}
-	return marketsChanged;
+	// Drop carried goods if markets were changed
+	this.goods.amount = null;
+	return true;
 };
 
 Trader.prototype.GetFirstMarket = function()
 {
-	return this.firstMarket;
+	return this.markets[0] || null;
 };
 
 Trader.prototype.GetSecondMarket = function()
 {
-	return this.secondMarket;
+	return this.markets[1] || null;
+};
+
+Trader.prototype.GetTraderGainMultiplier = function()
+{
+	return ApplyValueModificationsToEntity("Trader/GainMultiplier", +this.template.GainMultiplier, this.entity);
 };
 
 Trader.prototype.HasBothMarkets = function()
 {
-	return this.firstMarket && this.secondMarket;
-};
-
-Trader.prototype.GetRequiredGoods = function()
-{
-	return this.requiredGoods;
-};
-
-Trader.prototype.SetRequiredGoods = function(requiredGoods)
-{
-	// Check that argument is a correct resource name
-	if (!requiredGoods || RESOURCES.indexOf(requiredGoods) == -1)
-		this.requiredGoods = undefined;
-	else
-		this.requiredGoods = requiredGoods;
+	return this.markets.length >= 2;
 };
 
 Trader.prototype.CanTrade = function(target)
 {
 	var cmpTraderIdentity = Engine.QueryInterface(this.entity, IID_Identity);
-	var cmpTargetIdentity = Engine.QueryInterface(target, IID_Identity);
-	// Check that the target exists
-	if (!cmpTargetIdentity)
+
+	var cmpTargetMarket = QueryMiragedInterface(target, IID_Market);
+	if (!cmpTargetMarket)
 		return false;
-	// Check that the target is not a foundation
+
 	var cmpTargetFoundation = Engine.QueryInterface(target, IID_Foundation);
 	if (cmpTargetFoundation)
 		return false;
-	var landTradingPossible = cmpTraderIdentity.HasClass("Organic") && cmpTargetIdentity.HasClass("Market");
-	var seaTradingPossible = cmpTraderIdentity.HasClass("Ship") && cmpTargetIdentity.HasClass("NavalMarket");
-	if (!landTradingPossible && !seaTradingPossible)
+
+	if (!(cmpTraderIdentity.HasClass("Organic") && cmpTargetMarket.HasType("land")) &&
+		!(cmpTraderIdentity.HasClass("Ship") && cmpTargetMarket.HasType("naval")))
 		return false;
 
 	var cmpTraderPlayer = QueryOwnerInterface(this.entity, IID_Player);
-	var traderPlayerId = cmpTraderPlayer.GetPlayerID();
 	var cmpTargetPlayer = QueryOwnerInterface(target, IID_Player);
 	var targetPlayerId = cmpTargetPlayer.GetPlayerID();
-	var ownershipSuitableForTrading = cmpTraderPlayer.IsAlly(targetPlayerId) || cmpTraderPlayer.IsNeutral(targetPlayerId);
-	if (!ownershipSuitableForTrading)
-		return false;
-	return true;
+
+	return !cmpTraderPlayer.IsEnemy(targetPlayerId);
 };
 
 Trader.prototype.PerformTrade = function(currentMarket)
 {
+	let previousMarket = this.markets[(this.index+this.markets.length) % this.markets.length];
+	if (previousMarket != currentMarket)  // Inconsistent markets
+	{
+		this.goods.amount = null;
+		return;
+	}
+
+	this.index = ++this.index % this.markets.length;
+	let nextMarket = this.markets[(this.index+this.markets.length) % this.markets.length];
+
 	if (this.goods.amount && this.goods.amount.traderGain)
 	{
-		var cmpPlayer = QueryOwnerInterface(this.entity, IID_Player);
+		let cmpPlayer = QueryOwnerInterface(this.entity);
 		if (cmpPlayer)
 			cmpPlayer.AddResource(this.goods.type, this.goods.amount.traderGain);
 
-		var cmpStatisticsTracker = QueryOwnerInterface(this.entity, IID_StatisticsTracker);
+		let cmpStatisticsTracker = QueryOwnerInterface(this.entity, IID_StatisticsTracker);
 		if (cmpStatisticsTracker)
 			cmpStatisticsTracker.IncreaseTradeIncomeCounter(this.goods.amount.traderGain);
 
 		if (this.goods.amount.market1Gain)
 		{
-			var cmpPlayer = QueryOwnerInterface(this.firstMarket, IID_Player);
+			cmpPlayer = QueryOwnerInterface(previousMarket);
 			if (cmpPlayer)
 				cmpPlayer.AddResource(this.goods.type, this.goods.amount.market1Gain);
 
-			var cmpStatisticsTracker = QueryOwnerInterface(this.firstMarket, IID_StatisticsTracker);
+			cmpStatisticsTracker = QueryOwnerInterface(previousMarket, IID_StatisticsTracker);
 			if (cmpStatisticsTracker)
 				cmpStatisticsTracker.IncreaseTradeIncomeCounter(this.goods.amount.market1Gain);
 		}
 
 		if (this.goods.amount.market2Gain)
 		{
-			var cmpPlayer = QueryOwnerInterface(this.secondMarket, IID_Player);
+			cmpPlayer = QueryOwnerInterface(nextMarket);
 			if (cmpPlayer)
 				cmpPlayer.AddResource(this.goods.type, this.goods.amount.market2Gain);
 
-			var cmpStatisticsTracker = QueryOwnerInterface(this.secondMarket, IID_StatisticsTracker);
+			cmpStatisticsTracker = QueryOwnerInterface(nextMarket, IID_StatisticsTracker);
 			if (cmpStatisticsTracker)
 				cmpStatisticsTracker.IncreaseTradeIncomeCounter(this.goods.amount.market2Gain);
 		}
 	}
 
-	// First take the preferred goods of the trader if any,
-	// otherwise choose one according to the player's trading priorities
-	// if still nothing (but should never happen), choose metal
-	var nextGoods = this.GetRequiredGoods();
-	if (!nextGoods || RESOURCES.indexOf(nextGoods) == -1)
-	{
-		var cmpPlayer = QueryOwnerInterface(this.entity, IID_Player);
-		if (cmpPlayer)
-			nextGoods = cmpPlayer.GetNextTradingGoods();
+	let cmpPlayer = QueryOwnerInterface(this.entity);
+	if (!cmpPlayer)
+		return;
 
-		if (!nextGoods || RESOURCES.indexOf(nextGoods) == -1)
-			nextGoods = "metal";
-	}
-	this.goods.type = nextGoods;
-	this.goods.amount = this.gain;
+	this.goods.type = cmpPlayer.GetNextTradingGoods();
+	this.goods.amount = this.CalculateGain(currentMarket, nextMarket);
 	this.goods.origin = currentMarket;
 };
 
@@ -242,23 +224,54 @@ Trader.prototype.GetGoods = function()
 	return this.goods;
 };
 
-Trader.prototype.GetNextMarket = function()
+/**
+ * Returns true if the trader has the given market (can be either a market or a mirage)
+ */
+Trader.prototype.HasMarket = function(market)
 {
-	if (this.goods.amount && this.goods.origin == this.firstMarket)
-		return this.secondMarket;
+	return this.markets.indexOf(market) != -1; 
+};
 
-	if (this.goods.amount && this.goods.origin != this.secondMarket)
-		this.goods.amount = null;   // leftover from previous trading
-	return this.firstMarket;
+/**
+ * Remove a market when this trader can no longer trade with it
+ */
+Trader.prototype.RemoveMarket = function(market)
+{
+	let index = this.markets.indexOf(market);
+	if (index == -1)
+		return;
+	this.markets.splice(index, 1);
+	let cmpUnitAI = Engine.QueryInterface(this.entity, IID_UnitAI);
+	if (cmpUnitAI)
+		cmpUnitAI.MarketRemoved(market);
+};
+
+/**
+ * Switch between a market and its mirage according to visibility
+ */
+Trader.prototype.SwitchMarket = function(oldMarket, newMarket)
+{
+	let index = this.markets.indexOf(oldMarket);
+	if (index == -1)
+		return;
+	this.markets[index] = newMarket;
+	let cmpUnitAI = Engine.QueryInterface(this.entity, IID_UnitAI);
+	if (cmpUnitAI)
+		cmpUnitAI.SwitchMarketOrder(oldMarket, newMarket);
 };
 
 Trader.prototype.StopTrading = function()
 {
-	// Drop carried goods
+	for (let market of this.markets)
+	{
+		let cmpMarket = QueryMiragedInterface(market, IID_Market);
+		if (cmpMarket)
+			cmpMarket.RemoveTrader(this.entity);
+	}
+	this.index = -1;
+	this.markets = [];
 	this.goods.amount = null;
-	// Reset markets
-	this.firstMarket = INVALID_ENTITY;
-	this.secondMarket = INVALID_ENTITY;
+	this.markets = [];
 };
 
 // Get range in which deals with market are available,
@@ -276,7 +289,7 @@ Trader.prototype.GetRange = function()
 Trader.prototype.OnGarrisonedUnitsChanged = function()
 {
 	if (this.HasBothMarkets())
-		this.gain = this.CalculateGain(this.firstMarket, this.secondMarket);
+		this.goods.amount = this.CalculateGain(this.markets[0], this.markets[1]);
 };
 
 Engine.RegisterComponentType(IID_Trader, "Trader", Trader);
