@@ -4,32 +4,34 @@ Trigger.prototype.Schema =
 	"<a:component type='system'/><empty/>";
 
 /**
- * Events we're able to receive and call handlers for
+ * Events we're able to receive and call handlers for.
  */
-Trigger.prototype.eventNames = 
-[ 
-	"StructureBuilt",  
-	"ConstructionStarted",  
-	"TrainingFinished",  
-	"TrainingQueued",  
-	"ResearchFinished",  
-	"ResearchQueued",  
+Trigger.prototype.eventNames =
+[
+	"CinemaPathEnded",
+	"CinemaQueueEnded",
+	"ConstructionStarted",
+	"Interval",
 	"OwnershipChanged",
 	"PlayerCommand",
-	"Interval",
+	"PlayerDefeated",
+	"PlayerWon",
 	"Range",
-	"TreasureCollected",
-	"CinemaPathEnded",
-	"CinemaQueueEnded"
-]; 
+	"ResearchFinished",
+	"ResearchQueued",
+	"StructureBuilt",
+	"TrainingFinished",
+	"TrainingQueued",
+	"TreasureCollected"
+];
 
 Trigger.prototype.Init = function()
 {
 	this.triggerPoints = {};
 
 	// Each event has its own set of actions determined by the map maker.
-	for each (var eventName in this.eventNames) 
-		this["On" + eventName + "Actions"] = {}; 
+	for (let eventName of this.eventNames)
+		this["On" + eventName + "Actions"] = {};
 };
 
 Trigger.prototype.RegisterTriggerPoint = function(ref, ent)
@@ -46,7 +48,7 @@ Trigger.prototype.RemoveRegisteredTriggerPoint = function(ref, ent)
 		warn("no trigger points found with ref "+ref);
 		return;
 	}
-	var i = this.triggerPoints[ref].indexOf(ent);
+	let i = this.triggerPoints[ref].indexOf(ent);
 	if (i == -1)
 	{
 		warn("entity " + ent + " wasn't found under the trigger points with ref "+ref);
@@ -60,14 +62,15 @@ Trigger.prototype.GetTriggerPoints = function(ref)
 	return this.triggerPoints[ref] || [];
 };
 
-/**  Binds the "action" function to one of the implemented events.
+/**
+ * Binds a function to the specified event.
  *
- * @param event Name of the event (see the list in init)  
- * @param action Functionname of a function available under this object
- * @param Extra Data for the trigger (enabled or not, delay for timers, range for range triggers ...)
+ * @param {string} event - One of eventNames
+ * @param {string} action - Name of a function available to this object
+ * @param {Object} data - f.e. enabled or not, delay for timers, range for range triggers
  *
- * Interval triggers example:
- * data = {enabled: true, interval: 1000, delay: 500}
+ * @example
+ * data = { enabled: true, interval: 1000, delay: 500 }
  *
  * Range trigger:
  * data.entities = [id1, id2] * Ids of the source
@@ -79,7 +82,7 @@ Trigger.prototype.GetTriggerPoints = function(ref)
  */
 Trigger.prototype.RegisterTrigger = function(event, action, data)
 {
-	var eventString = event + "Actions";
+	let eventString = event + "Actions";
 	if (!this[eventString])
 	{
 		warn("Trigger.js: Invalid trigger event \"" + event + "\".");
@@ -93,7 +96,7 @@ Trigger.prototype.RegisterTrigger = function(event, action, data)
 	// clone the data to be sure it's only modified locally
 	// We could run into triggers overwriting each other's data otherwise.
 	// F.e. getting the wrong timer tag
-	data = clone(data) || {"enabled": false};
+	data = clone(data) || { "enabled": false };
 
 	this[eventString][action] = data;
 
@@ -106,9 +109,9 @@ Trigger.prototype.RegisterTrigger = function(event, action, data)
 			return;
 		}
 		data.queries = [];
-		for (var ent of data.entities)
+		for (let ent of data.entities)
 		{
-			var cmpTriggerPoint = Engine.QueryInterface(ent, IID_TriggerPoint);
+			let cmpTriggerPoint = Engine.QueryInterface(ent, IID_TriggerPoint);
 			if (!cmpTriggerPoint)
 			{
 				warn("Trigger.js: Range triggers must be defined on trigger points");
@@ -122,22 +125,21 @@ Trigger.prototype.RegisterTrigger = function(event, action, data)
 		this.EnableTrigger(event, action);
 };
 
-// Disable trigger
 Trigger.prototype.DisableTrigger = function(event, action)
 {
-	var eventString = event + "Actions";
+	let eventString = event + "Actions";
 	if (!this[eventString][action])
 	{
 		warn("Trigger.js: Disabling unknown trigger");
 		return;
 	}
-	var data = this[eventString][action];
+	let data = this[eventString][action];
 	// special casing interval and range triggers for performance
 	if (event == "OnInterval")
 	{
 		if (!data.timer) // don't disable it a second time
 			return;
-		var cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
+		let cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
 		cmpTimer.CancelTimer(data.timer);
 		data.timer = null;
 	}
@@ -148,24 +150,23 @@ Trigger.prototype.DisableTrigger = function(event, action)
 			warn("Trigger.js: Range query wasn't set up before trying to disable it.");
 			return;
 		}
-		var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
-		for (var query of data.queries)
+		let cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+		for (let query of data.queries)
 			cmpRangeManager.DisableActiveQuery(query);
 	}
 
 	data.enabled = false;
 };
 
-// Enable trigger
 Trigger.prototype.EnableTrigger = function(event, action)
 {
-	var eventString = event + "Actions";
+	let eventString = event + "Actions";
 	if (!this[eventString][action])
 	{
 		warn("Trigger.js: Enabling unknown trigger");
 		return;
 	}
-	var data = this[eventString][action];
+	let data = this[eventString][action];
 	// special casing interval and range triggers for performance
 	if (event == "OnInterval")
 	{
@@ -176,9 +177,9 @@ Trigger.prototype.EnableTrigger = function(event, action)
 			warn("Trigger.js: An interval trigger should have an intervel in its data");
 			return;
 		}
-		var cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
-		var timer = cmpTimer.SetInterval(this.entity, IID_Trigger, "DoAction", data.delay || 0, data.interval, {"action" : action});
-		data.timer = timer;
+		let cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
+		data.timer = cmpTimer.SetInterval(this.entity, IID_Trigger, "DoAction",
+			data.delay || 0, data.interval, { "action" : action });
 	}
 	else if (event == "OnRange")
 	{
@@ -187,46 +188,42 @@ Trigger.prototype.EnableTrigger = function(event, action)
 			warn("Trigger.js: Range query wasn't set up before");
 			return;
 		}
-		var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
-		for (var query of data.queries)
+		let cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+		for (let query of data.queries)
 			cmpRangeManager.EnableActiveQuery(query);
 	}
 
 	data.enabled = true;
 };
 
-/** 
- * This function executes the actions bound to the events 
- * It's either called directlty from other simulation scripts,  
- * or from message listeners in this file 
- * 
- * @param event Name of the event (see the list in init) 
- * @param data Data object that will be passed to the actions 
- */ 
+/**
+ * This function executes the actions bound to the events.
+ * It's either called directlty from other simulation scripts,
+ * or from message listeners in this file
+ *
+ * @param {string} event - One of eventNames
+ * @param {Object} data - will be passed to the actions
+ */
 Trigger.prototype.CallEvent = function(event, data)
 {
-	var eventString = "On" + event + "Actions";
-	
+	let eventString = "On" + event + "Actions";
+
 	if (!this[eventString])
 	{
 		warn("Trigger.js: Unknown trigger event called:\"" + event + "\".");
 		return;
 	}
-	
-	for (var action in this[eventString])
-	{
+
+	for (let action in this[eventString])
 		if (this[eventString][action].enabled)
-			this.DoAction({"action": action, "data":data});
-	}
+			this.DoAction({ "action": action, "data":data });
 };
 
-// Handles "OnStructureBuilt" event.
 Trigger.prototype.OnGlobalConstructionFinished = function(msg)
 {
-	this.CallEvent("StructureBuilt", {"building": msg.newentity}); // The data for this one is {"building": constructedBuilding}
+	this.CallEvent("StructureBuilt", { "building": msg.newentity });
 };
 
-// Handles "OnTrainingFinished" event.
 Trigger.prototype.OnGlobalTrainingFinished = function(msg)
 {
 	this.CallEvent("TrainingFinished", msg);
@@ -236,21 +233,17 @@ Trigger.prototype.OnGlobalTrainingFinished = function(msg)
 	// See function "SpawnUnits" in ProductionQueue for more details
 };
 
-// Handles "OnTrainingFinished" event.
 Trigger.prototype.OnGlobalResearchFinished = function(msg)
 {
 	this.CallEvent("ResearchFinished", msg);
-	// The data for this one is {"player": playerID,
-	//							 "tech": tech}
+	// The data for this one is { "player": playerID, "tech": tech }
 };
 
-// Handles "OnCinemaPathEnded" event.
 Trigger.prototype.OnGlobalCinemaPathEnded = function(msg)
 {
 	this.CallEvent("CinemaPathEnded", msg);
 };
 
-// Handles "OnCinemaQueueEnded" event.
 Trigger.prototype.OnGlobalCinemaQueueEnded = function(msg)
 {
 	this.CallEvent("CinemaQueueEnded", msg);
@@ -262,21 +255,36 @@ Trigger.prototype.OnGlobalOwnershipChanged = function(msg)
 	// data is {"entity": ent, "from": playerId, "to": playerId}
 };
 
-/** 
- * Execute a function after a certain delay 
- * @param time The delay expressed in milleseconds 
- * @param action Name of the action function 
- * @param data Data object that will be passed to the action function 
- */ 
-Trigger.prototype.DoAfterDelay = function(miliseconds, action, data)
+Trigger.prototype.OnGlobalPlayerDefeated = function(msg)
 {
-	var cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
-	return cmpTimer.SetTimeout(SYSTEM_ENTITY, IID_Trigger, "DoAction", miliseconds, {"action": action, "data": data});
+	this.CallEvent("PlayerDefeated", msg);
 };
 
-/** 
- * Called by the trigger listeners to exucute the actual action. Including sanity checks. 
- */ 
+Trigger.prototype.OnGlobalPlayerWon = function(msg)
+{
+	this.CallEvent("PlayerWon", msg);
+};
+
+/**
+ * Execute a function after a certain delay.
+ *
+ * @param {Number} time - delay in milleseconds
+ * @param {String} action - Name of the action function
+ * @param {Object} data - will be passed to the action function
+ */
+Trigger.prototype.DoAfterDelay = function(miliseconds, action, data)
+{
+	let cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
+
+	return cmpTimer.SetTimeout(SYSTEM_ENTITY, IID_Trigger, "DoAction", miliseconds, {
+		"action": action,
+		"data": data
+	});
+};
+
+/**
+ * Called by the trigger listeners to exucute the actual action. Including sanity checks.
+ */
 Trigger.prototype.DoAction = function(msg)
 {
 	if (this[msg.action])
