@@ -1,4 +1,4 @@
-function ValueModificationManager() {};
+function ValueModificationManager() {}
 
 /*
  * A component to give the C++ defined components access to all value modifying components 
@@ -7,6 +7,8 @@ function ValueModificationManager() {};
 ValueModificationManager.prototype.Schema =
 	"<a:component type='system'/><empty/>";
 
+ValueModificationManager.prototype.Serialize = null;
+
 ValueModificationManager.prototype.ApplyModifications = function(valueName, currentValue, entity)
 {
 	return ApplyValueModificationsToEntity(valueName, currentValue, entity);
