@@ -1,3 +1,7 @@
 Engine.RegisterInterface("EndGameManager");
-Engine.RegisterMessageType("PlayerDefeated");
+
+/**
+ * Message of the form {}
+ * sent from EndGameManager component.
+ */
 Engine.RegisterMessageType("GameTypeChanged");
