@@ -15,6 +15,8 @@ Engine.LoadComponentScript("interfaces/Gate.js");
 Engine.LoadComponentScript("interfaces/Guard.js");
 Engine.LoadComponentScript("interfaces/Heal.js");
 Engine.LoadComponentScript("interfaces/Health.js");
+Engine.LoadComponentScript("interfaces/Loot.js");
+Engine.LoadComponentScript("interfaces/Market.js");
 Engine.LoadComponentScript("interfaces/Pack.js");
 Engine.LoadComponentScript("interfaces/ProductionQueue.js");
 Engine.LoadComponentScript("interfaces/Promotion.js");
@@ -28,6 +30,7 @@ Engine.LoadComponentScript("interfaces/Trader.js");
 Engine.LoadComponentScript("interfaces/Timer.js");
 Engine.LoadComponentScript("interfaces/StatisticsTracker.js");
 Engine.LoadComponentScript("interfaces/UnitAI.js");
+Engine.LoadComponentScript("interfaces/Upgrade.js");
 Engine.LoadComponentScript("interfaces/BuildingAI.js");
 Engine.LoadComponentScript("GuiInterface.js");
 
@@ -89,6 +92,7 @@ AddMock(100, IID_Player, {
 	IsEnemy: function() { return true; },
 	GetDisabledTemplates: function() { return {}; },
 	HasSharedDropsites: function() { return false; },
+	HasSharedLos: function() { return false; },
 });
 
 AddMock(100, IID_EntityLimits, {
@@ -125,6 +129,7 @@ AddMock(100, IID_StatisticsTracker, {
 			"unitsTrained": 10,
 			"unitsLost": 9,
 			"buildingsConstructed": 5,
+			"buildingsCaptured": 7,
 			"buildingsLost": 4,
 			"civCentresBuilt": 1,
 			"resourcesGathered": {
@@ -171,6 +176,7 @@ AddMock(101, IID_Player, {
 	IsEnemy: function() { return false; },
 	GetDisabledTemplates: function() { return {}; },
 	HasSharedDropsites: function() { return false; },
+	HasSharedLos: function() { return false; },
 });
 
 AddMock(101, IID_EntityLimits, {
@@ -207,6 +213,7 @@ AddMock(101, IID_StatisticsTracker, {
 			"unitsTrained": 10,
 			"unitsLost": 9,
 			"buildingsConstructed": 5,
+			"buildingsCaptured": 7,
 			"buildingsLost": 4,
 			"civCentresBuilt": 1,
 			"resourcesGathered": {
@@ -253,6 +260,7 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetSimulationState(), {
 			cheatsEnabled: false,
 			disabledTemplates: {},
 			hasSharedDropsites: false,
+			hasSharedLos: false,
 			phase: "village",
 			isAlly: [false, false],
 			isMutualAlly: [false, false],
@@ -294,6 +302,7 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetSimulationState(), {
 			cheatsEnabled: false,
 			disabledTemplates: {},
 			hasSharedDropsites: false,
+			hasSharedLos: false,
 			phase: "village",
 			isAlly: [true, true],
 			isMutualAlly: [false, false],
@@ -344,6 +353,7 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetExtendedSimulationState(), {
 			cheatsEnabled: false,
 			disabledTemplates: {},
 			hasSharedDropsites: false,
+			hasSharedLos: false,
 			phase: "village",
 			isAlly: [false, false],
 			isMutualAlly: [false, false],
@@ -361,6 +371,7 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetExtendedSimulationState(), {
 				unitsTrained: 10,
 				unitsLost: 9,
 				buildingsConstructed: 5,
+				buildingsCaptured: 7,
 				buildingsLost: 4,
 				civCentresBuilt: 1,
 				resourcesGathered: {
@@ -397,6 +408,7 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetExtendedSimulationState(), {
 			cheatsEnabled: false,
 			disabledTemplates: {},
 			hasSharedDropsites: false,
+			hasSharedLos: false,
 			phase: "village",
 			isAlly: [true, true],
 			isMutualAlly: [false, false],
@@ -414,6 +426,7 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetExtendedSimulationState(), {
 				unitsTrained: 10,
 				unitsLost: 9,
 				buildingsConstructed: 5,
+				buildingsCaptured: 7,
 				buildingsLost: 4,
 				civCentresBuilt: 1,
 				resourcesGathered: {
@@ -495,8 +508,10 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetEntityState(-1, 10), {
 	garrisonHolder: null,
 	gate: null,
 	guard: null,
+	market: null,
 	mirage: null,
 	pack: null,
+	upgrade: null,
 	player: -1,
 	position: {x:1, y:2, z:3},
 	production: null,
@@ -520,7 +535,8 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetExtendedEntityState(-1, 10), {
 		prices: { "buy": {"food":150}, "sell": {"food":25} },
 	},
 	buildingAI: null,
-	healer: null,
+	heal: null,
+	loot: null,
 	obstruction: null,
 	turretParent: null,
 	promotion: null,
@@ -529,4 +545,5 @@ TS_ASSERT_UNEVAL_EQUALS(cmp.GetExtendedEntityState(-1, 10), {
 	resourceDropsite: null,
 	resourceGatherRates: null,
 	resourceSupply: null,
+	speed: null,
 });
