@@ -48,10 +48,9 @@ function Cheat(input)
 		}
 		return;
 	case "defeatplayer":
-		var playerEnt = cmpPlayerManager.GetPlayerByID(input.parameter);
-		if (playerEnt == INVALID_ENTITY)
-			return;
-		Engine.PostMessage(playerEnt, MT_PlayerDefeated, { "playerId": input.parameter });
+		cmpPlayer = QueryPlayerIDInterface(input.parameter);
+		if (cmpPlayer)
+			cmpPlayer.SetState("defeated");
 		return;
 	case "createunits":
 		var cmpProductionQueue = input.selected.length && Engine.QueryInterface(input.selected[0], IID_ProductionQueue);
@@ -90,8 +89,8 @@ function Cheat(input)
 			return;
 
 		// check if specialised tech exists (like phase_town_athen)
-		var cmpTechnologyTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TechnologyTemplateManager);
-		if (cmpTechnologyTemplateManager.ListAllTechs().indexOf(parameter + "_" + cmpPlayer.civ) > -1)
+		var cmpDataTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_DataTemplateManager);
+		if (cmpDataTemplateManager.ListAllTechs().indexOf(parameter + "_" + cmpPlayer.civ) > -1)
 			parameter += "_" + cmpPlayer.civ;
 
 		Cheat({ "player": input.player, "action": "researchTechnology", "parameter": parameter, "selected": input.selected });
