@@ -4,13 +4,15 @@ var g_DebugCommands = false;
 
 function ProcessCommand(player, cmd)
 {
-	// Do some basic checks here that commanding player is valid
-	var data = {};
-	data.cmpPlayerMan = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
-	if (!data.cmpPlayerMan || player < 0)
+	let data = {
+		"cmpPlayerManager": Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager)
+	};
+
+	if (!data.cmpPlayerManager || player < 0)
 		return;
 
-	data.playerEnt = data.cmpPlayerMan.GetPlayerByID(player);
+	data.playerEnt = data.cmpPlayerManager.GetPlayerByID(player);
+
 	if (data.playerEnt == INVALID_ENTITY)
 		return;
 
@@ -131,6 +133,13 @@ var g_Commands = {
 
 	"reveal-map": function(player, cmd, data)
 	{
+		var cmpGuiInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
+		cmpGuiInterface.PushNotification({
+			"type": "aichat",
+			"players": [player],
+			"message": "(Cheat - reveal map)" // TODO: translate me!
+		});
+
 		// Reveal the map for all players, not just the current player,
 		// primarily to make it obvious to everyone that the player is cheating
 		var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
@@ -168,18 +177,24 @@ var g_Commands = {
 			warn("Invalid command: attack target is not owned by enemy of player "+player+": "+uneval(cmd));
 
 		let allowCapture = cmd.allowCapture || cmd.allowCapture == null;
-		// See UnitAI.CanAttack for target checks
+
 		GetFormationUnitAIs(data.entities, player).forEach(cmpUnitAI => {
 			cmpUnitAI.Attack(cmd.target, cmd.queued, allowCapture);
 		});
 	},
 
+	"patrol": function(player, cmd, data)
+	{
+		GetFormationUnitAIs(data.entities, player).forEach(cmpUnitAI =>
+			cmpUnitAI.Patrol(cmd.x, cmd.z, cmd.targetClasses, cmd.queued)
+		);
+	},
+
 	"heal": function(player, cmd, data)
 	{
 		if (g_DebugCommands && !(IsOwnedByPlayer(player, cmd.target) || IsOwnedByAllyOfPlayer(player, cmd.target)))
 			warn("Invalid command: heal target is not owned by player "+player+" or their ally: "+uneval(cmd));
 
-		// See UnitAI.CanHeal for target checks
 		GetFormationUnitAIs(data.entities, player).forEach(cmpUnitAI => {
 			cmpUnitAI.Heal(cmd.target, cmd.queued);
 		});
@@ -191,7 +206,6 @@ var g_Commands = {
 		if (g_DebugCommands && !IsOwnedByAllyOfPlayer(player, cmd.target))
 			warn("Invalid command: repair target is not owned by ally of player "+player+": "+uneval(cmd));
 
-		// See UnitAI.CanRepair for target checks
 		GetFormationUnitAIs(data.entities, player).forEach(cmpUnitAI => {
 			cmpUnitAI.Repair(cmd.target, cmd.autocontinue, cmd.queued);
 		});
@@ -202,7 +216,6 @@ var g_Commands = {
 		if (g_DebugCommands && !(IsOwnedByPlayer(player, cmd.target) || IsOwnedByGaia(cmd.target)))
 			warn("Invalid command: resource is not owned by gaia or player "+player+": "+uneval(cmd));
 
-		// See UnitAI.CanGather for target checks
 		GetFormationUnitAIs(data.entities, player).forEach(cmpUnitAI => {
 			cmpUnitAI.Gather(cmd.target, cmd.queued);
 		});
@@ -220,7 +233,6 @@ var g_Commands = {
 		if (g_DebugCommands && !IsOwnedByPlayer(player, cmd.target))
 			warn("Invalid command: dropsite is not owned by player "+player+": "+uneval(cmd));
 
-		// See UnitAI.CanReturnResource for target checks
 		GetFormationUnitAIs(data.entities, player).forEach(cmpUnitAI => {
 			cmpUnitAI.ReturnResource(cmd.target, cmd.queued);
 		});
@@ -360,25 +372,35 @@ var g_Commands = {
 	{
 		for (let ent of data.entities)
 		{
-			// don't allow to delete entities who are half-captured
-			var cmpCapturable = Engine.QueryInterface(ent, IID_Capturable);
-			if (cmpCapturable)
+			let cmpHealth = QueryMiragedInterface(ent, IID_Health);
+			if (!data.controlAllUnits)
 			{
-				var capturePoints = cmpCapturable.GetCapturePoints();
-				var maxCapturePoints = cmpCapturable.GetMaxCapturePoints();
-				if (capturePoints[player] < maxCapturePoints / 2)
-					return;
-			}
-			// either kill or delete the entity
-			var cmpHealth = Engine.QueryInterface(ent, IID_Health);
-			if (cmpHealth)
-			{
-				if (cmpHealth.IsUndeletable())
+				if (cmpHealth && cmpHealth.IsUndeletable())
+					continue;
+
+				let cmpCapturable = QueryMiragedInterface(ent, IID_Capturable);
+				if (cmpCapturable &&
+				    cmpCapturable.GetCapturePoints()[player] < cmpCapturable.GetMaxCapturePoints() / 2)
+					continue;
+
+				let cmpResourceSupply = QueryMiragedInterface(ent, IID_ResourceSupply);
+				if (cmpResourceSupply && cmpResourceSupply.GetKillBeforeGather())
 					continue;
-				var cmpResourceSupply = Engine.QueryInterface(ent, IID_ResourceSupply);
-				if (!cmpResourceSupply || !cmpResourceSupply.GetKillBeforeGather())
-					cmpHealth.Kill();
 			}
+
+			let cmpMirage = Engine.QueryInterface(ent, IID_Mirage);
+			if (cmpMirage)
+			{
+				let cmpMiragedHealth = Engine.QueryInterface(cmpMirage.parent, IID_Health);
+				if (cmpMiragedHealth)
+					cmpMiragedHealth.Kill();
+				else
+					Engine.DestroyEntity(cmpMirage.parent);
+
+				Engine.DestroyEntity(ent);
+			}
+			else if (cmpHealth)
+				cmpHealth.Kill();
 			else
 				Engine.DestroyEntity(ent);
 		}
@@ -412,8 +434,9 @@ var g_Commands = {
 
 	"defeat-player": function(player, cmd, data)
 	{
-		// Send "OnPlayerDefeated" message to player
-		Engine.PostMessage(data.playerEnt, MT_PlayerDefeated, { "playerId": player } );
+		let cmpPlayer = QueryPlayerIDInterface(player);
+		if (cmpPlayer)
+			cmpPlayer.SetState("defeated", !!cmd.resign);
 	},
 
 	"garrison": function(player, cmd, data)
@@ -578,12 +601,6 @@ var g_Commands = {
 		}
 	},
 
-	"wall-to-gate": function(player, cmd, data)
-	{
-		for (let ent of data.entities)
-			TryTransformWallToGate(ent, data.cmpPlayer, cmd);
-	},
-
 	"lock-gate": function(player, cmd, data)
 	{
 		for (let ent of data.entities)
@@ -606,16 +623,6 @@ var g_Commands = {
 		});
 	},
 
-	"select-required-goods": function(player, cmd, data)
-	{
-		for (let ent of data.entities)
-		{
-			var cmpTrader = Engine.QueryInterface(ent, IID_Trader);
-			if (cmpTrader)
-				cmpTrader.SetRequiredGoods(cmd.requiredGoods);
-		}
-	},
-
 	"set-trading-goods": function(player, cmd, data)
 	{
 		data.cmpPlayer.SetTradingGoods(cmd.tradingGoods);
@@ -668,6 +675,69 @@ var g_Commands = {
 		}
 	},
 
+	"upgrade": function(player, cmd, data)
+	{
+		for (let ent of data.entities)
+		{
+			var cmpUpgrade = Engine.QueryInterface(ent, IID_Upgrade);
+
+			if (!cmpUpgrade || !cmpUpgrade.CanUpgradeTo(cmd.template))
+				continue;
+
+			if (cmpUpgrade.WillCheckPlacementRestrictions(cmd.template) && ObstructionsBlockingTemplateChange(ent, cmd.template))
+			{
+				var cmpGUIInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
+				cmpGUIInterface.PushNotification({
+					"players": [data.cmpPlayer.GetPlayerID()],
+					"message": markForTranslation("Cannot upgrade as distance requirements are not verified or terrain is obstructed.")
+				});
+				continue;
+			}
+
+			if (!CanGarrisonedChangeTemplate(ent, cmd.template))
+			{
+				var cmpGUIInterface = Engine.QueryInterface(SYSTEM_ENTITY, IID_GuiInterface);
+				cmpGUIInterface.PushNotification({
+					"players": [data.cmpPlayer.GetPlayerID()],
+					"message": markForTranslation("Cannot upgrade a garrisoned entity.")
+				});
+				continue;
+			}
+
+			// Check entity limits
+			var cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
+			var template = cmpTemplateManager.GetTemplate(cmd.template);
+			var cmpEntityLimits = QueryPlayerIDInterface(player, IID_EntityLimits);
+			if (template.TrainingRestrictions && !cmpEntityLimits.AllowedToTrain(template.TrainingRestrictions.Category, 1) ||
+				template.BuildRestrictions && !cmpEntityLimits.AllowedToBuild(template.BuildRestrictions.Category))
+			{
+				if (g_DebugCommands)
+					warn("Invalid command: build limits check failed for player " + player + ": " + uneval(cmd));
+				continue;
+			}
+
+			var cmpTechnologyManager = QueryOwnerInterface(ent, IID_TechnologyManager);
+			if (cmpUpgrade.GetRequiredTechnology(cmd.template) && !cmpTechnologyManager.IsTechnologyResearched(cmpUpgrade.GetRequiredTechnology(cmd.template)))
+			{
+				if (g_DebugCommands)
+					warn("Invalid command: upgrading requires unresearched technology: " + uneval(cmd));
+				continue;
+			}
+
+			cmpUpgrade.Upgrade(cmd.template, data.cmpPlayer);
+		}
+	},
+
+	"cancel-upgrade": function(player, cmd, data)
+	{
+		for (let ent of data.entities)
+		{
+			let cmpUpgrade = Engine.QueryInterface(ent, IID_Upgrade);
+			if (cmpUpgrade)
+				cmpUpgrade.CancelUpgrade(data.cmpPlayer.playerID);
+		}
+	},
+
 	"attack-request": function(player, cmd, data)
 	{
 		// Send a chat message to human players
@@ -740,7 +810,7 @@ function notifyAlertFailure(player)
 	cmpGUIInterface.PushNotification({
 		"type": "text",
 		"players": [player],
-		"message": "You can't raise the alert to a higher level !",
+		"message": "You can't raise the alert to a higher level!",
 		"translateMessage": true
 	});
 }
@@ -960,7 +1030,7 @@ function TryConstructBuilding(player, cmpPlayer, controlAllUnits, cmd)
 
 	// Check entity limits
 	var cmpEntityLimits = QueryPlayerIDInterface(player, IID_EntityLimits);
-	if (!cmpEntityLimits || !cmpEntityLimits.AllowedToBuild(cmpBuildRestrictions.GetCategory()))
+	if (cmpEntityLimits && !cmpEntityLimits.AllowedToBuild(cmpBuildRestrictions.GetCategory()))
 	{
 		if (g_DebugCommands)
 			warn("Invalid command: build limits check failed for player "+player+": "+uneval(cmd));
@@ -972,8 +1042,7 @@ function TryConstructBuilding(player, cmpPlayer, controlAllUnits, cmd)
 	}
 
 	var cmpTechnologyManager = QueryPlayerIDInterface(player, IID_TechnologyManager);
-
-	if (!cmpTechnologyManager.CanProduce(cmd.template))
+	if (cmpTechnologyManager && !cmpTechnologyManager.CanProduce(cmd.template))
 	{
 		if (g_DebugCommands)
 			warn("Invalid command: required technology check failed for player "+player+": "+uneval(cmd));
@@ -1450,7 +1519,6 @@ function ClusterEntities(ents, separationDistance)
 	while (clusters.length > 1)
 	{
 		// search two clusters that are closer than the required distance
-		var smallDist = Infinity;
 		var closeClusters = undefined;
 
 		for (var i = matrix.length - 1; i >= 0 && !closeClusters; --i)
@@ -1517,7 +1585,6 @@ function CanMoveEntsIntoFormation(ents, formationTemplate)
 		return false;
 
 	var count = 0;
-	var reqClasses = requirements.classesRequired || [];
 	for (let ent of ents)
 	{
 		var cmpIdentity = Engine.QueryInterface(ent, IID_Identity);
@@ -1567,79 +1634,6 @@ function FilterEntityListWithAllies(entities, player, controlAll)
 	return entities.filter(ent => CanControlUnitOrIsAlly(ent, player, controlAll));
 }
 
-/**
- * Try to transform a wall to a gate
- */
-function TryTransformWallToGate(ent, cmpPlayer, cmd)
-{
-	var cmpIdentity = Engine.QueryInterface(ent, IID_Identity);
-	if (!cmpIdentity)
-		return;
-
-	if (!cmpIdentity.HasClass("LongWall"))
-	{
-		if (g_DebugCommands)
-			warn("Invalid command: invalid wall conversion to gate for player "+player+": "+uneval(cmd));
-		return;
-	}
-
-	var civ = cmpIdentity.GetCiv();
-	var gate = Engine.AddEntity(cmd.template);
-
-	var cmpCost = Engine.QueryInterface(gate, IID_Cost);
-	if (!cmpPlayer.TrySubtractResources(cmpCost.GetResourceCosts()))
-	{
-		if (g_DebugCommands)
-			warn("Invalid command: convert gate cost check failed for player "+player+": "+uneval(cmd));
-
-		Engine.DestroyEntity(gate);
-		return;
-	}
-
-	ReplaceBuildingWith(ent, gate);
-}
-
-/**
- * Unconditionally replace a building with another one
- */
-function ReplaceBuildingWith(ent, building)
-{
-	// Move the building to the right place
-	var cmpPosition = Engine.QueryInterface(ent, IID_Position);
-	var cmpBuildingPosition = Engine.QueryInterface(building, IID_Position);
-	var pos = cmpPosition.GetPosition2D();
-	cmpBuildingPosition.JumpTo(pos.x, pos.y);
-	var rot = cmpPosition.GetRotation();
-	cmpBuildingPosition.SetYRotation(rot.y);
-	cmpBuildingPosition.SetXZRotation(rot.x, rot.z);
-
-	// Copy ownership
-	var cmpOwnership = Engine.QueryInterface(ent, IID_Ownership);
-	var cmpBuildingOwnership = Engine.QueryInterface(building, IID_Ownership);
-	cmpBuildingOwnership.SetOwner(cmpOwnership.GetOwner());
-
-	// Copy control groups
-	var cmpObstruction = Engine.QueryInterface(ent, IID_Obstruction);
-	var cmpBuildingObstruction = Engine.QueryInterface(building, IID_Obstruction);
-	cmpBuildingObstruction.SetControlGroup(cmpObstruction.GetControlGroup());
-	cmpBuildingObstruction.SetControlGroup2(cmpObstruction.GetControlGroup2());
-
-	// Copy health level from the old entity to the new
-	var cmpHealth = Engine.QueryInterface(ent, IID_Health);
-	var cmpBuildingHealth = Engine.QueryInterface(building, IID_Health);
-	var healthFraction = Math.max(0, Math.min(1, cmpHealth.GetHitpoints() / cmpHealth.GetMaxHitpoints()));
-	var buildingHitpoints = Math.round(cmpBuildingHealth.GetMaxHitpoints() * healthFraction);
-	cmpBuildingHealth.SetHitpoints(buildingHitpoints);
-
-	PlaySound("constructed", building);
-
-	Engine.PostMessage(ent, MT_ConstructionFinished,
-		{ "entity": ent, "newentity": building });
-	Engine.BroadcastMessage(MT_EntityRenamed, { entity: ent, newentity: building });
-
-	Engine.DestroyEntity(ent);
-}
-
 Engine.RegisterGlobal("GetFormationRequirements", GetFormationRequirements);
 Engine.RegisterGlobal("CanMoveEntsIntoFormation", CanMoveEntsIntoFormation);
 Engine.RegisterGlobal("GetDockAngle", GetDockAngle);
