@@ -11,11 +11,10 @@ function PreInitGame()
 	Engine.BroadcastMessage(MT_SkirmishReplace, {});
 	Engine.FlushDestroyedEntities(); 
 
-	let cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
-	let playerIds = cmpPlayerManager.GetAllPlayerEntities().slice(1); // ignore gaia
-	for (let playerId of playerIds)
+	let numPlayers = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager).GetNumPlayers();
+	for (let i = 1; i < numPlayers; ++i) // ignore gaia
 	{
-		let cmpTechnologyManager = Engine.QueryInterface(playerId, IID_TechnologyManager);
+		let cmpTechnologyManager = QueryPlayerIDInterface(i, IID_TechnologyManager);
 		if (cmpTechnologyManager)
 			cmpTechnologyManager.UpdateAutoResearch();
 	}
@@ -44,11 +43,10 @@ function InitGame(settings)
 
 	// Sandbox, Very Easy, Easy, Medium, Hard, Very Hard
 	let rate = [ 0.50, 0.64, 0.80, 1.00, 1.25, 1.56 ];
-	let cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
 	let cmpAIManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_AIManager);
-	for (let i = 1; i < settings.PlayerData.length; ++i)
+	for (let i = 0; i < settings.PlayerData.length; ++i)
 	{
-		let cmpPlayer = Engine.QueryInterface(cmpPlayerManager.GetPlayerByID(i), IID_Player);
+		let cmpPlayer = QueryPlayerIDInterface(i);
 		cmpPlayer.SetCheatsEnabled(!!settings.CheatsEnabled);
 		if (settings.PlayerData[i] && settings.PlayerData[i].AI && settings.PlayerData[i].AI != "")
 		{
