@@ -22,7 +22,7 @@ var tGrassPatch = "medit_dirt_b";
 
 var tShoreBlend = ["medit_sand_wet","medit_rocks_wet"];
 var tShore = ["medit_rocks","medit_sand","medit_sand"];
-var tSandTransition = ["medit_sand","medit_rocks_grass","medit_rocks_grass","medit_rocks_grass"]
+var tSandTransition = ["medit_sand","medit_rocks_grass","medit_rocks_grass","medit_rocks_grass"];
 var tVeryDeepWater = ["medit_sea_depths","medit_sea_coral_deep"];
 var tDeepWater = ["medit_sea_coral_deep","tropic_ocean_coral"];
 var tCreekWater = "medit_sea_coral_plants";
@@ -32,9 +32,8 @@ var ePine = "gaia/flora_tree_aleppo_pine";
 var ePalmTall = "gaia/flora_tree_cretan_date_palm_tall";
 var eFanPalm = "gaia/flora_tree_medit_fan_palm";
 var eCypress = "gaia/flora_tree_cypress";
-var eApple = "gaia/flora_tree_apple"
+var eApple = "gaia/flora_tree_apple";
 var eBush = "gaia/flora_bush_berry";
-var eChicken = "gaia/fauna_chicken";
 var eFish = "gaia/fauna_fish";
 var ePig = "gaia/fauna_pig";
 var eStoneMine = "gaia/geology_stonemine_medit_quarry";
@@ -61,10 +60,6 @@ var tForestNicae = [tForestFloor + TERRAIN_SEPARATOR + ePine,tForestFloor + TERR
 var tForestNicaeLight = [tForestFloor + TERRAIN_SEPARATOR + ePine,tForestFloor + TERRAIN_SEPARATOR + ePine,tForestFloor + TERRAIN_SEPARATOR + eFanPalm, tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor];
 var tForestNicaeScarce = [tForestFloor + TERRAIN_SEPARATOR + ePine,tForestFloor + TERRAIN_SEPARATOR + ePine,tForestFloor + TERRAIN_SEPARATOR + eFanPalm, tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor,tForestFloor];
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
 
 InitMap();
@@ -191,7 +186,7 @@ for (var island = 0; island <= 1; island++)
 		if (swap)
 			angle += PI/2;
 		fx = radius * cos(angle);
-		fz = radius * sin(angle);	
+		fz = radius * sin(angle);
 		fx = round(islandX[island] + fx);
 		fz = round(islandZ[island] + fz);
 		var size = scaleByMapSize(75,100);
@@ -216,19 +211,19 @@ for (var island = 0; island <= 1; island++)
 		if (swap)
 			angle += PI/2;
 		var startX = smallRadius * cos(angle);
-		var startZ = smallRadius * sin(angle);	
+		var startZ = smallRadius * sin(angle);
 		startX = round(islandX[island] + startX);
 		startZ = round(islandZ[island] + startZ);
-		
+
 		var endX = bigRadius * cos(angle);
-		var endZ = bigRadius * sin(angle);	
+		var endZ = bigRadius * sin(angle);
 		endX = round(islandX[island] + endX);
 		endZ = round(islandZ[island] + endZ);
-		
+
 		var placer = new ClumpPlacer(130, 0.7, 0.8, 10, round((startX+endX*3)/4),round((startZ+endZ*3)/4));
 		var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, -1,5);	// base height is -10
 		createArea(placer, [elevationPainter], null);
-		
+
 		straightPassageMaker(startX, startZ,endX,endZ, 25, 18, 4,clShore,null);
 	}
 }
@@ -315,15 +310,15 @@ for (var i = 0; i < numPlayers; i++)
 {
 	var id = playerIDs[i];
 	log("Creating base for player " + id + "...");
-	
+
 	// some constants
 	var radius = 23;
-	
+
 	// get the x and z in tiles
 	fx = playerX[i];
 	fz = playerZ[i];
-	
-	
+
+
 	// let's create a nice platform
 	var placer = new ClumpPlacer(PI*radius*radius, 0.95, 0.3, 10, fx,fz);
 	var PlayerArea = createArea(placer, [paintClass(clPlayer)], null);
@@ -334,35 +329,23 @@ for (var i = 0; i < numPlayers; i++)
 	var painter = new LayeredPainter([tRoadWild,tRoad],[1]);
 	var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, getHeight(fx,fz),10);
 	createArea(placer, [painter,paintClass(clSettlement),elevationPainter], null);
-	
+
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : false});
-	
-	// create animals
-	for (var j = 0; j < 2; ++j)
-	{
-		var aAngle = randFloat(0, TWO_PI);
-		var aDist = 7;
-		var aX = round(fx + aDist * cos(aAngle));
-		var aZ = round(fz + aDist * sin(aAngle));
-		var group = new SimpleGroup(
-			[new SimpleObject(eChicken, 5,5, 0,2)],
-			true, clBaseResource, aX, aZ
-		);
-		createObjectGroup(group, 0);
-	}
-	
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': false });
+
+	placeDefaultChicken(fx, fz, clBaseResource);
+
 	// create berry bushes
 	var bbAngle = randFloat(0, TWO_PI);
 	var bbDist = 11;
 	var bbX = round(fx + bbDist * cos(bbAngle));
 	var bbZ = round(fz + bbDist * sin(bbAngle));
-	group = new SimpleGroup(
+	var group = new SimpleGroup(
 		[new SimpleObject(eBush, 5,5, 1,2)],
 		true, clBaseResource, bbX, bbZ
 	);
 	createObjectGroup(group, 0);
-	
+
 	// create metal mine
 	// this makes sure it's created on the same level as the player.
 	var mAngle = randFloat(playerAngle[i] + PI/2,playerAngle[i] + PI/3);
@@ -379,7 +362,7 @@ for (var i = 0; i < numPlayers; i++)
 	group = new SimpleGroup(
 		[new SimpleObject(eStoneMine, 1,1, 0,2),new SimpleObject(aBushB, 1,1, 2,2), new SimpleObject(aBushA, 0,2, 1,3), new SimpleObject(ePine, 0,1, 3,3)], true, clBaseResource, mX, mZ );
 	createObjectGroup(group, 0);
-	
+
 	group = new SimpleGroup([new SimpleObject(ePine, 1,3, 1,4),new SimpleObject(ePalmTall, 0,1, 1,4),new SimpleObject(eFanPalm, 0,1, 0,2)], true, clForest);
 	createObjectGroups(group, 0, [avoidClasses(clBaseResource,3, clSettlement,0), stayClasses(clPlayer,1)], 150, 1000);
 }
@@ -421,10 +404,10 @@ if(mapSize > 150)
 		if (swap)
 			angle += PI/2;
 		var x1 = round(CorsX + (radius+5)*cos(angle));
-		var y1 = round(CorsZ + (radius+5)*sin(angle));	
+		var y1 = round(CorsZ + (radius+5)*sin(angle));
 		var x2 = round(CorsX + (radius-4)*cos(angle));
-		var y2 = round(CorsZ + (radius-4)*sin(angle));	
-		straightPassageMaker(x1, y1, x2, y2, 1, 6, 2,clPassage,tGrass)
+		var y2 = round(CorsZ + (radius-4)*sin(angle));
+		straightPassageMaker(x1, y1, x2, y2, 1, 6, 2, clPassage, tGrass);
 	}
 	for (var i = 0; i < nb; i++) {
 		var radius = sqrt(fractionToSize(0.1)/PI)+ 2;
@@ -432,10 +415,10 @@ if(mapSize > 150)
 		if (swap)
 			angle += PI/2;
 		var x1 = round(SardX + (radius+5)*cos(angle));
-		var y1 = round(SardZ + (radius+5)*sin(angle));	
+		var y1 = round(SardZ + (radius+5)*sin(angle));
 		var x2 = round(SardX + (radius-4)*cos(angle));
-		var y2 = round(SardZ + (radius-4)*sin(angle));	
-		straightPassageMaker(x1, y1, x2, y2, 1, 6, 2,clPassage,tGrass)
+		var y2 = round(SardZ + (radius-4)*sin(angle));
+		straightPassageMaker(x1, y1, x2, y2, 1, 6, 2, clPassage, tGrass);
 	}
 }
 for (var i = 0; i <= 3; i++) {
@@ -444,10 +427,10 @@ for (var i = 0; i <= 3; i++) {
 	if (swap)
 		angle += PI/2;
 	var x1 = round(CorsX + (radius+7)*cos(angle));
-	var y1 = round(CorsZ + (radius+7)*sin(angle));	
+	var y1 = round(CorsZ + (radius+7)*sin(angle));
 	var x2 = round(CorsX + (radius-5)*cos(angle));
-	var y2 = round(CorsZ + (radius-5)*sin(angle));	
-	straightPassageMaker(x1, y1, x2, y2, 4, 10, 3,clPassage,tGrass)
+	var y2 = round(CorsZ + (radius-5)*sin(angle));
+	straightPassageMaker(x1, y1, x2, y2, 4, 10, 3, clPassage, tGrass);
 }
 for (var i = 0; i <= 3; i++) {
 	var radius = sqrt(fractionToSize(0.18)*1.8/PI)+ 2;
@@ -455,10 +438,10 @@ for (var i = 0; i <= 3; i++) {
 	if (swap)
 		angle += PI/2;
 	var x1 = round(SardX + (radius+7)*cos(angle));
-	var y1 = round(SardZ + (radius+7)*sin(angle));	
+	var y1 = round(SardZ + (radius+7)*sin(angle));
 	var x2 = round(SardX + (radius-5)*cos(angle));
-	var y2 = round(SardZ + (radius-5)*sin(angle));	
-	straightPassageMaker(x1, y1, x2, y2, 4, 10, 3,clPassage,tGrass)
+	var y2 = round(SardZ + (radius-5)*sin(angle));
+	straightPassageMaker(x1, y1, x2, y2, 4, 10, 3, clPassage, tGrass);
 }
 RMS.SetProgress(50);
 
@@ -639,7 +622,7 @@ function straightPassageMaker(x1, z1, x2, z2, startWidth, centerWidth, smooth, t
 {
 	var mapSize = g_Map.size;
 	var stepNB = sqrt((x2-x1)*(x2-x1) + (z2-z1)*(z2-z1)) + 2;
-	
+
 	var startHeight = getHeight(x1,z1);
 	var finishHeight = getHeight(x2,z2);
 	for (var step = 0; step <= stepNB; step+=0.5)
@@ -669,7 +652,7 @@ function straightPassageMaker(x1, z1, x2, z2, startWidth, centerWidth, smooth, t
 		{
 			var rx = po*direction[0];
 			var rz = po*direction[1];
-			
+
 			var relativeWidth = abs(po / Math.floor(width/2));
 			var targetHeight = ((stepNB-step)*startHeight + finishHeight*step) / stepNB;
 			if (round(ix + rx) < mapSize && round(iz + rz) < mapSize && round(ix + rx) >= 0 && round(iz + rz) >= 0)
