@@ -8,17 +8,15 @@ const tOceanCoral = "medit_sea_coral_plants";
 const tBeachWet = "medit_sand_wet";
 const tBeachDry = "medit_sand";
 const tBeachGrass = "medit_rocks_grass";
-const tBeach = ["medit_rocks_grass","medit_sand", "medit_rocks_grass_shrubs"]
-//const tBeachBlend = ["medit_rocks_grass","medit_grass_field_dry", "medit_grass_field_brown","medit_rocks_shrubs", "medit_rocks_grass_shrubs"];
+const tBeach = ["medit_rocks_grass","medit_sand", "medit_rocks_grass_shrubs"];
 const tBeachBlend = ["medit_rocks_grass", "medit_rocks_grass_shrubs"];
 const tBeachCliff = "medit_dirt";
 const tCity = "medit_city_tile";
 const tGrassDry = ["medit_grass_field_dry", "medit_grass_field_b"];
-//const tGrass = ["medit_grass_field_dry", "medit_grass_field_brown", "medit_grass_field_b"];
 const tGrass = ["medit_rocks_grass", "medit_rocks_grass","medit_dirt","medit_rocks_grass_shrubs"];
 const tGrassLush = ["grass_temperate_dry_tufts", "medit_grass_flowers"];
 const tGrassShrubs = "medit_shrubs";
-const tCliffShrubs = ["medit_cliff_aegean_shrubs", "medit_cliff_italia_grass","medit_cliff_italia"]
+const tCliffShrubs = ["medit_cliff_aegean_shrubs", "medit_cliff_italia_grass","medit_cliff_italia"];
 const tGrassRock = ["medit_rocks_grass"];
 const tDirt = "medit_dirt";
 const tDirtGrass = "medit_dirt_b";
@@ -40,7 +38,6 @@ const oPine = "gaia/flora_tree_aleppo_pine";
 const oPoplar = "gaia/flora_tree_poplar";
 const oDateT = "gaia/flora_tree_cretan_date_palm_tall";
 const oDateS = "gaia/flora_tree_cretan_date_palm_short";
-const oChicken = "gaia/fauna_chicken";
 const oDeer = "gaia/fauna_deer";
 const oFish = "gaia/fauna_fish";
 const oWhale = "gaia/fauna_whale_humpback";
@@ -70,19 +67,12 @@ const pPineForest = [tForestFloor+TERRAIN_SEPARATOR+oPine, tGrass];
 const pPoplarForest = [tForestFloor+TERRAIN_SEPARATOR+oLombardyPoplar, tGrass];
 const pMainForest = [tForestFloor+TERRAIN_SEPARATOR+oCarob, tForestFloor+TERRAIN_SEPARATOR+oBeech, tGrass, tGrass];
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
-
 InitMap();
 
 const numPlayers = getNumPlayers();
 const mapSize = getMapSize();
 
-// create tile classes
-
 var clCoral = createTileClass();
 var clPlayer = createTileClass();
 var clIsland = createTileClass();
@@ -99,23 +89,13 @@ var clBaseResource = createTileClass();
 // randomize player order
 var playerIDs = [];
 for (var i = 0; i < numPlayers; i++)
-{
 	playerIDs.push(i+1);
-}
 playerIDs = sortPlayers(playerIDs);
 
 //array holding starting islands based on number of players
 var startingPlaces=[[0],[0,3],[0,2,4],[0,1,3,4],[0,1,2,3,4],[0,1,2,3,4,5]];
 
-//figure out how many spoke islands
-var numIslands =6;
-if(numPlayers<6){
-    numIslands=6;
-}else{
-    numIslands=numPlayers;
-}
-
-//figure out coordinates of spoke islands
+var numIslands = Math.max(6, numPlayers);
 var islandX = new Array(numIslands);
 var islandZ = new Array(numIslands);
 var islandAngle = new Array(numIslands);
@@ -130,30 +110,27 @@ for (var i=0; i < numIslands; i++)
 	islandZ[i] = 0.5 + 0.39*sin(islandAngle[i]);
 }
 
-
-for(var i=0;i<numIslands;i++){
+for (var i = 0; i < numIslands; ++i)
+{
 	var radius = scaleByMapSize(15,40);
 	var coral=scaleByMapSize(1,5);
 	var wet = 3;
 	var dry = 1;
 	var gbeach = 2;
 	var elevation = 3;
-	
+
 	// get the x and z in tiles
 	var fx = fractionToTiles(islandX[i]);
 	var fz = fractionToTiles(islandZ[i]);
 	var ix = round(fx);
 	var iz = round(fz);
-	
+
 	var islandSize = PI*radius*radius;
 	var islandBottom=PI*(radius+coral)*(radius+coral);
-	
+
 	//create base
 	var placer = new ClumpPlacer(islandBottom, .7, .1, 10, ix, iz);
-	var terrainPainter = new LayeredPainter(
-        [tOceanRockDeep, tOceanCoral],
-        [5]
-	);
+	var terrainPainter = new LayeredPainter([tOceanRockDeep, tOceanCoral], [5]);
 	createArea(placer, [terrainPainter, paintClass(clCoral)],avoidClasses(clCoral,0));
 }
 
@@ -163,70 +140,51 @@ for(var i=0;i<numIslands;i++){
 for (var i=0; i < numIslands; i++)
 {
 	log("Creating base Island " + (i + 1) + "...");
-	
+
 	var radius = scaleByMapSize(15,40);
 	var coral=scaleByMapSize(2,5);
 	var wet = 3;
 	var dry = 1;
 	var gbeach = 2;
 	var elevation = 3;
-	
+
 	// get the x and z in tiles
 	var fx = fractionToTiles(islandX[i]);
 	var fz = fractionToTiles(islandZ[i]);
 	var ix = round(fx);
 	var iz = round(fz);
-	
+
 	var islandSize = PI*radius*radius;
 	var islandBottom=PI*(radius+coral)*(radius+coral);
-	
+
 	// create island
 	var placer = new ClumpPlacer(islandSize, .7, .1, 10, ix, iz);
 	var terrainPainter = new LayeredPainter(
-        [tOceanCoral,tBeachWet, tBeachDry, tBeach, tBeachBlend, tGrass],
-        [1,wet,dry,1,gbeach]
+		[tOceanCoral,tBeachWet, tBeachDry, tBeach, tBeachBlend, tGrass],
+		[1, wet, dry, 1, gbeach]
 	);
-	var elevationPainter = new SmoothElevationPainter(
-	    ELEVATION_SET,
-	    elevation,
-	    5
-    );
-    var temp = createArea(placer, [terrainPainter, paintClass(clPlayer), elevationPainter],avoidClasses(clPlayer,0));
-    
-    areas.push(temp);
+	var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, elevation, 5);
+	var temp = createArea(placer, [terrainPainter, paintClass(clPlayer), elevationPainter],avoidClasses(clPlayer,0));
+	areas.push(temp);
+
+	placeDefaultChicken(fx, fz, clBaseResource);
 
-	// create animals
-    var group;
-	for (var j = 0; j < 2; ++j)
-	{
-		var aAngle = randFloat(0, TWO_PI);
-		var aDist = 7;
-		var aX = round(fx + aDist * cos(aAngle));
-		var aZ = round(fz + aDist * sin(aAngle));
-		group = new SimpleGroup(
-			[new SimpleObject(oChicken, 5,5, 0,2)],
-			true, clBaseResource, aX, aZ
-		);
-		createObjectGroup(group, 0);
-	}
-	
 	// create berry bushes
 	var bbAngle = randFloat(0, TWO_PI);
 	var bbDist = 10;
 	var bbX = round(fx + bbDist * cos(bbAngle));
 	var bbZ = round(fz + bbDist * sin(bbAngle));
-	group = new SimpleGroup(
+	var group = new SimpleGroup(
 		[new SimpleObject(oBerryBush, 5,5, 0,3)],
 		true, clBaseResource, bbX, bbZ
 	);
 	createObjectGroup(group, 0);
-	
+
 	// create metal mine
 	var mAngle = bbAngle;
 	while(abs(mAngle - bbAngle) < PI/3)
-	{
 		mAngle = randFloat(0, TWO_PI);
-	}
+
 	var mDist = 12;
 	var mX = round(fx + mDist * cos(mAngle));
 	var mZ = round(fz + mDist * sin(mAngle));
@@ -235,7 +193,7 @@ for (var i=0; i < numIslands; i++)
 		true, clBaseResource, mX, mZ
 	);
 	createObjectGroup(group, 0);
-	
+
 	// create stone mines
 	mAngle += randFloat(PI/8, PI/4);
 	mX = round(fx + mDist * cos(mAngle));
@@ -258,110 +216,96 @@ for (var i=0; i < numIslands; i++)
 	);
 	createObjectGroup(group, 0, avoidClasses(clBaseResource,2));
 }
-
-
-//Populate the islands with the players
-log("Populating islands ...");
-
-//nPlayer is the player we are on i is the island we are on
-var nPlayer=0;
-for(var i=0;i<numIslands;i++)
-{
-if((numPlayers>=6)||(i==startingPlaces[numPlayers-1][nPlayer])){
-
-	var id = playerIDs[nPlayer];
-
-	// get the x and z in tiles
-	var fx = fractionToTiles(islandX[i]);
-	var fz = fractionToTiles(islandZ[i]);
-	var ix = round(fx);
-	var iz = round(fz);
-
-    //create city patch
-    var cityRadius = 6;
-	var placer = new ClumpPlacer(PI*cityRadius*cityRadius, 0.6, 0.3, 10, ix, iz);
-	var painter = new LayeredPainter([tGrass, tCity], [1]);
-	createArea(placer, [painter,paintClass(clCity)], null);
-
-	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : 'towers'});
-
-    nPlayer++;
-}
-}
-
-
 RMS.SetProgress(15);
 
+log("Populating islands ...");
+//nPlayer is the player we are on i is the island we are on
+var nPlayer = 0;
+for (let i = 0; i < numIslands; ++i)
+	if (numPlayers >= 6 || i == startingPlaces[numPlayers-1][nPlayer])
+	{
+		var id = playerIDs[nPlayer];
+
+		// Get the x and z in tiles
+		var fx = fractionToTiles(islandX[i]);
+		var fz = fractionToTiles(islandZ[i]);
+		var ix = round(fx);
+		var iz = round(fz);
+
+		// Create city patch
+		var cityRadius = 6;
+		var placer = new ClumpPlacer(PI*cityRadius*cityRadius, 0.6, 0.3, 10, ix, iz);
+		var painter = new LayeredPainter([tGrass, tCity], [1]);
+		createArea(placer, [painter,paintClass(clCity)], null);
+
+		placeCivDefaultEntities(fx, fz, id, { 'iberWall': 'towers' });
+
+		++nPlayer;
+	}
+RMS.SetProgress(20);
 
 // get the x and z in tiles
-
-var nCenter=floor(scaleByMapSize(1,4))
+var nCenter = floor(scaleByMapSize(1,4));
 var startAngle = randFloat() * 2 * PI;
-for (var i=0; i < nCenter; i++)
+for (var i = 0; i < nCenter; ++i)
 {
-	var fx=.5;
-	var fz=.5;
-	if(nCenter==1){
-	    fx=.5;
-	    fz=.5;
-	}else{
-	    var isangle = startAngle + i*2*PI/nCenter+randFloat(-PI/8,PI/8);
-	    var dRadius = randFloat(.1,.16);
-	    fx = 0.5 + dRadius*cos(isangle);
-	    fz = 0.5 + dRadius*sin(isangle);
+	var fx = 0.5;
+	var fz = 0.5;
+
+	if (nCenter != 1)
+	{
+		let isangle = startAngle + i*2*PI/nCenter + PI/8 * randFloat(-1, -1);
+		let dRadius = randFloat(0.1, 0.16);
+		fx = 0.5 + dRadius * cos(isangle);
+		fz = 0.5 + dRadius * sin(isangle);
 	}
-    var ix = round(fractionToTiles(fx));
-    var iz = round(fractionToTiles(fz));
 
-    var radius = scaleByMapSize(15,30);
-    var coral= 2;
-    var wet = 3;
-    var dry = 1;
-    var gbeach = 2;
-    var elevation = 3;
+	var ix = round(fractionToTiles(fx));
+	var iz = round(fractionToTiles(fz));
 
-    var islandSize = PI*radius*radius;
-    var islandBottom=PI*(radius+coral)*(radius+coral);
+	var radius = scaleByMapSize(15,30);
+	var coral= 2;
+	var wet = 3;
+	var dry = 1;
+	var gbeach = 2;
+	var elevation = 3;
 
-    //create base
-    var placer = new ClumpPlacer(islandBottom, .7, .1, 10, ix, iz);
-    var terrainPainter = new LayeredPainter(
-        [tOceanRockDeep, tOceanCoral],
-        [5]
-    );
-    createArea(placer, [terrainPainter, paintClass(clCoral)],avoidClasses(clCoral,0,clPlayer,0));
+	var islandSize = PI*radius*radius;
+	var islandBottom=PI*(radius+coral)*(radius+coral);
 
-    // create island
-    var placer = new ClumpPlacer(islandSize, .7, .1, 10, ix, iz);
-    var terrainPainter = new LayeredPainter(
-        [tOceanCoral,tBeachWet, tBeachDry, tBeach, tBeachBlend, tGrass],
-        [1,wet,dry,1,gbeach]
-    );
-    var elevationPainter = new SmoothElevationPainter(
-        ELEVATION_SET,
-        elevation,
-        5
-    );
-    var temp = createArea(placer, [terrainPainter, paintClass(clIsland), elevationPainter],avoidClasses(clPlayer,0));
+	// Create base
+	var placer = new ClumpPlacer(islandBottom, .7, .1, 10, ix, iz);
+	var terrainPainter = new LayeredPainter(
+		[tOceanRockDeep, tOceanCoral],
+		[5]
+	);
+	createArea(placer, [terrainPainter, paintClass(clCoral)],avoidClasses(clCoral,0,clPlayer,0));
 
-    areas.push(temp);
-}    
+	// Create island
+	var placer = new ClumpPlacer(islandSize, .7, .1, 10, ix, iz);
+	var terrainPainter = new LayeredPainter(
+		[tOceanCoral,tBeachWet, tBeachDry, tBeach, tBeachBlend, tGrass],
+		[1, wet, dry, 1, gbeach]
+	);
+	var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, elevation, 5);
+	var temp = createArea(placer, [terrainPainter, paintClass(clIsland), elevationPainter],avoidClasses(clPlayer,0));
+
+	areas.push(temp);
+}
 RMS.SetProgress(30);
 
-// create bumps
 log("Creating bumps...");
 placer = new ClumpPlacer(scaleByMapSize(20, 60), 0.3, 0.06, 1);
 painter = new SmoothElevationPainter(ELEVATION_MODIFY, 2, 3);
 createAreasInAreas(
 	placer,
-	painter, 
+	painter,
 	avoidClasses(clCity, 0),
 	scaleByMapSize(25, 75),15,
 	areas
 );
+RMS.SetProgress(34);
 
-// create hills
 log("Creating hills...");
 placer = new ClumpPlacer(scaleByMapSize(20, 150), 0.2, 0.1, 1);
 terrainPainter = new LayeredPainter(
@@ -371,25 +315,19 @@ terrainPainter = new LayeredPainter(
 elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 12, 2);
 createAreasInAreas(
 	placer,
-	[terrainPainter, elevationPainter, paintClass(clHill)], 
+	[terrainPainter, elevationPainter, paintClass(clHill)],
 	avoidClasses(clCity, 15, clHill, 15),
 	scaleByMapSize(5, 30), 15,
 	areas
 );
+RMS.SetProgress(38);
 
-RMS.SetProgress(40);
-//find all water
+// Find all water
 for (var ix = 0; ix < mapSize; ix++)
-{
 	for (var iz = 0; iz < mapSize; iz++)
-	{
-	if(getHeight(ix,iz)<0){
-	    addToClass(ix,iz,clWater);
-	}
-	}
-}
+		if (getHeight(ix,iz) < 0)
+			addToClass(ix,iz,clWater);
 
-// create forests
 log("Creating forests...");
 var types = [
 	[[tForestFloor, tGrass, pPalmForest], [tForestFloor, pPalmForest]],
@@ -408,43 +346,37 @@ for (var i = 0; i < types.length; ++i)
 		);
 	createAreasInAreas(
 		placer,
-		[painter, paintClass(clForest)], 
+		[painter, paintClass(clForest)],
 		avoidClasses(clCity, 1, clWater, 3, clForest, 3, clHill, 1),
 		num, 20, areas
 	);
 }
-
-RMS.SetProgress(60);
+RMS.SetProgress(42);
 
 log("Creating stone mines...");
-// create large stone quarries
 group = new SimpleGroup([new SimpleObject(oStoneSmall, 0,2, 0,4), new SimpleObject(oStoneLarge, 1,1, 0,4)], true, clRock);
 createObjectGroupsByAreas(group, 0,
 	[avoidClasses(clWater, 1, clForest, 1, clHill, 1, clPlayer, 5, clRock, 1)],
 	scaleByMapSize(4,16), 200, areas
 );
+RMS.SetProgress(46);
 
-// create small stone quarries
+log("Creating small stone mines...");
 group = new SimpleGroup([new SimpleObject(oStoneSmall, 2,5, 1,3)], true, clRock);
 createObjectGroupsByAreas(group, 0,
 	[avoidClasses(clWater, 1, clForest, 1, clHill, 1, clPlayer, 5, clRock, 2)],
 	scaleByMapSize(4,16), 200, areas
 );
-RMS.SetProgress(70);
+RMS.SetProgress(50);
 
 log("Creating metal mines...");
-// create large metal quarries
 group = new SimpleGroup([new SimpleObject(oMetalLarge, 1,1, 0,4)], true, clMetal);
 createObjectGroupsByAreas(group, 0,
 	[avoidClasses(clWater, 1, clForest, 1, clHill, 1, clPlayer, 5, clMetal, 2, clRock, 1)],
 	scaleByMapSize(4,16), 200, areas
 );
+RMS.SetProgress(54);
 
-RMS.SetProgress(80);
-
-
-
-//create shrub patches
 log("Creating shrub patches...");
 var sizes = [scaleByMapSize(2, 32), scaleByMapSize(3, 48), scaleByMapSize(5, 80)];
 for (var i = 0; i < sizes.length; i++)
@@ -458,8 +390,8 @@ for (var i = 0; i < sizes.length; i++)
 		scaleByMapSize(4, 16), 20, areas
 	);
 }
+RMS.SetProgress(58);
 
-//create grass patches
 log("Creating grass patches...");
 var sizes = [scaleByMapSize(2, 32), scaleByMapSize(3, 48), scaleByMapSize(5, 80)];
 for (var i = 0; i < sizes.length; i++)
@@ -473,23 +405,19 @@ for (var i = 0; i < sizes.length; i++)
 		scaleByMapSize(4, 16), 20, areas
 	);
 }
-
-RMS.SetProgress(90);
+RMS.SetProgress(62);
 
 log("Creating straggler trees...");
-// create straggler trees
-var trees = [oCarob, oBeech, oLombardyPoplar, oLombardyPoplar, oPine];
-for (var t in trees)
-{
-	group = new SimpleGroup([new SimpleObject(trees[t], 1,1, 0,1)], true, clForest);
-	createObjectGroupsByAreas(group, 0,
+for (let tree of [oCarob, oBeech, oLombardyPoplar, oLombardyPoplar, oPine])
+	createObjectGroupsByAreas(
+		new SimpleGroup([new SimpleObject(tree, 1,1, 0,1)], true, clForest),
+		0,
 		avoidClasses(clWater, 2, clForest, 2, clCity, 3, clBaseResource, 1, clRock, 1, clMetal, 1, clPlayer, 1, clHill, 1),
 		scaleByMapSize(2, 38), 50, areas
 	);
-}
+RMS.SetProgress(66);
 
-
-// create straggler cypresses
+log("Create straggler cypresses...");
 group = new SimpleGroup(
 	[new SimpleObject(oCypress2, 1,3, 0,3), new SimpleObject(oCypress1, 0,2, 0,2)],
 	true
@@ -498,9 +426,9 @@ createObjectGroupsByAreas(group, 0,
 	avoidClasses(clWater, 2, clForest, 2, clCity, 3, clBaseResource, 1, clRock, 1, clMetal, 1, clPlayer, 1, clHill, 1),
 	scaleByMapSize(5, 75), 50, areas
 );
+RMS.SetProgress(70);
 
-
-// create straggler date palms
+log("Create straggler date palms...");
 group = new SimpleGroup(
 	[new SimpleObject(oDateS, 1,3, 0,3), new SimpleObject(oDateT, 0,2, 0,2)],
 	true
@@ -509,19 +437,19 @@ createObjectGroupsByAreas(group, 0,
 	avoidClasses(clWater, 2, clForest, 1, clCity, 0, clBaseResource, 1, clRock, 1, clMetal, 1, clPlayer, 1, clHill, 1),
 	scaleByMapSize(5, 75), 50, areas
 );
+RMS.SetProgress(74);
 
 log("Creating rocks...");
-// create rocks
 group = new SimpleGroup(
-	[new SimpleObject(aRockSmall, 0,3, 0,2), new SimpleObject(aRockMed, 0,2, 0,2), 
+	[new SimpleObject(aRockSmall, 0,3, 0,2), new SimpleObject(aRockMed, 0,2, 0,2),
 	new SimpleObject(aRockLarge, 0,1, 0,2)]
 );
 createObjectGroups(group, 0,
 	avoidClasses(clWater, 0, clCity, 0),
 	scaleByMapSize(30, 180), 50
 );
+RMS.SetProgress(78);
 
-// create deer
 log("Creating deer...");
 group = new SimpleGroup(
 	[new SimpleObject(oDeer, 5,7, 0,4)],
@@ -531,50 +459,48 @@ createObjectGroups(group, 0,
 	avoidClasses(clWater, 5, clForest, 1, clHill, 1, clCity, 10, clMetal, 2, clRock, 2, clFood, 8),
 	3 * numPlayers, 50
 );
-
-RMS.SetProgress(95);
+RMS.SetProgress(82);
 
 log("Creating berry bushes...");
-// create berry bushes
 group = new SimpleGroup([new SimpleObject(oBerryBush, 5,7, 0,3)], true, clFood);
 createObjectGroups(group, 0,
 	avoidClasses(clWater, 2, clForest, 1, clHill, 1, clCity, 10, clMetal, 2, clRock, 2, clFood, 8),
 	1.5 * numPlayers, 100
 );
+RMS.SetProgress(86);
 
 log("Creating Fish...");
-// create Fish
 group = new SimpleGroup([new SimpleObject(oFish, 1,1, 0,3)], true, clFood);
 createObjectGroups(group, 0,
 	[stayClasses(clWater,1),avoidClasses(clFood, 8)],
 	scaleByMapSize(40,200), 100
 );
+RMS.SetProgress(90);
 
 log("Creating Whales...");
-// create Whales
 group = new SimpleGroup([new SimpleObject(oWhale, 1,1, 0,3)], true, clFood);
 createObjectGroups(group, 0,
 	[stayClasses(clWater,1),avoidClasses(clFood, 8, clPlayer,4,clIsland,4)],
 	scaleByMapSize(10,40), 100
 );
+RMS.SetProgress(94);
 
 log("Creating shipwrecks...");
-// create shipwreck
 group = new SimpleGroup([new SimpleObject(oShipwreck, 1,1, 0,3)], true, clFood);
 createObjectGroups(group, 0,
 	[stayClasses(clWater,1),avoidClasses(clFood, 8)],
 	scaleByMapSize(6,16), 100
 );
+RMS.SetProgress(98);
 
 log("Creating shipwreck debris...");
-// create shipwreck debris
 group = new SimpleGroup([new SimpleObject(oShipDebris, 1,2, 0,4)], true, clFood);
 createObjectGroups(group, 0,
 	[stayClasses(clWater,1),avoidClasses(clFood, 8)],
 	scaleByMapSize(10,20), 100
 );
+RMS.SetProgress(99);
 
-// Adjust environment
 setSkySet("sunny");
 setWaterColor(0.2,0.294,0.49);
 setWaterTint(0.208, 0.659, 0.925);
@@ -582,5 +508,4 @@ setWaterMurkiness(0.72);
 setWaterWaviness(3.0);
 setWaterType("ocean");
 
-// Export map data
 ExportMap();
