@@ -20,7 +20,6 @@ const tWater = "temp_mud_a";
 const oBeech = "gaia/flora_tree_euro_beech_aut";
 const oOak = "gaia/flora_tree_oak_aut";
 const oPine = "gaia/flora_tree_pine";
-const oChicken = "gaia/fauna_chicken";
 const oDeer = "gaia/fauna_deer";
 const oFish = "gaia/fauna_fish";
 const oSheep = "gaia/fauna_rabbit";
@@ -47,20 +46,13 @@ const pForestD = [tForestFloor + TERRAIN_SEPARATOR + oBeech, tForestFloor];
 const pForestO = [tForestFloor + TERRAIN_SEPARATOR + oOak, tForestFloor];
 const pForestP = [tForestFloor + TERRAIN_SEPARATOR + oPine, tForestFloor];
 
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
-
 log("Initializing map...");
-
 InitMap();
 
 const numPlayers = getNumPlayers();
 const mapSize = getMapSize();
 const mapArea = mapSize*mapSize;
 
-// create tile classes
-
 var clPlayer = createTileClass();
 var clHill = createTileClass();
 var clForest = createTileClass();
@@ -72,17 +64,14 @@ var clFood = createTileClass();
 var clBaseResource = createTileClass();
 var clSettlement = createTileClass();
 
-
 // randomize player order
 var playerIDs = [];
 for (var i = 0; i < numPlayers; i++)
-{
 	playerIDs.push(i+1);
-}
+
 playerIDs = sortPlayers(playerIDs);
 
 // place players
-
 var playerX = new Array(numPlayers);
 var playerZ = new Array(numPlayers);
 var playerAngle = new Array(numPlayers);
@@ -100,12 +89,12 @@ for (var i=0; i < numPlayers; i++)
 {
 	var startEntities = getStartingEntities(i);
 	// Place starting entities
-	createStartingPlayerEntities(playerX[i], playerZ[i], i+1, startEntities, BUILDING_ANGlE)
+	createStartingPlayerEntities(playerX[i], playerZ[i], i+1, startEntities);
 	var uDist = 8;
 	var uSpace = 2;
 	for (var j = 1; j < startEntities.length - 1; ++j)
 	{
-		var uAngle = BUILDING_ANGlE - PI * (2-j) / 2;
+		var uAngle = BUILDING_ORIENTATION - PI * (2-j) / 2;
 		var count = (startEntities[j].Count !== undefined ? startEntities[j].Count : 1);
 		for (var numberofentities = 0; numberofentities < count; numberofentities++)
 		{
@@ -114,8 +103,9 @@ for (var i=0; i < numPlayers; i++)
 			placeObject(ux, uz, startEntities[j].Template, i+1, uAngle);
 		}
 	}
-	// create resources
-	var bbAngle = BUILDING_ANGlE;
+
+	// Create treasure
+	var bbAngle = BUILDING_ORIENTATION;
 	var bbDist = 10;
 	var bbX = round(playerX[i] + bbDist * cos(bbAngle));
 	var bbZ = round(playerZ[i] + bbDist * sin(bbAngle));
@@ -124,7 +114,7 @@ for (var i=0; i < numPlayers; i++)
 		true, clBaseResource, bbX, bbZ
 	);
 	createObjectGroup(group, 0);
-	
+
 	bbAngle += PI/2;
 	var bbX = round(playerX[i] + bbDist * cos(bbAngle));
 	var bbZ = round(playerZ[i] + bbDist * sin(bbAngle));
@@ -142,7 +132,7 @@ for (var i=0; i < numPlayers; i++)
 		true, clBaseResource, bbX, bbZ
 	);
 	createObjectGroup(group, 0);
-	
+
 	bbAngle += PI/2;
 	var bbX = round(playerX[i] + bbDist * cos(bbAngle));
 	var bbZ = round(playerZ[i] + bbDist * sin(bbAngle));
@@ -151,18 +141,17 @@ for (var i=0; i < numPlayers; i++)
 		true, clBaseResource, bbX, bbZ
 	);
 	createObjectGroup(group, 0);
-	
+
 	// Base texture
 	var civ = getCivCode(i);
-	var tilesSize = (civ == "cart" ? 27 : 22);
-	
+	var tilesSize = civ == "cart" ? 27 : 22;
+
 	const minBoundX = (playerX[i] > tilesSize ? playerX[i] - tilesSize : 0);
 	const minBoundY = (playerZ[i] > tilesSize ? playerZ[i] - tilesSize : 0);
 	const maxBoundX = (playerX[i] < mapSize - tilesSize ? playerX[i] + tilesSize : mapSize);
 	const maxBoundY = (playerZ[i] < mapSize - tilesSize ? playerZ[i] + tilesSize : mapSize);
-	
+
 	for (var tx = minBoundX; tx < maxBoundX; ++tx)
-	{
 		for (var ty = minBoundY; ty < maxBoundY; ++ty)
 		{
 			var unboundSumOfXY = tx + ty - minBoundX - minBoundY;
@@ -172,8 +161,7 @@ for (var i=0; i < numPlayers; i++)
 				addToClass(floor(tx), floor(ty), clPlayer);
 			}
 		}
-	}
-	
+
 	// Place custom fortress
 	if (civ == "brit" || civ == "gaul" || civ == "iber")
 	{
@@ -191,10 +179,9 @@ for (var i=0; i < numPlayers; i++)
 			"cornerIn", "wallLong", "house", "tower", "wallLong", "tower", "wallLong",
 			"cornerIn", "wallLong", "house", "tower"];
 	}
-	placeCustomFortress(playerX[i], playerZ[i], new Fortress("Spahbod", wall), civ, i+1, BUILDING_ANGlE);
+	placeCustomFortress(playerX[i], playerZ[i], new Fortress("Spahbod", wall), civ, i+1);
 }
 
-// create lakes
 log("Creating lakes...");
 var numLakes = round(scaleByMapSize(1,4) * numPlayers);
 var placer = new ClumpPlacer(scaleByMapSize(100,250), 0.8, 0.1, 10);
@@ -205,14 +192,12 @@ var terrainPainter = new LayeredPainter(
 var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, -4, 3);
 var waterAreas = createAreas(
 	placer,
-	[terrainPainter, elevationPainter, paintClass(clWater)], 
+	[terrainPainter, elevationPainter, paintClass(clWater)],
 	avoidClasses(clPlayer, 7, clWater, 20),
 	numLakes
 );
-
 RMS.SetProgress(15);
 
-// create reeds
 log("Creating reeds...");
 group = new SimpleGroup(
 	[new SimpleObject(aReeds, 5,10, 0,4), new SimpleObject(aLillies, 0,1, 0,4)], true
@@ -222,34 +207,28 @@ createObjectGroupsByAreas(group, 0,
 	numLakes, 100,
 	waterAreas
 );
-
-RMS.SetProgress(20);
-
-// create fish
-log("Creating fish...");
-group = new SimpleGroup(
-	[new SimpleObject(oFish, 1,1, 0,1)],
-	true, clFood
-);
-createObjectGroupsByAreas(group, 0,
-	borderClasses(clWater, 2, 0),  avoidClasses(clFood, 8),
-	numLakes, 50,
-	waterAreas
-);
-waterAreas = [];
-
 RMS.SetProgress(25);
 
-// create bumps
-createBumps(avoidClasses(clWater, 2, clPlayer, 5));
-
+log("Creating fish...");
+createObjectGroupsByAreas(
+	new SimpleGroup(
+		[new SimpleObject(oFish, 1,1, 0,1)],
+		true, clFood
+	),
+	0,
+	[stayClasses(clWater, 4),  avoidClasses(clFood, 8)],
+	numLakes / 4,
+	50,
+	waterAreas
+);
 RMS.SetProgress(30);
 
-// create hills
+createBumps(avoidClasses(clWater, 2, clPlayer, 5));
+RMS.SetProgress(35);
+
 log("Creating hills...");
 createHills([tCliff, tCliff, tHill], avoidClasses(clPlayer, 5, clWater, 5, clHill, 15), clHill, scaleByMapSize(1, 4) * numPlayers);
-
-RMS.SetProgress(35);
+RMS.SetProgress(40);
 
 // calculate desired number of trees for map (based on size)
 const MIN_TREES = 500;
@@ -260,7 +239,6 @@ var totalTrees = scaleByMapSize(MIN_TREES, MAX_TREES);
 var numForest = totalTrees * P_FOREST;
 g_numStragglerTrees = totalTrees * (1.0 - P_FOREST);
 
-// create forests
 log("Creating forests...");
 var types = [
 	[[tForestFloor, tGrass, pForestD], [tForestFloor, pForestD]],
@@ -278,15 +256,13 @@ for (var i = 0; i < types.length; ++i)
 		);
 	createAreas(
 		placer,
-		[painter, paintClass(clForest)], 
+		[painter, paintClass(clForest)],
 		avoidClasses(clPlayer, 5, clWater, 3, clForest, 15, clHill, 1),
 		num
 	);
 }
-
 RMS.SetProgress(50);
 
-// create dirt patches
 log("Creating dirt patches...");
 createLayeredPatches(
  [scaleByMapSize(3, 6), scaleByMapSize(5, 10), scaleByMapSize(8, 21)],
@@ -294,45 +270,39 @@ createLayeredPatches(
  [1,1],
  avoidClasses(clWater, 1, clForest, 0, clHill, 0, clDirt, 5, clPlayer, 1)
 );
-
 RMS.SetProgress(55);
 
-// create grass patches
 log("Creating grass patches...");
 createPatches(
  [scaleByMapSize(2, 4), scaleByMapSize(3, 7), scaleByMapSize(5, 15)],
  tGrassPatch,
  avoidClasses(clWater, 1, clForest, 0, clHill, 0, clDirt, 5, clPlayer, 1)
 );
-
 RMS.SetProgress(60);
 
 log("Creating stone mines...");
-// create stone quarries
 createMines(
  [
   [new SimpleObject(oStoneSmall, 0,2, 0,4), new SimpleObject(oStoneLarge, 1,1, 0,4)],
   [new SimpleObject(oStoneSmall, 2,5, 1,3)]
  ],
  avoidClasses(clWater, 0, clForest, 1, clPlayer, 5, clRock, 10, clHill, 1)
-)
+);
+RMS.SetProgress(65);
 
 log("Creating metal mines...");
-// create large metal quarries
 createMines(
  [
   [new SimpleObject(oMetalLarge, 1,1, 0,4)]
  ],
  avoidClasses(clWater, 0, clForest, 1, clPlayer, 5, clMetal, 10, clRock, 5, clHill, 1),
  clMetal
-)
-
+);
 RMS.SetProgress(70);
 
-//create decoration
 createDecoration
 (
- [[new SimpleObject(aRockMedium, 1,3, 0,1)], 
+ [[new SimpleObject(aRockMedium, 1,3, 0,1)],
   [new SimpleObject(aRockLarge, 1,2, 0,1), new SimpleObject(aRockMedium, 1,3, 0,2)],
   [new SimpleObject(aGrassShort, 1,2, 0,1, -PI/8,PI/8)],
   [new SimpleObject(aGrass, 2,4, 0,1.8, -PI/8,PI/8), new SimpleObject(aGrassShort, 3,6, 1.2,2.5, -PI/8,PI/8)],
@@ -347,7 +317,6 @@ createDecoration
  ],
  avoidClasses(clWater, 0, clForest, 0, clPlayer, 1, clHill, 0)
 );
-
 RMS.SetProgress(80);
 
 // create animals
@@ -356,20 +325,21 @@ createFood
  [
   [new SimpleObject(oSheep, 2,3, 0,2)],
   [new SimpleObject(oDeer, 5,7, 0,4)]
- ], 
+ ],
  [
   3 * numPlayers,
   3 * numPlayers
  ],
  avoidClasses(clWater, 0, clForest, 0, clPlayer, 6, clHill, 1, clFood, 20)
 );
+RMS.SetProgress(85);
 
 // create fruits
 createFood
 (
  [
   [new SimpleObject(oBerryBush, 5,7, 0,4)]
- ], 
+ ],
  [
   randInt(1, 4) * numPlayers + 2
  ],
@@ -378,10 +348,10 @@ createFood
 
 RMS.SetProgress(90);
 
-// create straggler trees
 log("Creating straggler trees...");
 var types = [oOak, oBeech, oPine];	// some variation
 createStragglerTrees(types, avoidClasses(clWater, 1, clForest, 1, clHill, 1, clPlayer, 1, clMetal, 1, clRock, 1));
+RMS.SetProgress(95);
 
 setSkySet("sunny");
 setWaterColor(0.157, 0.149, 0.443);
@@ -398,5 +368,4 @@ setPPContrast(0.56);
 setPPBloom(0.38);
 setPPEffect("hdr");
 
-// Export map data
 ExportMap();
