@@ -1,19 +1,3 @@
-function decayErrodeHeightmap(strength, heightmap)
-{
-	strength = strength || 0.9; // 0 to 1
-	heightmap = heightmap || g_Map.height;
-
-	let referenceHeightmap = deepcopy(heightmap);
-	// let map = [[1, 0], [0, 1], [-1, 0], [0, -1]]; // faster
-	let map = [[1, 0], [1, 1], [0, 1], [-1, 1], [-1, 0], [-1, -1], [0, -1], [1, -1]]; // smoother
-	let max_x = heightmap.length;
-	let max_y = heightmap[0].length;
-	for (let x = 0; x < max_x; ++x)
-		for (let y = 0; y < max_y; ++y)
-			for (let i = 0; i < map.length; ++i)
-				heightmap[x][y] += strength / map.length * (referenceHeightmap[(x + map[i][0] + max_x) % max_x][(y + map[i][1] + max_y) % max_y] - referenceHeightmap[x][y]); // Not entirely sure if scaling with map.length is perfect but tested values seam to indicate it is
-}
-
 /**
  * Returns starting position in tile coordinates for the given player.
  */
@@ -28,6 +12,7 @@ function getPlayerTileCoordinates(playerIdx, teamIdx, fractionX, fractionZ)
 }
 
 RMS.LoadLibrary("rmgen");
+RMS.LoadLibrary("heightmap");
 
 const g_InitialMines = 1;
 const g_InitialMineDistance = 14;
@@ -54,7 +39,6 @@ const oTree3 = rBiomeE3();
 const oTree4 = rBiomeE4();
 const oTree5 = rBiomeE5();
 const oFruitBush = rBiomeE6();
-const oChicken = rBiomeE7();
 const oMainHuntableAnimal = rBiomeE8();
 const oFish = rBiomeE9();
 const oSecondaryHuntableAnimal = rBiomeE10();
@@ -74,7 +58,6 @@ const aRockMedium = rBiomeA6();
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
 
 log("Initializing map...");
 InitMap();
@@ -181,7 +164,7 @@ for (let i = 0; i < teams.length; ++i)
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 
 		// create starting units
-		placeCivDefaultEntities(fx, fz, teams[i][p], BUILDING_ANGlE, { "iberWall": false });
+		placeCivDefaultEntities(fx, fz, teams[i][p], { "iberWall": false });
 	}
 
 	log("Create initial mines for team " + i);
@@ -214,19 +197,7 @@ for (let i = 0; i < teams.length; ++i)
 	{
 		let [playerAngle, fx, fz, ix, iz] = getPlayerTileCoordinates(p, i, fractionX, fractionZ);
 
-		// create initial chicken
-		for (let j = 0; j < 2; ++j)
-		{
-			let aAngle = randFloat(0, TWO_PI);
-			let aDist = 7;
-			let aX = round(fx + aDist * cos(aAngle));
-			let aZ = round(fz + aDist * sin(aAngle));
-			let group = new SimpleGroup(
-				[new SimpleObject(oChicken, 5, 5, 0, 2)],
-				true, clBaseResource, aX, aZ
-			);
-			createObjectGroup(group, 0, [stayClasses(clLand, 5)]);
-		}
+		placeDefaultChicken(fx, fz, clBaseResource, [stayClasses(clLand, 5)]);
 
 		// create initial berry bushes
 		let bbAngle = randFloat(PI, PI*1.5);
@@ -372,7 +343,7 @@ RMS.SetProgress(70);
 
 log("Smoothing heightmap...");
 for (let i = 0; i < 5; ++i)
-	decayErrodeHeightmap(0.5);
+	globalSmoothHeightmap();
 
 // repaint clLand to compensate for smoothing
 unPaintTileClassBasedOnHeight(-10, 10, 3, clLand);
@@ -420,7 +391,7 @@ createAreas(
 	scaleByMapSize(4, 13)
 );
 for (let i = 0; i < 3; ++i)
-	decayErrodeHeightmap(0.2);
+	globalSmoothHeightmap();
 
 createStragglerTrees(
 		[oTree1, oTree2, oTree4, oTree3],
