@@ -22,7 +22,6 @@ const oMetalLarge = "gaia/geology_metal_tropic_slabs";
 const oFish = "gaia/fauna_fish";
 const oDeer = "gaia/fauna_deer";
 const oSheep = "gaia/fauna_tiger";
-const oChicken = "gaia/fauna_chicken";
 const oBush = "gaia/flora_bush_berry";
 
 // decorative props
@@ -34,9 +33,6 @@ const aBush3 = "actor|props/flora/plant_tropic_large.xml";
 
 const pForestD = [tForestFloor + TERRAIN_SEPARATOR + oTree, tForestFloor];
 const pForestP = [tForestFloor + TERRAIN_SEPARATOR + oPalm, tForestFloor];
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
 
 log("Initializing map...");
 
@@ -80,7 +76,7 @@ var playerPos = new Array(numPlayers);
 for (var i = 0; i < numPlayers; i++)
 {
 	playerPos[i] = (i + 1) / (numPlayers + 1);
-	playerX[i] = 0.45 + 0.2*(i%2)
+	playerX[i] = 0.45 + 0.2*(i%2);
 	playerZ[i] = playerPos[i];
 }
 
@@ -88,12 +84,12 @@ for (var i = 0; i < numPlayers; i++)
 {
 	var id = playerIDs[i];
 	log("Creating base for player " + id + "...");
-	
+
 	// some constants
 	var radius = scaleByMapSize(15,25);
 	var cliffRadius = 2;
 	var elevation = 20;
-	
+
 	// get the x and z in tiles
 	var fx = fractionToTiles(playerX[i]);
 	var fz = fractionToTiles(playerZ[i]);
@@ -104,41 +100,29 @@ for (var i = 0; i < numPlayers; i++)
 	addToClass(ix, iz+5, clPlayer);
 	addToClass(ix-5, iz, clPlayer);
 	addToClass(ix, iz-5, clPlayer);
-	
+
 	// create the city patch
 	var cityRadius = radius/3;
 	var placer = new ClumpPlacer(PI*cityRadius*cityRadius, 0.6, 0.3, 10, ix, iz);
 	var painter = new LayeredPainter([tRoadWild, tRoad], [1]);
 	createArea(placer, painter, null);
-	
+
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
-	
-		// create animals
-	for (var j = 0; j < 2; ++j)
-	{
-		var aAngle = randFloat(0, TWO_PI);
-		var aDist = 7;
-		var aX = round(fx + aDist * cos(aAngle));
-		var aZ = round(fz + aDist * sin(aAngle));
-		var group = new SimpleGroup(
-			[new SimpleObject(oChicken, 5,5, 0,2)],
-			true, clBaseResource, aX, aZ
-		);
-		createObjectGroup(group, 0);
-	}
-	
+	placeCivDefaultEntities(fx, fz, id);
+
+		placeDefaultChicken(fx, fz, clBaseResource);
+
 	// create berry bushes
 	var bbAngle = randFloat(0, TWO_PI);
 	var bbDist = 12;
 	var bbX = round(fx + bbDist * cos(bbAngle));
 	var bbZ = round(fz + bbDist * sin(bbAngle));
-	group = new SimpleGroup(
+	var group = new SimpleGroup(
 		[new SimpleObject(oBush, 5,5, 0,3)],
 		true, clBaseResource, bbX, bbZ
 	);
 	createObjectGroup(group, 0);
-	
+
 	// create metal mine
 	var bbAngle = randFloat(0, TWO_PI);
 	var bbDist = 12;
@@ -157,7 +141,7 @@ for (var i = 0; i < numPlayers; i++)
 		true, clBaseResource, mX, mZ
 	);
 	createObjectGroup(group, 0);
-	
+
 	// create stone mines
 	mAngle += randFloat(PI/8, PI/4);
 	mX = round(fx + mDist * cos(mAngle));
@@ -179,7 +163,7 @@ for (var i = 0; i < numPlayers; i++)
 		false, clBaseResource, tX, tZ
 	);
 	createObjectGroup(group, 0, avoidClasses(clBaseResource,2));
-	
+
 }
 
 RMS.SetProgress(15);
@@ -206,9 +190,7 @@ for (var ix = 0; ix < mapSize; ix++)
 			}
 		}
 		else if (ix > 0.69 * mapSize)
-		{
-			addToClass(ix, iz, clMountains)
-		}
+			addToClass(ix, iz, clMountains);
 	}
 }
 
@@ -224,7 +206,7 @@ for (var i = 0; i < scaleByMapSize(20,120); i++)
 	var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 3, 3);
 	createArea(
 		placer,
-		[terrainPainter, elevationPainter, unPaintClass(clWater)], 
+		[terrainPainter, elevationPainter, unPaintClass(clWater)],
 		null
 	);
 }
@@ -232,7 +214,7 @@ for (var i = 0; i < scaleByMapSize(20,120); i++)
 paintTerrainBasedOnHeight(-6, 1, 1, tWater);
 paintTerrainBasedOnHeight(1, 2.8, 1, tShoreBlend);
 paintTerrainBasedOnHeight(0, 1, 1, tShore);
-paintTileClassBasedOnHeight(-6, 0.5, 1, clWater)
+paintTileClassBasedOnHeight(-6, 0.5, 1, clWater);
 
 RMS.SetProgress(45);
 
@@ -246,7 +228,7 @@ var terrainPainter = new LayeredPainter(
 var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 25, 3);
 createAreas(
 	placer,
-	[terrainPainter, elevationPainter, paintClass(clHill)], 
+	[terrainPainter, elevationPainter, paintClass(clHill)],
 	[avoidClasses(clPlayer, 20, clHill, 5, clWater, 2, clBaseResource, 2), stayClasses(clMountains, 0)],
 	scaleByMapSize(5, 40) * numPlayers
 );
@@ -282,7 +264,7 @@ for (var i = 0; i < types.length; ++i)
 		);
 	createAreas(
 		placer,
-		[painter, paintClass(clForest)], 
+		[painter, paintClass(clForest)],
 		avoidClasses(clPlayer, 20, clForest, 10, clHill, 0, clWater, 8),
 		num
 	);
@@ -469,15 +451,14 @@ createObjectGroups(group, 0,
 	25 * numPlayers, 60
 );
 
-setSunColour(0.6, 0.6, 0.6);	
+setSunColor(0.6, 0.6, 0.6);
 setSunElevation(PI/ 3);
 
-setWaterColour(0.524,0.734,0.839);
+setWaterColor(0.524,0.734,0.839);
 setWaterTint(0.369,0.765,0.745);
-setWaterReflectionTint(1,1,1);
-setWaterWaviness(1.5);
+setWaterWaviness(1.0);
+setWaterType("ocean");
 setWaterMurkiness(0.35);
-setWaterReflectionTintStrength(0.0);
 
 setFogFactor(0.4);
 setFogThickness(0.2);
