@@ -6,7 +6,16 @@ const CELL_SIZE = 4;
 const HEIGHT_UNITS_PER_METRE = 92;
 const MIN_MAP_SIZE = 128;
 const MAX_MAP_SIZE = 512;
+const MAP_BORDER_WIDTH = 3;
 const FALLBACK_CIV = "athen";
+/**
+ * Constants needed for heightmap_manipulation.js
+ */
+const MAX_HEIGHT_RANGE = 0xFFFF / HEIGHT_UNITS_PER_METRE; // Engine limit, Roughly 700 meters
+const MIN_HEIGHT = - SEA_LEVEL;
+const MAX_HEIGHT = MAX_HEIGHT_RANGE - SEA_LEVEL;
+// Default angle for buildings
+const BUILDING_ORIENTATION = - PI / 4;
 
 function fractionToTiles(f)
 {
@@ -82,24 +91,6 @@ function min(a, b)
 	return a < b ? a : b;
 }
 
-/**
- * "Inside-out" implementation of Fisher-Yates shuffle
- */
-function shuffleArray(source)
-{
-	if (!source.length)
-		return [];
-
-	let result = [source[0]];
-	for (let i = 1; i < source.length; ++i)
-	{
-		let j = randInt(0, i);
-		result[i] = result[j];
-		result[j] = source[i];
-	}
-	return result;
-}
-
 /**
  * Retries the given function with those arguments as often as specified.
  */
@@ -275,7 +266,7 @@ function createSimpleTerrain(terrain)
 
 function placeObject(x, z, type, player, angle)
 {
-	if (g_Map.validT(x, z, 3))
+	if (g_Map.validT(x, z, MAP_BORDER_WIDTH))
 		g_Map.addObject(new Entity(type, player, x, z, angle));
 }
 
