@@ -61,7 +61,7 @@ function passageMaker(x1, z1, x2, z2, width, maxheight, height, smooth, tileclas
 					if (tileclass !== undefined)
 					{
 						addToClass(ix, iz, tileclass);
-					}	
+					}
 					if (terrain !== undefined)
 					{
 						placeTerrain(ix, iz, terrain);
@@ -69,7 +69,7 @@ function passageMaker(x1, z1, x2, z2, width, maxheight, height, smooth, tileclas
 				}
 			}
 		}
-	}	
+	}
 	TILE_CENTERED_HEIGHT_MAP = tchm;
 }
 
@@ -136,23 +136,23 @@ function rndRiver(f, seed)
 //	fx&fz: position of player base
 //	playerid: id of player
 //	civEntities: use getStartingEntities(id-1) fo this one
-//	BUILDING_ANGlE: angle of main base building
+//	orientation: orientation of the main base building, default is BUILDING_ORIENTATION
 //
 ///////////////////////////////////////////////////////////////////////////////////////////
-function createStartingPlayerEntities(fx, fz, playerid, civEntities, BUILDING_ANGlE)
+function createStartingPlayerEntities(fx, fz, playerid, civEntities, orientation = BUILDING_ORIENTATION)
 {
 	var uDist = 6;
 	var uSpace = 2;
-	placeObject(fx, fz, civEntities[0].Template, playerid, BUILDING_ANGlE);
+	placeObject(fx, fz, civEntities[0].Template, playerid, orientation);
 	for (var j = 1; j < civEntities.length; ++j)
 	{
-		var uAngle = BUILDING_ANGlE - PI * (2-j) / 2;
+		var uAngle = orientation - PI * (2-j) / 2;
 		var count = (civEntities[j].Count !== undefined ? civEntities[j].Count : 1);
 		for (var numberofentities = 0; numberofentities < count; numberofentities++)
 		{
 			var ux = fx + uDist * cos(uAngle) + numberofentities * uSpace * cos(uAngle + PI/2) - (0.75 * uSpace * floor(count / 2) * cos(uAngle + PI/2));
 			var uz = fz + uDist * sin(uAngle) + numberofentities * uSpace * sin(uAngle + PI/2) - (0.75 * uSpace * floor(count / 2) * sin(uAngle + PI/2));
-			placeObject(ux, uz, civEntities[j].Template, playerid, uAngle); 
+			placeObject(ux, uz, civEntities[j].Template, playerid, uAngle);
 		}
 	}
 }
@@ -163,48 +163,71 @@ function createStartingPlayerEntities(fx, fz, playerid, civEntities, BUILDING_AN
 //	Creates the default starting player entities depending on the players civ
 //	fx&fy: position of player base
 //	playerid: id of player
-//	angle: angle of main base building, optional, default is BUILDING_ANGlE
 //	kwargs: Takes some optional keyword arguments to tweek things
 //		'iberWall': may be false, 'walls' (default) or 'towers'. Determines the defensive structures Iberians get as civ bonus
+//		'orientation': angle of the main base building, default is BUILDING_ORIENTATION
 //
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-function placeCivDefaultEntities(fx, fz, playerid, angle, kwargs)
+function placeCivDefaultEntities(fx, fz, playerid, kwargs = {})
 {
 	// Unpack kwargs
-	kwargs = (kwargs || {});
 	var iberWall = 'walls';
 	if (getMapSize() <= 128)
 		iberWall = false;
 	if ('iberWall' in kwargs)
 		iberWall = kwargs['iberWall'];
+	var orientation = BUILDING_ORIENTATION;
+	if ('orientation' in kwargs)
+		orientation = kwargs['orientation'];
 	// Place default civ starting entities
 	var civ = getCivCode(playerid-1);
 	var civEntities = getStartingEntities(playerid-1);
 	var uDist = 6;
 	var uSpace = 2;
-	placeObject(fx, fz, civEntities[0].Template, playerid, angle);
+	placeObject(fx, fz, civEntities[0].Template, playerid, orientation);
 	for (var j = 1; j < civEntities.length; ++j)
 	{
-		var uAngle = angle - PI * (2-j) / 2;
+		var uAngle = orientation - PI * (2-j) / 2;
 		var count = (civEntities[j].Count !== undefined ? civEntities[j].Count : 1);
 		for (var numberofentities = 0; numberofentities < count; numberofentities++)
 		{
 			var ux = fx + uDist * cos(uAngle) + numberofentities * uSpace * cos(uAngle + PI/2) - (0.75 * uSpace * floor(count / 2) * cos(uAngle + PI/2));
 			var uz = fz + uDist * sin(uAngle) + numberofentities * uSpace * sin(uAngle + PI/2) - (0.75 * uSpace * floor(count / 2) * sin(uAngle + PI/2));
-			placeObject(ux, uz, civEntities[j].Template, playerid, uAngle); 
+			placeObject(ux, uz, civEntities[j].Template, playerid, uAngle);
 		}
 	}
 	// Add defensive structiures for Iberians as their civ bonus
 	if (civ == 'iber' && iberWall != false)
 	{
 		if (iberWall == 'towers')
-			placePolygonalWall(fx, fz, 15, ['entry'], 'tower', civ, playerid, angle, 7);
+			placePolygonalWall(fx, fz, 15, ['entry'], 'tower', civ, playerid, orientation, 7);
 		else
 			placeGenericFortress(fx, fz, 20/*radius*/, playerid);
 	}
 }
 
+function placeDefaultChicken(playerX, playerZ, tileClass, constraint = undefined, template = "gaia/fauna_chicken")
+{
+	for (let j = 0; j < 2; ++j)
+		for (var tries = 0; tries < 10; ++tries)
+		{
+			let aAngle = randFloat(0, TWO_PI);
 
+			// Roman and ptolemian civic centers have a big footprint!
+			let aDist = 9;
+
+			let aX = round(playerX + aDist * cos(aAngle));
+			let aZ = round(playerZ + aDist * sin(aAngle));
+
+			let group = new SimpleGroup(
+				[new SimpleObject(template, 5,5, 0,2)],
+				true, tileClass, aX, aZ
+			);
+
+			if (createObjectGroup(group, 0, constraint))
+				break;
+		}
+}
 /////////////////////////////////////////////////////////////////////////////////////////
 // paintTerrainBasedOnHeight
 //
@@ -357,7 +380,7 @@ function unPaintTileClassBasedOnHeight(minheight, maxheight, mode, tileclass)
 //	startPoint: [x, y] array defining the start point
 //	endPoint: [x, y] array defining the ending point
 //	heightRange: [min, max] array defining the range which the height of the intended point can be. includes both "min" and "max"
-//  step: how much tile units per turn should the search go. more value means faster but less accurate 
+//  step: how much tile units per turn should the search go. more value means faster but less accurate
 //  n: how many points to skip before ending the search. skips """n-1 points""".
 //
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -415,7 +438,7 @@ function checkIfIntersect (x1, y1, x2, y2, x3, y3, x4, y4, width)
 	{
 		var m = (y1 - y2) / (x1 - x2);
 		var b = y1 - m * x1;
-		var m2 = sqrt(m * m + 1)
+		var m2 = sqrt(m * m + 1);
 		if ((Math.abs((y3 - x3 * m - b)/m2) < width) || (Math.abs((y4 - x4 * m - b)/m2) < width))
 			return true;
 		//neccessary for some situations.
@@ -428,7 +451,7 @@ function checkIfIntersect (x1, y1, x2, y2, x3, y3, x4, y4, width)
 		{
 			var m = (y3 - y4) / (x3 - x4);
 			var b = y3 - m * x3;
-			var m2 = sqrt(m * m + 1)
+			var m2 = sqrt(m * m + 1);
 			if ((Math.abs((y1 - x1 * m - b)/m2) < width) || (Math.abs((y2 - x2 * m - b)/m2) < width))
 				return true;
 		}
@@ -468,7 +491,7 @@ function distanceOfPointFromLine (x1, y1, x2, y2, x3, y3)
 	{
 		var m = (y1 - y2) / (x1 - x2);
 		var b = y1 - m * x1;
-		var m2 = sqrt(m * m + 1)
+		var m2 = sqrt(m * m + 1);
 		return Math.abs((y3 - x3 * m - b)/m2);
 	}
 }
@@ -491,7 +514,7 @@ function createRamp (x1, y1, x2, y2, minHeight, maxHeight, width, smoothLevel, m
 {
 	var halfWidth = width / 2;
 	var mapSize = g_Map.size;
-	
+
 	if (y1 == y2)
 	{
 		var x3 = x2;
@@ -504,12 +527,12 @@ function createRamp (x1, y1, x2, y2, minHeight, maxHeight, width, smoothLevel, m
 		var x3 = x2 + halfWidth;
 		var y3 = - m * x3 + b;
 	}
-	
+
 	var minBoundX = (x1 <= x2 ? (x1 > halfWidth ? x1 - halfWidth : 0) : (x2 > halfWidth ? x2 - halfWidth : 0));
 	var maxBoundX = (x1 >= x2 ? (x1 < mapSize - halfWidth ? x1 + halfWidth : mapSize) : (x2 < mapSize - halfWidth ? x2 + halfWidth : mapSize));
 	var minBoundY = (y1 <= y2 ? (y1 > halfWidth ? y1 - halfWidth : 0) : (y2 > halfWidth ? y2 - halfWidth : 0));
 	var maxBoundY = (y1 >= y2 ? (x1 < mapSize - halfWidth ? y1 + halfWidth : mapSize) : (y2 < mapSize - halfWidth ? y2 + halfWidth : mapSize));
-	
+
 	for (var x = minBoundX; x < maxBoundX; ++x)
 	{
 		for (var y = minBoundY; y < maxBoundY; ++y)
@@ -551,14 +574,14 @@ function createMountain(maxHeight, minRadius, maxRadius, numCircles, constraint,
 {
 	fcc = (fcc !== undefined ? fcc : 0);
 	q = (q !== undefined ? q : []);
-	
+
 	// checking for an array of constraints
 	if (constraint instanceof Array)
 	{
 		var constraintArray = constraint;
 		constraint = new AndConstraint(constraintArray);
 	}
-	
+
 	// Preliminary bounds check
 	if (!g_Map.inMapBounds(x, z) || !constraint.allows(x, z))
 	{
@@ -567,7 +590,7 @@ function createMountain(maxHeight, minRadius, maxRadius, numCircles, constraint,
 
 	var size = getMapSize();
 	var queueEmpty = (q.length ? false : true);
-	
+
 	var gotRet = new Array(size);
 	for (var i = 0; i < size; ++i)
 	{
@@ -577,21 +600,21 @@ function createMountain(maxHeight, minRadius, maxRadius, numCircles, constraint,
 			gotRet[i][j] = -1;
 		}
 	}
-	
+
 	--size;
-	
+
 	if (minRadius < 1) minRadius = 1;
 	if (minRadius > maxRadius) minRadius = maxRadius;
-	
-	var edges = [[x, z]]
+
+	var edges = [[x, z]];
 	var circles = [];
-	
+
 	for (var i = 0; i < numCircles; ++i)
 	{
 		var badPoint = false;
 		var point = edges[randInt(edges.length)];
 		var cx = point[0], cz = point[1];
-		
+
 		if (queueEmpty)
 		{
 			var radius = randInt(minRadius, maxRadius);
@@ -601,27 +624,27 @@ function createMountain(maxHeight, minRadius, maxRadius, numCircles, constraint,
 			var radius = q.pop();
 			queueEmpty = (q.length ? false : true);
 		}
-		
+
 		var sx = cx - radius, lx = cx + radius;
 		var sz = cz - radius, lz = cz + radius;
-		
+
 		sx = (sx < 0 ? 0 : sx);
 		sz = (sz < 0 ? 0 : sz);
 		lx = (lx > size ? size : lx);
 		lz = (lz > size ? size : lz);
-		
+
 		var radius2 = radius * radius;
 		var dx, dz, distance2;
-		
+
 		//log (uneval([sx, sz, lx, lz]));
-		
+
 		for (var ix = sx; ix <= lx; ++ix)
 		{
 			for (var iz = sz; iz <= lz; ++ iz)
 			{
 				dx = ix - cx;
 				dz = iz - cz;
-				distance2 = dx * dx + dz * dz
+				distance2 = dx * dx + dz * dz;
 				if (dx * dx + dz * dz <= radius2)
 				{
 					if (g_Map.inMapBounds(ix, iz))
@@ -631,9 +654,9 @@ function createMountain(maxHeight, minRadius, maxRadius, numCircles, constraint,
 							badPoint = true;
 							break;
 						}
-						
+
 						var state = gotRet[ix][iz];
-						
+
 						if (state == -1)
 						{
 							gotRet[ix][iz] = -2;
@@ -644,7 +667,7 @@ function createMountain(maxHeight, minRadius, maxRadius, numCircles, constraint,
 							var s = edges.splice(state, 1);
 
 							gotRet[ix][iz] = -2;
-							
+
 							var edgesLength = edges.length;
 							for (var k = state; k < edges.length; ++k)
 							{
@@ -657,13 +680,13 @@ function createMountain(maxHeight, minRadius, maxRadius, numCircles, constraint,
 			if (badPoint)
 				break;
 		}
-		
+
 		if (badPoint)
 			continue;
 		else
 			circles.push([cx, cz, radius]);
-			
-		
+
+
 		for (var ix = sx; ix <= lx; ++ix)
 		{
 			for (var iz = sz; iz <= lz; ++ iz)
@@ -671,7 +694,7 @@ function createMountain(maxHeight, minRadius, maxRadius, numCircles, constraint,
 				if (fcc)
 					if ((x - ix) > fcc || (ix - x) > fcc || (z - iz) > fcc || (iz - z) > fcc)
 						continue;
-				
+
 				if (gotRet[ix][iz] == -2)
 				{
 					if (ix > 0)
@@ -714,27 +737,27 @@ function createMountain(maxHeight, minRadius, maxRadius, numCircles, constraint,
 			}
 		}
 	}
-	
+
 	var numFinalCircles = circles.length;
-	
+
 	for (var i = 0; i < numFinalCircles; ++i)
 	{
 		var point = circles[i];
 		var cx = point[0], cz = point[1], radius = point[2];
-		
+
 		var sx = cx - radius, lx = cx + radius;
 		var sz = cz - radius, lz = cz + radius;
-		
+
 		sx = (sx < 0 ? 0 : sx);
 		sz = (sz < 0 ? 0 : sz);
 		lx = (lx > size ? size : lx);
 		lz = (lz > size ? size : lz);
-		
+
 		var radius2 = radius * radius;
 		var dx, dz, distance2;
-		
+
 		var clumpHeight = (radius/maxRadius)*maxHeight*randFloat(0.8,1.2);
-		
+
 		for (var ix = sx; ix <= lx; ++ix)
 		{
 			for (var iz = sz; iz <= lz; ++ iz)
@@ -742,9 +765,9 @@ function createMountain(maxHeight, minRadius, maxRadius, numCircles, constraint,
 				dx = ix - cx;
 				dz = iz - cz;
 				distance2 = dx * dx + dz * dz;
-				
+
 				var newHeight = round((Math.sin(PI*(2*((radius - sqrt(distance2))/radius)/3 - 1/6)) + 0.5) * 2 / 3 *clumpHeight) + randInt(0,2);
-				
+
 				if (dx * dx + dz * dz <= radius2)
 				{
 					if (g_Map.getHeight(ix, iz) < newHeight)
