@@ -26,7 +26,6 @@ const oTree3 = rBiomeE3();
 const oTree4 = rBiomeE4();
 const oTree5 = rBiomeE5();
 const oFruitBush = rBiomeE6();
-const oChicken = rBiomeE7();
 const oMainHuntableAnimal = rBiomeE8();
 const oFish = rBiomeE9();
 const oSecondaryHuntableAnimal = rBiomeE10();
@@ -46,10 +45,6 @@ const aBushSmall = rBiomeA8();
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
-
-
-// initialize map
 
 log("Initializing map...");
 
@@ -66,7 +61,6 @@ log(mapSize);
 var clPlayer = createTileClass();
 var clHill = createTileClass();
 var clForest = createTileClass();
-var clWater = createTileClass();
 var clDirt = createTileClass();
 var clRock = createTileClass();
 var clMetal = createTileClass();
@@ -76,7 +70,7 @@ var clSettlement = createTileClass();
 var clLand = createTileClass();
 
 //Paint the whole map
-	
+
 for (var ix = 0; ix < mapSize; ix++)
 {
 	for (var iz = 0; iz < mapSize; iz++)
@@ -156,7 +150,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		IslandZ[4*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.36);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -170,7 +164,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		//centeral island id numPlayers
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 		isConnected[e+2*numPlayers][e] = 1;
@@ -191,7 +185,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		IslandZ[e+2*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.81);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -204,7 +198,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 			cliffRadius				// blend radius
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
-		
+
 		//Small Isles
 		isConnected[e+3*numPlayers][e+numPlayers] = 1;
 		var fx = fractionToTiles(0.5 + 0.27*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -215,7 +209,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		IslandZ[e+3*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.49);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -229,7 +223,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 			isConnected[e][e+numPlayers] = 1;
@@ -241,7 +235,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 			{
 				isConnected[0][e+numPlayers] = 1;
 			}
-	
+
 			//second island id 4
 			var fx = fractionToTiles(0.5 + 0.41*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
 			var fz = fractionToTiles(0.5 + 0.41*sin(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -251,7 +245,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 			IslandZ[e+numPlayers]=iz;
 			// calculate size based on the radius
 			var hillSize = PI * radius * radius;
-			
+
 			// create the hill
 			var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 			var terrainPainter = new LayeredPainter(
@@ -301,7 +295,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		IslandZ[4*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.36);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -315,7 +309,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		//centeral island id numPlayers
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 		isConnected[e+2*numPlayers][e] = 1;
@@ -336,7 +330,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		IslandZ[e+2*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.81);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -349,7 +343,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 			cliffRadius				// blend radius
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
-		
+
 		//Small Isles
 		isConnected[e+3*numPlayers][e+numPlayers] = 1;
 		var fx = fractionToTiles(0.5 + 0.27*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -360,7 +354,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		IslandZ[e+3*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.49);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -374,7 +368,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 			isConnected[e][e+numPlayers] = 1;
@@ -386,7 +380,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 			{
 				isConnected[0][e+numPlayers] = 1;
 			}
-	
+
 			//second island id 4
 			var fx = fractionToTiles(0.5 + 0.41*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
 			var fz = fractionToTiles(0.5 + 0.41*sin(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -396,7 +390,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 			IslandZ[e+numPlayers]=iz;
 			// calculate size based on the radius
 			var hillSize = PI * radius * radius;
-			
+
 			// create the hill
 			var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 			var terrainPainter = new LayeredPainter(
@@ -447,7 +441,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		IslandZ[4*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.36);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -461,7 +455,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		//centeral island id numPlayers
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 		isConnected[e+2*numPlayers][e] = 1;
@@ -482,7 +476,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		IslandZ[e+2*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.81);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -495,7 +489,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 			cliffRadius				// blend radius
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
-		
+
 		//Small Isles
 		isConnected[e+3*numPlayers][e+numPlayers] = 1;
 		var fx = fractionToTiles(0.5 + 0.41*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -506,7 +500,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		IslandZ[e+3*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.49);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -520,7 +514,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 			isConnected[e][e+numPlayers] = 1;
@@ -532,7 +526,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 			{
 				isConnected[0][e+numPlayers] = 1;
 			}
-	
+
 			//second island id 4
 			var fx = fractionToTiles(0.5 + 0.27*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
 			var fz = fractionToTiles(0.5 + 0.27*sin(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -542,7 +536,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 			IslandZ[e+numPlayers]=iz;
 			// calculate size based on the radius
 			var hillSize = PI * radius * radius;
-			
+
 			// create the hill
 			var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 			var terrainPainter = new LayeredPainter(
@@ -557,7 +551,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 			createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
 	}
-	
+
 			//More than 4 PLAYERS
 		//-----------------
 		//-----------------
@@ -584,9 +578,9 @@ if ((mapSize == 128)||(mapSize == 192)){
 			sX = sX + playerX[l];
 			sZ = sZ + playerZ[l];
 		}
-		
+
 		//centeral island id numPlayers
-		
+
 		var fx = fractionToTiles((sX)/numPlayers);
 		var fz = fractionToTiles((sZ)/numPlayers);
 		var ix = round(fx);
@@ -595,7 +589,7 @@ if ((mapSize == 128)||(mapSize == 192)){
 		IslandZ[numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = PI * radius * radius;
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -608,8 +602,8 @@ if ((mapSize == 128)||(mapSize == 192)){
 			cliffRadius				// blend radius
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
-		
-		
+
+
 	}
 }
 
@@ -654,7 +648,7 @@ if (mapSize == 256){
 		IslandZ[4*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.36);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -668,7 +662,7 @@ if (mapSize == 256){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		//centeral island id numPlayers
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 		isConnected[e+2*numPlayers][e] = 1;
@@ -689,7 +683,7 @@ if (mapSize == 256){
 		IslandZ[e+2*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.81);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -702,7 +696,7 @@ if (mapSize == 256){
 			cliffRadius				// blend radius
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
-		
+
 		//Small Isles
 		isConnected[e+3*numPlayers][e+numPlayers] = 1;
 		var fx = fractionToTiles(0.5 + 0.41*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -713,7 +707,7 @@ if (mapSize == 256){
 		IslandZ[e+3*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.49);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -727,7 +721,7 @@ if (mapSize == 256){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 			isConnected[e][e+numPlayers] = 1;
@@ -739,7 +733,7 @@ if (mapSize == 256){
 			{
 				isConnected[0][e+numPlayers] = 1;
 			}
-	
+
 			//second island id 4
 			var fx = fractionToTiles(0.5 + 0.26*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
 			var fz = fractionToTiles(0.5 + 0.26*sin(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -749,7 +743,7 @@ if (mapSize == 256){
 			IslandZ[e+numPlayers]=iz;
 			// calculate size based on the radius
 			var hillSize = PI * radius * radius;
-			
+
 			// create the hill
 			var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 			var terrainPainter = new LayeredPainter(
@@ -785,11 +779,11 @@ if (mapSize == 256){
 		//connections
 		var sX = 0;
 		var sZ = 0;
-		
 
-		
+
+
 		//centeral island id numPlayers
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 		if (e+1<numPlayers)
@@ -817,7 +811,7 @@ if (mapSize == 256){
 		IslandZ[e+numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.81);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -831,7 +825,7 @@ if (mapSize == 256){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
-		
+
 	}
 }
 
@@ -876,7 +870,7 @@ if (mapSize == 320){
 		IslandZ[4*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.36);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -890,7 +884,7 @@ if (mapSize == 320){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		//centeral island id numPlayers
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 		isConnected[e+2*numPlayers][e] = 1;
@@ -911,7 +905,7 @@ if (mapSize == 320){
 		IslandZ[e+2*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.81);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -924,7 +918,7 @@ if (mapSize == 320){
 			cliffRadius				// blend radius
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
-		
+
 		//Small Isles
 		isConnected[e+3*numPlayers][e+numPlayers] = 1;
 		var fx = fractionToTiles(0.5 + 0.41*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -935,7 +929,7 @@ if (mapSize == 320){
 		IslandZ[e+3*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.49);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -949,7 +943,7 @@ if (mapSize == 320){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 			isConnected[e][e+numPlayers] = 1;
@@ -961,7 +955,7 @@ if (mapSize == 320){
 			{
 				isConnected[0][e+numPlayers] = 1;
 			}
-	
+
 			//second island id 4
 			var fx = fractionToTiles(0.5 + 0.26*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
 			var fz = fractionToTiles(0.5 + 0.26*sin(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -971,7 +965,7 @@ if (mapSize == 320){
 			IslandZ[e+numPlayers]=iz;
 			// calculate size based on the radius
 			var hillSize = PI * radius * radius;
-			
+
 			// create the hill
 			var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 			var terrainPainter = new LayeredPainter(
@@ -1022,7 +1016,7 @@ if (mapSize == 320){
 		IslandZ[4*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.36);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -1036,7 +1030,7 @@ if (mapSize == 320){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		//centeral island id numPlayers
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 		isConnected[e+2*numPlayers][e] = 1;
@@ -1057,7 +1051,7 @@ if (mapSize == 320){
 		IslandZ[e+2*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.81);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -1070,7 +1064,7 @@ if (mapSize == 320){
 			cliffRadius				// blend radius
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
-		
+
 		//Small Isles
 		isConnected[e+3*numPlayers][e+numPlayers] = 1;
 		var fx = fractionToTiles(0.5 + 0.41*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -1081,7 +1075,7 @@ if (mapSize == 320){
 		IslandZ[e+3*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.49);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -1095,7 +1089,7 @@ if (mapSize == 320){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 			isConnected[e][e+numPlayers] = 1;
@@ -1107,7 +1101,7 @@ if (mapSize == 320){
 			{
 				isConnected[0][e+numPlayers] = 1;
 			}
-	
+
 			//second island id 4
 			var fx = fractionToTiles(0.5 + 0.26*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
 			var fz = fractionToTiles(0.5 + 0.26*sin(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -1117,7 +1111,7 @@ if (mapSize == 320){
 			IslandZ[e+numPlayers]=iz;
 			// calculate size based on the radius
 			var hillSize = PI * radius * radius;
-			
+
 			// create the hill
 			var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 			var terrainPainter = new LayeredPainter(
@@ -1152,11 +1146,11 @@ if (mapSize == 320){
 		//connections
 		var sX = 0;
 		var sZ = 0;
-		
 
-		
+
+
 		//centeral island id numPlayers
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 		if (e+1<numPlayers)
@@ -1184,7 +1178,7 @@ if (mapSize == 320){
 		IslandZ[e+numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.81);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -1198,7 +1192,7 @@ if (mapSize == 320){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
-		
+
 	}
 }
 
@@ -1243,7 +1237,7 @@ if (mapSize > 383){
 		IslandZ[4*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.36);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -1257,7 +1251,7 @@ if (mapSize > 383){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		//centeral island id numPlayers
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 		isConnected[e+2*numPlayers][e] = 1;
@@ -1278,7 +1272,7 @@ if (mapSize > 383){
 		IslandZ[e+2*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.81);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -1291,7 +1285,7 @@ if (mapSize > 383){
 			cliffRadius				// blend radius
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
-		
+
 		//Small Isles
 		isConnected[e+3*numPlayers][e+numPlayers] = 1;
 		var fx = fractionToTiles(0.5 + 0.41*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -1302,7 +1296,7 @@ if (mapSize > 383){
 		IslandZ[e+3*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.49);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -1316,7 +1310,7 @@ if (mapSize > 383){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 			isConnected[e][e+numPlayers] = 1;
@@ -1328,7 +1322,7 @@ if (mapSize > 383){
 			{
 				isConnected[0][e+numPlayers] = 1;
 			}
-	
+
 			//second island id 4
 			var fx = fractionToTiles(0.5 + 0.24*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
 			var fz = fractionToTiles(0.5 + 0.24*sin(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -1338,7 +1332,7 @@ if (mapSize > 383){
 			IslandZ[e+numPlayers]=iz;
 			// calculate size based on the radius
 			var hillSize = PI * radius * radius;
-			
+
 			// create the hill
 			var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 			var terrainPainter = new LayeredPainter(
@@ -1352,7 +1346,7 @@ if (mapSize > 383){
 			);
 			createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
-		
+
 	}
 
 		//6,7,8 PLAYERS
@@ -1390,7 +1384,7 @@ if (mapSize > 383){
 		IslandZ[4*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.36);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -1403,11 +1397,11 @@ if (mapSize > 383){
 			cliffRadius				// blend radius
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
-		
 
-		
+
+
 		//centeral island id numPlayers
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 		isConnected[e+2*numPlayers][e] = 1;
@@ -1428,7 +1422,7 @@ if (mapSize > 383){
 		IslandZ[e+2*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.81);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -1441,7 +1435,7 @@ if (mapSize > 383){
 			cliffRadius				// blend radius
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
-		
+
 		//Small Isles
 		isConnected[e+3*numPlayers][e+numPlayers] = 1;
 		var fx = fractionToTiles(0.5 + 0.41*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -1452,7 +1446,7 @@ if (mapSize > 383){
 		IslandZ[e+3*numPlayers]=iz;
 		// calculate size based on the radius
 		var hillSize = floor(PI * radius * radius * 0.36);
-		
+
 		// create the hill
 		var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
@@ -1466,7 +1460,7 @@ if (mapSize > 383){
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
-		
+
 		for (var e = 0; e <numPlayers; e++)
 		{
 			isConnected[e][e+numPlayers] = 1;
@@ -1478,7 +1472,7 @@ if (mapSize > 383){
 			{
 				isConnected[0][e+numPlayers] = 1;
 			}
-	
+
 			//second island id 4
 			var fx = fractionToTiles(0.5 + 0.28*cos(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
 			var fz = fractionToTiles(0.5 + 0.28*sin(startAngle + e*TWO_PI/numPlayers + TWO_PI/(2*numPlayers)));
@@ -1488,7 +1482,7 @@ if (mapSize > 383){
 			IslandZ[e+numPlayers]=iz;
 			// calculate size based on the radius
 			var hillSize = PI * radius * radius * 0.81;
-			
+
 			// create the hill
 			var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 			var terrainPainter = new LayeredPainter(
@@ -1502,7 +1496,7 @@ if (mapSize > 383){
 			);
 			createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 		}
-		
+
 	}
 }
 
@@ -1520,10 +1514,10 @@ for (var i = 0; i < numPlayers; i++)
 {
 	var id = playerIDs[i];
 	log("Creating base for player " + id + "...");
-	
+
 	// some constants
 
-	
+
 	// get the x and z in tiles
 	var fx = fractionToTiles(playerX[i]);
 	var fz = fractionToTiles(playerZ[i]);
@@ -1533,7 +1527,7 @@ for (var i = 0; i < numPlayers; i++)
 		IslandZ[i]=iz;
 	// calculate size based on the radius
 	var hillSize = PI * radius * radius;
-	
+
 	// create the hill
 	var placer = new ClumpPlacer(hillSize, 0.95, 0.6, 10, ix, iz);
 	var terrainPainter = new LayeredPainter(
@@ -1546,42 +1540,30 @@ for (var i = 0; i < numPlayers; i++)
 		cliffRadius				// blend radius
 	);
 	createArea(placer, [terrainPainter, elevationPainter, paintClass(clPlayer)], null);
-	
-	
+
+
 	// create the city patch
 	var cityRadius = radius/3;
 	placer = new ClumpPlacer(PI*cityRadius*cityRadius, 0.6, 0.3, 10, ix, iz);
 	var painter = new LayeredPainter([tRoadWild, tRoad], [1]);
 	createArea(placer, painter, null);
-	
+
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE, {'iberWall' : 'towers'});
-	
-	// create animals
-	for (var j = 0; j < 2; ++j)
-	{
-		var aAngle = randFloat(0, TWO_PI);
-		var aDist = 7;
-		var aX = round(fx + aDist * cos(aAngle));
-		var aZ = round(fz + aDist * sin(aAngle));
-		var group = new SimpleGroup(
-			[new SimpleObject(oChicken, 5,5, 0,2)],
-			true, clBaseResource, aX, aZ
-		);
-		createObjectGroup(group, 0);
-	}
-	
+	placeCivDefaultEntities(fx, fz, id, { 'iberWall': 'towers' });
+
+	placeDefaultChicken(fx, fz, clBaseResource);
+
 	// create berry bushes
 	var bbAngle = randFloat(0, TWO_PI);
 	var bbDist = 10;
 	var bbX = round(fx + bbDist * cos(bbAngle));
 	var bbZ = round(fz + bbDist * sin(bbAngle));
-	group = new SimpleGroup(
+	var group = new SimpleGroup(
 		[new SimpleObject(oFruitBush, 5,5, 0,3)],
 		true, clBaseResource, bbX, bbZ
 	);
 	createObjectGroup(group, 0);
-	
+
 	// create metal mine
 	var mAngle = bbAngle;
 	while(abs(mAngle - bbAngle) < PI/3)
@@ -1596,7 +1578,7 @@ for (var i = 0; i < numPlayers; i++)
 		true, clBaseResource, mX, mZ
 	);
 	createObjectGroup(group, 0);
-	
+
 	// create stone mines
 	mAngle += randFloat(PI/8, PI/4);
 	mX = round(fx + mDist * cos(mAngle));
@@ -1606,7 +1588,7 @@ for (var i = 0; i < numPlayers; i++)
 		true, clBaseResource, mX, mZ
 	);
 	createObjectGroup(group, 0);
-	
+
 	// create starting trees
 	var num = floor(hillSize / 60);
 	var tAngle = randFloat(-PI/3, 4*PI/3);
@@ -1618,7 +1600,7 @@ for (var i = 0; i < numPlayers; i++)
 		false, clBaseResource, tX, tZ
 	);
 	createObjectGroup(group, 0, [avoidClasses(clBaseResource,2), stayClasses(clPlayer, 3)]);
-	
+
 	// create grass tufts
 	var num = hillSize / 250;
 	for (var j = 0; j < num; j++)
@@ -1731,7 +1713,7 @@ for (var i = 0; i < types.length; ++i)
 		);
 	createAreas(
 		placer,
-		[painter, paintClass(clForest)], 
+		[painter, paintClass(clForest)],
 		[avoidClasses(clPlayer, 6, clForest, 10, clHill, 0), stayClasses(clLand, 4)],
 		num
 	);
@@ -1805,7 +1787,7 @@ group = new SimpleGroup(
 );
 createObjectGroups(
 	group, 0,
-	[avoidClasses(clWater, 0, clForest, 0, clPlayer, 0, clHill, 0), stayClasses(clLand, 4)],
+	[avoidClasses(clForest, 0, clPlayer, 0, clHill, 0), stayClasses(clLand, 4)],
 	scaleByMapSize(16, 262), 50
 );
 
@@ -1818,7 +1800,7 @@ group = new SimpleGroup(
 );
 createObjectGroups(
 	group, 0,
-	[avoidClasses(clWater, 0, clForest, 0, clPlayer, 0, clHill, 0), stayClasses(clLand, 4)],
+	[avoidClasses(clForest, 0, clPlayer, 0, clHill, 0), stayClasses(clLand, 4)],
 	scaleByMapSize(8, 131), 50
 );
 
@@ -1831,7 +1813,7 @@ group = new SimpleGroup(
 	true, clFood
 );
 createObjectGroups(group, 0,
-	[avoidClasses(clWater, 0, clForest, 0, clPlayer, 10, clHill, 1, clFood, 20), stayClasses(clLand, 4)],
+	[avoidClasses(clForest, 0, clPlayer, 10, clHill, 1, clFood, 20), stayClasses(clLand, 4)],
 	3 * numPlayers, 50
 );
 
@@ -1844,7 +1826,7 @@ group = new SimpleGroup(
 	true, clFood
 );
 createObjectGroups(group, 0,
-	[avoidClasses(clWater, 0, clForest, 0, clPlayer, 10, clHill, 1, clFood, 20), stayClasses(clLand, 4)],
+	[avoidClasses(clForest, 0, clPlayer, 10, clHill, 1, clFood, 20), stayClasses(clLand, 4)],
 	3 * numPlayers, 50
 );
 
@@ -1855,7 +1837,7 @@ group = new SimpleGroup(
 	true, clFood
 );
 createObjectGroups(group, 0,
-	[avoidClasses(clWater, 0, clForest, 0, clPlayer, 10, clHill, 1, clFood, 20), stayClasses(clLand, 4)],
+	[avoidClasses(clForest, 0, clPlayer, 10, clHill, 1, clFood, 20), stayClasses(clLand, 4)],
 	3 * numPlayers, 50
 );
 
@@ -1873,7 +1855,7 @@ for (var i = 0; i < types.length; ++i)
 		true, clForest
 	);
 	createObjectGroups(group, 0,
-		[avoidClasses(clWater, 1, clForest, 1, clHill, 1, clPlayer, 9, clMetal, 1, clRock, 1), stayClasses(clLand, 4)],
+		[avoidClasses(clForest, 1, clHill, 1, clPlayer, 9, clMetal, 1, clRock, 1), stayClasses(clLand, 4)],
 		num
 	);
 }
@@ -1888,7 +1870,7 @@ group = new SimpleGroup(
 	[new SimpleObject(aGrassShort, 1,2, 0,1, -PI/8,PI/8)]
 );
 createObjectGroups(group, 0,
-	[avoidClasses(clWater, 2, clHill, 2, clPlayer, 2, clDirt, 0), stayClasses(clLand, 4)],
+	[avoidClasses(clHill, 2, clPlayer, 2, clDirt, 0), stayClasses(clLand, 4)],
 	planetm * scaleByMapSize(13, 200)
 );
 
@@ -1900,7 +1882,7 @@ group = new SimpleGroup(
 	[new SimpleObject(aGrass, 2,4, 0,1.8, -PI/8,PI/8), new SimpleObject(aGrassShort, 3,6, 1.2,2.5, -PI/8,PI/8)]
 );
 createObjectGroups(group, 0,
-	[avoidClasses(clWater, 3, clHill, 2, clPlayer, 2, clDirt, 1, clForest, 0), stayClasses(clLand, 4)],
+	[avoidClasses(clHill, 2, clPlayer, 2, clDirt, 1, clForest, 0), stayClasses(clLand, 4)],
 	planetm * scaleByMapSize(13, 200)
 );
 
@@ -1912,20 +1894,18 @@ group = new SimpleGroup(
 	[new SimpleObject(aBushMedium, 1,2, 0,2), new SimpleObject(aBushSmall, 2,4, 0,2)]
 );
 createObjectGroups(group, 0,
-	[avoidClasses(clWater, 1, clHill, 1, clPlayer, 1, clDirt, 1), stayClasses(clLand, 4)],
+	[avoidClasses(clHill, 1, clPlayer, 1, clDirt, 1), stayClasses(clLand, 4)],
 	planetm * scaleByMapSize(13, 200), 50
 );
 
-random_terrain = randInt(1,3)
-if (random_terrain==1){
+random_terrain = randInt(1,3);
+if (random_terrain == 1)
 	setSkySet("cirrus");
-}
-else if (random_terrain ==2){
+else if (random_terrain == 2)
 	setSkySet("cumulus");
-}
-else if (random_terrain ==3){
+else if (random_terrain == 3)
 	setSkySet("sunny");
-}
+
 setSunRotation(randFloat(0, TWO_PI));
 setSunElevation(randFloat(PI/ 5, PI / 3));
 
