@@ -27,7 +27,6 @@ const oTree3 = rBiomeE3();
 const oTree4 = rBiomeE4();
 const oTree5 = rBiomeE5();
 const oFruitBush = rBiomeE6();
-const oChicken = rBiomeE7();
 const oMainHuntableAnimal = rBiomeE8();
 const oFish = rBiomeE9();
 const oSecondaryHuntableAnimal = rBiomeE10();
@@ -48,9 +47,6 @@ const aBushSmall = rBiomeA8();
 
 const pForest1 = [tForestFloor2 + TERRAIN_SEPARATOR + oTree1, tForestFloor2 + TERRAIN_SEPARATOR + oTree2, tForestFloor2];
 const pForest2 = [tForestFloor1 + TERRAIN_SEPARATOR + oTree4, tForestFloor1 + TERRAIN_SEPARATOR + oTree5, tForestFloor1];
-const BUILDING_ANGlE = -PI/4;
-
-// initialize map
 
 log("Initializing map...");
 
@@ -111,7 +107,7 @@ if (md == 2) //continent
 		playerAngle[i] = startAngle + i*TWO_PI/numPlayers;
 		playerX[i] = 0.5 + 0.25*cos(playerAngle[i]);
 		playerZ[i] = 0.5 + 0.25*sin(playerAngle[i]);
-		
+
 		var fx = fractionToTiles(playerX[i]);
 		var fz = fractionToTiles(playerZ[i]);
 		var ix = round(fx);
@@ -121,7 +117,7 @@ if (md == 2) //continent
 		addToClass(ix, iz+5, clPlayer);
 		addToClass(ix-5, iz, clPlayer);
 		addToClass(ix, iz-5, clPlayer);
-		
+
 		var placer = new ChainPlacer(2, floor(scaleByMapSize(5, 9)), floor(scaleByMapSize(5, 20)), 1, ix, iz, 0, [floor(scaleByMapSize(23, 50))]);
 		var elevationPainter = new SmoothElevationPainter(
 			ELEVATION_SET,			// type
@@ -147,13 +143,13 @@ if (md == 2) //continent
 		4				// blend radius
 	);
 	createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
-	
+
 	var clPeninsulaSteam = createTileClass();
-	
+
 	if (randInt(1,3)==1) // peninsula
 	{
 		var angle = randFloat(0, TWO_PI);
-	
+
 		var fx = fractionToTiles(0.5 + 0.25*cos(angle));
 		var fz = fractionToTiles(0.5 + 0.25*sin(angle));
 		ix = round(fx);
@@ -170,12 +166,12 @@ if (md == 2) //continent
 			4				// blend radius
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
-		
+
 		var fx = fractionToTiles(0.5 + 0.35*cos(angle));
 		var fz = fractionToTiles(0.5 + 0.35*sin(angle));
 		ix = round(fx);
 		iz = round(fz);
-		
+
 		var placer = new ClumpPlacer(mapArea * 0.3, 0.9, 0.01, 10, ix, iz);
 		createArea(placer, [paintClass(clPeninsulaSteam)], null);
 	}
@@ -198,7 +194,7 @@ playerIDs = primeSortPlayers(sortPlayers(playerIDs));
 	var playerAngle = new Array(numPlayers);
 	var playerPos = new Array(numPlayers);
 	var iop = 0;
-	
+
 	var mdd1 = randInt(1,2);
 	if (mdd1 == 1) //vertical
 	{
@@ -247,7 +243,7 @@ playerIDs = primeSortPlayers(sortPlayers(playerIDs));
 		}
 	}
 
-	
+
 	var WATER_WIDTH = randFloat(0.22,0.3)+scaleByMapSize(1,4)/20;
 	log("Creating sea");
 	var theta = randFloat(0, 1);
@@ -260,17 +256,17 @@ playerIDs = primeSortPlayers(sortPlayers(playerIDs));
 		{
 			var x = ix / (mapSize + 1.0);
 			var z = iz / (mapSize + 1.0);
-			
+
 			// add the rough shape of the water
 			var km = 20/scaleByMapSize(35, 160);
-			
+
 			var fadeDist = 0.05;
-			
+
 			if (mdd1 == 1) //vertical
 			{
 				var cu = km*rndRiver(theta+z*0.5*(mapSize/64),seed);
 				var cu2 = km*rndRiver(theta2+z*0.5*(mapSize/64),seed2);
-				
+
 				if ((x > cu + 0.5 - WATER_WIDTH/2) && (x < cu2 + 0.5 + WATER_WIDTH/2))
 				{
 					var h;
@@ -286,7 +282,7 @@ playerIDs = primeSortPlayers(sortPlayers(playerIDs));
 					{
 						h = -3.0;
 					}
-					
+
 					if (h < -1.5)
 					{
 						placeTerrain(ix, iz, tWater);
@@ -295,7 +291,7 @@ playerIDs = primeSortPlayers(sortPlayers(playerIDs));
 					{
 						placeTerrain(ix, iz, tShore);
 					}
-					
+
 					setHeight(ix, iz, h);
 					if (h < 0){
 						addToClass(ix, iz, clWater);
@@ -311,7 +307,7 @@ playerIDs = primeSortPlayers(sortPlayers(playerIDs));
 			{
 				var cu = km*rndRiver(theta+x*0.5*(mapSize/64),seed);
 				var cu2 = km*rndRiver(theta2+x*0.5*(mapSize/64),seed2);
-				
+
 				if ((z > cu + 0.5 - WATER_WIDTH/2) && (z < cu2 + 0.5 + WATER_WIDTH/2))
 				{
 					var h;
@@ -327,7 +323,7 @@ playerIDs = primeSortPlayers(sortPlayers(playerIDs));
 					{
 						h = -3.0;
 					}
-					
+
 					if (h < -1.5)
 					{
 						placeTerrain(ix, iz, tWater);
@@ -336,7 +332,7 @@ playerIDs = primeSortPlayers(sortPlayers(playerIDs));
 					{
 						placeTerrain(ix, iz, tShore);
 					}
-					
+
 					setHeight(ix, iz, h);
 					if (h < 0){
 						addToClass(ix, iz, clWater);
@@ -350,7 +346,7 @@ playerIDs = primeSortPlayers(sortPlayers(playerIDs));
 			}
 		}
 	}
-	
+
 
 	// linked
 	if (mdd1 == 1) //vertical
@@ -385,7 +381,7 @@ playerIDs = primeSortPlayers(sortPlayers(playerIDs));
 		elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 3.1, 4);
 		createAreas(
 			placer,
-			[terrainPainter, elevationPainter, paintClass(clLand)], 
+			[terrainPainter, elevationPainter, paintClass(clLand)],
 			avoidClasses(clLand, 3, clPlayer, 3),
 			scaleByMapSize(2, 5)*randInt(8,14)
 		);
@@ -402,7 +398,7 @@ playerIDs = primeSortPlayers(sortPlayers(playerIDs));
 		elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 3.1, 4);
 		createAreas(
 			placer,
-			[terrainPainter, elevationPainter, paintClass(clLand)], 
+			[terrainPainter, elevationPainter, paintClass(clLand)],
 			null,
 			scaleByMapSize(2, 5)*randInt(8,14)
 		);
@@ -486,15 +482,15 @@ else if (md == 4) //central river
 			playerX[i] = 0.25 + 0.5*(i%2);
 		}
 	}
-	
+
 	// create the main river
 	log("Creating the main river");
-	
+
 	if (mdd1 == 2)
 		var placer = new PathPlacer(fractionToTiles(0.5), 1, fractionToTiles(0.5) , fractionToTiles(0.99), scaleByMapSize(14,24), 0.5, 3*(scaleByMapSize(1,4)), 0.1, 0.01);
 	else
 		var placer = new PathPlacer(1, fractionToTiles(0.5), fractionToTiles(0.99), fractionToTiles(0.5), scaleByMapSize(14,24), 0.5, 3*(scaleByMapSize(1,4)), 0.1, 0.01);
-	
+
 	var terrainPainter = new LayeredPainter(
 		[tShore, tWater, tWater],		// terrains
 		[1, 3]								// widths
@@ -505,25 +501,25 @@ else if (md == 4) //central river
 		4				// blend radius
 	);
 	createArea(placer, [terrainPainter, elevationPainter], avoidClasses(clPlayer, 4));
-	
+
 	if (mdd1 == 1)
 		placer = new ClumpPlacer(floor(PI*scaleByMapSize(10,20)*scaleByMapSize(10,20)/4), 0.95, 0.6, 10, 1, fractionToTiles(0.5));
 	else
 		placer = new ClumpPlacer(floor(PI*scaleByMapSize(10,20)*scaleByMapSize(10,20)/4), 0.95, 0.6, 10, fractionToTiles(0.5), 1);
-	
+
 	var painter = new LayeredPainter([tWater, tWater], [1]);
 	var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, -4, 2);
 	createArea(placer, [painter, elevationPainter], avoidClasses(clPlayer, 8));
-	
+
 	if (mdd1 == 1)
 		placer = new ClumpPlacer(floor(PI*scaleByMapSize(10,20)*scaleByMapSize(10,20)/4), 0.95, 0.6, 10, fractionToTiles(0.99), fractionToTiles(0.5));
 	else
 		placer = new ClumpPlacer(floor(PI*scaleByMapSize(10,20)*scaleByMapSize(10,20)/4), 0.95, 0.6, 10, fractionToTiles(0.5), fractionToTiles(0.99));
-		
+
 	var painter = new LayeredPainter([tWater, tWater], [1]);
 	var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, -4, 2);
 	createArea(placer, [painter, elevationPainter], avoidClasses(clPlayer, 8));
-	
+
 	// create the shallows of the main river
 	log("Creating the shallows of the main river");
 
@@ -535,7 +531,7 @@ else if (md == 4) //central river
 		else
 			passageMaker(floor(fractionToTiles(0.35)), floor(fractionToTiles(cLocation)), floor(fractionToTiles(0.65)), floor(fractionToTiles(cLocation)), scaleByMapSize(4,8), -2, -2, 2, clShallow, undefined, -4);
 	}
-	
+
 	if (randInt(1,2) == 1)
 	{
 		for (var i = 0; i < numPlayers; i++)
@@ -549,7 +545,7 @@ else if (md == 4) //central river
 			placer = new ClumpPlacer(PI*cityRadius*cityRadius, 0.6, 0.3, 10, ix, iz);
 			createArea(placer, paintClass(clPlayer), null);
 		}
-	
+
 		// create tributaries
 		log("Creating tributaries");
 
@@ -569,15 +565,15 @@ else if (md == 4) //central river
 				var point = getTIPIADBON([fractionToTiles(cLocation), fractionToTiles(0.5 + cDistance)], [fractionToTiles(cLocation), fractionToTiles(0.5 - cDistance)], [-6, -1.5], 0.5, 5, 0.01);
 			else
 				var point = getTIPIADBON([fractionToTiles(0.5 + cDistance), fractionToTiles(cLocation)], [fractionToTiles(0.5 - cDistance), fractionToTiles(cLocation)], [-6, -1.5], 0.5, 5, 0.01);
-			
+
 			if (point !== undefined)
 			{
 				if (mdd1 == 1)
 					var placer = new PathPlacer(floor(point[0]), floor(point[1]), floor(fractionToTiles(0.5 + 0.49*cos(tang))), floor(fractionToTiles(0.5 + 0.49*sin(tang))), scaleByMapSize(10,20), 0.4, 3*(scaleByMapSize(1,4)), 0.1, 0.05);
 				else
 					var placer = new PathPlacer(floor(point[0]), floor(point[1]), floor(fractionToTiles(0.5 + 0.49*sin(tang))), floor(fractionToTiles(0.5 + 0.49*cos(tang))), scaleByMapSize(10,20), 0.4, 3*(scaleByMapSize(1,4)), 0.1, 0.05);
-					
-				
+
+
 				var terrainPainter = new LayeredPainter(
 					[tShore, tWater, tWater],		// terrains
 					[1, 3]								// widths
@@ -594,14 +590,14 @@ else if (md == 4) //central river
 						placer = new ClumpPlacer(floor(PI*scaleByMapSize(10,20)*scaleByMapSize(10,20)/4), 0.95, 0.6, 10, fractionToTiles(0.5 + 0.49*cos(tang)), fractionToTiles(0.5 + 0.49*sin(tang)));
 					else
 						placer = new ClumpPlacer(floor(PI*scaleByMapSize(10,20)*scaleByMapSize(10,20)/4), 0.95, 0.6, 10, fractionToTiles(0.5 + 0.49*sin(tang)), fractionToTiles(0.5 + 0.49*cos(tang)));
-						
+
 					var painter = new LayeredPainter([tWater, tWater], [1]);
 					var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, -4, 2);
 					createArea(placer, [painter, elevationPainter], avoidClasses(clPlayer, 3));
 				}
 			}
 		}
-		
+
 		if (mdd1 == 1)
 		{
 			passageMaker(floor(fractionToTiles(0.2)), floor(fractionToTiles(0.25)), floor(fractionToTiles(0.8)), floor(fractionToTiles(0.25)), scaleByMapSize(4,8), -2, -2, 2, clShallow, undefined, -4);
@@ -638,7 +634,7 @@ else if (md == 5) //rivers and lake
 		playerAngle[i] = startAngle + i*TWO_PI/numPlayers;
 		playerX[i] = 0.5 + 0.35*cos(playerAngle[i]);
 		playerZ[i] = 0.5 + 0.35*sin(playerAngle[i]);
-		
+
 		var fx = fractionToTiles(playerX[i]);
 		var fz = fractionToTiles(playerZ[i]);
 		var ix = round(fx);
@@ -649,7 +645,7 @@ else if (md == 5) //rivers and lake
 		addToClass(ix-5, iz, clPlayer);
 		addToClass(ix, iz-5, clPlayer);
 	}
-	
+
 
 
 	for (var ix = 0; ix < mapSize; ix++)
@@ -682,7 +678,7 @@ else if (md == 5) //rivers and lake
 			4				// blend radius
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clWater)], null);
-		
+
 		// create shore jaggedness
 		log("Creating shore jaggedness...");
 
@@ -694,12 +690,12 @@ else if (md == 5) //rivers and lake
 		elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 3, 4);
 		createAreas(
 			placer,
-			[terrainPainter, elevationPainter, unPaintClass(clWater)], 
+			[terrainPainter, elevationPainter, unPaintClass(clWater)],
 			borderClasses(clWater, 4, 7),
 			scaleByMapSize(12, 130) * 2, 150
 		);
 	}
-	
+
 	if ((randInt(1,3) == 1)&&(mdd1 == 1))//island
 	{
 		var placer = new ClumpPlacer(mapArea * 0.006 * lSize, 0.7, 0.1, 10, ix, iz);
@@ -730,7 +726,7 @@ else if (md == 6) //edge seas
 	}
 
 	var mdd1 = randInt(1,2);
-	
+
 	// randomize player order
 	var playerIDs = [];
 	for (var i = 0; i < numPlayers; i++)
@@ -758,7 +754,7 @@ else if (md == 6) //edge seas
 			playerX[i] = 0.4 + 0.2*(i%2);
 			playerZ[i] = playerPos[i];
 		}
-		
+
 		var fx = fractionToTiles(playerX[i]);
 		var fz = fractionToTiles(playerZ[i]);
 		var ix = round(fx);
@@ -769,10 +765,10 @@ else if (md == 6) //edge seas
 		addToClass(ix-5, iz, clPlayer);
 		addToClass(ix, iz-5, clPlayer);
 	}
-	
+
 	var mdd2 = randInt(1,3);
 	var fadedistance = 7;
-	
+
 	if (mdd1 == 1)
 	{
 		if ((mdd2 == 1)||(mdd2 == 3))
@@ -797,7 +793,7 @@ else if (md == 6) //edge seas
 						}
 					}
 				}
-				
+
 			}
 		}
 		if ((mdd2 == 2)||(mdd2 == 3))
@@ -876,7 +872,7 @@ else if (md == 6) //edge seas
 			}
 		}
 	}
-	
+
 	// create shore jaggedness
 	log("Creating shore jaggedness...");
 	placer = new ChainPlacer(2, floor(scaleByMapSize(4, 6)), 3, 1);
@@ -887,7 +883,7 @@ else if (md == 6) //edge seas
 	elevationPainter = new SmoothElevationPainter(ELEVATION_SET, -5, 4);
 	createAreas(
 		placer,
-		[terrainPainter, elevationPainter, paintClass(clWater)], 
+		[terrainPainter, elevationPainter, paintClass(clWater)],
 		[avoidClasses(clPlayer, 20), borderClasses(clWater, 6, 4)],
 		scaleByMapSize(7, 130) * 2, 150
 	);
@@ -900,11 +896,11 @@ else if (md == 6) //edge seas
 	elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 3, 4);
 	createAreas(
 		placer,
-		[terrainPainter, elevationPainter, unPaintClass(clWater)], 
+		[terrainPainter, elevationPainter, unPaintClass(clWater)],
 		borderClasses(clWater, 4, 7),
 		scaleByMapSize(12, 130) * 2, 150
 	);
-	
+
 	var mdd3 = randInt(1,5);
 	if (mdd3 == 1)
 	{
@@ -918,7 +914,7 @@ else if (md == 6) //edge seas
 		elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 3.1, 4);
 		createAreas(
 			placer,
-			[terrainPainter, elevationPainter, paintClass(clLand)], 
+			[terrainPainter, elevationPainter, paintClass(clLand)],
 			avoidClasses(clLand, 3, clPlayer, 3),
 			scaleByMapSize(2, 5)*randInt(8,14)
 		);
@@ -935,7 +931,7 @@ else if (md == 6) //edge seas
 		elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 3.1, 4);
 		createAreas(
 			placer,
-			[terrainPainter, elevationPainter, paintClass(clLand)], 
+			[terrainPainter, elevationPainter, paintClass(clLand)],
 			null,
 			scaleByMapSize(2, 5)*randInt(8,14)
 		);
@@ -954,9 +950,9 @@ else if (md == 7) //gulf
 				setHeight(ix, iz, 3);
 		}
 	}
-	
+
 	var mdd1 = randFloat(0,4);
-	
+
 	// randomize player order
 	var playerIDs = [];
 	for (var i = 0; i < numPlayers; i++)
@@ -990,7 +986,7 @@ else if (md == 7) //gulf
 		placer = new ClumpPlacer(PI*cityRadius*cityRadius, 0.6, 0.3, 10, ix, iz);
 		createArea(placer, paintClass(clPlayer), null);
 	}
-	
+
 	fx = fractionToTiles(0.5);
 	fz = fractionToTiles(0.5);
 	ix = round(fx);
@@ -1047,7 +1043,7 @@ else if (md == 7) //gulf
 		-3,				// elevation
 		4				// blend radius
 	);
-	createArea(placer, [terrainPainter, elevationPainter, paintClass(clWater)], avoidClasses(clPlayer,floor(scaleByMapSize(15,25))));	
+	createArea(placer, [terrainPainter, elevationPainter, paintClass(clWater)], avoidClasses(clPlayer,floor(scaleByMapSize(15,25))));
 }
 //********************************************************************************************************
 else if (md == 8) //lakes
@@ -1084,7 +1080,7 @@ else if (md == 8) //lakes
 				setHeight(ix, iz, 3);
 		}
 	}
-	
+
 	for (var i = 0; i < numPlayers; i++)
 	{
 		var fx = fractionToTiles(playerX[i]);
@@ -1096,7 +1092,7 @@ else if (md == 8) //lakes
 		placer = new ClumpPlacer(PI*cityRadius*cityRadius, 0.6, 0.3, 10, ix, iz);
 		createArea(placer, paintClass(clPlayer), null);
 	}
-	
+
 	var lakeAreas = [];
 	var playerConstraint = new AvoidTileClassConstraint(clPlayer, 20);
 	var waterConstraint = new AvoidTileClassConstraint(clWater, 8);
@@ -1112,13 +1108,13 @@ else if (md == 8) //lakes
 	// create lakes
 	log("Creating lakes...");
 
-	var numLakes = scaleByMapSize(5, 16)
+	var numLakes = scaleByMapSize(5, 16);
 	for (var i = 0; i < numLakes; ++i)
 	{
 		lakeAreaLen = lakeAreas.length;
 		if (!lakeAreaLen)
 			break;
-		
+
 		chosenPoint = lakeAreas[randInt(lakeAreaLen)];
 
 		placer = new ChainPlacer(1, floor(scaleByMapSize(4, 8)), floor(scaleByMapSize(40, 180)), 0.7, chosenPoint[0], chosenPoint[1]);
@@ -1129,7 +1125,7 @@ else if (md == 8) //lakes
 		elevationPainter = new SmoothElevationPainter(ELEVATION_SET, -5, 5);
 		var newLake = createAreas(
 			placer,
-			[terrainPainter, elevationPainter, paintClass(clWater)], 
+			[terrainPainter, elevationPainter, paintClass(clWater)],
 			avoidClasses(clPlayer, 20, clWater, 8),
 			1, 1
 		);
@@ -1144,7 +1140,7 @@ else if (md == 8) //lakes
 					lakeAreas[n++] = lakeAreas[j];
 			}
 			lakeAreas.length = n;
-		}		
+		}
 	}
 }
 //********************************************************************************************************
@@ -1182,7 +1178,7 @@ else if (md == 9) //passes
 				setHeight(ix, iz, 3);
 		}
 	}
-	
+
 	//create ranges
 	log ("Creating ranges...");
 	for (var m = 0; m < numPlayers; m++)
@@ -1203,7 +1199,7 @@ else if (md == 9) //passes
 		var painter = new LayeredPainter([tWater, tWater], [1]);
 		var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 24, 0);
 		createArea(placer, [painter, elevationPainter], avoidClasses(clPlayer, 5));
-			
+
 		var placer = new PathPlacer(fractionToTiles(0.5 + 0.3*cos(tang) - 0.1 * cos(tang+PI/2)), fractionToTiles(0.5 + 0.3*sin(tang) - 0.1 * sin(tang+PI/2)), fractionToTiles(0.5 + 0.3*cos(tang) + 0.1 * cos(tang+PI/2)), fractionToTiles(0.5 + 0.3*sin(tang) + 0.1 * sin(tang+PI/2)), scaleByMapSize(14,24), 0.4, 3*(scaleByMapSize(1,3)), 0.2, 0.05);
 		var painter = new LayeredPainter([tCliff, tCliff], [1]);
 		var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 3, 2);
@@ -1216,7 +1212,7 @@ else if (md == 9) //passes
 		var fz = fractionToTiles(0.5);
 		ix = round(fx);
 		iz = round(fz);
-			
+
 		var placer = new ClumpPlacer(mapArea * 0.005, 0.7, 0.1, 10, ix, iz);
 		var terrainPainter = new LayeredPainter(
 			[tShore, tWater, tWater, tWater],		// terrains
@@ -1285,13 +1281,13 @@ else if (md == 10) //lowlands
 				setHeight(ix, iz, 30);
 		}
 	}
-	
-	
+
+
 	var radius = scaleByMapSize(18,32);
 	var cliffRadius = 2;
 	var elevation = 20;
 	var hillSize = PI * radius * radius;
-	
+
 	var split = 1;
 	if ((mapSize / 64 == 2)&&(numPlayers <= 2))
 	{
@@ -1317,7 +1313,7 @@ else if (md == 10) //lowlands
 	{
 		split = 2;
 	}
-	
+
 	for (var i = 0; i < numPlayers*split; i++)
 	{
 		var tang = startAngle + (i)*TWO_PI/(numPlayers*split);
@@ -1338,7 +1334,7 @@ else if (md == 10) //lowlands
 		);
 		createArea(placer, [terrainPainter, elevationPainter, paintClass(clLand)], null);
 	}
-	
+
 	var fx = fractionToTiles(0.5);
 	var fz = fractionToTiles(0.5);
 	ix = round(fx);
@@ -1357,7 +1353,7 @@ else if (md == 10) //lowlands
 		4				// blend radius
 	);
 	createArea(placer, [terrainPainter, elevationPainter, paintClass(clWater)], null);
-	
+
 	for (var m = 0; m < numPlayers*split; m++)
 	{
 		var tang = startAngle + m*TWO_PI/(numPlayers*split);
@@ -1426,7 +1422,7 @@ for (var i = 0; i < numPlayers; i++)
 {
 	var id = playerIDs[i];
 	log("Creating base for player " + id + "...");
-	
+
 	// some constants
 	var radius = scaleByMapSize(17,29);
 	var shoreRadius = 4;
@@ -1438,30 +1434,18 @@ for (var i = 0; i < numPlayers; i++)
 	var fz = fractionToTiles(playerZ[i]);
 	var ix = round(fx);
 	var iz = round(fz);
-	
+
 	// create starting units
-	placeCivDefaultEntities(fx, fz, id, BUILDING_ANGlE);
-	
-	// create animals
-	for (var j = 0; j < 2; ++j)
-	{
-		var aAngle = randFloat(0, TWO_PI);
-		var aDist = 7;
-		var aX = round(fx + aDist * cos(aAngle));
-		var aZ = round(fz + aDist * sin(aAngle));
-		var group = new SimpleGroup(
-			[new SimpleObject(oChicken, 5,5, 0,2)],
-			true, clBaseResource, aX, aZ
-		);
-		createObjectGroup(group, 0);
-	}
-	
+	placeCivDefaultEntities(fx, fz, id);
+
+	placeDefaultChicken(fx, fz, clBaseResource);
+
 	// create berry bushes
 	var bbAngle = randFloat(0, TWO_PI);
 	var bbDist = 12;
 	var bbX = round(fx + bbDist * cos(bbAngle));
 	var bbZ = round(fz + bbDist * sin(bbAngle));
-	group = new SimpleGroup(
+	var group = new SimpleGroup(
 		[new SimpleObject(oFruitBush, 5,5, 0,3)],
 		true, clBaseResource, bbX, bbZ
 	);
@@ -1479,7 +1463,7 @@ for (var i = 0; i < numPlayers; i++)
 		);
 		createObjectGroup(group, 0);
 	}
-	
+
 	// create metal mine
 	var mAngle = bbAngle;
 	while(abs(mAngle - bbAngle) < PI/3)
@@ -1494,7 +1478,7 @@ for (var i = 0; i < numPlayers; i++)
 		true, clBaseResource, mX, mZ
 	);
 	createObjectGroup(group, 0);
-	
+
 	// create stone mines
 	mAngle += randFloat(PI/8, PI/4);
 	mX = round(fx + mDist * cos(mAngle));
@@ -1516,7 +1500,7 @@ for (var i = 0; i < numPlayers; i++)
 		false, clBaseResource, tX, tZ
 	);
 	createObjectGroup(group, 0, avoidClasses(clBaseResource,2));
-	
+
 	// create grass tufts
 	var num = hillSize / 250;
 	for (var j = 0; j < num; j++)
@@ -1552,7 +1536,7 @@ placer = new ClumpPlacer(scaleByMapSize(20, 50), 0.3, 0.06, 1);
 painter = new SmoothElevationPainter(ELEVATION_MODIFY, 2, 2);
 createAreas(
 	placer,
-	painter, 
+	painter,
 	[avoidClasses(clWater, 2, clPlayer, 10), stayClasses(clLand, 3)],
 	randInt(0,scaleByMapSize(200, 400))
 );
@@ -1567,7 +1551,7 @@ terrainPainter = new LayeredPainter(
 elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 18, 2);
 createAreas(
 	placer,
-	[terrainPainter, elevationPainter, paintClass(clHill)], 
+	[terrainPainter, elevationPainter, paintClass(clHill)],
 	[avoidClasses(clPlayer, 20, clHill, randInt(6, 18)), stayClasses(clLand, 0)],
 	randInt(0, scaleByMapSize(4, 8))*randInt(1, scaleByMapSize(4, 9))
 );
@@ -1616,7 +1600,7 @@ if (random_terrain != g_BiomeSavanna)
 			);
 		createAreas(
 			placer,
-			[painter, paintClass(clForest)], 
+			[painter, paintClass(clForest)],
 			[avoidClasses(clPlayer, 20, clForest, randInt(5, 15), clHill, 0), stayClasses(clLand, 4)],
 			num
 		);
@@ -1629,7 +1613,7 @@ log("Creating dirt patches...");
 var sizes = [scaleByMapSize(3, 6), scaleByMapSize(5, 10), scaleByMapSize(8, 21)];
 var numb = 1;
 if (random_terrain == 6)
-	numb = 3
+	numb = 3;
 for (var i = 0; i < sizes.length; i++)
 {
 	placer = new ChainPlacer(1, floor(scaleByMapSize(3, 5)), sizes[i], 0.5);
@@ -1827,25 +1811,20 @@ createObjectGroups(group, 0,
 	planetm * scaleByMapSize(13, 200), 50
 );
 
-random_terrain = randInt(1,6)
-if (random_terrain==1){
+random_terrain = randInt(1,6);
+if (random_terrain == 1)
 	setSkySet("cirrus");
-}
-else if (random_terrain ==2){
+else if (random_terrain == 2)
 	setSkySet("cumulus");
-}
-else if (random_terrain ==3){
+else if (random_terrain == 3)
 	setSkySet("sunny");
-}
-else if (random_terrain ==4){
+else if (random_terrain == 4)
 	setSkySet("sunny 1");
-}
-else if (random_terrain ==5){
+else if (random_terrain == 5)
 	setSkySet("mountainous");
-}
-else if (random_terrain ==6){
+else if (random_terrain == 6)
 	setSkySet("stratus");
-}
+
 setSunRotation(randFloat(0, TWO_PI));
 setSunElevation(randFloat(PI/ 5, PI / 3));
 
