@@ -16,6 +16,7 @@ const ACTION_NONE = 0;
 const ACTION_GARRISON = 1;
 const ACTION_REPAIR = 2;
 const ACTION_GUARD = 3;
+const ACTION_PATROL = 4;
 var preSelectedAction = ACTION_NONE;
 
 const INPUT_NORMAL = 0;
@@ -205,10 +206,16 @@ function getActionInfo(action, target)
 				data.targetClasses = Engine.HotkeyIsPressed("session.attackmoveUnit") ? { "attack": ["Unit"] } : { "attack": ["Unit", "Structure"] };
 				cursor = "action-attack-move";
 			}
+			else if (Engine.HotkeyIsPressed("session.patrol"))
+			{
+				data.command = "patrol";
+				data.targetClasses = { "attack": ["Unit"] };
+				cursor = "action-patrol";
+			}
 			return { "possible": true, "data": data, "cursor": cursor };
 		}
 
-		return { "possible": (action == "move" || action == "attack-move" || action == "remove-guard") };
+		return { "possible": ["move", "attack-move", "remove-guard", "patrol"].indexOf(action) > -1 };
 	}
 
 	// Look at the first targeted entity
@@ -219,7 +226,7 @@ function getActionInfo(action, target)
 	// Check if the target entity is a resource, dropsite, foundation, or enemy unit.
 	// Check if any entities in the selection can gather the requested resource,
 	// can return to the dropsite, can build the foundation, or can attack the enemy
-	for each (var entityID in selection)
+	for (let entityID of selection)
 	{
 		var entState = GetExtendedEntityState(entityID);
 		if (!entState)
@@ -228,7 +235,7 @@ function getActionInfo(action, target)
 		if (unitActions[action] && unitActions[action].getActionInfo)
 		{
 			var r = unitActions[action].getActionInfo(entState, targetState, simState);
-			if (r) // return true if it's possible for one of the entities
+			if (r && r.possible) // return true if it's possible for one of the entities
 				return r;
 		}
 	}
@@ -255,7 +262,7 @@ function determineAction(x, y, fromMinimap)
 		return undefined;
 
 	// If the selection isn't friendly units, no action
-	var allOwnedByPlayer = selection.every(function(ent) {
+	var allOwnedByPlayer = selection.every(ent => {
 		var entState = GetEntityState(ent);
 		return entState && entState.player == g_ViewedPlayer;
 	});
@@ -339,7 +346,6 @@ function tryPlaceBuilding(queued)
 
 	var selection = g_Selection.toList();
 
-	// Start the construction
 	Engine.PostNetworkCommand({
 		"type": "construct",
 		"template": placementSupport.template,
@@ -442,31 +448,29 @@ function updateBandbox(bandbox, ev, hidden)
 
 // Define some useful unit filters for getPreferredEntities
 var unitFilters = {
-	"isUnit": function (entity) {
+	"isUnit": entity => {
 		var entState = GetEntityState(entity);
-		if (!entState)
-			return false;
-		return hasClass(entState, "Unit");
+		return entState && hasClass(entState, "Unit");
 	},
-	"isDefensive": function (entity) {
+	"isDefensive": entity => {
 		var entState = GetEntityState(entity);
-		if (!entState)
-			return false;
-		return hasClass(entState, "Defensive");
+		return entState && hasClass(entState, "Defensive");
 	},
-	"isNotSupport": function (entity) {
+	"isMilitary": entity => {
 		var entState = GetEntityState(entity);
-		if (!entState)
-			return false;
-		return hasClass(entState, "Unit") && !hasClass(entState, "Support") && !hasClass(entState, "Domestic");
+		return entState &&
+			g_MilitaryTypes.some(c => hasClass(entState, c));
 	},
-	"isIdle": function (entity) {
+	"isIdle": entity => {
 		var entState = GetEntityState(entity);
-		if (!entState)
-			return false;
-		return hasClass(entState, "Unit") && entState.unitAI && entState.unitAI.isIdle;
+
+		return entState &&
+			hasClass(entState, "Unit") &&
+			entState.unitAI &&
+			entState.unitAI.isIdle &&
+			!hasClass(entState, "Domestic");
 	},
-	"isAnything": function (entity) {
+	"isAnything": entity => {
 		return true;
 	}
 };
@@ -480,7 +484,7 @@ function getPreferredEntities(ents)
 
 	// Handle hotkeys
 	if (Engine.HotkeyIsPressed("selection.milonly"))
-		filters = [unitFilters.isNotSupport];
+		filters = [unitFilters.isMilitary];
 	if (Engine.HotkeyIsPressed("selection.idleonly"))
 		filters = [unitFilters.isIdle];
 
@@ -488,7 +492,7 @@ function getPreferredEntities(ents)
 	for (var i = 0; i < filters.length; ++i)
 	{
 		preferredEnts = ents.filter(filters[i]);
-		if (preferredEnts.length > 0)
+		if (preferredEnts.length)
 			break;
 	}
 	return preferredEnts;
@@ -534,7 +538,7 @@ function handleInputBeforeGui(ev, hoveredObject)
 		case "mousemotion":
 			var rect = updateBandbox(bandbox, ev, false);
 
-			var ents = Engine.PickPlayerEntitiesInRect(rect[0], rect[1], rect[2], rect[3], g_IsObserver ? -1 : Engine.GetPlayerID());
+			var ents = Engine.PickPlayerEntitiesInRect(rect[0], rect[1], rect[2], rect[3], g_ViewedPlayer);
 			var preferredEntities = getPreferredEntities(ents);
 			g_Selection.setHighlightList(preferredEntities);
 
@@ -546,7 +550,7 @@ function handleInputBeforeGui(ev, hoveredObject)
 				var rect = updateBandbox(bandbox, ev, true);
 
 				// Get list of entities limited to preferred entities
-				var ents = getPreferredEntities(Engine.PickPlayerEntitiesInRect(rect[0], rect[1], rect[2], rect[3], g_IsObserver ? -1 : Engine.GetPlayerID()));
+				var ents = getPreferredEntities(Engine.PickPlayerEntitiesInRect(rect[0], rect[1], rect[2], rect[3], g_ViewedPlayer));
 
 				// Remove the bandbox hover highlighting
 				g_Selection.setHighlightList([]);
@@ -683,10 +687,11 @@ function handleInputBeforeGui(ev, hoveredObject)
 
 				if (result && result.cost)
 				{
-					placementSupport.tooltipMessage = getEntityCostTooltip(result);
 					var neededResources = Engine.GuiInterfaceCall("GetNeededResources", { "cost": result.cost });
-					if (neededResources)
-						placementSupport.tooltipMessage += getNeededResourcesTooltip(neededResources);
+					placementSupport.tooltipMessage = [
+						getEntityCostTooltip(result),
+						getNeededResourcesTooltip(neededResources)
+					].filter(tip => tip).join("\n");
 				}
 
 				break;
@@ -712,9 +717,7 @@ function handleInputBeforeGui(ev, hoveredObject)
 						}
 					}
 					else
-					{
 						placementSupport.tooltipMessage = translate("Cannot build wall here!");
-					}
 
 					updateBuildingPlacementPreview();
 					return true;
@@ -927,8 +930,11 @@ function handleInputAfterGui(ev)
 				var action = determineAction(ev.x, ev.y);
 				if (!action)
 					break;
-				preSelectedAction = ACTION_NONE;
-				inputState = INPUT_NORMAL;
+				if (!Engine.HotkeyIsPressed("session.queue"))
+				{
+					preSelectedAction = ACTION_NONE;
+					inputState = INPUT_NORMAL;
+				}
 				return doAction(action, ev);
 			}
 			else if (ev.button == SDL_BUTTON_RIGHT && preSelectedAction != ACTION_NONE)
@@ -1226,18 +1232,6 @@ function startBuildingPlacement(buildTemplate, playerState)
 	}
 }
 
-// Called by GUI when user changes required trading goods
-function selectRequiredGoods(data)
-{
-	Engine.PostNetworkCommand({ "type": "select-required-goods", "entities": data.entities, "requiredGoods": data.requiredGoods} );
-}
-
-// Called by GUI when user clicks exchange resources button
-function exchangeResources(command)
-{
-	Engine.PostNetworkCommand({ "type": "barter", "sell": command.sell, "buy": command.buy, "amount": command.amount });
-}
-
 // Camera jumping: when the user presses a hotkey the current camera location is marked.
 // When they press another hotkey the camera jumps back to that position. If the camera is already roughly at that location,
 // jump back to where it was previously.
@@ -1274,7 +1268,6 @@ var batchTrainingEntities;
 var batchTrainingType;
 var batchTrainingCount;
 var batchTrainingEntityAllowedCount;
-const batchIncrementSize = 5;
 
 function flushTrainingBatch()
 {
@@ -1312,7 +1305,7 @@ function flushTrainingBatch()
 
 function getBuildingsWhichCanTrainEntity(entitiesToCheck, trainEntType)
 {
-	return entitiesToCheck.filter(function(entity) {
+	return entitiesToCheck.filter(entity => {
 		var state = GetEntityState(entity);
 		var canTrain = state && state.production && state.production.entities.length &&
 			state.production.entities.indexOf(trainEntType) != -1;
@@ -1384,6 +1377,8 @@ function addTrainingToQueue(selection, trainEntType, playerState)
 	if (!decrement)
 		var template = GetTemplateData(trainEntType);
 
+	let batchIncrementSize = +Engine.ConfigDB_GetValue("user", "gui.session.batchtrainingsize");
+
 	if (Engine.HotkeyIsPressed("session.batchtrain") && batchTrainingPossible)
 	{
 		if (inputState == INPUT_BATCHTRAINING)
@@ -1463,43 +1458,47 @@ function addResearchToQueue(entity, researchType)
 	Engine.PostNetworkCommand({ "type": "research", "entity": entity, "template": researchType });
 }
 
-// Returns the number of units that will be present in a batch if the user clicks
-// the training button with shift down
-function getTrainingBatchStatus(playerState, entity, trainEntType, selection)
+/**
+ * Returns the number of units that will be present in a batch if the user clicks
+ * the training button with shift down
+ */
+function getTrainingBatchStatus(playerState, trainEntType, selection)
 {
-	var appropriateBuildings = [entity];
-	if (selection && selection.indexOf(entity) != -1)
+	let batchIncrementSize = +Engine.ConfigDB_GetValue("user", "gui.session.batchtrainingsize");
+	var appropriateBuildings = [];
+	if (selection)
 		appropriateBuildings = getBuildingsWhichCanTrainEntity(selection, trainEntType);
 	var nextBatchTrainingCount = 0;
 	var currentBatchTrainingCount = 0;
 
-	if (inputState == INPUT_BATCHTRAINING && batchTrainingEntities.indexOf(entity) != -1 &&
-		batchTrainingType == trainEntType)
+	var limits;
+	if (inputState == INPUT_BATCHTRAINING && batchTrainingType == trainEntType)
 	{
 		nextBatchTrainingCount = batchTrainingCount;
 		currentBatchTrainingCount = batchTrainingCount;
-		var limits = {
+		limits = {
 			"canBeAddedCount": batchTrainingEntityAllowedCount
 		};
 	}
 	else
-	{
-		var limits = getEntityLimitAndCount(playerState, trainEntType);
-	}
+		limits = getEntityLimitAndCount(playerState, trainEntType);
+
 	// We need to calculate count after the next increment if it's possible
 	if (limits.canBeAddedCount == undefined ||
 		limits.canBeAddedCount > nextBatchTrainingCount * appropriateBuildings.length)
 		nextBatchTrainingCount += batchIncrementSize;
+
 	// If training limits don't allow us to train batchTrainingCount in each appropriate building
 	// train as many full batches as we can and remainer in one more building.
 	var buildingsCountToTrainFullBatch = appropriateBuildings.length;
 	var remainderToTrain = 0;
 	if (limits.canBeAddedCount !== undefined &&
-		limits.canBeAddedCount < nextBatchTrainingCount * appropriateBuildings.length)
+	    limits.canBeAddedCount < nextBatchTrainingCount * appropriateBuildings.length)
 	{
 		buildingsCountToTrainFullBatch = Math.floor(limits.canBeAddedCount / nextBatchTrainingCount);
 		remainderToTrain = limits.canBeAddedCount % nextBatchTrainingCount;
 	}
+
 	return [buildingsCountToTrainFullBatch, nextBatchTrainingCount, remainderToTrain, currentBatchTrainingCount];
 }
 
@@ -1515,21 +1514,19 @@ function changePrimarySelectionGroup(templateName, deselectGroup)
 	g_Selection.makePrimarySelection(templateName, Engine.HotkeyIsPressed("session.deselectgroup") || deselectGroup);
 }
 
-// Performs the specified command (delete, town bell, repair, etc.)
-function performCommand(entity, commandName)
+function performCommand(entState, commandName)
 {
-	if (!entity)
+	if (!entState)
 		return;
-	var entState = GetExtendedEntityState(entity);
 
-	if (!controlsPlayer(entState.player))
+	if (!controlsPlayer(entState.player) &&
+	    !(g_IsObserver && commandName == "focus-rally"))
 		return;
 
 	if (g_EntityCommands[commandName])
 		g_EntityCommands[commandName].execute(entState);
 }
 
-// Performs the specified command for ally unit
 function performAllyCommand(entity, commandName)
 {
 	if (!entity)
@@ -1544,18 +1541,16 @@ function performAllyCommand(entity, commandName)
 		g_AllyEntityCommands[commandName].execute(entState);
 }
 
-// Performs the specified formation
-function performFormation(entity, formationTemplate)
+function performFormation(entities, formationTemplate)
 {
-	if (entity)
+	if (entities)
 		Engine.PostNetworkCommand({
 			"type": "formation",
-			"entities": g_Selection.toList(),
+			"entities": entities,
 			"name": formationTemplate
 		});
 }
 
-// Performs the specified group
 function performGroup(action, groupId)
 {
 	switch (action)
@@ -1592,21 +1587,17 @@ function performGroup(action, groupId)
 		break;
 	}
 }
-// Performs the specified stance
-function performStance(entity, stanceName)
+
+function performStance(entities, stanceName)
 {
-	if (entity)
-	{
-		var selection = g_Selection.toList();
+	if (entities)
 		Engine.PostNetworkCommand({
 			"type": "stance",
-			"entities": selection,
+			"entities": entities,
 			"name": stanceName
 		});
-	}
 }
 
-// Lock / Unlock the gate
 function lockGate(lock)
 {
 	var selection = g_Selection.toList();
@@ -1617,7 +1608,6 @@ function lockGate(lock)
 	});
 }
 
-// Pack / unpack unit(s)
 function packUnit(pack)
 {
 	var selection = g_Selection.toList();
@@ -1629,7 +1619,6 @@ function packUnit(pack)
 	});
 }
 
-// Cancel un/packing unit(s)
 function cancelPackUnit(pack)
 {
 	var selection = g_Selection.toList();
@@ -1641,27 +1630,23 @@ function cancelPackUnit(pack)
 	});
 }
 
-// Transform a wall to a gate
-function transformWallToGate(template)
+function upgradeEntity(Template)
 {
-	var selection = g_Selection.toList();
 	Engine.PostNetworkCommand({
-		"type": "wall-to-gate",
-		"entities": selection.filter( function(e) { return getWallGateTemplate(e) == template; } ),
-		"template": template,
+		"type": "upgrade",
+		"entities": g_Selection.toList(),
+		"template": Template,
+		"queued": false
 	});
 }
 
-// Gets the gate form (if any) of a given long wall piece
-function getWallGateTemplate(entity)
+function cancelUpgradeEntity()
 {
-	// TODO: find the gate template name in a better way
-	var entState = GetEntityState(entity);
-	var index;
-
-	if (entState && !entState.foundation && hasClass(entState, "LongWall") && (index = entState.template.indexOf("long")) >= 0)
-		return entState.template.substr(0, index) + "gate";
-	return undefined;
+	Engine.PostNetworkCommand({
+		"type": "cancel-upgrade",
+		"entities": g_Selection.toList(),
+		"queued": false
+	});
 }
 
 // Set the camera to follow the given unit
@@ -1683,14 +1668,14 @@ function setCameraFollow(entity)
 }
 
 var lastIdleUnit = 0;
-var currIdleClass = 0;
-var lastIdleType = undefined;
+var currIdleClassIndex = 0;
+var lastIdleClasses = [];
 
 function resetIdleUnit()
 {
 	lastIdleUnit = 0;
-	currIdleClass = 0;
-	lastIdleType = undefined;
+	currIdleClassIndex = 0;
+	lastIdleClasses = [];
 }
 
 function findIdleUnit(classes)
@@ -1699,61 +1684,46 @@ function findIdleUnit(classes)
 	var selectall = Engine.HotkeyIsPressed("selection.offscreen");
 
 	// Reset the last idle unit, etc., if the selection type has changed.
-	var type = classes.join();
-	if (selectall || type != lastIdleType)
+	if (selectall || classes.length != lastIdleClasses.length || !classes.every((v,i) => v === lastIdleClasses[i]))
 		resetIdleUnit();
-	lastIdleType = type;
+	lastIdleClasses = classes;
 
-	// If selectall is true, there is no limit and it's necessary to iterate
-	// over all of the classes, resetting only when the first match is found.
-	var matched = false;
-
-	for (var i = 0; i < classes.length; ++i)
+	var data = {
+		"viewedPlayer": g_ViewedPlayer,
+		"excludeUnits": append ? g_Selection.toList() : [],
+		// If the current idle class index is not 0, put the class at that index first.
+		"idleClasses": classes.slice(currIdleClassIndex, classes.length).concat(classes.slice(0, currIdleClassIndex))
+	};
+	if (!selectall)
 	{
-		var data = {
-			"idleClass": classes[currIdleClass],
-			"prevUnit": lastIdleUnit,
-			"limit": 1,
-			"excludeUnits": []
-		};
-
-		if (append)
-			data.excludeUnits = g_Selection.toList();
-
-		if (selectall)
-			data = { "idleClass": classes[currIdleClass] };
-
-		data.viewedPlayer = g_ViewedPlayer;
-
-		// Check if we have new valid entity
-		var idleUnits = Engine.GuiInterfaceCall("FindIdleUnits", data);
-		if (idleUnits.length && idleUnits[0] != lastIdleUnit)
-		{
-			lastIdleUnit = idleUnits[0];
-			if (!append && (!selectall || selectall && !matched))
-				g_Selection.reset();
-
-			if (selectall)
-				g_Selection.addList(idleUnits);
-			else
-			{
-				g_Selection.addList([lastIdleUnit]);
-				var position = GetEntityState(lastIdleUnit).position;
-				if (position)
-					Engine.CameraMoveTo(position.x, position.z);
-				return;
-			}
-
-			matched = true;
-		}
-
-		lastIdleUnit = 0;
-		currIdleClass = (currIdleClass + 1) % classes.length;
+		data.limit = 1;
+		data.prevUnit = lastIdleUnit;
 	}
 
-	// TODO: display a message or play a sound to indicate no more idle units, or something
-	// Reset for next cycle
-	resetIdleUnit();
+	var idleUnits = Engine.GuiInterfaceCall("FindIdleUnits", data);
+	if (!idleUnits.length)
+	{
+		// TODO: display a message or play a sound to indicate no more idle units, or something
+		// Reset for next cycle
+		resetIdleUnit();
+		return;
+	}
+
+	if (!append)
+		g_Selection.reset();
+	g_Selection.addList(idleUnits);
+
+	if (selectall)
+		return;
+
+	lastIdleUnit = idleUnits[0];
+	var entityState = GetEntityState(lastIdleUnit);
+	var position = entityState.position;
+	if (position)
+		Engine.CameraMoveTo(position.x, position.z);
+	// Move the idle class index to the first class an idle unit was found for.
+	var indexChange = data.idleClasses.findIndex(elem => hasClass(entityState, elem));
+	currIdleClassIndex = (currIdleClassIndex + indexChange) % classes.length;
 }
 
 function stopUnits(entities)
@@ -1772,7 +1742,7 @@ function unload(garrisonHolder, entities)
 function unloadTemplate(template)
 {
 	// Filter out all entities that aren't garrisonable.
-	var garrisonHolders = g_Selection.toList().filter(function(e) {
+	var garrisonHolders = g_Selection.toList().filter(e => {
 		var state = GetEntityState(e);
 		if (state && state.garrisonHolder)
 			return true;
@@ -1810,7 +1780,7 @@ function unloadSelection()
 
 function unloadAllByOwner()
 {
-	var garrisonHolders = g_Selection.toList().filter(function(e) {
+	var garrisonHolders = g_Selection.toList().filter(e => {
 		var state = GetEntityState(e);
 		return state && state.garrisonHolder;
 	});
@@ -1820,11 +1790,9 @@ function unloadAllByOwner()
 function unloadAll()
 {
 	// Filter out all entities that aren't garrisonable.
-	var garrisonHolders = g_Selection.toList().filter(function(e) {
+	var garrisonHolders = g_Selection.toList().filter(e => {
 		var state = GetEntityState(e);
-		if (state && state.garrisonHolder)
-			return true;
-		return false;
+		return state && state.garrisonHolder;
 	});
 
 	Engine.PostNetworkCommand({ "type": "unload-all", "garrisonHolders": garrisonHolders });
@@ -1833,9 +1801,9 @@ function unloadAll()
 function backToWork()
 {
 	// Filter out all entities that can't go back to work.
-	var workers = g_Selection.toList().filter(function(e) {
+	var workers = g_Selection.toList().filter(e => {
 		var state = GetEntityState(e);
-		return (state && state.unitAI && state.unitAI.hasWorkOrders);
+		return state && state.unitAI && state.unitAI.hasWorkOrders;
 	});
 
 	Engine.PostNetworkCommand({ "type": "back-to-work", "entities": workers });
@@ -1844,19 +1812,31 @@ function backToWork()
 function removeGuard()
 {
 	// Filter out all entities that are currently guarding/escorting.
-	var entities = g_Selection.toList().filter(function(e) {
+	var entities = g_Selection.toList().filter(e => {
 		var state = GetEntityState(e);
-		return (state && state.unitAI && state.unitAI.isGuarding);
+		return state && state.unitAI && state.unitAI.isGuarding;
 	});
 
 	Engine.PostNetworkCommand({ "type": "remove-guard", "entities": entities });
 }
 
+function raiseAlert()
+{
+	let entities = g_Selection.toList().filter(e => {
+		let state = GetEntityState(e);
+		return state && state.alertRaiser && !state.alertRaiser.hasRaisedAlert;
+	});
+
+	Engine.PostNetworkCommand({ "type": "increase-alert-level", "entities": entities });
+}
+
 function increaseAlertLevel()
 {
-	var entities = g_Selection.toList().filter(function(e) {
-		var state = GetEntityState(e);
-		return (state && state.alertRaiser && state.alertRaiser.canIncreaseLevel);
+	raiseAlert();
+
+	let entities = g_Selection.toList().filter(e => {
+		let state = GetEntityState(e);
+		return state && state.alertRaiser && state.alertRaiser.canIncreaseLevel;
 	});
 
 	Engine.PostNetworkCommand({ "type": "increase-alert-level", "entities": entities });
@@ -1864,9 +1844,9 @@ function increaseAlertLevel()
 
 function endOfAlert()
 {
-	var entities = g_Selection.toList().filter(function(e) {
-		var state = GetEntityState(e);
-		return (state && state.alertRaiser && state.alertRaiser.hasRaisedAlert);
+	let entities = g_Selection.toList().filter(e => {
+		let state = GetEntityState(e);
+		return state && state.alertRaiser && state.alertRaiser.hasRaisedAlert;
 	});
 
 	Engine.PostNetworkCommand({ "type": "alert-end", "entities": entities });
@@ -1884,35 +1864,3 @@ function clearSelection()
 	preSelectedAction = ACTION_NONE;
 }
 
-/**
- * Returns a list of all items in the productionqueue of the selection
- * @param selection List with entity ids
- */
-function getTrainingQueueItems(selection)
-{
-	var entStates = [];
-	for (var ent of selection)
-	{
-		var entState = GetEntityState(ent);
-		if (entState.production)
-			entStates.push(entState);
-	}
-	var queue = [];
-	var i = 0;
-	do
-	{
-		var foundNewItems = false;
-		for (entState of entStates)
-		{
-			if (!entState.production.queue[i])
-				continue;
-			var item = entState.production.queue[i];
-			item.producingEnt = entState.id;
-			queue.push(item);
-			foundNewItems = true;
-		}
-		i++;
-	}
-	while (foundNewItems);
-	return queue;
-}
