@@ -35,6 +35,7 @@ var g_IsMenuOpen = false;
 
 var g_IsDiplomacyOpen = false;
 var g_IsTradeOpen = false;
+var g_IsObjectivesOpen = false;
 
 // Redefined every time someone makes a tribute (so we can save some data in a closure). Called in input.js handleInputBeforeGui.
 var g_FlushTributing = function() {};
@@ -49,7 +50,10 @@ function updateMenuPosition(dt)
 {
 	let menu = Engine.GetGUIObjectByName("menu");
 
-	let maxOffset = g_IsMenuOpen ? (END_MENU_POSITION - menu.size.bottom) : (menu.size.top - MENU_TOP);
+	let maxOffset = g_IsMenuOpen ?
+		END_MENU_POSITION - menu.size.bottom :
+		menu.size.top - MENU_TOP;
+
 	if (maxOffset <= 0)
 		return;
 
@@ -110,7 +114,6 @@ function resignMenuButton()
 		400, 200,
 		translate("Are you sure you want to resign?"),
 		translate("Confirmation"),
-		0,
 		[translate("No"), translate("Yes")],
 		[resumeGame, resignGame]
 	);
@@ -143,7 +146,6 @@ function exitMenuButton()
 		400, 200,
 		messageTypes[messageType].caption,
 		translate("Confirmation"),
-		0,
 		[translate("No"), translate("Yes")],
 		messageTypes[messageType].buttons
 	);
@@ -155,7 +157,6 @@ function resignQuestion()
 		400, 200,
 		translate("Do you want to resign or will you return soon?"),
 		translate("Confirmation"),
-		0,
 		[translate("I will return"), translate("I resign")],
 		[leaveGame, resignGame],
 		[true, false]
@@ -168,14 +169,16 @@ function openDeleteDialog(selection)
 
 	let deleteSelectedEntities = function (selectionArg)
 	{
-		Engine.PostNetworkCommand({ "type": "delete-entities", "entities": selectionArg });
+		Engine.PostNetworkCommand({
+			"type": "delete-entities",
+			"entities": selectionArg
+		});
 	};
 
 	messageBox(
 		400, 200,
 		translate("Destroy everything currently selected?"),
 		translate("Delete"),
-		0,
 		[translate("No"), translate("Yes")],
 		[resumeGame, deleteSelectedEntities],
 		[null, selection]
@@ -186,77 +189,109 @@ function openSave()
 {
 	closeOpenDialogs();
 	pauseGame();
-	Engine.PushGuiPage("page_savegame.xml", { "savedGameData": getSavedGameData(), "callback": "resumeGame" });
+
+	Engine.PushGuiPage("page_savegame.xml", {
+		"savedGameData": getSavedGameData(),
+		"callback": "resumeGame"
+	});
 }
 
 function openOptions()
 {
 	closeOpenDialogs();
 	pauseGame();
-	Engine.PushGuiPage("page_options.xml", { "callback": "resumeGame" });
+
+	Engine.PushGuiPage("page_options.xml", {
+		"callback": "resumeGame"
+	});
 }
 
-function openChat()
+function openChat(teamChat = false)
 {
 	if (g_Disconnected)
 		return;
 
 	closeOpenDialogs();
 
-	setTeamChat(false);
+	let chatAddressee = Engine.GetGUIObjectByName("chatAddressee");
+	let command = teamChat ? (g_IsObserver ? "/observers" : "/allies") : "";
+	chatAddressee.selected = chatAddressee.list_data.indexOf(command);
 
-	Engine.GetGUIObjectByName("chatInput").focus(); // Grant focus to the input area
+	Engine.GetGUIObjectByName("chatInput").focus();
 	Engine.GetGUIObjectByName("chatDialogPanel").hidden = false;
+
+	updateChatHistory();
 }
 
 function closeChat()
 {
-	Engine.GetGUIObjectByName("chatInput").caption = ""; // Clear chat input
+	Engine.GetGUIObjectByName("chatInput").caption = "";
 	Engine.GetGUIObjectByName("chatInput").blur(); // Remove focus
 	Engine.GetGUIObjectByName("chatDialogPanel").hidden = true;
 }
 
-/**
- * If the teamchat hotkey was pressed, set allies or observers as addressees,
- * otherwise send to everyone.
- */
-function setTeamChat(teamChat = false)
+function initChatWindow()
 {
-	let command = teamChat ? (g_IsObserver ? "/observers" : "/allies") : "";
-	let chatAddressee = Engine.GetGUIObjectByName("chatAddressee");
-	chatAddressee.selected = chatAddressee.list_data.indexOf(command);
+	let filters = prepareForDropdown(g_ChatHistoryFilters);
+	let chatHistoryFilter = Engine.GetGUIObjectByName("chatHistoryFilter");
+	chatHistoryFilter.list = filters.text;
+	chatHistoryFilter.list_data = filters.key;
+	chatHistoryFilter.selected = 0;
+
+	Engine.GetGUIObjectByName("extendedChat").checked =
+		Engine.ConfigDB_GetValue("user", "chat.session.extended") == "true";
+
+	resizeChatWindow();
 }
 
-/**
- * Opens chat-window or closes it and sends the userinput.
- */
-function toggleChatWindow(teamChat)
+function resizeChatWindow()
 {
-	if (g_Disconnected)
+	// Hide/show the panel
+	let chatHistoryPage = Engine.GetGUIObjectByName("chatHistoryPage");
+	let extended = Engine.GetGUIObjectByName("extendedChat").checked;
+	chatHistoryPage.hidden = !extended;
+
+	// Resize the window
+	let chatDialogPanel = Engine.GetGUIObjectByName("chatDialogPanel");
+	let chatPage = Engine.GetGUIObjectByName("chatPage");
+	let panelSize = chatDialogPanel.size;
+	let topOffset = 80;
+	let height = -chatPage.size.top + (extended ? chatHistoryPage.size.bottom : 0);
+	panelSize.top = -height / 2 - topOffset;
+	panelSize.bottom = height / 2 - topOffset;
+	chatDialogPanel.size = panelSize;
+}
+
+function updateChatHistory()
+{
+	if (Engine.GetGUIObjectByName("chatDialogPanel").hidden ||
+	    !Engine.GetGUIObjectByName("extendedChat").checked)
 		return;
 
-	let chatWindow = Engine.GetGUIObjectByName("chatDialogPanel");
-	let chatInput = Engine.GetGUIObjectByName("chatInput");
-	let hidden = chatWindow.hidden;
+	let chatHistoryFilter = Engine.GetGUIObjectByName("chatHistoryFilter");
+	let selected = chatHistoryFilter.list_data[chatHistoryFilter.selected];
 
-	closeOpenDialogs();
+	Engine.GetGUIObjectByName("chatHistory").caption =
+		g_ChatHistory.filter(msg => msg.filter[selected]).map(msg =>
+			Engine.ConfigDB_GetValue("user", "chat.timestamp") == "true" ?
+				sprintf(translate("%(time)s %(message)s"), {
+					"time": msg.timePrefix,
+					"message": msg.txt
+				}) :
+				msg.txt
+		).join("\n");
+}
 
-	if (hidden)
-	{
-		setTeamChat(teamChat);
-		chatInput.focus();
-	}
-	else
-	{
-		if (chatInput.caption.length)
-		{
-			submitChatInput();
-			return;
-		}
-		chatInput.caption = "";
-	}
+function onToggleChatWindowExtended()
+{
+	// Save user preference
+	let extended = Engine.GetGUIObjectByName("extendedChat").checked.toString();
+	Engine.ConfigDB_CreateValue("user", "chat.session.extended", extended);
+	Engine.ConfigDB_WriteValueToFile("user", "chat.session.extended", extended, "config/user.cfg");
 
-	chatWindow.hidden = !hidden;
+	resizeChatWindow();
+
+	Engine.GetGUIObjectByName("chatInput").focus();
 }
 
 function openDiplomacy()
@@ -299,7 +334,6 @@ function diplomacySetupTexts(i, rowsize)
 	size.bottom = rowsize * i;
 	row.size = size;
 
-	// Set background color
 	row.sprite = "color: " + rgbToGuiColor(g_Players[i].color) + " 32";
 
 	Engine.GetGUIObjectByName("diplomacyPlayerName["+(i-1)+"]").caption = colorizePlayernameByID(i);
@@ -325,8 +359,13 @@ function diplomacyFormatStanceButtons(i, hidden)
 
 		button.caption = g_Players[g_ViewedPlayer]["is" + stance][i] ? translate("x") : "";
 		button.enabled = controlsPlayer(g_ViewedPlayer);
-		button.onpress = (function(player, stance) { return function() {
-			Engine.PostNetworkCommand({ "type": "diplomacy", "player": i, "to": stance.toLowerCase() });
+
+		button.onPress = (function(player, stance) { return function() {
+			Engine.PostNetworkCommand({
+				"type": "diplomacy",
+				"player": i,
+				"to": stance.toLowerCase()
+			});
 		}; })(i, stance);
 	}
 }
@@ -341,7 +380,7 @@ function diplomacyFormatTributeButtons(i, hidden)
 			continue;
 
 		button.enabled = controlsPlayer(g_ViewedPlayer);
-		button.tooltip = formatTributeTooltip(g_Players[i], resource, 100);
+		button.tooltip = formatTributeTooltip(i, resource, 100);
 		button.onpress = (function(i, resource, button) {
 			// Shift+click to send 500, shift+click+click to send 1000, etc.
 			// See INPUT_MASSTRIBUTING in input.js
@@ -359,14 +398,14 @@ function diplomacyFormatTributeButtons(i, hidden)
 					amounts[type] = 0;
 				amounts[resource] = 100 * multiplier;
 
-				button.tooltip = formatTributeTooltip(g_Players[i], resource, amounts[resource]);
+				button.tooltip = formatTributeTooltip(i, resource, amounts[resource]);
 
 				// This is in a closure so that we have access to `player`, `amounts`, and `multiplier` without some
 				// evil global variable hackery.
 				g_FlushTributing = function() {
 					Engine.PostNetworkCommand({ "type": "tribute", "player": i, "amounts":  amounts });
 					multiplier = 1;
-					button.tooltip = formatTributeTooltip(g_Players[i], resource, 100);
+					button.tooltip = formatTributeTooltip(i, resource, 100);
 				};
 
 				if (!isBatchTrainPressed)
@@ -639,20 +678,65 @@ function toggleGameSpeed()
 	gameSpeed.hidden = !gameSpeed.hidden;
 }
 
+function toggleObjectives()
+{
+	let open = g_IsObjectivesOpen;
+	closeOpenDialogs();
+
+	if (!open)
+		openObjectives();
+}
+
+function openObjectives()
+{
+	g_IsObjectivesOpen = true;
+
+	let player = g_Players[Engine.GetPlayerID()];
+	let playerState = player && player.state;
+	let isActive = !playerState || playerState == "active";
+
+	Engine.GetGUIObjectByName("gameDescriptionText").caption = getGameDescription(true);
+
+	let objectivesPlayerstate = Engine.GetGUIObjectByName("objectivesPlayerstate");
+	objectivesPlayerstate.hidden = isActive;
+	objectivesPlayerstate.caption = g_PlayerStateMessages[playerState] || "";
+
+	let gameDescription = Engine.GetGUIObjectByName("gameDescription");
+	let gameDescriptionSize = gameDescription.size;
+	gameDescriptionSize.top = Engine.GetGUIObjectByName(
+		isActive ? "objectivesTitle" : "objectivesPlayerstate").size.bottom;
+	gameDescription.size = gameDescriptionSize;
+
+	Engine.GetGUIObjectByName("objectivesPanel").hidden = false;
+}
+
+function closeObjectives()
+{
+	g_IsObjectivesOpen = false;
+	Engine.GetGUIObjectByName("objectivesPanel").hidden = true;
+}
+
+/**
+ * Allows players to see their own summary.
+ * If they have shared ally vision researched, they are able to see the summary of there allies too.
+ */
 function openGameSummary()
 {
 	closeOpenDialogs();
 	pauseGame();
 
 	let extendedSimState = Engine.GuiInterfaceCall("GetExtendedSimulationState");
-
 	Engine.PushGuiPage("page_summary.xml", {
-		"timeElapsed" : extendedSimState.timeElapsed,
-		"playerStates": extendedSimState.players,
-		"players": g_Players,
-		"mapSettings": Engine.GetMapSettings(),
-		"isInGame": true,
-		"gameResult": translate("Current Scores"),
+		"sim": {
+			"mapSettings": g_GameAttributes.settings,
+			"playerStates":extendedSimState.players.filter((state,player) =>
+				g_IsObserver || player == 0 || player == g_ViewedPlayer ||
+				extendedSimState.players[g_ViewedPlayer].hasSharedLos && g_Players[player].isMutualAlly[g_ViewedPlayer]),
+			"timeElapsed" : extendedSimState.timeElapsed
+		},
+		"gui": {
+			"isInGame": true
+		},
 		"callback": "resumeGame"
 	});
 }
@@ -670,25 +754,39 @@ function openStrucTree()
 }
 
 /**
- * Pause the game in single player mode.
+ * Pause or resume the game.
+ *
+ * @param explicit - true if the player explicitly wants to pause or resume.
+ * If this argument isn't set, a multiplayer game won't be paused and the pause overlay
+ * won't be shown in single player.
  */
-function pauseGame()
+function pauseGame(pause = true, explicit = false)
 {
-	if (g_IsNetworked)
+	if (g_IsNetworked && !explicit)
 		return;
 
-	Engine.GetGUIObjectByName("pauseButtonText").caption = translate("Resume");
-	Engine.GetGUIObjectByName("pauseOverlay").hidden = false;
-	Engine.SetPaused(true);
+	if (explicit)
+		g_Paused = pause;
+
+	Engine.SetPaused(g_Paused || pause, !!explicit);
+
+	if (g_IsNetworked)
+	{
+		setClientPauseState(Engine.GetPlayerGUID(), g_Paused);
+		return;
+	}
+
+	updatePauseOverlay();
 }
 
-function resumeGame()
+function resumeGame(explicit = false)
 {
-	Engine.GetGUIObjectByName("pauseButtonText").caption = translate("Pause");
-	Engine.GetGUIObjectByName("pauseOverlay").hidden = true;
-	Engine.SetPaused(false);
+	pauseGame(false, explicit);
 }
 
+/**
+ * Called when the current player toggles a pause button.
+ */
 function togglePause()
 {
 	if (!Engine.GetGUIObjectByName("pauseButton").enabled)
@@ -696,12 +794,40 @@ function togglePause()
 
 	closeOpenDialogs();
 
-	let pauseOverlay = Engine.GetGUIObjectByName("pauseOverlay");
+	pauseGame(!g_Paused, true);
+}
 
-	Engine.SetPaused(pauseOverlay.hidden);
-	Engine.GetGUIObjectByName("pauseButtonText").caption = pauseOverlay.hidden ? translate("Resume") : translate("Pause");
+/**
+ * Called when a client pauses or resumes in a multiplayer game.
+ */
+function setClientPauseState(guid, paused)
+{
+	// Update the list of pausing clients.
+	let index = g_PausingClients.indexOf(guid);
+	if (paused && index == -1)
+		g_PausingClients.push(guid);
+	else if (!paused && index != -1)
+		g_PausingClients.splice(index, 1);
 
-	pauseOverlay.hidden = !pauseOverlay.hidden;
+	updatePauseOverlay();
+
+	Engine.SetPaused(!!g_PausingClients.length, false);
+}
+
+/**
+ * Update the pause overlay.
+ */
+function updatePauseOverlay()
+{
+	Engine.GetGUIObjectByName("pauseButtonText").caption = g_Paused ? translate("Resume") : translate("Pause");
+	Engine.GetGUIObjectByName("resumeMessage").hidden = !g_Paused;
+
+	Engine.GetGUIObjectByName("pausedByText").hidden = !g_IsNetworked;
+	Engine.GetGUIObjectByName("pausedByText").caption = sprintf(translate("Paused by %(players)s"),
+		{ "players": g_PausingClients.map(guid => colorizePlayernameByGUID(guid)).join(translate(", ")) });
+
+	Engine.GetGUIObjectByName("pauseOverlay").hidden = !(g_Paused || g_PausingClients.length);
+	Engine.GetGUIObjectByName("pauseOverlay").onPress = g_Paused ? togglePause : function() {};
 }
 
 function openManual()
@@ -741,18 +867,20 @@ function toggleDeveloperOverlay()
 
 function closeOpenDialogs()
 {
+	 // TODO: also close message boxes
 	closeMenu();
 	closeChat();
 	closeDiplomacy();
 	closeTrade();
+	closeObjectives();
 }
 
-function formatTributeTooltip(player, resource, amount)
+function formatTributeTooltip(playerID, resource, amount)
 {
 	return sprintf(translate("Tribute %(resourceAmount)s %(resourceType)s to %(playerName)s. Shift-click to tribute %(greaterAmount)s."), {
 		"resourceAmount": amount,
 		"resourceType": getLocalizedResourceName(resource, "withinSentence"),
-		"playerName": "[color=\"" + rgbToGuiColor(player.color) + "\"]" + player.name + "[/color]",
-		"greaterAmount": (amount < 500 ? 500 : amount + 500)
+		"playerName": colorizePlayernameByID(playerID),
+		"greaterAmount": amount < 500 ? 500 : amount + 500
 	});
 }
