@@ -15,10 +15,15 @@ const g_ChatTimeout = 30;
 const g_ChatLines = 20;
 
 /**
- * The strings to be displayed including sender and formating.
+ * The currently displayed strings, limited by the given timeframe and limit above.
  */
 var g_ChatMessages = [];
 
+/**
+ * All unparsed chat messages received since connect, including timestamp.
+ */
+var g_ChatHistory = [];
+
 /**
  * Holds the timer-IDs used for hiding the chat after g_ChatTimeout seconds.
  */
@@ -28,28 +33,83 @@ var g_ChatTimers = [];
  * Handle all netmessage types that can occur.
  */
 var g_NetMessageTypes = {
-	"netstatus": msg => handleNetStatusMessage(msg),
-	"netwarn": msg => addNetworkWarning(msg),
-	"players": msg => handlePlayerAssignmentsMessage(msg),
-	"rejoined": msg => addChatMessage({ "type": "rejoined", "guid": msg.guid }),
-	"kicked": msg => addChatMessage({ "type": "system", "text": sprintf(translate("%(username)s has been kicked"), { "username": msg.username }) }),
-	"banned": msg => addChatMessage({ "type": "system", "text": sprintf(translate("%(username)s has been banned"), { "username": msg.username }) }),
-	"chat": msg => addChatMessage({ "type": "message", "guid": msg.guid, "text": msg.text }),
-	"aichat": msg => addChatMessage({ "type": "message", "guid": msg.guid, "text": msg.text, "translate": true }),
-	"gamesetup": msg => "", // Needed for autostart
-	"start": msg => ""
+	"netstatus": msg => {
+		handleNetStatusMessage(msg);
+	},
+	"netwarn": msg => {
+		addNetworkWarning(msg);
+	},
+	"players": msg => {
+		handlePlayerAssignmentsMessage(msg);
+	},
+	"paused": msg => {
+		setClientPauseState(msg.guid, msg.pause);
+	},
+	"rejoined": msg => {
+		addChatMessage({
+			"type": "rejoined",
+			"guid": msg.guid
+		});
+	},
+	"kicked": msg => {
+		addChatMessage({
+			"type": "kicked",
+			"username": msg.username,
+			"banned": msg.banned
+		});
+	},
+	"chat": msg => {
+		addChatMessage({
+			"type": "message",
+			"guid": msg.guid,
+			"text": msg.text
+		});
+	},
+	"aichat": msg => {
+		addChatMessage({
+			"type": "message",
+			"guid": msg.guid,
+			"text": msg.text,
+			"translate": true
+		});
+	},
+	"gamesetup": msg => {}, // Needed for autostart
+	"start": msg => {}
 };
 
 var g_FormatChatMessage = {
 	"system": msg => msg.text,
-	"connect": msg => sprintf(translate("%(player)s is starting to rejoin the game."), { "player": colorizePlayernameByGUID(msg.guid) }),
-	"disconnect": msg => sprintf(translate("%(player)s has left the game."), { "player": colorizePlayernameByGUID(msg.guid) }),
-	"rejoined": msg => sprintf(translate("%(player)s has rejoined the game."), { "player": colorizePlayernameByGUID(msg.guid) }),
+	"connect": msg =>
+		sprintf(translate("%(player)s is starting to rejoin the game."), {
+			"player": colorizePlayernameByGUID(msg.guid)
+		}),
+	"disconnect": msg =>
+		sprintf(translate("%(player)s has left the game."), {
+			"player": colorizePlayernameByGUID(msg.guid)
+		}),
+	"rejoined": msg =>
+		sprintf(translate("%(player)s has rejoined the game."), {
+			"player": colorizePlayernameByGUID(msg.guid)
+		}),
+	"kicked": msg =>
+		sprintf(
+			msg.banned ?
+				translate("%(username)s has been banned") :
+				translate("%(username)s has been kicked"),
+			{
+				"username": colorizePlayernameHelper(
+					msg.username,
+					g_Players.findIndex(p => p.name == msg.username)
+				)
+			}
+		),
 	"clientlist": msg => getUsernameList(),
 	"message": msg => formatChatCommand(msg),
 	"defeat": msg => formatDefeatMessage(msg),
+	"won": msg => formatWinMessage(msg),
 	"diplomacy": msg => formatDiplomacyMessage(msg),
 	"tribute": msg => formatTributeMessage(msg),
+	"barter": msg => formatBarterMessage(msg),
 	"attack": msg => formatAttackMessage(msg)
 };
 
@@ -60,8 +120,10 @@ var g_StatusMessageTypes = {
 	"authenticated": msg => translate("Connection to the server has been authenticated."),
 	"connected": msg => translate("Connected to the server."),
 	"disconnected": msg => translate("Connection to the server has been lost.") + "\n" +
-	                // Translation: States the reason why the client disconnected from the server.
-	                sprintf(translate("Reason: %(reason)s."), { "reason": getDisconnectReason(msg.reason) }),
+		// Translation: States the reason why the client disconnected from the server.
+		sprintf(translate("Reason: %(reason)s."), {
+			"reason": getDisconnectReason(msg.reason, true)
+		}),
 	"waiting_for_players": msg => translate("Waiting for other players to connect..."),
 	"join_syncing": msg => translate("Synchronising gameplay with other players..."),
 	"active": msg => ""
@@ -116,6 +178,60 @@ var g_IsChatAddressee = {
 		addresseeGUID == Engine.GetPlayerGUID()
 };
 
+/**
+ * Notice only messages will be filtered that are visible to the player in the first place.
+ */
+var g_ChatHistoryFilters = [
+	{
+		"key": "all",
+		"text": translateWithContext("chat history filter", "Chat and notifications"),
+		"filter": (msg, senderID) => true
+	},
+	{
+		"key": "chat",
+		"text": translateWithContext("chat history filter", "Chat messages"),
+		"filter": (msg, senderID) => msg.type == "message"
+	},
+	{
+		"key": "player",
+		"text": translateWithContext("chat history filter", "Players chat"),
+		"filter": (msg, senderID) =>
+			msg.type == "message" &&
+			senderID > 0 && !isPlayerObserver(senderID)
+	},
+	{
+		"key": "ally",
+		"text": translateWithContext("chat history filter", "Ally chat"),
+		"filter": (msg, senderID) =>
+			msg.type == "message" &&
+			msg.cmd && msg.cmd == "/allies"
+	},
+	{
+		"key": "enemy",
+		"text": translateWithContext("chat history filter", "Enemy chat"),
+		"filter": (msg, senderID) =>
+			msg.type == "message" &&
+			msg.cmd && msg.cmd == "/enemies"
+	},
+	{
+		"key": "observer",
+		"text": translateWithContext("chat history filter", "Observer chat"),
+		"filter": (msg, senderID) =>
+			msg.type == "message" &&
+			msg.cmd && msg.cmd == "/observers"
+	},
+	{
+		"key": "private",
+		"text": translateWithContext("chat history filter", "Private chat"),
+		"filter": (msg, senderID) => !!msg.isVisiblePM
+	}
+];
+
+var g_PlayerStateMessages = {
+	"won": translate("You have won!"),
+	"defeated": translate("You have been defeated!")
+};
+
 /**
  * Chatmessage shown on diplomacy change.
  */
@@ -139,6 +255,8 @@ var g_DiplomacyMessages = {
 
 /**
  * Defines how the GUI reacts to notifications that are sent by the simulation.
+ * Don't open new pages (message boxes) here! Otherwise further notifications
+ * handled in the same turn can't access the GUI objects anymore.
  */
 var g_NotificationsTypes =
 {
@@ -149,7 +267,6 @@ var g_NotificationsTypes =
 			"guid": findGuidForPlayerID(player) || -1,
 			"text": notification.message
 		};
-
 		if (message.guid == -1)
 			message.player = player;
 
@@ -158,15 +275,13 @@ var g_NotificationsTypes =
 	"aichat": function(notification, player)
 	{
 		let message = {
-			"guid": findGuidForPlayerID(player) || -1,
 			"type": "message",
 			"text": notification.message,
+			"guid": findGuidForPlayerID(player) || -1,
+			"player": player,
 			"translate": true
 		};
 
-		if (message.guid == -1)
-			message.player = player;
-
 		if (notification.translateParameters)
 		{
 			message.translateParameters = notification.translateParameters;
@@ -188,11 +303,21 @@ var g_NotificationsTypes =
 		addChatMessage({
 			"type": "defeat",
 			"guid": findGuidForPlayerID(player),
+			"player": player,
+			"resign": !!notification.resign
+		});
+		playerFinished(player, false);
+		sendLobbyPlayerlistUpdate();
+	},
+	"won": function(notification, player)
+	{
+		addChatMessage({
+			"type": "won",
+			"guid": findGuidForPlayerID(player),
 			"player": player
 		});
-
-		updateDiplomacy();
-		updateChatAddressees();
+		playerFinished(player, true);
+		sendLobbyPlayerlistUpdate();
 	},
 	"diplomacy": function(notification, player)
 	{
@@ -218,6 +343,17 @@ var g_NotificationsTypes =
 			"amounts": notification.amounts
 		});
 	},
+	"barter": function(notification, player)
+	{
+		addChatMessage({
+			"type": "barter",
+			"player": player,
+			"amountsSold": notification.amountsSold,
+			"amountsBought": notification.amountsBought,
+			"resourceSold": notification.resourceSold,
+			"resourceBought": notification.resourceBought
+		});
+	},
 	"attack": function(notification, player)
 	{
 		if (player != g_ViewedPlayer)
@@ -315,14 +451,13 @@ function getCheatsData()
 
 /**
  * Reads userinput from the chat and sends a simulation command in case it is a known cheat.
- * Hence cheats won't be sent as chat over network.
  *
- * @param {string} text
  * @returns {boolean} - True if a cheat was executed.
  */
 function executeCheat(text)
 {
-	if (g_IsObserver || !g_Players[Engine.GetPlayerID()].cheatsEnabled)
+	if (!controlsPlayer(Engine.GetPlayerID()) ||
+	    !g_Players[Engine.GetPlayerID()].cheatsEnabled)
 		return false;
 
 	// Find the cheat code that is a prefix of the user input
@@ -362,8 +497,7 @@ function findGuidForPlayerID(playerID)
  */
 function handleNotifications()
 {
-	let notifications = Engine.GuiInterfaceCall("GetNotifications");
-	for (let notification of notifications)
+	for (let notification of Engine.GuiInterfaceCall("GetNotifications"))
 	{
 		if (!notification.players || !notification.type || !g_NotificationsTypes[notification.type])
 		{
@@ -381,7 +515,7 @@ function handleNotifications()
  */
 function updateDiplomacy()
 {
-	g_Players = getPlayerData(g_PlayerAssignments, g_Players);
+	g_Players = getPlayerData(g_Players);
 
 	if (g_IsDiplomacyOpen)
 		openDiplomacy();
@@ -412,19 +546,24 @@ function updateTimeNotifications()
 }
 
 /**
- * Processes a CNetMessage (see NetMessage.h, NetMessages.h) sent by the CNetServer.
+ * Process every CNetMessage (see NetMessage.h, NetMessages.h) sent by the CNetServer.
  * Saves the received object to mainlog.html.
- *
- * @param {Object} msg
  */
-function handleNetMessage(msg)
+function handleNetMessages()
 {
-	log("Net message: " + uneval(msg));
+	while (true)
+	{
+		let msg = Engine.PollNetworkClient();
+		if (!msg)
+			return;
 
-	if (g_NetMessageTypes[msg.type])
-		g_NetMessageTypes[msg.type](msg);
-	else
-		error("Unrecognised net message type '" + msg.type + "'");
+		log("Net message: " + uneval(msg));
+
+		if (g_NetMessageTypes[msg.type])
+			g_NetMessageTypes[msg.type](msg);
+		else
+			error("Unrecognised net message type '" + msg.type + "'");
+	}
 }
 
 /**
@@ -441,6 +580,8 @@ function handleNetStatusMessage(message)
 		return;
 	}
 
+	g_IsNetworkedActive = message.status == "active";
+
 	let label = Engine.GetGUIObjectByName("netStatus");
 	let statusMessage = g_StatusMessageTypes[message.status](message);
 	label.caption = statusMessage;
@@ -448,6 +589,10 @@ function handleNetStatusMessage(message)
 
 	if (message.status == "disconnected")
 	{
+		// Hide the pause overlay, and pause animations.
+		Engine.GetGUIObjectByName("pauseOverlay").hidden = true;
+		Engine.SetPaused(true, false);
+
 		g_Disconnected = true;
 		closeOpenDialogs();
 	}
@@ -455,49 +600,60 @@ function handleNetStatusMessage(message)
 
 function handlePlayerAssignmentsMessage(message)
 {
-	// Find and report all leavings
 	for (let guid in g_PlayerAssignments)
-	{
-		if (message.hosts[guid])
-			continue;
+		if (!message.newAssignments[guid])
+			onClientLeave(guid);
 
-		addChatMessage({ "type": "disconnect", "guid": guid });
+	let joins = Object.keys(message.newAssignments).filter(guid => !g_PlayerAssignments[guid]);
 
-		for (let id in g_Players)
-			if (g_Players[id].guid == guid)
-				g_Players[id].offline = true;
-	}
+	g_PlayerAssignments = message.newAssignments;
 
-	let joins = Object.keys(message.hosts).filter(guid => !g_PlayerAssignments[guid]);
-
-	g_PlayerAssignments = message.hosts;
-
-	// Report all joinings
 	joins.forEach(guid => {
-
-		let playerID = g_PlayerAssignments[guid].player;
-		if (g_Players[playerID])
-		{
-			g_Players[playerID].guid = guid;
-			g_Players[playerID].name = g_PlayerAssignments[guid].name;
-			g_Players[playerID].offline = false;
-		}
-
-		addChatMessage({ "type": "connect", "guid": guid });
+		onClientJoin(guid);
 	});
 
 	updateChatAddressees();
+	sendLobbyPlayerlistUpdate();
+}
 
-	// Update lobby gamestatus
-	if (g_IsController && Engine.HasXmppClient())
+function onClientJoin(guid)
+{
+	let playerID = g_PlayerAssignments[guid].player;
+
+	if (g_Players[playerID])
 	{
-		let players = Object.keys(g_PlayerAssignments).map(guid => g_PlayerAssignments[guid].name);
-		Engine.SendChangeStateGame(Object.keys(g_PlayerAssignments).length, players.join(", "));
+		g_Players[playerID].guid = guid;
+		g_Players[playerID].name = g_PlayerAssignments[guid].name;
+		g_Players[playerID].offline = false;
 	}
+
+	addChatMessage({
+		"type": "connect",
+		"guid": guid
+	});
+}
+
+function onClientLeave(guid)
+{
+	setClientPauseState(guid, false);
+
+	for (let id in g_Players)
+		if (g_Players[id].guid == guid)
+			g_Players[id].offline = true;
+
+	addChatMessage({
+		"type": "disconnect",
+		"guid": guid
+	});
 }
 
 function updateChatAddressees()
 {
+	// Remember previously selected item
+	let chatAddressee = Engine.GetGUIObjectByName("chatAddressee");
+	let selectedName = chatAddressee.list_data[chatAddressee.selected] || "";
+	selectedName = selectedName.substr(0, 4) == "/msg" && selectedName.substr(5);
+
 	let addressees = [
 		{
 			"label": translateWithContext("chat addressee", "Everyone"),
@@ -523,30 +679,37 @@ function updateChatAddressees()
 	});
 
 	// Add playernames for private messages
-	for (let guid of sortGUIDsByPlayerID())
+	let guids = sortGUIDsByPlayerID();
+	for (let guid of guids)
 	{
-		if (guid == Engine.GetPlayerGUID())
+		if (guid == Engine.GetPlayerGUID() || guid == "local")
 			continue;
 
-		let username = g_PlayerAssignments[guid].name;
-		let playerIndex = g_PlayerAssignments[guid].player;
+		let playerID = g_PlayerAssignments[guid].player;
 
 		// Don't provide option for PM from observer to player
-		if (g_IsObserver && !isPlayerObserver(playerIndex))
+		if (g_IsObserver && !isPlayerObserver(playerID))
 			continue;
 
-		let colorBox = isPlayerObserver(playerIndex) ? "" : '[color="' + rgbToGuiColor(g_Players[playerIndex].color) + '"]■ [/color]';
+		let colorBox = isPlayerObserver(playerID) ? "" : colorizePlayernameHelper("■", playerID) + " ";
 
 		addressees.push({
-			"cmd": "/msg " + username,
-			"label": colorBox + username
+			"cmd": "/msg " + g_PlayerAssignments[guid].name,
+			"label": colorBox + g_PlayerAssignments[guid].name
 		});
 	}
 
-	let chatAddressee = Engine.GetGUIObjectByName("chatAddressee");
+	// Select mock item if the selected addressee went offline
+	if (selectedName && guids.every(guid => g_PlayerAssignments[guid].name != selectedName))
+		addressees.push({
+			"cmd": "/msg " + selectedName,
+			"label": sprintf(translate("\\[OFFLINE] %(player)s"), { "player": selectedName })
+		});
+
+	let oldChatAddressee = chatAddressee.list_data[chatAddressee.selected];
 	chatAddressee.list = addressees.map(adressee => adressee.label);
 	chatAddressee.list_data = addressees.map(adressee => adressee.cmd);
-	chatAddressee.selected = 0;
+	chatAddressee.selected = Math.max(0, chatAddressee.list_data.indexOf(oldChatAddressee));
 }
 
 /**
@@ -571,12 +734,9 @@ function submitChatDirectly(text)
  */
 function submitChatInput()
 {
-	let input = Engine.GetGUIObjectByName("chatInput");
-	let text = input.caption;
+	let text = Engine.GetGUIObjectByName("chatInput").caption;
 
-	input.blur(); // Remove focus
-	input.caption = ""; // Clear chat input
-	toggleChatWindow();
+	closeChat();
 
 	if (!text.length)
 		return;
@@ -608,6 +768,7 @@ function addChatMessage(msg)
 	if (!formatted)
 		return;
 
+	// Update chat overlay
 	g_ChatMessages.push(formatted);
 	g_ChatTimers.push(setTimeout(removeOldChatMessage, g_ChatTimeout * 1000));
 
@@ -615,6 +776,23 @@ function addChatMessage(msg)
 		removeOldChatMessage();
 	else
 		Engine.GetGUIObjectByName("chatText").caption = g_ChatMessages.join("\n");
+
+	// Save to chat history
+	let historical = {
+		"txt": formatted,
+		"timePrefix": sprintf(translate("\\[%(time)s]"), {
+			"time": Engine.FormatMillisecondsIntoDateString(new Date().getTime(), translate("HH:mm"))
+		}),
+		"filter": {}
+	};
+
+	// Apply the filters now before diplomacies or playerstates change
+	let senderID = msg.guid && g_PlayerAssignments[msg.guid] ? g_PlayerAssignments[msg.guid].player : 0;
+	for (let filter of g_ChatHistoryFilters)
+		historical.filter[filter.key] = filter.filter(msg, senderID);
+
+	g_ChatHistory.push(historical);
+	updateChatHistory();
 }
 
 /**
@@ -652,12 +830,17 @@ function colorizePlayernameHelper(username, playerID)
 
 function formatDefeatMessage(msg)
 {
-	// In singleplayer, the local player is "You". "You has" is incorrect.
-	let message = !g_IsNetworked && msg.player == Engine.GetPlayerID() ?
-			translate("You have been defeated.") :
-			translate("%(player)s has been defeated.");
+	return sprintf(
+		msg.resign ?
+			translate("%(player)s has resigned.") :
+			translate("%(player)s has been defeated."),
+		{ "player": colorizePlayernameByID(msg.player) }
+	);
+}
 
-	return sprintf(message, {
+function formatWinMessage(msg)
+{
+	return sprintf(translate("%(player)s has won."), {
 		"player": colorizePlayernameByID(msg.player)
 	});
 }
@@ -697,6 +880,24 @@ function formatTributeMessage(msg)
 	});
 }
 
+function formatBarterMessage(msg)
+{
+	if (!g_IsObserver)
+		return "";
+
+	let amountsSold = {};
+	amountsSold[msg.resourceSold] = msg.amountsSold;
+
+	let amountsBought = {};
+	amountsBought[msg.resourceBought] = msg.amountsBought;
+
+	return sprintf(translate("%(player)s bartered %(amountsBought)s for %(amountsSold)s."), {
+		"player": colorizePlayernameByID(msg.player),
+		"amountsBought": getLocalizedResourceAmounts(amountsBought),
+		"amountsSold": getLocalizedResourceAmounts(amountsSold)
+	});
+}
+
 function formatAttackMessage(msg)
 {
 	if (msg.player != g_ViewedPlayer)
@@ -727,6 +928,7 @@ function formatChatCommand(msg)
 	// Translate or escape text
 	if (!msg.text)
 		return "";
+
 	if (msg.translate)
 	{
 		msg.text = translate(msg.text);
@@ -738,8 +940,15 @@ function formatChatCommand(msg)
 		}
 	}
 	else
+	{
 		msg.text = escapeText(msg.text);
 
+		let userName = g_PlayerAssignments[Engine.GetPlayerGUID() || "local"].name;
+
+		if (userName != g_PlayerAssignments[msg.guid].name)
+			notifyUser(userName, msg.text);
+	}
+
 	// GUID for players, playerID for AIs
 	let coloredUsername = msg.guid != -1 ? colorizePlayernameByGUID(msg.guid) : colorizePlayernameByID(msg.player);
 
@@ -753,7 +962,7 @@ function formatChatCommand(msg)
 
 /**
  * Checks if the current user is an addressee of the chatmessage sent by another player.
- * Sets the context of that message.
+ * Sets the context and potentially addresseeGUID of that message.
  * Returns true if the message should be displayed.
  *
  * @param {Object} msg
@@ -764,24 +973,19 @@ function parseChatAddressee(msg)
 		return true;
 
 	// Split addressee command and message-text
-	let cmd = msg.text.split(/\s/)[0];
-	msg.text = msg.text.substr(cmd.length + 1);
+	msg.cmd = msg.text.split(/\s/)[0];
+	msg.text = msg.text.substr(msg.cmd.length + 1);
 
-	if (cmd == "/ally")
-		cmd = "/allies";
+	// GUID is "local" in singleplayer, some string in multiplayer.
+	// Chat messages sent by the simulation (AI) come with the playerID.
+	let senderID = msg.player ? msg.player : (g_PlayerAssignments[msg.guid] || msg).player;
 
-	if (cmd == "/enemy")
-		cmd = "/enemies";
-
-	if (cmd == "/observer")
-		cmd = "/observers";
-
-	// GUID for players and observers, ID for bots
-	let senderID = (g_PlayerAssignments[msg.guid] || msg).player;
-	let isSender = msg.guid ? msg.guid == Engine.GetPlayerGUID() : senderID == Engine.GetPlayerID();
+	let isSender = msg.guid && msg.guid != "local" ?
+		msg.guid == Engine.GetPlayerGUID() :
+		senderID == Engine.GetPlayerID();
 
 	// Parse private message
-	let isPM = cmd == "/msg";
+	let isPM = msg.cmd == "/msg";
 	let addresseeGUID;
 	let addresseeIndex;
 	if (isPM)
@@ -804,20 +1008,22 @@ function parseChatAddressee(msg)
 	}
 
 	// Set context string
-	if (!g_ChatAddresseeContext[cmd])
+	if (!g_ChatAddresseeContext[msg.cmd])
 	{
 		if (isSender)
-			warn("Unknown chat command: " + cmd);
+			warn("Unknown chat command: " + msg.cmd);
 		return false;
 	}
-	msg.context = g_ChatAddresseeContext[cmd];
+	msg.context = g_ChatAddresseeContext[msg.cmd];
 
 	// For observers only permit public- and observer-chat and PM to observers
 	if (isPlayerObserver(senderID) &&
-			(isPM && !isPlayerObserver(addresseeIndex) || !isPM && cmd != "/observers"))
+	    (isPM && !isPlayerObserver(addresseeIndex) || !isPM && msg.cmd != "/observers"))
 		return false;
+	let visible = isSender || g_IsChatAddressee[msg.cmd](senderID, addresseeGUID);
+	msg.isVisiblePM = isPM && visible;
 
-	return isSender || g_IsChatAddressee[cmd](senderID, addresseeGUID);
+	return visible;
 }
 
 /**
@@ -843,7 +1049,7 @@ function matchUsername(text)
 }
 
 /**
- * Unused multiplayer-dialog.
+ * Custom dialog response handling, usable by trigger maps.
  */
 function sendDialogAnswer(guiObject, dialogName)
 {
@@ -859,7 +1065,7 @@ function sendDialogAnswer(guiObject, dialogName)
 }
 
 /**
- * Unused multiplayer-dialog.
+ * Custom dialog opening, usable by trigger maps.
  */
 function openDialog(dialogName, data, player)
 {
