@@ -19,6 +19,44 @@ function getResourceTypeDisplayName(resourceType)
 		return getLocalizedResourceName(resourceCode, "firstWord");
 }
 
+// Updates the health bar of garrisoned units
+function updateGarrisonHealthBar(entState, selection)
+{
+	if (!entState.garrisonHolder)
+		return;
+
+	// Summing up the Health of every single unit
+	let totalGarrisonHealth = 0;
+	let maxGarrisonHealth = 0;
+	for (let selEnt of selection)
+	{
+		let selEntState = GetEntityState(selEnt);
+		if (selEntState.garrisonHolder)
+			for (let ent of selEntState.garrisonHolder.entities)
+			{
+				let state = GetEntityState(ent);
+				totalGarrisonHealth += state.hitpoints || 0;
+				maxGarrisonHealth += state.maxHitpoints || 0;
+			}
+	}
+
+	// Configuring the health bar
+	let healthGarrison = Engine.GetGUIObjectByName("healthGarrison");
+	healthGarrison.hidden = totalGarrisonHealth <= 0;
+	if (totalGarrisonHealth > 0)
+	{
+		let healthBarGarrison = Engine.GetGUIObjectByName("healthBarGarrison");
+		let healthSize = healthBarGarrison.size;
+		healthSize.rtop = 100-100*Math.max(0, Math.min(1, totalGarrisonHealth / maxGarrisonHealth));
+		healthBarGarrison.size = healthSize;
+		healthGarrison.tooltip = sprintf(translate("%(label)s %(current)s / %(max)s"), {
+			"label": "[font=\"sans-bold-13\"]" + translate("Hitpoints:") + "[/font]",
+			"current": Math.ceil(totalGarrisonHealth),
+			"max": Math.ceil(maxGarrisonHealth)
+		});
+	}
+}
+
 // Fills out information that most entities have
 function displaySingle(entState)
 {
@@ -78,7 +116,7 @@ function displaySingle(entState)
 
 		Engine.GetGUIObjectByName("healthStats").caption = sprintf(translate("%(hitpoints)s / %(maxHitpoints)s"), {
 			"hitpoints": Math.ceil(entState.hitpoints),
-			"maxHitpoints": entState.maxHitpoints
+			"maxHitpoints": Math.ceil(entState.maxHitpoints)
 		});
 	}
 
@@ -108,12 +146,10 @@ function displaySingle(entState)
 
 		Engine.GetGUIObjectByName("captureStats").caption = sprintf(translate("%(capturePoints)s / %(maxCapturePoints)s"), {
 			"capturePoints": Math.ceil(entState.capturePoints[entState.player]),
-			"maxCapturePoints": entState.maxCapturePoints
+			"maxCapturePoints": Math.ceil(entState.maxCapturePoints)
 		});
 	}
 
-	// TODO: Stamina
-
 	// Experience
 	Engine.GetGUIObjectByName("experience").hidden = !entState.promotion;
 	if (entState.promotion)
@@ -122,7 +158,7 @@ function displaySingle(entState)
 		let experienceSize = experienceBar.size;
 		experienceSize.rtop = 100 - (100 * Math.max(0, Math.min(1, 1.0 * +entState.promotion.curr / +entState.promotion.req)));
 		experienceBar.size = experienceSize;
- 
+
 		if (entState.promotion.curr < entState.promotion.req)
 			Engine.GetGUIObjectByName("experience").tooltip = sprintf(translate("%(experience)s %(current)s / %(required)s"), {
 				"experience": "[font=\"sans-bold-13\"]" + translate("Experience:") + "[/font]",
@@ -141,10 +177,10 @@ function displaySingle(entState)
 	if (entState.resourceSupply)
 	{
 		let resources = entState.resourceSupply.isInfinite ? translate("∞") :  // Infinity symbol
-						sprintf(translate("%(amount)s / %(max)s"), {
-							"amount": Math.ceil(+entState.resourceSupply.amount),
-							"max": entState.resourceSupply.max
-						});
+			sprintf(translate("%(amount)s / %(max)s"), {
+				"amount": Math.ceil(+entState.resourceSupply.amount),
+				"max": entState.resourceSupply.max
+			});
 
 		let resourceType = getResourceTypeDisplayName(entState.resourceSupply.type);
 
@@ -231,86 +267,64 @@ function displaySingle(entState)
 		Engine.GetGUIObjectByName("resourceCarryingText").hidden = true;
 	}
 
-	// Set Player details
 	Engine.GetGUIObjectByName("specific").caption = specificName;
 	Engine.GetGUIObjectByName("player").caption = playerName;
 	Engine.GetGUIObjectByName("playerColorBackground").sprite = "color: " + playerColor;
-	
-	if (genericName !== specificName)
-		Engine.GetGUIObjectByName("generic").caption = sprintf(translate("(%(genericName)s)"), { "genericName": genericName });
-	else
-		Engine.GetGUIObjectByName("generic").caption = "";
+	Engine.GetGUIObjectByName("generic").caption = genericName == specificName ? "" :
+		sprintf(translate("(%(genericName)s)"), {
+			"genericName": genericName
+		});
 
-	if ("gaia" != playerState.civ)
-	{
-		Engine.GetGUIObjectByName("playerCivIcon").sprite = "stretched:grayscale:" + civEmblem;
-		Engine.GetGUIObjectByName("player").tooltip = civName;
-	}
-	else
-	{
-		Engine.GetGUIObjectByName("playerCivIcon").sprite = "";
-		Engine.GetGUIObjectByName("player").tooltip = "";
-	}
+	let isGaia = "gaia" == playerState.civ;
+	Engine.GetGUIObjectByName("playerCivIcon").sprite = isGaia ? "" : "stretched:grayscale:" + civEmblem;
+	Engine.GetGUIObjectByName("player").tooltip = isGaia ? "" : civName;
 
-	// Icon image
 	// TODO: we should require all entities to have icons
-	Engine.GetGUIObjectByName("icon").sprite = template.icon ? ("stretched:session/portraits/" + template.icon) : "bkFillBlack";
+	Engine.GetGUIObjectByName("icon").sprite = template.icon ? ("stretched:session/portraits/" + template.icon) : "BackgroundBlack";
 
-	let armorString = getArmorTooltip(entState.armour);
+	Engine.GetGUIObjectByName("attackAndArmorStats").tooltip = [
+		getAttackTooltip,
+		getSplashDamageTooltip,
+		getHealerTooltip,
+		getArmorTooltip,
+		getRepairRateTooltip,
+		getBuildRateTooltip,
+		getSpeedTooltip,
+		getGarrisonTooltip,
+		getProjectilesTooltip,
+		getLootTooltip
+	].map(func => func(entState)).filter(tip => tip).join("\n");
 
-	// Attack and Armor
-	Engine.GetGUIObjectByName("attackAndArmorStats").tooltip = entState.attack ? (getAttackTooltip(entState) + "\n" + armorString) : armorString;
-
-	// Repair Rate
-	if (entState.repairRate)
-		Engine.GetGUIObjectByName("attackAndArmorStats").tooltip += getRepairRateTooltip(entState.repairRate);
-
-	// Build Rate
-	if (entState.buildRate)
-		Engine.GetGUIObjectByName("attackAndArmorStats").tooltip += getBuildRateTooltip(entState.buildRate);
-
-	// Icon Tooltip
-	let iconTooltip = "";
+	let iconTooltips = [];
 
 	if (genericName)
-		iconTooltip = "[font=\"sans-bold-16\"]" + genericName + "[/font]";
+		iconTooltips.push("[font=\"sans-bold-16\"]" + genericName + "[/font]");
 
-	if (template.visibleIdentityClasses && template.visibleIdentityClasses.length)
-	{
-		iconTooltip += "\n[font=\"sans-bold-13\"]" + translate("Classes:") + "[/font] ";
-		iconTooltip += "[font=\"sans-13\"]" + translate(template.visibleIdentityClasses[0]) ;
-		for (let i = 1; i < template.visibleIdentityClasses.length; i++)
-			iconTooltip += ", " + translate(template.visibleIdentityClasses[i]);
-		iconTooltip += "[/font]";
-	}
+	iconTooltips = iconTooltips.concat([
+		getVisibleEntityClassesFormatted,
+		getAurasTooltip,
+		getEntityTooltip
+	].map(func => func(template)));
 
-	if (template.auras)
-		iconTooltip += getAurasTooltip(template);
+	Engine.GetGUIObjectByName("iconBorder").tooltip = iconTooltips.filter(tip => tip).join("\n");
 
-	if (template.tooltip)
-		iconTooltip += "\n[font=\"sans-13\"]" + template.tooltip + "[/font]";
-
-	Engine.GetGUIObjectByName("iconBorder").tooltip = iconTooltip;
-
-	// Unhide Details Area
 	Engine.GetGUIObjectByName("detailsAreaSingle").hidden = false;
 	Engine.GetGUIObjectByName("detailsAreaMultiple").hidden = true;
 }
 
 // Fills out information for multiple entities
-function displayMultiple(selection)
+function displayMultiple(entStates)
 {
 	let averageHealth = 0;
 	let maxHealth = 0;
 	let maxCapturePoints = 0;
-	let capturePoints = (new Array(9)).fill(0);
+	let capturePoints = (new Array(g_MaxPlayers + 1)).fill(0);
 	let playerID = 0;
+	let totalCarrying = {};
+	let totalLoot = {};
 
-	for (let i = 0; i < selection.length; i++)
+	for (let entState of entStates)
 	{
-		let entState = GetEntityState(selection[i]);
-		if (!entState)
-			continue;
 		playerID = entState.player; // trust that all selected entities have the same owner
 		if (entState.hitpoints)
 		{
@@ -322,6 +336,20 @@ function displayMultiple(selection)
 			maxCapturePoints += entState.maxCapturePoints;
 			capturePoints = entState.capturePoints.map((v, i) => v + capturePoints[i]);
 		}
+
+		let carrying = calculateCarriedResources(
+			entState.resourceCarrying,
+			entState.trader && entState.trader.goods
+		);
+
+		for (let type in entState.loot)
+			totalLoot[type] = (totalLoot[type] || 0) + entState.loot[type];
+
+		for (let type in carrying)
+		{
+			totalCarrying[type] = (totalCarrying[type] || 0) + carrying[type];
+			totalLoot[type] = (totalLoot[type] || 0) + carrying[type];
+		}
 	}
 
 	Engine.GetGUIObjectByName("healthMultiple").hidden = averageHealth <= 0;
@@ -334,8 +362,8 @@ function displayMultiple(selection)
 
 		Engine.GetGUIObjectByName("healthMultiple").tooltip = sprintf(translate("%(label)s %(current)s / %(max)s"), {
 			"label": "[font=\"sans-bold-13\"]" + translate("Hitpoints:") + "[/font]",
-			"current": averageHealth,
-			"max": maxHealth
+			"current": Math.ceil(averageHealth),
+			"max": Math.ceil(maxHealth)
 		});
 	}
 
@@ -352,7 +380,7 @@ function displayMultiple(selection)
 			sizeObj.rbottom = startSize + size;
 			unitCaptureBar.size = sizeObj;
 			unitCaptureBar.sprite = "color: " + rgbToGuiColor(g_Players[playerID].color, 128);
-			unitCaptureBar.hidden=false;
+			unitCaptureBar.hidden = false;
 			return startSize + size;
 		};
 
@@ -371,26 +399,49 @@ function displayMultiple(selection)
 		});
 	}
 
-	// TODO: Stamina
-	// Engine.GetGUIObjectByName("staminaBarMultiple");
+	let numberOfUnits = Engine.GetGUIObjectByName("numberOfUnits");
+	numberOfUnits.caption = entStates.length;
+	numberOfUnits.tooltip = "";
 
-	Engine.GetGUIObjectByName("numberOfUnits").caption = selection.length;
+	if (Object.keys(totalCarrying).length)
+		numberOfUnits.tooltip = sprintf(translate("%(label)s %(details)s\n"), {
+			"label": headerFont(translate("Carrying:")),
+			"details": bodyFont(RESOURCES.filter(res => !!totalCarrying[res]).map(
+				res => sprintf(translate("%(type)s %(amount)s"),
+					{ "type": costIcon(res), "amount": totalCarrying[res] })).join("  "))
+		});
+
+	if (Object.keys(totalLoot).length)
+		numberOfUnits.tooltip += sprintf(translate("%(label)s %(details)s"), {
+			"label": headerFont(translate("Loot:")),
+			"details": bodyFont(Object.keys(totalLoot).map(
+				res => sprintf(translate("%(type)s %(amount)s"),
+					{ "type": costIcon(res), "amount": totalLoot[res] })).join("  "))
+		});
 
 	// Unhide Details Area
 	Engine.GetGUIObjectByName("detailsAreaMultiple").hidden = false;
 	Engine.GetGUIObjectByName("detailsAreaSingle").hidden = true;
 }
 
-// Updates middle entity Selection Details Panel
+// Updates middle entity Selection Details Panel and left Unit Commands Panel
 function updateSelectionDetails()
 {
 	let supplementalDetailsPanel = Engine.GetGUIObjectByName("supplementalSelectionDetails");
 	let detailsPanel = Engine.GetGUIObjectByName("selectionDetails");
 	let commandsPanel = Engine.GetGUIObjectByName("unitCommands");
 
-	let selection = g_Selection.toList();
+	let entStates = [];
 
-	if (selection.length == 0)
+	for (let sel of g_Selection.toList())
+	{
+		let entState = GetExtendedEntityState(sel);
+		if (!entState)
+			continue;
+		entStates.push(entState);
+	}
+
+	if (entStates.length == 0)
 	{
 		Engine.GetGUIObjectByName("detailsAreaMultiple").hidden = true;
 		Engine.GetGUIObjectByName("detailsAreaSingle").hidden = true;
@@ -402,22 +453,19 @@ function updateSelectionDetails()
 		return;
 	}
 
-	/* If the unit has no data (e.g. it was killed), don't try displaying any
-	 data for it. (TODO: it should probably be removed from the selection too;
-	 also need to handle multi-unit selections) */
-	let entState = GetExtendedEntityState(selection[0]);
-	if (!entState)
-		return;
-
 	// Fill out general info and display it
-	if (selection.length == 1)
-		displaySingle(entState);
+	if (entStates.length == 1)
+		displaySingle(entStates[0]);
 	else
-		displayMultiple(selection);
+		displayMultiple(entStates);
 
 	// Show basic details.
 	detailsPanel.hidden = false;
 
 	// Fill out commands panel for specific unit selected (or first unit of primary group)
-	updateUnitCommands(entState, supplementalDetailsPanel, commandsPanel, selection);
+	updateUnitCommands(entStates, supplementalDetailsPanel, commandsPanel);
+
+	// Show health bar for garrisoned units if the garrison panel is visible
+	if (Engine.GetGUIObjectByName("unitGarrisonPanel") && !Engine.GetGUIObjectByName("unitGarrisonPanel").hidden)
+		updateGarrisonHealthBar(entStates[0], g_Selection.toList());
 }
