@@ -37,9 +37,9 @@ Trigger.prototype.SpawnAndAttack = function()
 	this.DoAfterDelay(this.attackTime, "SpawnAndAttack", {});
 };
 
-var cmpTrigger = Engine.QueryInterface(SYSTEM_ENTITY, IID_Trigger);
-
-cmpTrigger.attackSize = 1; // attack with 1 soldier
-cmpTrigger.attackTime = 60*1000; // attack in 1 minute
-cmpTrigger.DoAfterDelay(cmpTrigger.attackTime, "SpawnAndAttack", {});
-
+{
+	let cmpTrigger = Engine.QueryInterface(SYSTEM_ENTITY, IID_Trigger);
+	cmpTrigger.attackSize = 1; // attack with 1 soldier
+	cmpTrigger.attackTime = 60 * 1000; // attack in 1 minute
+	cmpTrigger.DoAfterDelay(cmpTrigger.attackTime, "SpawnAndAttack", {});
+}
