@@ -41,7 +41,7 @@ function loadUnit(templateName)
 		return null;
 	var template = loadTemplate(templateName);
 
-	var unit = GetTemplateDataHelper(template);
+	var unit = GetTemplateDataHelper(template, null, g_AuraData);
 	unit.phase = false;
 
 	if (unit.requiredTechnology)
@@ -56,23 +56,30 @@ function loadUnit(templateName)
 
 	if (template.ProductionQueue)
 	{
-		unit.trainer = [];
-		for (let build of template.ProductionQueue.Entities._string.split(" "))
+		unit.production = {};
+		if (template.ProductionQueue.Entities)
 		{
-			build = build.replace("{civ}", g_SelectedCiv);
-			unit.trainer.push(build);
-			if (g_Lists.units.indexOf(build) === -1)
-				g_Lists.units.push(build);
+			unit.production.units = [];
+			for (let build of template.ProductionQueue.Entities._string.split(" "))
+			{
+				build = build.replace("{civ}", g_SelectedCiv);
+				unit.production.units.push(build);
+				if (g_Lists.units.indexOf(build) < 0)
+					g_Lists.units.push(build);
+			}
+		}
+		if (template.ProductionQueue.Technologies)
+		{
+			unit.production.techs = [];
+			for (let research of template.ProductionQueue.Technologies._string.split(" "))
+			{
+				unit.production.techs.push(research);
+				if (g_Lists.techs.indexOf(research) < 0)
+					g_Lists.techs.push(research);
+			}
 		}
 	}
 
-	if (template.Heal)
-		unit.healer = {
-			"Range": +template.Heal.Range || 0,
-			"HP": +template.Heal.HP || 0,
-			"Rate": +template.Heal.Rate || 0
-		};
-
 	if (template.Builder && template.Builder.Entities._string)
 		for (let build of template.Builder.Entities._string.split(" "))
 		{
@@ -87,7 +94,7 @@ function loadUnit(templateName)
 function loadStructure(templateName)
 {
 	var template = loadTemplate(templateName);
-	var structure = GetTemplateDataHelper(template);
+	var structure = GetTemplateDataHelper(template, null, g_AuraData);
 	structure.phase = false;
 
 	if (structure.requiredTechnology)
@@ -102,6 +109,7 @@ function loadStructure(templateName)
 		"technology": [],
 		"units": []
 	};
+
 	if (template.ProductionQueue)
 	{
 		if (template.ProductionQueue.Entities && template.ProductionQueue.Entities._string)
@@ -131,6 +139,10 @@ function loadStructure(templateName)
 		structure.armour = struct.armour;
 		structure.auras = struct.auras;
 
+		// For technology cost multiplier, we need to use the tower
+		struct = loadStructure(structure.wallSet.templates.tower);
+		structure.techCostMultiplier = struct.techCostMultiplier;
+
 		let health;
 
 		for (let wSegm in structure.wallSet.templates)
@@ -150,17 +162,15 @@ function loadStructure(templateName)
 				continue;
 			}
 
-			if (health.min > wPart.health)
-				health.min = wPart.health;
-			else if (health.max < wPart.health)
-				health.max = wPart.health;
+			health.min = Math.min(health.min, wPart.health);
+			health.max = Math.max(health.max, wPart.health);
 		}
 		if (health.min == health.max)
 			structure.health = health.min;
 		else
 			structure.health = sprintf(translate("%(val1)s to %(val2)s"), {
-				val1: health.min,
-				val2: health.max
+				"val1": health.min,
+				"val2": health.max
 			});
 	}
 
@@ -180,7 +190,7 @@ function loadTechnology(techName)
 	{
 		for (let op in template.requirements)
 		{
-			let val = template.requirements[op];	
+			let val = template.requirements[op];
 			let req = calcReqs(op, val);
 
 			switch (op)
@@ -208,7 +218,7 @@ function loadTechnology(techName)
 				break;
 
 			case "all":
-				if (req[0].length < 1)
+				if (!req[0].length)
 					tech.reqs.generic = req[1];
 				else
 					for (let r of req[0])
@@ -248,7 +258,7 @@ function loadTechnologyPair(pairCode)
 
 	return {
 		"techs": [ pairInfo.top, pairInfo.bottom ],
-		"req": (pairInfo.supersedes !== undefined) ? pairInfo.supersedes : ""
+		"req": pairInfo.supersedes || ""
 	};
 }
 
@@ -267,6 +277,7 @@ function calcReqs(op, val)
 	{
 	case "civ":
 	case "class":
+	case "notciv":
 	case "number":
 		// nothing needs doing
 		break;
@@ -289,6 +300,7 @@ function calcReqs(op, val)
 				switch (o)
 				{
 				case "civ":
+				case "notciv":
 					c.push(r);
 					break;
 
